import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* Amazon Certificate Manager
*/
export declare namespace ACM {
    /**
     * @stability stable
     */
    interface AcmCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#certificate_authority_arn AcmCertificate#certificate_authority_arn}.
         *
         * @stability stable
         */
        readonly certificateAuthorityArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#certificate_body AcmCertificate#certificate_body}.
         *
         * @stability stable
         */
        readonly certificateBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#certificate_chain AcmCertificate#certificate_chain}.
         *
         * @stability stable
         */
        readonly certificateChain?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#domain_name AcmCertificate#domain_name}.
         *
         * @stability stable
         */
        readonly domainName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#private_key AcmCertificate#private_key}.
         *
         * @stability stable
         */
        readonly privateKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#subject_alternative_names AcmCertificate#subject_alternative_names}.
         *
         * @stability stable
         */
        readonly subjectAlternativeNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#tags AcmCertificate#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#tags_all AcmCertificate#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#validation_method AcmCertificate#validation_method}.
         *
         * @stability stable
         */
        readonly validationMethod?: string;
        /**
         * options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#options AcmCertificate#options}
         *
         * @stability stable
         */
        readonly options?: AcmCertificateOptions;
    }
    /**
     * @stability stable
     */
    class AcmCertificateDomainValidationOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        get resourceRecordName(): string;
        /**
         * @stability stable
         */
        get resourceRecordType(): string;
        /**
         * @stability stable
         */
        get resourceRecordValue(): string;
    }
    /**
     * @stability stable
     */
    interface AcmCertificateOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html#certificate_transparency_logging_preference AcmCertificate#certificate_transparency_logging_preference}.
         *
         * @stability stable
         */
        readonly certificateTransparencyLoggingPreference?: string;
    }
    /**
     * @stability stable
     */
    class AcmCertificateOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _certificateTransparencyLoggingPreference?;
        /**
         * @stability stable
         */
        get certificateTransparencyLoggingPreference(): string | undefined;
        /**
         * @stability stable
         */
        set certificateTransparencyLoggingPreference(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateTransparencyLoggingPreference(): void;
        /**
         * @stability stable
         */
        get certificateTransparencyLoggingPreferenceInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html aws_acm_certificate}.
     *
     * @stability stable
     */
    class AcmCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate.html aws_acm_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: AcmCertificateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _certificateAuthorityArn?;
        /**
         * @stability stable
         */
        get certificateAuthorityArn(): string | undefined;
        /**
         * @stability stable
         */
        set certificateAuthorityArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateAuthorityArn(): void;
        /**
         * @stability stable
         */
        get certificateAuthorityArnInput(): string | undefined;
        private _certificateBody?;
        /**
         * @stability stable
         */
        get certificateBody(): string | undefined;
        /**
         * @stability stable
         */
        set certificateBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateBody(): void;
        /**
         * @stability stable
         */
        get certificateBodyInput(): string | undefined;
        private _certificateChain?;
        /**
         * @stability stable
         */
        get certificateChain(): string | undefined;
        /**
         * @stability stable
         */
        set certificateChain(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateChain(): void;
        /**
         * @stability stable
         */
        get certificateChainInput(): string | undefined;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string | undefined;
        /**
         * @stability stable
         */
        set domainName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainName(): void;
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        domainValidationOptions(index: string): AcmCertificateDomainValidationOptions;
        /**
         * @stability stable
         */
        get id(): string;
        private _privateKey?;
        /**
         * @stability stable
         */
        get privateKey(): string | undefined;
        /**
         * @stability stable
         */
        set privateKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrivateKey(): void;
        /**
         * @stability stable
         */
        get privateKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _subjectAlternativeNames?;
        /**
         * @stability stable
         */
        get subjectAlternativeNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set subjectAlternativeNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubjectAlternativeNames(): void;
        /**
         * @stability stable
         */
        get subjectAlternativeNamesInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get validationEmails(): string[];
        private _validationMethod?;
        /**
         * @stability stable
         */
        get validationMethod(): string | undefined;
        /**
         * @stability stable
         */
        set validationMethod(value: string | undefined);
        /**
         * @stability stable
         */
        resetValidationMethod(): void;
        /**
         * @stability stable
         */
        get validationMethodInput(): string | undefined;
        private _options?;
        private __optionsOutput;
        /**
         * @stability stable
         */
        get options(): AcmCertificateOptionsOutputReference;
        /**
         * @stability stable
         */
        putOptions(value: AcmCertificateOptions | undefined): void;
        /**
         * @stability stable
         */
        resetOptions(): void;
        /**
         * @stability stable
         */
        get optionsInput(): AcmCertificateOptions | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AcmCertificateValidationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation.html#certificate_arn AcmCertificateValidation#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation.html#validation_record_fqdns AcmCertificateValidation#validation_record_fqdns}.
         *
         * @stability stable
         */
        readonly validationRecordFqdns?: string[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation.html#timeouts AcmCertificateValidation#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: AcmCertificateValidationTimeouts;
    }
    /**
     * @stability stable
     */
    interface AcmCertificateValidationTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation.html#create AcmCertificateValidation#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class AcmCertificateValidationTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation.html aws_acm_certificate_validation}.
     *
     * @stability stable
     */
    class AcmCertificateValidation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/acm_certificate_validation.html aws_acm_certificate_validation} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AcmCertificateValidationConfig);
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string;
        /**
         * @stability stable
         */
        set certificateArn(value: string);
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _validationRecordFqdns?;
        /**
         * @stability stable
         */
        get validationRecordFqdns(): string[] | undefined;
        /**
         * @stability stable
         */
        set validationRecordFqdns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetValidationRecordFqdns(): void;
        /**
         * @stability stable
         */
        get validationRecordFqdnsInput(): string[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): AcmCertificateValidationTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: AcmCertificateValidationTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): AcmCertificateValidationTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#certificate_authority_arn AcmpcaCertificate#certificate_authority_arn}.
         *
         * @stability stable
         */
        readonly certificateAuthorityArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#certificate_signing_request AcmpcaCertificate#certificate_signing_request}.
         *
         * @stability stable
         */
        readonly certificateSigningRequest: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#signing_algorithm AcmpcaCertificate#signing_algorithm}.
         *
         * @stability stable
         */
        readonly signingAlgorithm: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#template_arn AcmpcaCertificate#template_arn}.
         *
         * @stability stable
         */
        readonly templateArn?: string;
        /**
         * validity block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#validity AcmpcaCertificate#validity}
         *
         * @stability stable
         */
        readonly validity: AcmpcaCertificateValidity;
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateValidity {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#type AcmpcaCertificate#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html#value AcmpcaCertificate#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    class AcmpcaCertificateValidityOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        set value(value: string);
        /**
         * @stability stable
         */
        get valueInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html aws_acmpca_certificate}.
     *
     * @stability stable
     */
    class AcmpcaCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate.html aws_acmpca_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AcmpcaCertificateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificate(): string;
        private _certificateAuthorityArn?;
        /**
         * @stability stable
         */
        get certificateAuthorityArn(): string;
        /**
         * @stability stable
         */
        set certificateAuthorityArn(value: string);
        /**
         * @stability stable
         */
        get certificateAuthorityArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get certificateChain(): string;
        private _certificateSigningRequest?;
        /**
         * @stability stable
         */
        get certificateSigningRequest(): string;
        /**
         * @stability stable
         */
        set certificateSigningRequest(value: string);
        /**
         * @stability stable
         */
        get certificateSigningRequestInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _signingAlgorithm?;
        /**
         * @stability stable
         */
        get signingAlgorithm(): string;
        /**
         * @stability stable
         */
        set signingAlgorithm(value: string);
        /**
         * @stability stable
         */
        get signingAlgorithmInput(): string | undefined;
        private _templateArn?;
        /**
         * @stability stable
         */
        get templateArn(): string | undefined;
        /**
         * @stability stable
         */
        set templateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetTemplateArn(): void;
        /**
         * @stability stable
         */
        get templateArnInput(): string | undefined;
        private _validity?;
        private __validityOutput;
        /**
         * @stability stable
         */
        get validity(): AcmpcaCertificateValidityOutputReference;
        /**
         * @stability stable
         */
        putValidity(value: AcmpcaCertificateValidity): void;
        /**
         * @stability stable
         */
        get validityInput(): AcmpcaCertificateValidity | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateAuthorityConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#enabled AcmpcaCertificateAuthority#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#permanent_deletion_time_in_days AcmpcaCertificateAuthority#permanent_deletion_time_in_days}.
         *
         * @stability stable
         */
        readonly permanentDeletionTimeInDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#tags AcmpcaCertificateAuthority#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#tags_all AcmpcaCertificateAuthority#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#type AcmpcaCertificateAuthority#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * certificate_authority_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#certificate_authority_configuration AcmpcaCertificateAuthority#certificate_authority_configuration}
         *
         * @stability stable
         */
        readonly certificateAuthorityConfiguration: AcmpcaCertificateAuthorityCertificateAuthorityConfiguration;
        /**
         * revocation_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#revocation_configuration AcmpcaCertificateAuthority#revocation_configuration}
         *
         * @stability stable
         */
        readonly revocationConfiguration?: AcmpcaCertificateAuthorityRevocationConfiguration;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#timeouts AcmpcaCertificateAuthority#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: AcmpcaCertificateAuthorityTimeouts;
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#common_name AcmpcaCertificateAuthority#common_name}.
         *
         * @stability stable
         */
        readonly commonName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#country AcmpcaCertificateAuthority#country}.
         *
         * @stability stable
         */
        readonly country?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#distinguished_name_qualifier AcmpcaCertificateAuthority#distinguished_name_qualifier}.
         *
         * @stability stable
         */
        readonly distinguishedNameQualifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#generation_qualifier AcmpcaCertificateAuthority#generation_qualifier}.
         *
         * @stability stable
         */
        readonly generationQualifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#given_name AcmpcaCertificateAuthority#given_name}.
         *
         * @stability stable
         */
        readonly givenName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#initials AcmpcaCertificateAuthority#initials}.
         *
         * @stability stable
         */
        readonly initials?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#locality AcmpcaCertificateAuthority#locality}.
         *
         * @stability stable
         */
        readonly locality?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#organization AcmpcaCertificateAuthority#organization}.
         *
         * @stability stable
         */
        readonly organization?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#organizational_unit AcmpcaCertificateAuthority#organizational_unit}.
         *
         * @stability stable
         */
        readonly organizationalUnit?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#pseudonym AcmpcaCertificateAuthority#pseudonym}.
         *
         * @stability stable
         */
        readonly pseudonym?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#state AcmpcaCertificateAuthority#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#surname AcmpcaCertificateAuthority#surname}.
         *
         * @stability stable
         */
        readonly surname?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#title AcmpcaCertificateAuthority#title}.
         *
         * @stability stable
         */
        readonly title?: string;
    }
    /**
     * @stability stable
     */
    class AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubjectOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _commonName?;
        /**
         * @stability stable
         */
        get commonName(): string | undefined;
        /**
         * @stability stable
         */
        set commonName(value: string | undefined);
        /**
         * @stability stable
         */
        resetCommonName(): void;
        /**
         * @stability stable
         */
        get commonNameInput(): string | undefined;
        private _country?;
        /**
         * @stability stable
         */
        get country(): string | undefined;
        /**
         * @stability stable
         */
        set country(value: string | undefined);
        /**
         * @stability stable
         */
        resetCountry(): void;
        /**
         * @stability stable
         */
        get countryInput(): string | undefined;
        private _distinguishedNameQualifier?;
        /**
         * @stability stable
         */
        get distinguishedNameQualifier(): string | undefined;
        /**
         * @stability stable
         */
        set distinguishedNameQualifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetDistinguishedNameQualifier(): void;
        /**
         * @stability stable
         */
        get distinguishedNameQualifierInput(): string | undefined;
        private _generationQualifier?;
        /**
         * @stability stable
         */
        get generationQualifier(): string | undefined;
        /**
         * @stability stable
         */
        set generationQualifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetGenerationQualifier(): void;
        /**
         * @stability stable
         */
        get generationQualifierInput(): string | undefined;
        private _givenName?;
        /**
         * @stability stable
         */
        get givenName(): string | undefined;
        /**
         * @stability stable
         */
        set givenName(value: string | undefined);
        /**
         * @stability stable
         */
        resetGivenName(): void;
        /**
         * @stability stable
         */
        get givenNameInput(): string | undefined;
        private _initials?;
        /**
         * @stability stable
         */
        get initials(): string | undefined;
        /**
         * @stability stable
         */
        set initials(value: string | undefined);
        /**
         * @stability stable
         */
        resetInitials(): void;
        /**
         * @stability stable
         */
        get initialsInput(): string | undefined;
        private _locality?;
        /**
         * @stability stable
         */
        get locality(): string | undefined;
        /**
         * @stability stable
         */
        set locality(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocality(): void;
        /**
         * @stability stable
         */
        get localityInput(): string | undefined;
        private _organization?;
        /**
         * @stability stable
         */
        get organization(): string | undefined;
        /**
         * @stability stable
         */
        set organization(value: string | undefined);
        /**
         * @stability stable
         */
        resetOrganization(): void;
        /**
         * @stability stable
         */
        get organizationInput(): string | undefined;
        private _organizationalUnit?;
        /**
         * @stability stable
         */
        get organizationalUnit(): string | undefined;
        /**
         * @stability stable
         */
        set organizationalUnit(value: string | undefined);
        /**
         * @stability stable
         */
        resetOrganizationalUnit(): void;
        /**
         * @stability stable
         */
        get organizationalUnitInput(): string | undefined;
        private _pseudonym?;
        /**
         * @stability stable
         */
        get pseudonym(): string | undefined;
        /**
         * @stability stable
         */
        set pseudonym(value: string | undefined);
        /**
         * @stability stable
         */
        resetPseudonym(): void;
        /**
         * @stability stable
         */
        get pseudonymInput(): string | undefined;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        private _surname?;
        /**
         * @stability stable
         */
        get surname(): string | undefined;
        /**
         * @stability stable
         */
        set surname(value: string | undefined);
        /**
         * @stability stable
         */
        resetSurname(): void;
        /**
         * @stability stable
         */
        get surnameInput(): string | undefined;
        private _title?;
        /**
         * @stability stable
         */
        get title(): string | undefined;
        /**
         * @stability stable
         */
        set title(value: string | undefined);
        /**
         * @stability stable
         */
        resetTitle(): void;
        /**
         * @stability stable
         */
        get titleInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateAuthorityCertificateAuthorityConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#key_algorithm AcmpcaCertificateAuthority#key_algorithm}.
         *
         * @stability stable
         */
        readonly keyAlgorithm: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#signing_algorithm AcmpcaCertificateAuthority#signing_algorithm}.
         *
         * @stability stable
         */
        readonly signingAlgorithm: string;
        /**
         * subject block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#subject AcmpcaCertificateAuthority#subject}
         *
         * @stability stable
         */
        readonly subject: AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject;
    }
    /**
     * @stability stable
     */
    class AcmpcaCertificateAuthorityCertificateAuthorityConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _keyAlgorithm?;
        /**
         * @stability stable
         */
        get keyAlgorithm(): string;
        /**
         * @stability stable
         */
        set keyAlgorithm(value: string);
        /**
         * @stability stable
         */
        get keyAlgorithmInput(): string | undefined;
        private _signingAlgorithm?;
        /**
         * @stability stable
         */
        get signingAlgorithm(): string;
        /**
         * @stability stable
         */
        set signingAlgorithm(value: string);
        /**
         * @stability stable
         */
        get signingAlgorithmInput(): string | undefined;
        private _subject?;
        private __subjectOutput;
        /**
         * @stability stable
         */
        get subject(): AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubjectOutputReference;
        /**
         * @stability stable
         */
        putSubject(value: AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject): void;
        /**
         * @stability stable
         */
        get subjectInput(): AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject | undefined;
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#custom_cname AcmpcaCertificateAuthority#custom_cname}.
         *
         * @stability stable
         */
        readonly customCname?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#enabled AcmpcaCertificateAuthority#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#expiration_in_days AcmpcaCertificateAuthority#expiration_in_days}.
         *
         * @stability stable
         */
        readonly expirationInDays: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#s3_bucket_name AcmpcaCertificateAuthority#s3_bucket_name}.
         *
         * @stability stable
         */
        readonly s3BucketName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#s3_object_acl AcmpcaCertificateAuthority#s3_object_acl}.
         *
         * @stability stable
         */
        readonly s3ObjectAcl?: string;
    }
    /**
     * @stability stable
     */
    class AcmpcaCertificateAuthorityRevocationConfigurationCrlConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _customCname?;
        /**
         * @stability stable
         */
        get customCname(): string | undefined;
        /**
         * @stability stable
         */
        set customCname(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomCname(): void;
        /**
         * @stability stable
         */
        get customCnameInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _expirationInDays?;
        /**
         * @stability stable
         */
        get expirationInDays(): number;
        /**
         * @stability stable
         */
        set expirationInDays(value: number);
        /**
         * @stability stable
         */
        get expirationInDaysInput(): number | undefined;
        private _s3BucketName?;
        /**
         * @stability stable
         */
        get s3BucketName(): string | undefined;
        /**
         * @stability stable
         */
        set s3BucketName(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3BucketName(): void;
        /**
         * @stability stable
         */
        get s3BucketNameInput(): string | undefined;
        private _s3ObjectAcl?;
        /**
         * @stability stable
         */
        get s3ObjectAcl(): string | undefined;
        /**
         * @stability stable
         */
        set s3ObjectAcl(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3ObjectAcl(): void;
        /**
         * @stability stable
         */
        get s3ObjectAclInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateAuthorityRevocationConfiguration {
        /**
         * crl_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#crl_configuration AcmpcaCertificateAuthority#crl_configuration}
         *
         * @stability stable
         */
        readonly crlConfiguration?: AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration;
    }
    /**
     * @stability stable
     */
    class AcmpcaCertificateAuthorityRevocationConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _crlConfiguration?;
        private __crlConfigurationOutput;
        /**
         * @stability stable
         */
        get crlConfiguration(): AcmpcaCertificateAuthorityRevocationConfigurationCrlConfigurationOutputReference;
        /**
         * @stability stable
         */
        putCrlConfiguration(value: AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetCrlConfiguration(): void;
        /**
         * @stability stable
         */
        get crlConfigurationInput(): AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration | undefined;
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateAuthorityTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html#create AcmpcaCertificateAuthority#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class AcmpcaCertificateAuthorityTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html aws_acmpca_certificate_authority}.
     *
     * @stability stable
     */
    class AcmpcaCertificateAuthority extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority.html aws_acmpca_certificate_authority} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AcmpcaCertificateAuthorityConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificate(): string;
        /**
         * @stability stable
         */
        get certificateChain(): string;
        /**
         * @stability stable
         */
        get certificateSigningRequest(): string;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get notAfter(): string;
        /**
         * @stability stable
         */
        get notBefore(): string;
        private _permanentDeletionTimeInDays?;
        /**
         * @stability stable
         */
        get permanentDeletionTimeInDays(): number | undefined;
        /**
         * @stability stable
         */
        set permanentDeletionTimeInDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetPermanentDeletionTimeInDays(): void;
        /**
         * @stability stable
         */
        get permanentDeletionTimeInDaysInput(): number | undefined;
        /**
         * @stability stable
         */
        get serial(): string;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _certificateAuthorityConfiguration?;
        private __certificateAuthorityConfigurationOutput;
        /**
         * @stability stable
         */
        get certificateAuthorityConfiguration(): AcmpcaCertificateAuthorityCertificateAuthorityConfigurationOutputReference;
        /**
         * @stability stable
         */
        putCertificateAuthorityConfiguration(value: AcmpcaCertificateAuthorityCertificateAuthorityConfiguration): void;
        /**
         * @stability stable
         */
        get certificateAuthorityConfigurationInput(): AcmpcaCertificateAuthorityCertificateAuthorityConfiguration | undefined;
        private _revocationConfiguration?;
        private __revocationConfigurationOutput;
        /**
         * @stability stable
         */
        get revocationConfiguration(): AcmpcaCertificateAuthorityRevocationConfigurationOutputReference;
        /**
         * @stability stable
         */
        putRevocationConfiguration(value: AcmpcaCertificateAuthorityRevocationConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetRevocationConfiguration(): void;
        /**
         * @stability stable
         */
        get revocationConfigurationInput(): AcmpcaCertificateAuthorityRevocationConfiguration | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): AcmpcaCertificateAuthorityTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: AcmpcaCertificateAuthorityTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): AcmpcaCertificateAuthorityTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AcmpcaCertificateAuthorityCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority_certificate.html#certificate AcmpcaCertificateAuthorityCertificate#certificate}.
         *
         * @stability stable
         */
        readonly certificate: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority_certificate.html#certificate_authority_arn AcmpcaCertificateAuthorityCertificate#certificate_authority_arn}.
         *
         * @stability stable
         */
        readonly certificateAuthorityArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority_certificate.html#certificate_chain AcmpcaCertificateAuthorityCertificate#certificate_chain}.
         *
         * @stability stable
         */
        readonly certificateChain?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority_certificate.html aws_acmpca_certificate_authority_certificate}.
     *
     * @stability stable
     */
    class AcmpcaCertificateAuthorityCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/acmpca_certificate_authority_certificate.html aws_acmpca_certificate_authority_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AcmpcaCertificateAuthorityCertificateConfig);
        private _certificate?;
        /**
         * @stability stable
         */
        get certificate(): string;
        /**
         * @stability stable
         */
        set certificate(value: string);
        /**
         * @stability stable
         */
        get certificateInput(): string | undefined;
        private _certificateAuthorityArn?;
        /**
         * @stability stable
         */
        get certificateAuthorityArn(): string;
        /**
         * @stability stable
         */
        set certificateAuthorityArn(value: string);
        /**
         * @stability stable
         */
        get certificateAuthorityArnInput(): string | undefined;
        private _certificateChain?;
        /**
         * @stability stable
         */
        get certificateChain(): string | undefined;
        /**
         * @stability stable
         */
        set certificateChain(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateChain(): void;
        /**
         * @stability stable
         */
        get certificateChainInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAcmCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html#domain DataAwsAcmCertificate#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html#key_types DataAwsAcmCertificate#key_types}.
         *
         * @stability stable
         */
        readonly keyTypes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html#most_recent DataAwsAcmCertificate#most_recent}.
         *
         * @stability stable
         */
        readonly mostRecent?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html#statuses DataAwsAcmCertificate#statuses}.
         *
         * @stability stable
         */
        readonly statuses?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html#tags DataAwsAcmCertificate#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html#types DataAwsAcmCertificate#types}.
         *
         * @stability stable
         */
        readonly types?: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html aws_acm_certificate}.
     *
     * @stability stable
     */
    class DataAwsAcmCertificate extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/acm_certificate.html aws_acm_certificate} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsAcmCertificateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyTypes?;
        /**
         * @stability stable
         */
        get keyTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set keyTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetKeyTypes(): void;
        /**
         * @stability stable
         */
        get keyTypesInput(): string[] | undefined;
        private _mostRecent?;
        /**
         * @stability stable
         */
        get mostRecent(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mostRecent(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMostRecent(): void;
        /**
         * @stability stable
         */
        get mostRecentInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _statuses?;
        /**
         * @stability stable
         */
        get statuses(): string[] | undefined;
        /**
         * @stability stable
         */
        set statuses(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetStatuses(): void;
        /**
         * @stability stable
         */
        get statusesInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _types?;
        /**
         * @stability stable
         */
        get types(): string[] | undefined;
        /**
         * @stability stable
         */
        set types(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTypes(): void;
        /**
         * @stability stable
         */
        get typesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAcmpcaCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate.html#arn DataAwsAcmpcaCertificate#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate.html#certificate_authority_arn DataAwsAcmpcaCertificate#certificate_authority_arn}.
         *
         * @stability stable
         */
        readonly certificateAuthorityArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate.html aws_acmpca_certificate}.
     *
     * @stability stable
     */
    class DataAwsAcmpcaCertificate extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate.html aws_acmpca_certificate} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsAcmpcaCertificateConfig);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        /**
         * @stability stable
         */
        get certificate(): string;
        private _certificateAuthorityArn?;
        /**
         * @stability stable
         */
        get certificateAuthorityArn(): string;
        /**
         * @stability stable
         */
        set certificateAuthorityArn(value: string);
        /**
         * @stability stable
         */
        get certificateAuthorityArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get certificateChain(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAcmpcaCertificateAuthorityConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate_authority.html#arn DataAwsAcmpcaCertificateAuthority#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate_authority.html#tags DataAwsAcmpcaCertificateAuthority#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * revocation_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate_authority.html#revocation_configuration DataAwsAcmpcaCertificateAuthority#revocation_configuration}
         *
         * @stability stable
         */
        readonly revocationConfiguration?: DataAwsAcmpcaCertificateAuthorityRevocationConfiguration[];
    }
    /**
     * @stability stable
     */
    interface DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration {
    }
    /**
     * @stability stable
     */
    interface DataAwsAcmpcaCertificateAuthorityRevocationConfiguration {
        /**
         * crl_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate_authority.html#crl_configuration DataAwsAcmpcaCertificateAuthority#crl_configuration}
         *
         * @stability stable
         */
        readonly crlConfiguration?: DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate_authority.html aws_acmpca_certificate_authority}.
     *
     * @stability stable
     */
    class DataAwsAcmpcaCertificateAuthority extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/acmpca_certificate_authority.html aws_acmpca_certificate_authority} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsAcmpcaCertificateAuthorityConfig);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        /**
         * @stability stable
         */
        get certificate(): string;
        /**
         * @stability stable
         */
        get certificateChain(): string;
        /**
         * @stability stable
         */
        get certificateSigningRequest(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get notAfter(): string;
        /**
         * @stability stable
         */
        get notBefore(): string;
        /**
         * @stability stable
         */
        get serial(): string;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get type(): string;
        private _revocationConfiguration?;
        /**
         * @stability stable
         */
        get revocationConfiguration(): DataAwsAcmpcaCertificateAuthorityRevocationConfiguration[] | undefined;
        /**
         * @stability stable
         */
        set revocationConfiguration(value: DataAwsAcmpcaCertificateAuthorityRevocationConfiguration[] | undefined);
        /**
         * @stability stable
         */
        resetRevocationConfiguration(): void;
        /**
         * @stability stable
         */
        get revocationConfigurationInput(): DataAwsAcmpcaCertificateAuthorityRevocationConfiguration[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
