import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* API Gateway
*/
export declare namespace APIGateway {
    /**
     * @stability stable
     */
    interface ApiGatewayAccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_account.html#cloudwatch_role_arn ApiGatewayAccount#cloudwatch_role_arn}.
         *
         * @stability stable
         */
        readonly cloudwatchRoleArn?: string;
    }
    /**
     * @stability stable
     */
    class ApiGatewayAccountThrottleSettings extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get burstLimit(): number;
        /**
         * @stability stable
         */
        get rateLimit(): number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_account.html aws_api_gateway_account}.
     *
     * @stability stable
     */
    class ApiGatewayAccount extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_account.html aws_api_gateway_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: ApiGatewayAccountConfig);
        private _cloudwatchRoleArn?;
        /**
         * @stability stable
         */
        get cloudwatchRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set cloudwatchRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchRoleArn(): void;
        /**
         * @stability stable
         */
        get cloudwatchRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        throttleSettings(index: string): ApiGatewayAccountThrottleSettings;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayApiKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html#description ApiGatewayApiKey#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html#enabled ApiGatewayApiKey#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html#name ApiGatewayApiKey#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html#tags ApiGatewayApiKey#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html#tags_all ApiGatewayApiKey#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html#value ApiGatewayApiKey#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html aws_api_gateway_api_key}.
     *
     * @stability stable
     */
    class ApiGatewayApiKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_api_key.html aws_api_gateway_api_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayApiKeyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get createdDate(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastUpdatedDate(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): string | undefined;
        /**
         * @stability stable
         */
        set value(value: string | undefined);
        /**
         * @stability stable
         */
        resetValue(): void;
        /**
         * @stability stable
         */
        get valueInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayAuthorizerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#authorizer_credentials ApiGatewayAuthorizer#authorizer_credentials}.
         *
         * @stability stable
         */
        readonly authorizerCredentials?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#authorizer_result_ttl_in_seconds ApiGatewayAuthorizer#authorizer_result_ttl_in_seconds}.
         *
         * @stability stable
         */
        readonly authorizerResultTtlInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#authorizer_uri ApiGatewayAuthorizer#authorizer_uri}.
         *
         * @stability stable
         */
        readonly authorizerUri?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#identity_source ApiGatewayAuthorizer#identity_source}.
         *
         * @stability stable
         */
        readonly identitySource?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#identity_validation_expression ApiGatewayAuthorizer#identity_validation_expression}.
         *
         * @stability stable
         */
        readonly identityValidationExpression?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#name ApiGatewayAuthorizer#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#provider_arns ApiGatewayAuthorizer#provider_arns}.
         *
         * @stability stable
         */
        readonly providerArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#rest_api_id ApiGatewayAuthorizer#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html#type ApiGatewayAuthorizer#type}.
         *
         * @stability stable
         */
        readonly type?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html aws_api_gateway_authorizer}.
     *
     * @stability stable
     */
    class ApiGatewayAuthorizer extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_authorizer.html aws_api_gateway_authorizer} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayAuthorizerConfig);
        private _authorizerCredentials?;
        /**
         * @stability stable
         */
        get authorizerCredentials(): string | undefined;
        /**
         * @stability stable
         */
        set authorizerCredentials(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuthorizerCredentials(): void;
        /**
         * @stability stable
         */
        get authorizerCredentialsInput(): string | undefined;
        private _authorizerResultTtlInSeconds?;
        /**
         * @stability stable
         */
        get authorizerResultTtlInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set authorizerResultTtlInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetAuthorizerResultTtlInSeconds(): void;
        /**
         * @stability stable
         */
        get authorizerResultTtlInSecondsInput(): number | undefined;
        private _authorizerUri?;
        /**
         * @stability stable
         */
        get authorizerUri(): string | undefined;
        /**
         * @stability stable
         */
        set authorizerUri(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuthorizerUri(): void;
        /**
         * @stability stable
         */
        get authorizerUriInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _identitySource?;
        /**
         * @stability stable
         */
        get identitySource(): string | undefined;
        /**
         * @stability stable
         */
        set identitySource(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdentitySource(): void;
        /**
         * @stability stable
         */
        get identitySourceInput(): string | undefined;
        private _identityValidationExpression?;
        /**
         * @stability stable
         */
        get identityValidationExpression(): string | undefined;
        /**
         * @stability stable
         */
        set identityValidationExpression(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdentityValidationExpression(): void;
        /**
         * @stability stable
         */
        get identityValidationExpressionInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _providerArns?;
        /**
         * @stability stable
         */
        get providerArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set providerArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetProviderArns(): void;
        /**
         * @stability stable
         */
        get providerArnsInput(): string[] | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayBasePathMappingConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_base_path_mapping.html#api_id ApiGatewayBasePathMapping#api_id}.
         *
         * @stability stable
         */
        readonly apiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_base_path_mapping.html#base_path ApiGatewayBasePathMapping#base_path}.
         *
         * @stability stable
         */
        readonly basePath?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_base_path_mapping.html#domain_name ApiGatewayBasePathMapping#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_base_path_mapping.html#stage_name ApiGatewayBasePathMapping#stage_name}.
         *
         * @stability stable
         */
        readonly stageName?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_base_path_mapping.html aws_api_gateway_base_path_mapping}.
     *
     * @stability stable
     */
    class ApiGatewayBasePathMapping extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_base_path_mapping.html aws_api_gateway_base_path_mapping} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayBasePathMappingConfig);
        private _apiId?;
        /**
         * @stability stable
         */
        get apiId(): string;
        /**
         * @stability stable
         */
        set apiId(value: string);
        /**
         * @stability stable
         */
        get apiIdInput(): string | undefined;
        private _basePath?;
        /**
         * @stability stable
         */
        get basePath(): string | undefined;
        /**
         * @stability stable
         */
        set basePath(value: string | undefined);
        /**
         * @stability stable
         */
        resetBasePath(): void;
        /**
         * @stability stable
         */
        get basePathInput(): string | undefined;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _stageName?;
        /**
         * @stability stable
         */
        get stageName(): string | undefined;
        /**
         * @stability stable
         */
        set stageName(value: string | undefined);
        /**
         * @stability stable
         */
        resetStageName(): void;
        /**
         * @stability stable
         */
        get stageNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayClientCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_client_certificate.html#description ApiGatewayClientCertificate#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_client_certificate.html#tags ApiGatewayClientCertificate#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_client_certificate.html#tags_all ApiGatewayClientCertificate#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_client_certificate.html aws_api_gateway_client_certificate}.
     *
     * @stability stable
     */
    class ApiGatewayClientCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_client_certificate.html aws_api_gateway_client_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: ApiGatewayClientCertificateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get createdDate(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get expirationDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get pemEncodedCertificate(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayDeploymentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html#description ApiGatewayDeployment#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html#rest_api_id ApiGatewayDeployment#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html#stage_description ApiGatewayDeployment#stage_description}.
         *
         * @stability stable
         */
        readonly stageDescription?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html#stage_name ApiGatewayDeployment#stage_name}.
         *
         * @stability stable
         */
        readonly stageName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html#triggers ApiGatewayDeployment#triggers}.
         *
         * @stability stable
         */
        readonly triggers?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html#variables ApiGatewayDeployment#variables}.
         *
         * @stability stable
         */
        readonly variables?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html aws_api_gateway_deployment}.
     *
     * @stability stable
     */
    class ApiGatewayDeployment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_deployment.html aws_api_gateway_deployment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayDeploymentConfig);
        /**
         * @stability stable
         */
        get createdDate(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get executionArn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get invokeUrl(): string;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _stageDescription?;
        /**
         * @stability stable
         */
        get stageDescription(): string | undefined;
        /**
         * @stability stable
         */
        set stageDescription(value: string | undefined);
        /**
         * @stability stable
         */
        resetStageDescription(): void;
        /**
         * @stability stable
         */
        get stageDescriptionInput(): string | undefined;
        private _stageName?;
        /**
         * @stability stable
         */
        get stageName(): string | undefined;
        /**
         * @stability stable
         */
        set stageName(value: string | undefined);
        /**
         * @stability stable
         */
        resetStageName(): void;
        /**
         * @stability stable
         */
        get stageNameInput(): string | undefined;
        private _triggers?;
        /**
         * @stability stable
         */
        get triggers(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set triggers(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTriggers(): void;
        /**
         * @stability stable
         */
        get triggersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _variables?;
        /**
         * @stability stable
         */
        get variables(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set variables(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetVariables(): void;
        /**
         * @stability stable
         */
        get variablesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayDocumentationPartConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#properties ApiGatewayDocumentationPart#properties}.
         *
         * @stability stable
         */
        readonly properties: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#rest_api_id ApiGatewayDocumentationPart#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * location block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#location ApiGatewayDocumentationPart#location}
         *
         * @stability stable
         */
        readonly location: ApiGatewayDocumentationPartLocation;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayDocumentationPartLocation {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#method ApiGatewayDocumentationPart#method}.
         *
         * @stability stable
         */
        readonly method?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#name ApiGatewayDocumentationPart#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#path ApiGatewayDocumentationPart#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#status_code ApiGatewayDocumentationPart#status_code}.
         *
         * @stability stable
         */
        readonly statusCode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html#type ApiGatewayDocumentationPart#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    class ApiGatewayDocumentationPartLocationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _method?;
        /**
         * @stability stable
         */
        get method(): string | undefined;
        /**
         * @stability stable
         */
        set method(value: string | undefined);
        /**
         * @stability stable
         */
        resetMethod(): void;
        /**
         * @stability stable
         */
        get methodInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string | undefined;
        /**
         * @stability stable
         */
        set statusCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatusCode(): void;
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html aws_api_gateway_documentation_part}.
     *
     * @stability stable
     */
    class ApiGatewayDocumentationPart extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_part.html aws_api_gateway_documentation_part} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayDocumentationPartConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _properties?;
        /**
         * @stability stable
         */
        get properties(): string;
        /**
         * @stability stable
         */
        set properties(value: string);
        /**
         * @stability stable
         */
        get propertiesInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _location?;
        private __locationOutput;
        /**
         * @stability stable
         */
        get location(): ApiGatewayDocumentationPartLocationOutputReference;
        /**
         * @stability stable
         */
        putLocation(value: ApiGatewayDocumentationPartLocation): void;
        /**
         * @stability stable
         */
        get locationInput(): ApiGatewayDocumentationPartLocation | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayDocumentationVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_version.html#description ApiGatewayDocumentationVersion#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_version.html#rest_api_id ApiGatewayDocumentationVersion#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_version.html#version ApiGatewayDocumentationVersion#version}.
         *
         * @stability stable
         */
        readonly version: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_version.html aws_api_gateway_documentation_version}.
     *
     * @stability stable
     */
    class ApiGatewayDocumentationVersion extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_documentation_version.html aws_api_gateway_documentation_version} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayDocumentationVersionConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        set version(value: string);
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayDomainNameConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#certificate_arn ApiGatewayDomainName#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#certificate_body ApiGatewayDomainName#certificate_body}.
         *
         * @stability stable
         */
        readonly certificateBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#certificate_chain ApiGatewayDomainName#certificate_chain}.
         *
         * @stability stable
         */
        readonly certificateChain?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#certificate_name ApiGatewayDomainName#certificate_name}.
         *
         * @stability stable
         */
        readonly certificateName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#certificate_private_key ApiGatewayDomainName#certificate_private_key}.
         *
         * @stability stable
         */
        readonly certificatePrivateKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#domain_name ApiGatewayDomainName#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#regional_certificate_arn ApiGatewayDomainName#regional_certificate_arn}.
         *
         * @stability stable
         */
        readonly regionalCertificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#regional_certificate_name ApiGatewayDomainName#regional_certificate_name}.
         *
         * @stability stable
         */
        readonly regionalCertificateName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#security_policy ApiGatewayDomainName#security_policy}.
         *
         * @stability stable
         */
        readonly securityPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#tags ApiGatewayDomainName#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#tags_all ApiGatewayDomainName#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * endpoint_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#endpoint_configuration ApiGatewayDomainName#endpoint_configuration}
         *
         * @stability stable
         */
        readonly endpointConfiguration?: ApiGatewayDomainNameEndpointConfiguration;
        /**
         * mutual_tls_authentication block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#mutual_tls_authentication ApiGatewayDomainName#mutual_tls_authentication}
         *
         * @stability stable
         */
        readonly mutualTlsAuthentication?: ApiGatewayDomainNameMutualTlsAuthentication;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayDomainNameEndpointConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#types ApiGatewayDomainName#types}.
         *
         * @stability stable
         */
        readonly types: string[];
    }
    /**
     * @stability stable
     */
    class ApiGatewayDomainNameEndpointConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _types?;
        /**
         * @stability stable
         */
        get types(): string[];
        /**
         * @stability stable
         */
        set types(value: string[]);
        /**
         * @stability stable
         */
        get typesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayDomainNameMutualTlsAuthentication {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#truststore_uri ApiGatewayDomainName#truststore_uri}.
         *
         * @stability stable
         */
        readonly truststoreUri: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html#truststore_version ApiGatewayDomainName#truststore_version}.
         *
         * @stability stable
         */
        readonly truststoreVersion?: string;
    }
    /**
     * @stability stable
     */
    class ApiGatewayDomainNameMutualTlsAuthenticationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _truststoreUri?;
        /**
         * @stability stable
         */
        get truststoreUri(): string;
        /**
         * @stability stable
         */
        set truststoreUri(value: string);
        /**
         * @stability stable
         */
        get truststoreUriInput(): string | undefined;
        private _truststoreVersion?;
        /**
         * @stability stable
         */
        get truststoreVersion(): string | undefined;
        /**
         * @stability stable
         */
        set truststoreVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetTruststoreVersion(): void;
        /**
         * @stability stable
         */
        get truststoreVersionInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html aws_api_gateway_domain_name}.
     *
     * @stability stable
     */
    class ApiGatewayDomainName extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_domain_name.html aws_api_gateway_domain_name} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayDomainNameConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set certificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateArn(): void;
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        private _certificateBody?;
        /**
         * @stability stable
         */
        get certificateBody(): string | undefined;
        /**
         * @stability stable
         */
        set certificateBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateBody(): void;
        /**
         * @stability stable
         */
        get certificateBodyInput(): string | undefined;
        private _certificateChain?;
        /**
         * @stability stable
         */
        get certificateChain(): string | undefined;
        /**
         * @stability stable
         */
        set certificateChain(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateChain(): void;
        /**
         * @stability stable
         */
        get certificateChainInput(): string | undefined;
        private _certificateName?;
        /**
         * @stability stable
         */
        get certificateName(): string | undefined;
        /**
         * @stability stable
         */
        set certificateName(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateName(): void;
        /**
         * @stability stable
         */
        get certificateNameInput(): string | undefined;
        private _certificatePrivateKey?;
        /**
         * @stability stable
         */
        get certificatePrivateKey(): string | undefined;
        /**
         * @stability stable
         */
        set certificatePrivateKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificatePrivateKey(): void;
        /**
         * @stability stable
         */
        get certificatePrivateKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get certificateUploadDate(): string;
        /**
         * @stability stable
         */
        get cloudfrontDomainName(): string;
        /**
         * @stability stable
         */
        get cloudfrontZoneId(): string;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _regionalCertificateArn?;
        /**
         * @stability stable
         */
        get regionalCertificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set regionalCertificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegionalCertificateArn(): void;
        /**
         * @stability stable
         */
        get regionalCertificateArnInput(): string | undefined;
        private _regionalCertificateName?;
        /**
         * @stability stable
         */
        get regionalCertificateName(): string | undefined;
        /**
         * @stability stable
         */
        set regionalCertificateName(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegionalCertificateName(): void;
        /**
         * @stability stable
         */
        get regionalCertificateNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get regionalDomainName(): string;
        /**
         * @stability stable
         */
        get regionalZoneId(): string;
        private _securityPolicy?;
        /**
         * @stability stable
         */
        get securityPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set securityPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecurityPolicy(): void;
        /**
         * @stability stable
         */
        get securityPolicyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _endpointConfiguration?;
        private __endpointConfigurationOutput;
        /**
         * @stability stable
         */
        get endpointConfiguration(): ApiGatewayDomainNameEndpointConfigurationOutputReference;
        /**
         * @stability stable
         */
        putEndpointConfiguration(value: ApiGatewayDomainNameEndpointConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetEndpointConfiguration(): void;
        /**
         * @stability stable
         */
        get endpointConfigurationInput(): ApiGatewayDomainNameEndpointConfiguration | undefined;
        private _mutualTlsAuthentication?;
        private __mutualTlsAuthenticationOutput;
        /**
         * @stability stable
         */
        get mutualTlsAuthentication(): ApiGatewayDomainNameMutualTlsAuthenticationOutputReference;
        /**
         * @stability stable
         */
        putMutualTlsAuthentication(value: ApiGatewayDomainNameMutualTlsAuthentication | undefined): void;
        /**
         * @stability stable
         */
        resetMutualTlsAuthentication(): void;
        /**
         * @stability stable
         */
        get mutualTlsAuthenticationInput(): ApiGatewayDomainNameMutualTlsAuthentication | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayGatewayResponseConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_gateway_response.html#response_parameters ApiGatewayGatewayResponse#response_parameters}.
         *
         * @stability stable
         */
        readonly responseParameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_gateway_response.html#response_templates ApiGatewayGatewayResponse#response_templates}.
         *
         * @stability stable
         */
        readonly responseTemplates?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_gateway_response.html#response_type ApiGatewayGatewayResponse#response_type}.
         *
         * @stability stable
         */
        readonly responseType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_gateway_response.html#rest_api_id ApiGatewayGatewayResponse#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_gateway_response.html#status_code ApiGatewayGatewayResponse#status_code}.
         *
         * @stability stable
         */
        readonly statusCode?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_gateway_response.html aws_api_gateway_gateway_response}.
     *
     * @stability stable
     */
    class ApiGatewayGatewayResponse extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_gateway_response.html aws_api_gateway_gateway_response} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayGatewayResponseConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _responseParameters?;
        /**
         * @stability stable
         */
        get responseParameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set responseParameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetResponseParameters(): void;
        /**
         * @stability stable
         */
        get responseParametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _responseTemplates?;
        /**
         * @stability stable
         */
        get responseTemplates(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set responseTemplates(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetResponseTemplates(): void;
        /**
         * @stability stable
         */
        get responseTemplatesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _responseType?;
        /**
         * @stability stable
         */
        get responseType(): string;
        /**
         * @stability stable
         */
        set responseType(value: string);
        /**
         * @stability stable
         */
        get responseTypeInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string | undefined;
        /**
         * @stability stable
         */
        set statusCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatusCode(): void;
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayIntegrationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#cache_key_parameters ApiGatewayIntegration#cache_key_parameters}.
         *
         * @stability stable
         */
        readonly cacheKeyParameters?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#cache_namespace ApiGatewayIntegration#cache_namespace}.
         *
         * @stability stable
         */
        readonly cacheNamespace?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#connection_id ApiGatewayIntegration#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#connection_type ApiGatewayIntegration#connection_type}.
         *
         * @stability stable
         */
        readonly connectionType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#content_handling ApiGatewayIntegration#content_handling}.
         *
         * @stability stable
         */
        readonly contentHandling?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#credentials ApiGatewayIntegration#credentials}.
         *
         * @stability stable
         */
        readonly credentials?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#http_method ApiGatewayIntegration#http_method}.
         *
         * @stability stable
         */
        readonly httpMethod: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#integration_http_method ApiGatewayIntegration#integration_http_method}.
         *
         * @stability stable
         */
        readonly integrationHttpMethod?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#passthrough_behavior ApiGatewayIntegration#passthrough_behavior}.
         *
         * @stability stable
         */
        readonly passthroughBehavior?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#request_parameters ApiGatewayIntegration#request_parameters}.
         *
         * @stability stable
         */
        readonly requestParameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#request_templates ApiGatewayIntegration#request_templates}.
         *
         * @stability stable
         */
        readonly requestTemplates?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#resource_id ApiGatewayIntegration#resource_id}.
         *
         * @stability stable
         */
        readonly resourceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#rest_api_id ApiGatewayIntegration#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#timeout_milliseconds ApiGatewayIntegration#timeout_milliseconds}.
         *
         * @stability stable
         */
        readonly timeoutMilliseconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#type ApiGatewayIntegration#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#uri ApiGatewayIntegration#uri}.
         *
         * @stability stable
         */
        readonly uri?: string;
        /**
         * tls_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#tls_config ApiGatewayIntegration#tls_config}
         *
         * @stability stable
         */
        readonly tlsConfig?: ApiGatewayIntegrationTlsConfig;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayIntegrationTlsConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html#insecure_skip_verification ApiGatewayIntegration#insecure_skip_verification}.
         *
         * @stability stable
         */
        readonly insecureSkipVerification?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class ApiGatewayIntegrationTlsConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _insecureSkipVerification?;
        /**
         * @stability stable
         */
        get insecureSkipVerification(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set insecureSkipVerification(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInsecureSkipVerification(): void;
        /**
         * @stability stable
         */
        get insecureSkipVerificationInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html aws_api_gateway_integration}.
     *
     * @stability stable
     */
    class ApiGatewayIntegration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration.html aws_api_gateway_integration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayIntegrationConfig);
        private _cacheKeyParameters?;
        /**
         * @stability stable
         */
        get cacheKeyParameters(): string[] | undefined;
        /**
         * @stability stable
         */
        set cacheKeyParameters(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCacheKeyParameters(): void;
        /**
         * @stability stable
         */
        get cacheKeyParametersInput(): string[] | undefined;
        private _cacheNamespace?;
        /**
         * @stability stable
         */
        get cacheNamespace(): string | undefined;
        /**
         * @stability stable
         */
        set cacheNamespace(value: string | undefined);
        /**
         * @stability stable
         */
        resetCacheNamespace(): void;
        /**
         * @stability stable
         */
        get cacheNamespaceInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string | undefined;
        /**
         * @stability stable
         */
        set connectionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetConnectionId(): void;
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _connectionType?;
        /**
         * @stability stable
         */
        get connectionType(): string | undefined;
        /**
         * @stability stable
         */
        set connectionType(value: string | undefined);
        /**
         * @stability stable
         */
        resetConnectionType(): void;
        /**
         * @stability stable
         */
        get connectionTypeInput(): string | undefined;
        private _contentHandling?;
        /**
         * @stability stable
         */
        get contentHandling(): string | undefined;
        /**
         * @stability stable
         */
        set contentHandling(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentHandling(): void;
        /**
         * @stability stable
         */
        get contentHandlingInput(): string | undefined;
        private _credentials?;
        /**
         * @stability stable
         */
        get credentials(): string | undefined;
        /**
         * @stability stable
         */
        set credentials(value: string | undefined);
        /**
         * @stability stable
         */
        resetCredentials(): void;
        /**
         * @stability stable
         */
        get credentialsInput(): string | undefined;
        private _httpMethod?;
        /**
         * @stability stable
         */
        get httpMethod(): string;
        /**
         * @stability stable
         */
        set httpMethod(value: string);
        /**
         * @stability stable
         */
        get httpMethodInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _integrationHttpMethod?;
        /**
         * @stability stable
         */
        get integrationHttpMethod(): string | undefined;
        /**
         * @stability stable
         */
        set integrationHttpMethod(value: string | undefined);
        /**
         * @stability stable
         */
        resetIntegrationHttpMethod(): void;
        /**
         * @stability stable
         */
        get integrationHttpMethodInput(): string | undefined;
        private _passthroughBehavior?;
        /**
         * @stability stable
         */
        get passthroughBehavior(): string | undefined;
        /**
         * @stability stable
         */
        set passthroughBehavior(value: string | undefined);
        /**
         * @stability stable
         */
        resetPassthroughBehavior(): void;
        /**
         * @stability stable
         */
        get passthroughBehaviorInput(): string | undefined;
        private _requestParameters?;
        /**
         * @stability stable
         */
        get requestParameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requestParameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequestParameters(): void;
        /**
         * @stability stable
         */
        get requestParametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _requestTemplates?;
        /**
         * @stability stable
         */
        get requestTemplates(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requestTemplates(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequestTemplates(): void;
        /**
         * @stability stable
         */
        get requestTemplatesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _resourceId?;
        /**
         * @stability stable
         */
        get resourceId(): string;
        /**
         * @stability stable
         */
        set resourceId(value: string);
        /**
         * @stability stable
         */
        get resourceIdInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _timeoutMilliseconds?;
        /**
         * @stability stable
         */
        get timeoutMilliseconds(): number | undefined;
        /**
         * @stability stable
         */
        set timeoutMilliseconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeoutMilliseconds(): void;
        /**
         * @stability stable
         */
        get timeoutMillisecondsInput(): number | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _uri?;
        /**
         * @stability stable
         */
        get uri(): string | undefined;
        /**
         * @stability stable
         */
        set uri(value: string | undefined);
        /**
         * @stability stable
         */
        resetUri(): void;
        /**
         * @stability stable
         */
        get uriInput(): string | undefined;
        private _tlsConfig?;
        private __tlsConfigOutput;
        /**
         * @stability stable
         */
        get tlsConfig(): ApiGatewayIntegrationTlsConfigOutputReference;
        /**
         * @stability stable
         */
        putTlsConfig(value: ApiGatewayIntegrationTlsConfig | undefined): void;
        /**
         * @stability stable
         */
        resetTlsConfig(): void;
        /**
         * @stability stable
         */
        get tlsConfigInput(): ApiGatewayIntegrationTlsConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayIntegrationResponseConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#content_handling ApiGatewayIntegrationResponse#content_handling}.
         *
         * @stability stable
         */
        readonly contentHandling?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#http_method ApiGatewayIntegrationResponse#http_method}.
         *
         * @stability stable
         */
        readonly httpMethod: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#resource_id ApiGatewayIntegrationResponse#resource_id}.
         *
         * @stability stable
         */
        readonly resourceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#response_parameters ApiGatewayIntegrationResponse#response_parameters}.
         *
         * @stability stable
         */
        readonly responseParameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#response_templates ApiGatewayIntegrationResponse#response_templates}.
         *
         * @stability stable
         */
        readonly responseTemplates?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#rest_api_id ApiGatewayIntegrationResponse#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#selection_pattern ApiGatewayIntegrationResponse#selection_pattern}.
         *
         * @stability stable
         */
        readonly selectionPattern?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html#status_code ApiGatewayIntegrationResponse#status_code}.
         *
         * @stability stable
         */
        readonly statusCode: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html aws_api_gateway_integration_response}.
     *
     * @stability stable
     */
    class ApiGatewayIntegrationResponse extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_integration_response.html aws_api_gateway_integration_response} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayIntegrationResponseConfig);
        private _contentHandling?;
        /**
         * @stability stable
         */
        get contentHandling(): string | undefined;
        /**
         * @stability stable
         */
        set contentHandling(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentHandling(): void;
        /**
         * @stability stable
         */
        get contentHandlingInput(): string | undefined;
        private _httpMethod?;
        /**
         * @stability stable
         */
        get httpMethod(): string;
        /**
         * @stability stable
         */
        set httpMethod(value: string);
        /**
         * @stability stable
         */
        get httpMethodInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _resourceId?;
        /**
         * @stability stable
         */
        get resourceId(): string;
        /**
         * @stability stable
         */
        set resourceId(value: string);
        /**
         * @stability stable
         */
        get resourceIdInput(): string | undefined;
        private _responseParameters?;
        /**
         * @stability stable
         */
        get responseParameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set responseParameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetResponseParameters(): void;
        /**
         * @stability stable
         */
        get responseParametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _responseTemplates?;
        /**
         * @stability stable
         */
        get responseTemplates(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set responseTemplates(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetResponseTemplates(): void;
        /**
         * @stability stable
         */
        get responseTemplatesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _selectionPattern?;
        /**
         * @stability stable
         */
        get selectionPattern(): string | undefined;
        /**
         * @stability stable
         */
        set selectionPattern(value: string | undefined);
        /**
         * @stability stable
         */
        resetSelectionPattern(): void;
        /**
         * @stability stable
         */
        get selectionPatternInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string;
        /**
         * @stability stable
         */
        set statusCode(value: string);
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayMethodConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#api_key_required ApiGatewayMethod#api_key_required}.
         *
         * @stability stable
         */
        readonly apiKeyRequired?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#authorization ApiGatewayMethod#authorization}.
         *
         * @stability stable
         */
        readonly authorization: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#authorization_scopes ApiGatewayMethod#authorization_scopes}.
         *
         * @stability stable
         */
        readonly authorizationScopes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#authorizer_id ApiGatewayMethod#authorizer_id}.
         *
         * @stability stable
         */
        readonly authorizerId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#http_method ApiGatewayMethod#http_method}.
         *
         * @stability stable
         */
        readonly httpMethod: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#operation_name ApiGatewayMethod#operation_name}.
         *
         * @stability stable
         */
        readonly operationName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#request_models ApiGatewayMethod#request_models}.
         *
         * @stability stable
         */
        readonly requestModels?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#request_parameters ApiGatewayMethod#request_parameters}.
         *
         * @stability stable
         */
        readonly requestParameters?: {
            [key: string]: boolean;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#request_validator_id ApiGatewayMethod#request_validator_id}.
         *
         * @stability stable
         */
        readonly requestValidatorId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#resource_id ApiGatewayMethod#resource_id}.
         *
         * @stability stable
         */
        readonly resourceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html#rest_api_id ApiGatewayMethod#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html aws_api_gateway_method}.
     *
     * @stability stable
     */
    class ApiGatewayMethod extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method.html aws_api_gateway_method} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayMethodConfig);
        private _apiKeyRequired?;
        /**
         * @stability stable
         */
        get apiKeyRequired(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set apiKeyRequired(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetApiKeyRequired(): void;
        /**
         * @stability stable
         */
        get apiKeyRequiredInput(): boolean | cdktf.IResolvable | undefined;
        private _authorization?;
        /**
         * @stability stable
         */
        get authorization(): string;
        /**
         * @stability stable
         */
        set authorization(value: string);
        /**
         * @stability stable
         */
        get authorizationInput(): string | undefined;
        private _authorizationScopes?;
        /**
         * @stability stable
         */
        get authorizationScopes(): string[] | undefined;
        /**
         * @stability stable
         */
        set authorizationScopes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAuthorizationScopes(): void;
        /**
         * @stability stable
         */
        get authorizationScopesInput(): string[] | undefined;
        private _authorizerId?;
        /**
         * @stability stable
         */
        get authorizerId(): string | undefined;
        /**
         * @stability stable
         */
        set authorizerId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuthorizerId(): void;
        /**
         * @stability stable
         */
        get authorizerIdInput(): string | undefined;
        private _httpMethod?;
        /**
         * @stability stable
         */
        get httpMethod(): string;
        /**
         * @stability stable
         */
        set httpMethod(value: string);
        /**
         * @stability stable
         */
        get httpMethodInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _operationName?;
        /**
         * @stability stable
         */
        get operationName(): string | undefined;
        /**
         * @stability stable
         */
        set operationName(value: string | undefined);
        /**
         * @stability stable
         */
        resetOperationName(): void;
        /**
         * @stability stable
         */
        get operationNameInput(): string | undefined;
        private _requestModels?;
        /**
         * @stability stable
         */
        get requestModels(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requestModels(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequestModels(): void;
        /**
         * @stability stable
         */
        get requestModelsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _requestParameters?;
        /**
         * @stability stable
         */
        get requestParameters(): {
            [key: string]: boolean;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requestParameters(value: {
            [key: string]: boolean;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequestParameters(): void;
        /**
         * @stability stable
         */
        get requestParametersInput(): cdktf.IResolvable | {
            [key: string]: boolean;
        } | undefined;
        private _requestValidatorId?;
        /**
         * @stability stable
         */
        get requestValidatorId(): string | undefined;
        /**
         * @stability stable
         */
        set requestValidatorId(value: string | undefined);
        /**
         * @stability stable
         */
        resetRequestValidatorId(): void;
        /**
         * @stability stable
         */
        get requestValidatorIdInput(): string | undefined;
        private _resourceId?;
        /**
         * @stability stable
         */
        get resourceId(): string;
        /**
         * @stability stable
         */
        set resourceId(value: string);
        /**
         * @stability stable
         */
        get resourceIdInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayMethodResponseConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html#http_method ApiGatewayMethodResponse#http_method}.
         *
         * @stability stable
         */
        readonly httpMethod: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html#resource_id ApiGatewayMethodResponse#resource_id}.
         *
         * @stability stable
         */
        readonly resourceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html#response_models ApiGatewayMethodResponse#response_models}.
         *
         * @stability stable
         */
        readonly responseModels?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html#response_parameters ApiGatewayMethodResponse#response_parameters}.
         *
         * @stability stable
         */
        readonly responseParameters?: {
            [key: string]: boolean;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html#rest_api_id ApiGatewayMethodResponse#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html#status_code ApiGatewayMethodResponse#status_code}.
         *
         * @stability stable
         */
        readonly statusCode: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html aws_api_gateway_method_response}.
     *
     * @stability stable
     */
    class ApiGatewayMethodResponse extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_response.html aws_api_gateway_method_response} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayMethodResponseConfig);
        private _httpMethod?;
        /**
         * @stability stable
         */
        get httpMethod(): string;
        /**
         * @stability stable
         */
        set httpMethod(value: string);
        /**
         * @stability stable
         */
        get httpMethodInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _resourceId?;
        /**
         * @stability stable
         */
        get resourceId(): string;
        /**
         * @stability stable
         */
        set resourceId(value: string);
        /**
         * @stability stable
         */
        get resourceIdInput(): string | undefined;
        private _responseModels?;
        /**
         * @stability stable
         */
        get responseModels(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set responseModels(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetResponseModels(): void;
        /**
         * @stability stable
         */
        get responseModelsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _responseParameters?;
        /**
         * @stability stable
         */
        get responseParameters(): {
            [key: string]: boolean;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set responseParameters(value: {
            [key: string]: boolean;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetResponseParameters(): void;
        /**
         * @stability stable
         */
        get responseParametersInput(): cdktf.IResolvable | {
            [key: string]: boolean;
        } | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string;
        /**
         * @stability stable
         */
        set statusCode(value: string);
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayMethodSettingsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#method_path ApiGatewayMethodSettings#method_path}.
         *
         * @stability stable
         */
        readonly methodPath: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#rest_api_id ApiGatewayMethodSettings#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#stage_name ApiGatewayMethodSettings#stage_name}.
         *
         * @stability stable
         */
        readonly stageName: string;
        /**
         * settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#settings ApiGatewayMethodSettings#settings}
         *
         * @stability stable
         */
        readonly settings: ApiGatewayMethodSettingsSettings;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayMethodSettingsSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#cache_data_encrypted ApiGatewayMethodSettings#cache_data_encrypted}.
         *
         * @stability stable
         */
        readonly cacheDataEncrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#cache_ttl_in_seconds ApiGatewayMethodSettings#cache_ttl_in_seconds}.
         *
         * @stability stable
         */
        readonly cacheTtlInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#caching_enabled ApiGatewayMethodSettings#caching_enabled}.
         *
         * @stability stable
         */
        readonly cachingEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#data_trace_enabled ApiGatewayMethodSettings#data_trace_enabled}.
         *
         * @stability stable
         */
        readonly dataTraceEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#logging_level ApiGatewayMethodSettings#logging_level}.
         *
         * @stability stable
         */
        readonly loggingLevel?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#metrics_enabled ApiGatewayMethodSettings#metrics_enabled}.
         *
         * @stability stable
         */
        readonly metricsEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#require_authorization_for_cache_control ApiGatewayMethodSettings#require_authorization_for_cache_control}.
         *
         * @stability stable
         */
        readonly requireAuthorizationForCacheControl?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#throttling_burst_limit ApiGatewayMethodSettings#throttling_burst_limit}.
         *
         * @stability stable
         */
        readonly throttlingBurstLimit?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#throttling_rate_limit ApiGatewayMethodSettings#throttling_rate_limit}.
         *
         * @stability stable
         */
        readonly throttlingRateLimit?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html#unauthorized_cache_control_header_strategy ApiGatewayMethodSettings#unauthorized_cache_control_header_strategy}.
         *
         * @stability stable
         */
        readonly unauthorizedCacheControlHeaderStrategy?: string;
    }
    /**
     * @stability stable
     */
    class ApiGatewayMethodSettingsSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cacheDataEncrypted?;
        /**
         * @stability stable
         */
        get cacheDataEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set cacheDataEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCacheDataEncrypted(): void;
        /**
         * @stability stable
         */
        get cacheDataEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _cacheTtlInSeconds?;
        /**
         * @stability stable
         */
        get cacheTtlInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set cacheTtlInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetCacheTtlInSeconds(): void;
        /**
         * @stability stable
         */
        get cacheTtlInSecondsInput(): number | undefined;
        private _cachingEnabled?;
        /**
         * @stability stable
         */
        get cachingEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set cachingEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCachingEnabled(): void;
        /**
         * @stability stable
         */
        get cachingEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _dataTraceEnabled?;
        /**
         * @stability stable
         */
        get dataTraceEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set dataTraceEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDataTraceEnabled(): void;
        /**
         * @stability stable
         */
        get dataTraceEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _loggingLevel?;
        /**
         * @stability stable
         */
        get loggingLevel(): string | undefined;
        /**
         * @stability stable
         */
        set loggingLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoggingLevel(): void;
        /**
         * @stability stable
         */
        get loggingLevelInput(): string | undefined;
        private _metricsEnabled?;
        /**
         * @stability stable
         */
        get metricsEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set metricsEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMetricsEnabled(): void;
        /**
         * @stability stable
         */
        get metricsEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _requireAuthorizationForCacheControl?;
        /**
         * @stability stable
         */
        get requireAuthorizationForCacheControl(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireAuthorizationForCacheControl(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireAuthorizationForCacheControl(): void;
        /**
         * @stability stable
         */
        get requireAuthorizationForCacheControlInput(): boolean | cdktf.IResolvable | undefined;
        private _throttlingBurstLimit?;
        /**
         * @stability stable
         */
        get throttlingBurstLimit(): number | undefined;
        /**
         * @stability stable
         */
        set throttlingBurstLimit(value: number | undefined);
        /**
         * @stability stable
         */
        resetThrottlingBurstLimit(): void;
        /**
         * @stability stable
         */
        get throttlingBurstLimitInput(): number | undefined;
        private _throttlingRateLimit?;
        /**
         * @stability stable
         */
        get throttlingRateLimit(): number | undefined;
        /**
         * @stability stable
         */
        set throttlingRateLimit(value: number | undefined);
        /**
         * @stability stable
         */
        resetThrottlingRateLimit(): void;
        /**
         * @stability stable
         */
        get throttlingRateLimitInput(): number | undefined;
        private _unauthorizedCacheControlHeaderStrategy?;
        /**
         * @stability stable
         */
        get unauthorizedCacheControlHeaderStrategy(): string | undefined;
        /**
         * @stability stable
         */
        set unauthorizedCacheControlHeaderStrategy(value: string | undefined);
        /**
         * @stability stable
         */
        resetUnauthorizedCacheControlHeaderStrategy(): void;
        /**
         * @stability stable
         */
        get unauthorizedCacheControlHeaderStrategyInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html aws_api_gateway_method_settings}.
     *
     * @stability stable
     */
    class ApiGatewayMethodSettings extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_method_settings.html aws_api_gateway_method_settings} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayMethodSettingsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _methodPath?;
        /**
         * @stability stable
         */
        get methodPath(): string;
        /**
         * @stability stable
         */
        set methodPath(value: string);
        /**
         * @stability stable
         */
        get methodPathInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _stageName?;
        /**
         * @stability stable
         */
        get stageName(): string;
        /**
         * @stability stable
         */
        set stageName(value: string);
        /**
         * @stability stable
         */
        get stageNameInput(): string | undefined;
        private _settings?;
        private __settingsOutput;
        /**
         * @stability stable
         */
        get settings(): ApiGatewayMethodSettingsSettingsOutputReference;
        /**
         * @stability stable
         */
        putSettings(value: ApiGatewayMethodSettingsSettings): void;
        /**
         * @stability stable
         */
        get settingsInput(): ApiGatewayMethodSettingsSettings | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayModelConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_model.html#content_type ApiGatewayModel#content_type}.
         *
         * @stability stable
         */
        readonly contentType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_model.html#description ApiGatewayModel#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_model.html#name ApiGatewayModel#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_model.html#rest_api_id ApiGatewayModel#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_model.html#schema ApiGatewayModel#schema}.
         *
         * @stability stable
         */
        readonly schema?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_model.html aws_api_gateway_model}.
     *
     * @stability stable
     */
    class ApiGatewayModel extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_model.html aws_api_gateway_model} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayModelConfig);
        private _contentType?;
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        set contentType(value: string);
        /**
         * @stability stable
         */
        get contentTypeInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _schema?;
        /**
         * @stability stable
         */
        get schema(): string | undefined;
        /**
         * @stability stable
         */
        set schema(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchema(): void;
        /**
         * @stability stable
         */
        get schemaInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayRequestValidatorConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_request_validator.html#name ApiGatewayRequestValidator#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_request_validator.html#rest_api_id ApiGatewayRequestValidator#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_request_validator.html#validate_request_body ApiGatewayRequestValidator#validate_request_body}.
         *
         * @stability stable
         */
        readonly validateRequestBody?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_request_validator.html#validate_request_parameters ApiGatewayRequestValidator#validate_request_parameters}.
         *
         * @stability stable
         */
        readonly validateRequestParameters?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_request_validator.html aws_api_gateway_request_validator}.
     *
     * @stability stable
     */
    class ApiGatewayRequestValidator extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_request_validator.html aws_api_gateway_request_validator} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayRequestValidatorConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _validateRequestBody?;
        /**
         * @stability stable
         */
        get validateRequestBody(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set validateRequestBody(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetValidateRequestBody(): void;
        /**
         * @stability stable
         */
        get validateRequestBodyInput(): boolean | cdktf.IResolvable | undefined;
        private _validateRequestParameters?;
        /**
         * @stability stable
         */
        get validateRequestParameters(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set validateRequestParameters(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetValidateRequestParameters(): void;
        /**
         * @stability stable
         */
        get validateRequestParametersInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayResourceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_resource.html#parent_id ApiGatewayResource#parent_id}.
         *
         * @stability stable
         */
        readonly parentId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_resource.html#path_part ApiGatewayResource#path_part}.
         *
         * @stability stable
         */
        readonly pathPart: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_resource.html#rest_api_id ApiGatewayResource#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_resource.html aws_api_gateway_resource}.
     *
     * @stability stable
     */
    class ApiGatewayResource extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_resource.html aws_api_gateway_resource} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayResourceConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _parentId?;
        /**
         * @stability stable
         */
        get parentId(): string;
        /**
         * @stability stable
         */
        set parentId(value: string);
        /**
         * @stability stable
         */
        get parentIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get path(): string;
        private _pathPart?;
        /**
         * @stability stable
         */
        get pathPart(): string;
        /**
         * @stability stable
         */
        set pathPart(value: string);
        /**
         * @stability stable
         */
        get pathPartInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayRestApiConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#api_key_source ApiGatewayRestApi#api_key_source}.
         *
         * @stability stable
         */
        readonly apiKeySource?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#binary_media_types ApiGatewayRestApi#binary_media_types}.
         *
         * @stability stable
         */
        readonly binaryMediaTypes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#body ApiGatewayRestApi#body}.
         *
         * @stability stable
         */
        readonly body?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#description ApiGatewayRestApi#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#disable_execute_api_endpoint ApiGatewayRestApi#disable_execute_api_endpoint}.
         *
         * @stability stable
         */
        readonly disableExecuteApiEndpoint?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#minimum_compression_size ApiGatewayRestApi#minimum_compression_size}.
         *
         * @stability stable
         */
        readonly minimumCompressionSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#name ApiGatewayRestApi#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#parameters ApiGatewayRestApi#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#policy ApiGatewayRestApi#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#tags ApiGatewayRestApi#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#tags_all ApiGatewayRestApi#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * endpoint_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#endpoint_configuration ApiGatewayRestApi#endpoint_configuration}
         *
         * @stability stable
         */
        readonly endpointConfiguration?: ApiGatewayRestApiEndpointConfiguration;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayRestApiEndpointConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#types ApiGatewayRestApi#types}.
         *
         * @stability stable
         */
        readonly types: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html#vpc_endpoint_ids ApiGatewayRestApi#vpc_endpoint_ids}.
         *
         * @stability stable
         */
        readonly vpcEndpointIds?: string[];
    }
    /**
     * @stability stable
     */
    class ApiGatewayRestApiEndpointConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _types?;
        /**
         * @stability stable
         */
        get types(): string[];
        /**
         * @stability stable
         */
        set types(value: string[]);
        /**
         * @stability stable
         */
        get typesInput(): string[] | undefined;
        private _vpcEndpointIds?;
        /**
         * @stability stable
         */
        get vpcEndpointIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcEndpointIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcEndpointIds(): void;
        /**
         * @stability stable
         */
        get vpcEndpointIdsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html aws_api_gateway_rest_api}.
     *
     * @stability stable
     */
    class ApiGatewayRestApi extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api.html aws_api_gateway_rest_api} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayRestApiConfig);
        private _apiKeySource?;
        /**
         * @stability stable
         */
        get apiKeySource(): string | undefined;
        /**
         * @stability stable
         */
        set apiKeySource(value: string | undefined);
        /**
         * @stability stable
         */
        resetApiKeySource(): void;
        /**
         * @stability stable
         */
        get apiKeySourceInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _binaryMediaTypes?;
        /**
         * @stability stable
         */
        get binaryMediaTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set binaryMediaTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetBinaryMediaTypes(): void;
        /**
         * @stability stable
         */
        get binaryMediaTypesInput(): string[] | undefined;
        private _body?;
        /**
         * @stability stable
         */
        get body(): string | undefined;
        /**
         * @stability stable
         */
        set body(value: string | undefined);
        /**
         * @stability stable
         */
        resetBody(): void;
        /**
         * @stability stable
         */
        get bodyInput(): string | undefined;
        /**
         * @stability stable
         */
        get createdDate(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _disableExecuteApiEndpoint?;
        /**
         * @stability stable
         */
        get disableExecuteApiEndpoint(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set disableExecuteApiEndpoint(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDisableExecuteApiEndpoint(): void;
        /**
         * @stability stable
         */
        get disableExecuteApiEndpointInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get executionArn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _minimumCompressionSize?;
        /**
         * @stability stable
         */
        get minimumCompressionSize(): number | undefined;
        /**
         * @stability stable
         */
        set minimumCompressionSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinimumCompressionSize(): void;
        /**
         * @stability stable
         */
        get minimumCompressionSizeInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        get rootResourceId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _endpointConfiguration?;
        private __endpointConfigurationOutput;
        /**
         * @stability stable
         */
        get endpointConfiguration(): ApiGatewayRestApiEndpointConfigurationOutputReference;
        /**
         * @stability stable
         */
        putEndpointConfiguration(value: ApiGatewayRestApiEndpointConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetEndpointConfiguration(): void;
        /**
         * @stability stable
         */
        get endpointConfigurationInput(): ApiGatewayRestApiEndpointConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayRestApiPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api_policy.html#policy ApiGatewayRestApiPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api_policy.html#rest_api_id ApiGatewayRestApiPolicy#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api_policy.html aws_api_gateway_rest_api_policy}.
     *
     * @stability stable
     */
    class ApiGatewayRestApiPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_rest_api_policy.html aws_api_gateway_rest_api_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayRestApiPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayStageConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#cache_cluster_enabled ApiGatewayStage#cache_cluster_enabled}.
         *
         * @stability stable
         */
        readonly cacheClusterEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#cache_cluster_size ApiGatewayStage#cache_cluster_size}.
         *
         * @stability stable
         */
        readonly cacheClusterSize?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#client_certificate_id ApiGatewayStage#client_certificate_id}.
         *
         * @stability stable
         */
        readonly clientCertificateId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#deployment_id ApiGatewayStage#deployment_id}.
         *
         * @stability stable
         */
        readonly deploymentId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#description ApiGatewayStage#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#documentation_version ApiGatewayStage#documentation_version}.
         *
         * @stability stable
         */
        readonly documentationVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#rest_api_id ApiGatewayStage#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#stage_name ApiGatewayStage#stage_name}.
         *
         * @stability stable
         */
        readonly stageName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#tags ApiGatewayStage#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#tags_all ApiGatewayStage#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#variables ApiGatewayStage#variables}.
         *
         * @stability stable
         */
        readonly variables?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#xray_tracing_enabled ApiGatewayStage#xray_tracing_enabled}.
         *
         * @stability stable
         */
        readonly xrayTracingEnabled?: boolean | cdktf.IResolvable;
        /**
         * access_log_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#access_log_settings ApiGatewayStage#access_log_settings}
         *
         * @stability stable
         */
        readonly accessLogSettings?: ApiGatewayStageAccessLogSettings;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayStageAccessLogSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#destination_arn ApiGatewayStage#destination_arn}.
         *
         * @stability stable
         */
        readonly destinationArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html#format ApiGatewayStage#format}.
         *
         * @stability stable
         */
        readonly format: string;
    }
    /**
     * @stability stable
     */
    class ApiGatewayStageAccessLogSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _destinationArn?;
        /**
         * @stability stable
         */
        get destinationArn(): string;
        /**
         * @stability stable
         */
        set destinationArn(value: string);
        /**
         * @stability stable
         */
        get destinationArnInput(): string | undefined;
        private _format?;
        /**
         * @stability stable
         */
        get format(): string;
        /**
         * @stability stable
         */
        set format(value: string);
        /**
         * @stability stable
         */
        get formatInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html aws_api_gateway_stage}.
     *
     * @stability stable
     */
    class ApiGatewayStage extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_stage.html aws_api_gateway_stage} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayStageConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _cacheClusterEnabled?;
        /**
         * @stability stable
         */
        get cacheClusterEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set cacheClusterEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCacheClusterEnabled(): void;
        /**
         * @stability stable
         */
        get cacheClusterEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _cacheClusterSize?;
        /**
         * @stability stable
         */
        get cacheClusterSize(): string | undefined;
        /**
         * @stability stable
         */
        set cacheClusterSize(value: string | undefined);
        /**
         * @stability stable
         */
        resetCacheClusterSize(): void;
        /**
         * @stability stable
         */
        get cacheClusterSizeInput(): string | undefined;
        private _clientCertificateId?;
        /**
         * @stability stable
         */
        get clientCertificateId(): string | undefined;
        /**
         * @stability stable
         */
        set clientCertificateId(value: string | undefined);
        /**
         * @stability stable
         */
        resetClientCertificateId(): void;
        /**
         * @stability stable
         */
        get clientCertificateIdInput(): string | undefined;
        private _deploymentId?;
        /**
         * @stability stable
         */
        get deploymentId(): string;
        /**
         * @stability stable
         */
        set deploymentId(value: string);
        /**
         * @stability stable
         */
        get deploymentIdInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _documentationVersion?;
        /**
         * @stability stable
         */
        get documentationVersion(): string | undefined;
        /**
         * @stability stable
         */
        set documentationVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentationVersion(): void;
        /**
         * @stability stable
         */
        get documentationVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get executionArn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get invokeUrl(): string;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        private _stageName?;
        /**
         * @stability stable
         */
        get stageName(): string;
        /**
         * @stability stable
         */
        set stageName(value: string);
        /**
         * @stability stable
         */
        get stageNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _variables?;
        /**
         * @stability stable
         */
        get variables(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set variables(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetVariables(): void;
        /**
         * @stability stable
         */
        get variablesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _xrayTracingEnabled?;
        /**
         * @stability stable
         */
        get xrayTracingEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set xrayTracingEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetXrayTracingEnabled(): void;
        /**
         * @stability stable
         */
        get xrayTracingEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _accessLogSettings?;
        private __accessLogSettingsOutput;
        /**
         * @stability stable
         */
        get accessLogSettings(): ApiGatewayStageAccessLogSettingsOutputReference;
        /**
         * @stability stable
         */
        putAccessLogSettings(value: ApiGatewayStageAccessLogSettings | undefined): void;
        /**
         * @stability stable
         */
        resetAccessLogSettings(): void;
        /**
         * @stability stable
         */
        get accessLogSettingsInput(): ApiGatewayStageAccessLogSettings | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayUsagePlanConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#description ApiGatewayUsagePlan#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#name ApiGatewayUsagePlan#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#product_code ApiGatewayUsagePlan#product_code}.
         *
         * @stability stable
         */
        readonly productCode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#tags ApiGatewayUsagePlan#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#tags_all ApiGatewayUsagePlan#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * api_stages block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#api_stages ApiGatewayUsagePlan#api_stages}
         *
         * @stability stable
         */
        readonly apiStages?: ApiGatewayUsagePlanApiStages[];
        /**
         * quota_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#quota_settings ApiGatewayUsagePlan#quota_settings}
         *
         * @stability stable
         */
        readonly quotaSettings?: ApiGatewayUsagePlanQuotaSettings;
        /**
         * throttle_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#throttle_settings ApiGatewayUsagePlan#throttle_settings}
         *
         * @stability stable
         */
        readonly throttleSettings?: ApiGatewayUsagePlanThrottleSettings;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayUsagePlanApiStages {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#api_id ApiGatewayUsagePlan#api_id}.
         *
         * @stability stable
         */
        readonly apiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#stage ApiGatewayUsagePlan#stage}.
         *
         * @stability stable
         */
        readonly stage: string;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayUsagePlanQuotaSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#limit ApiGatewayUsagePlan#limit}.
         *
         * @stability stable
         */
        readonly limit: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#offset ApiGatewayUsagePlan#offset}.
         *
         * @stability stable
         */
        readonly offset?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#period ApiGatewayUsagePlan#period}.
         *
         * @stability stable
         */
        readonly period: string;
    }
    /**
     * @stability stable
     */
    class ApiGatewayUsagePlanQuotaSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _limit?;
        /**
         * @stability stable
         */
        get limit(): number;
        /**
         * @stability stable
         */
        set limit(value: number);
        /**
         * @stability stable
         */
        get limitInput(): number | undefined;
        private _offset?;
        /**
         * @stability stable
         */
        get offset(): number | undefined;
        /**
         * @stability stable
         */
        set offset(value: number | undefined);
        /**
         * @stability stable
         */
        resetOffset(): void;
        /**
         * @stability stable
         */
        get offsetInput(): number | undefined;
        private _period?;
        /**
         * @stability stable
         */
        get period(): string;
        /**
         * @stability stable
         */
        set period(value: string);
        /**
         * @stability stable
         */
        get periodInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ApiGatewayUsagePlanThrottleSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#burst_limit ApiGatewayUsagePlan#burst_limit}.
         *
         * @stability stable
         */
        readonly burstLimit?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html#rate_limit ApiGatewayUsagePlan#rate_limit}.
         *
         * @stability stable
         */
        readonly rateLimit?: number;
    }
    /**
     * @stability stable
     */
    class ApiGatewayUsagePlanThrottleSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _burstLimit?;
        /**
         * @stability stable
         */
        get burstLimit(): number | undefined;
        /**
         * @stability stable
         */
        set burstLimit(value: number | undefined);
        /**
         * @stability stable
         */
        resetBurstLimit(): void;
        /**
         * @stability stable
         */
        get burstLimitInput(): number | undefined;
        private _rateLimit?;
        /**
         * @stability stable
         */
        get rateLimit(): number | undefined;
        /**
         * @stability stable
         */
        set rateLimit(value: number | undefined);
        /**
         * @stability stable
         */
        resetRateLimit(): void;
        /**
         * @stability stable
         */
        get rateLimitInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html aws_api_gateway_usage_plan}.
     *
     * @stability stable
     */
    class ApiGatewayUsagePlan extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan.html aws_api_gateway_usage_plan} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayUsagePlanConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _productCode?;
        /**
         * @stability stable
         */
        get productCode(): string | undefined;
        /**
         * @stability stable
         */
        set productCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetProductCode(): void;
        /**
         * @stability stable
         */
        get productCodeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _apiStages?;
        /**
         * @stability stable
         */
        get apiStages(): ApiGatewayUsagePlanApiStages[] | undefined;
        /**
         * @stability stable
         */
        set apiStages(value: ApiGatewayUsagePlanApiStages[] | undefined);
        /**
         * @stability stable
         */
        resetApiStages(): void;
        /**
         * @stability stable
         */
        get apiStagesInput(): ApiGatewayUsagePlanApiStages[] | undefined;
        private _quotaSettings?;
        private __quotaSettingsOutput;
        /**
         * @stability stable
         */
        get quotaSettings(): ApiGatewayUsagePlanQuotaSettingsOutputReference;
        /**
         * @stability stable
         */
        putQuotaSettings(value: ApiGatewayUsagePlanQuotaSettings | undefined): void;
        /**
         * @stability stable
         */
        resetQuotaSettings(): void;
        /**
         * @stability stable
         */
        get quotaSettingsInput(): ApiGatewayUsagePlanQuotaSettings | undefined;
        private _throttleSettings?;
        private __throttleSettingsOutput;
        /**
         * @stability stable
         */
        get throttleSettings(): ApiGatewayUsagePlanThrottleSettingsOutputReference;
        /**
         * @stability stable
         */
        putThrottleSettings(value: ApiGatewayUsagePlanThrottleSettings | undefined): void;
        /**
         * @stability stable
         */
        resetThrottleSettings(): void;
        /**
         * @stability stable
         */
        get throttleSettingsInput(): ApiGatewayUsagePlanThrottleSettings | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayUsagePlanKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan_key.html#key_id ApiGatewayUsagePlanKey#key_id}.
         *
         * @stability stable
         */
        readonly keyId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan_key.html#key_type ApiGatewayUsagePlanKey#key_type}.
         *
         * @stability stable
         */
        readonly keyType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan_key.html#usage_plan_id ApiGatewayUsagePlanKey#usage_plan_id}.
         *
         * @stability stable
         */
        readonly usagePlanId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan_key.html aws_api_gateway_usage_plan_key}.
     *
     * @stability stable
     */
    class ApiGatewayUsagePlanKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_usage_plan_key.html aws_api_gateway_usage_plan_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayUsagePlanKeyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string;
        /**
         * @stability stable
         */
        set keyId(value: string);
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
        private _keyType?;
        /**
         * @stability stable
         */
        get keyType(): string;
        /**
         * @stability stable
         */
        set keyType(value: string);
        /**
         * @stability stable
         */
        get keyTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get name(): string;
        private _usagePlanId?;
        /**
         * @stability stable
         */
        get usagePlanId(): string;
        /**
         * @stability stable
         */
        set usagePlanId(value: string);
        /**
         * @stability stable
         */
        get usagePlanIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ApiGatewayVpcLinkConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_vpc_link.html#description ApiGatewayVpcLink#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_vpc_link.html#name ApiGatewayVpcLink#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_vpc_link.html#tags ApiGatewayVpcLink#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_vpc_link.html#tags_all ApiGatewayVpcLink#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_vpc_link.html#target_arns ApiGatewayVpcLink#target_arns}.
         *
         * @stability stable
         */
        readonly targetArns: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_vpc_link.html aws_api_gateway_vpc_link}.
     *
     * @stability stable
     */
    class ApiGatewayVpcLink extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/api_gateway_vpc_link.html aws_api_gateway_vpc_link} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ApiGatewayVpcLinkConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetArns?;
        /**
         * @stability stable
         */
        get targetArns(): string[];
        /**
         * @stability stable
         */
        set targetArns(value: string[]);
        /**
         * @stability stable
         */
        get targetArnsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsApiGatewayApiKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_api_key.html#id DataAwsApiGatewayApiKey#id}.
         *
         * @stability stable
         */
        readonly id: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_api_key.html#tags DataAwsApiGatewayApiKey#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_api_key.html aws_api_gateway_api_key}.
     *
     * @stability stable
     */
    class DataAwsApiGatewayApiKey extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_api_key.html aws_api_gateway_api_key} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsApiGatewayApiKeyConfig);
        /**
         * @stability stable
         */
        get createdDate(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        private _id?;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        set id(value: string);
        /**
         * @stability stable
         */
        get idInput(): string | undefined;
        /**
         * @stability stable
         */
        get lastUpdatedDate(): string;
        /**
         * @stability stable
         */
        get name(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsApiGatewayDomainNameConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_domain_name.html#domain_name DataAwsApiGatewayDomainName#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_domain_name.html#tags DataAwsApiGatewayDomainName#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsApiGatewayDomainNameEndpointConfiguration extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get types(): string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_domain_name.html aws_api_gateway_domain_name}.
     *
     * @stability stable
     */
    class DataAwsApiGatewayDomainName extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_domain_name.html aws_api_gateway_domain_name} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsApiGatewayDomainNameConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificateArn(): string;
        /**
         * @stability stable
         */
        get certificateName(): string;
        /**
         * @stability stable
         */
        get certificateUploadDate(): string;
        /**
         * @stability stable
         */
        get cloudfrontDomainName(): string;
        /**
         * @stability stable
         */
        get cloudfrontZoneId(): string;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        endpointConfiguration(index: string): DataAwsApiGatewayDomainNameEndpointConfiguration;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get regionalCertificateArn(): string;
        /**
         * @stability stable
         */
        get regionalCertificateName(): string;
        /**
         * @stability stable
         */
        get regionalDomainName(): string;
        /**
         * @stability stable
         */
        get regionalZoneId(): string;
        /**
         * @stability stable
         */
        get securityPolicy(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsApiGatewayResourceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_resource.html#path DataAwsApiGatewayResource#path}.
         *
         * @stability stable
         */
        readonly path: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_resource.html#rest_api_id DataAwsApiGatewayResource#rest_api_id}.
         *
         * @stability stable
         */
        readonly restApiId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_resource.html aws_api_gateway_resource}.
     *
     * @stability stable
     */
    class DataAwsApiGatewayResource extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_resource.html aws_api_gateway_resource} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsApiGatewayResourceConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get parentId(): string;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        set path(value: string);
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        /**
         * @stability stable
         */
        get pathPart(): string;
        private _restApiId?;
        /**
         * @stability stable
         */
        get restApiId(): string;
        /**
         * @stability stable
         */
        set restApiId(value: string);
        /**
         * @stability stable
         */
        get restApiIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsApiGatewayRestApiConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_rest_api.html#name DataAwsApiGatewayRestApi#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_rest_api.html#tags DataAwsApiGatewayRestApi#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsApiGatewayRestApiEndpointConfiguration extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get types(): string[];
        /**
         * @stability stable
         */
        get vpcEndpointIds(): string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_rest_api.html aws_api_gateway_rest_api}.
     *
     * @stability stable
     */
    class DataAwsApiGatewayRestApi extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_rest_api.html aws_api_gateway_rest_api} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsApiGatewayRestApiConfig);
        /**
         * @stability stable
         */
        get apiKeySource(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get binaryMediaTypes(): string[];
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        endpointConfiguration(index: string): DataAwsApiGatewayRestApiEndpointConfiguration;
        /**
         * @stability stable
         */
        get executionArn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get minimumCompressionSize(): number;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        get rootResourceId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsApiGatewayVpcLinkConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_vpc_link.html#name DataAwsApiGatewayVpcLink#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_vpc_link.html#tags DataAwsApiGatewayVpcLink#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_vpc_link.html aws_api_gateway_vpc_link}.
     *
     * @stability stable
     */
    class DataAwsApiGatewayVpcLink extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/api_gateway_vpc_link.html aws_api_gateway_vpc_link} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsApiGatewayVpcLinkConfig);
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get statusMessage(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get targetArns(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
