import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS AppSync
*/
export declare namespace AppSync {
    /**
     * @stability stable
     */
    interface AppsyncApiKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_api_key.html#api_id AppsyncApiKey#api_id}.
         *
         * @stability stable
         */
        readonly apiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_api_key.html#description AppsyncApiKey#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_api_key.html#expires AppsyncApiKey#expires}.
         *
         * @stability stable
         */
        readonly expires?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_api_key.html aws_appsync_api_key}.
     *
     * @stability stable
     */
    class AppsyncApiKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_api_key.html aws_appsync_api_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AppsyncApiKeyConfig);
        private _apiId?;
        /**
         * @stability stable
         */
        get apiId(): string;
        /**
         * @stability stable
         */
        set apiId(value: string);
        /**
         * @stability stable
         */
        get apiIdInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _expires?;
        /**
         * @stability stable
         */
        get expires(): string | undefined;
        /**
         * @stability stable
         */
        set expires(value: string | undefined);
        /**
         * @stability stable
         */
        resetExpires(): void;
        /**
         * @stability stable
         */
        get expiresInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AppsyncDatasourceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#api_id AppsyncDatasource#api_id}.
         *
         * @stability stable
         */
        readonly apiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#description AppsyncDatasource#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#name AppsyncDatasource#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#service_role_arn AppsyncDatasource#service_role_arn}.
         *
         * @stability stable
         */
        readonly serviceRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#type AppsyncDatasource#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * dynamodb_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#dynamodb_config AppsyncDatasource#dynamodb_config}
         *
         * @stability stable
         */
        readonly dynamodbConfig?: AppsyncDatasourceDynamodbConfig;
        /**
         * elasticsearch_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#elasticsearch_config AppsyncDatasource#elasticsearch_config}
         *
         * @stability stable
         */
        readonly elasticsearchConfig?: AppsyncDatasourceElasticsearchConfig;
        /**
         * http_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#http_config AppsyncDatasource#http_config}
         *
         * @stability stable
         */
        readonly httpConfig?: AppsyncDatasourceHttpConfig;
        /**
         * lambda_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#lambda_config AppsyncDatasource#lambda_config}
         *
         * @stability stable
         */
        readonly lambdaConfig?: AppsyncDatasourceLambdaConfig;
    }
    /**
     * @stability stable
     */
    interface AppsyncDatasourceDynamodbConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#region AppsyncDatasource#region}.
         *
         * @stability stable
         */
        readonly region?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#table_name AppsyncDatasource#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#use_caller_credentials AppsyncDatasource#use_caller_credentials}.
         *
         * @stability stable
         */
        readonly useCallerCredentials?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class AppsyncDatasourceDynamodbConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _region?;
        /**
         * @stability stable
         */
        get region(): string | undefined;
        /**
         * @stability stable
         */
        set region(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegion(): void;
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
        private _useCallerCredentials?;
        /**
         * @stability stable
         */
        get useCallerCredentials(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set useCallerCredentials(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetUseCallerCredentials(): void;
        /**
         * @stability stable
         */
        get useCallerCredentialsInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncDatasourceElasticsearchConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#endpoint AppsyncDatasource#endpoint}.
         *
         * @stability stable
         */
        readonly endpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#region AppsyncDatasource#region}.
         *
         * @stability stable
         */
        readonly region?: string;
    }
    /**
     * @stability stable
     */
    class AppsyncDatasourceElasticsearchConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _endpoint?;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        set endpoint(value: string);
        /**
         * @stability stable
         */
        get endpointInput(): string | undefined;
        private _region?;
        /**
         * @stability stable
         */
        get region(): string | undefined;
        /**
         * @stability stable
         */
        set region(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegion(): void;
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncDatasourceHttpConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#endpoint AppsyncDatasource#endpoint}.
         *
         * @stability stable
         */
        readonly endpoint: string;
    }
    /**
     * @stability stable
     */
    class AppsyncDatasourceHttpConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _endpoint?;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        set endpoint(value: string);
        /**
         * @stability stable
         */
        get endpointInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncDatasourceLambdaConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html#function_arn AppsyncDatasource#function_arn}.
         *
         * @stability stable
         */
        readonly functionArn: string;
    }
    /**
     * @stability stable
     */
    class AppsyncDatasourceLambdaConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _functionArn?;
        /**
         * @stability stable
         */
        get functionArn(): string;
        /**
         * @stability stable
         */
        set functionArn(value: string);
        /**
         * @stability stable
         */
        get functionArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html aws_appsync_datasource}.
     *
     * @stability stable
     */
    class AppsyncDatasource extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_datasource.html aws_appsync_datasource} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AppsyncDatasourceConfig);
        private _apiId?;
        /**
         * @stability stable
         */
        get apiId(): string;
        /**
         * @stability stable
         */
        set apiId(value: string);
        /**
         * @stability stable
         */
        get apiIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _serviceRoleArn?;
        /**
         * @stability stable
         */
        get serviceRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set serviceRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceRoleArn(): void;
        /**
         * @stability stable
         */
        get serviceRoleArnInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _dynamodbConfig?;
        private __dynamodbConfigOutput;
        /**
         * @stability stable
         */
        get dynamodbConfig(): AppsyncDatasourceDynamodbConfigOutputReference;
        /**
         * @stability stable
         */
        putDynamodbConfig(value: AppsyncDatasourceDynamodbConfig | undefined): void;
        /**
         * @stability stable
         */
        resetDynamodbConfig(): void;
        /**
         * @stability stable
         */
        get dynamodbConfigInput(): AppsyncDatasourceDynamodbConfig | undefined;
        private _elasticsearchConfig?;
        private __elasticsearchConfigOutput;
        /**
         * @stability stable
         */
        get elasticsearchConfig(): AppsyncDatasourceElasticsearchConfigOutputReference;
        /**
         * @stability stable
         */
        putElasticsearchConfig(value: AppsyncDatasourceElasticsearchConfig | undefined): void;
        /**
         * @stability stable
         */
        resetElasticsearchConfig(): void;
        /**
         * @stability stable
         */
        get elasticsearchConfigInput(): AppsyncDatasourceElasticsearchConfig | undefined;
        private _httpConfig?;
        private __httpConfigOutput;
        /**
         * @stability stable
         */
        get httpConfig(): AppsyncDatasourceHttpConfigOutputReference;
        /**
         * @stability stable
         */
        putHttpConfig(value: AppsyncDatasourceHttpConfig | undefined): void;
        /**
         * @stability stable
         */
        resetHttpConfig(): void;
        /**
         * @stability stable
         */
        get httpConfigInput(): AppsyncDatasourceHttpConfig | undefined;
        private _lambdaConfig?;
        private __lambdaConfigOutput;
        /**
         * @stability stable
         */
        get lambdaConfig(): AppsyncDatasourceLambdaConfigOutputReference;
        /**
         * @stability stable
         */
        putLambdaConfig(value: AppsyncDatasourceLambdaConfig | undefined): void;
        /**
         * @stability stable
         */
        resetLambdaConfig(): void;
        /**
         * @stability stable
         */
        get lambdaConfigInput(): AppsyncDatasourceLambdaConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AppsyncFunctionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html#api_id AppsyncFunction#api_id}.
         *
         * @stability stable
         */
        readonly apiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html#data_source AppsyncFunction#data_source}.
         *
         * @stability stable
         */
        readonly dataSource: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html#description AppsyncFunction#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html#function_version AppsyncFunction#function_version}.
         *
         * @stability stable
         */
        readonly functionVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html#name AppsyncFunction#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html#request_mapping_template AppsyncFunction#request_mapping_template}.
         *
         * @stability stable
         */
        readonly requestMappingTemplate: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html#response_mapping_template AppsyncFunction#response_mapping_template}.
         *
         * @stability stable
         */
        readonly responseMappingTemplate: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html aws_appsync_function}.
     *
     * @stability stable
     */
    class AppsyncFunction extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_function.html aws_appsync_function} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AppsyncFunctionConfig);
        private _apiId?;
        /**
         * @stability stable
         */
        get apiId(): string;
        /**
         * @stability stable
         */
        set apiId(value: string);
        /**
         * @stability stable
         */
        get apiIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _dataSource?;
        /**
         * @stability stable
         */
        get dataSource(): string;
        /**
         * @stability stable
         */
        set dataSource(value: string);
        /**
         * @stability stable
         */
        get dataSourceInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get functionId(): string;
        private _functionVersion?;
        /**
         * @stability stable
         */
        get functionVersion(): string | undefined;
        /**
         * @stability stable
         */
        set functionVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetFunctionVersion(): void;
        /**
         * @stability stable
         */
        get functionVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _requestMappingTemplate?;
        /**
         * @stability stable
         */
        get requestMappingTemplate(): string;
        /**
         * @stability stable
         */
        set requestMappingTemplate(value: string);
        /**
         * @stability stable
         */
        get requestMappingTemplateInput(): string | undefined;
        private _responseMappingTemplate?;
        /**
         * @stability stable
         */
        get responseMappingTemplate(): string;
        /**
         * @stability stable
         */
        set responseMappingTemplate(value: string);
        /**
         * @stability stable
         */
        get responseMappingTemplateInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AppsyncGraphqlApiConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#authentication_type AppsyncGraphqlApi#authentication_type}.
         *
         * @stability stable
         */
        readonly authenticationType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#name AppsyncGraphqlApi#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#schema AppsyncGraphqlApi#schema}.
         *
         * @stability stable
         */
        readonly schema?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#tags AppsyncGraphqlApi#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#tags_all AppsyncGraphqlApi#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#xray_enabled AppsyncGraphqlApi#xray_enabled}.
         *
         * @stability stable
         */
        readonly xrayEnabled?: boolean | cdktf.IResolvable;
        /**
         * additional_authentication_provider block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#additional_authentication_provider AppsyncGraphqlApi#additional_authentication_provider}
         *
         * @stability stable
         */
        readonly additionalAuthenticationProvider?: AppsyncGraphqlApiAdditionalAuthenticationProvider[];
        /**
         * log_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#log_config AppsyncGraphqlApi#log_config}
         *
         * @stability stable
         */
        readonly logConfig?: AppsyncGraphqlApiLogConfig;
        /**
         * openid_connect_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#openid_connect_config AppsyncGraphqlApi#openid_connect_config}
         *
         * @stability stable
         */
        readonly openidConnectConfig?: AppsyncGraphqlApiOpenidConnectConfig;
        /**
         * user_pool_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#user_pool_config AppsyncGraphqlApi#user_pool_config}
         *
         * @stability stable
         */
        readonly userPoolConfig?: AppsyncGraphqlApiUserPoolConfig;
    }
    /**
     * @stability stable
     */
    interface AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#auth_ttl AppsyncGraphqlApi#auth_ttl}.
         *
         * @stability stable
         */
        readonly authTtl?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#client_id AppsyncGraphqlApi#client_id}.
         *
         * @stability stable
         */
        readonly clientId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#iat_ttl AppsyncGraphqlApi#iat_ttl}.
         *
         * @stability stable
         */
        readonly iatTtl?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#issuer AppsyncGraphqlApi#issuer}.
         *
         * @stability stable
         */
        readonly issuer: string;
    }
    /**
     * @stability stable
     */
    class AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authTtl?;
        /**
         * @stability stable
         */
        get authTtl(): number | undefined;
        /**
         * @stability stable
         */
        set authTtl(value: number | undefined);
        /**
         * @stability stable
         */
        resetAuthTtl(): void;
        /**
         * @stability stable
         */
        get authTtlInput(): number | undefined;
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string | undefined;
        /**
         * @stability stable
         */
        set clientId(value: string | undefined);
        /**
         * @stability stable
         */
        resetClientId(): void;
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _iatTtl?;
        /**
         * @stability stable
         */
        get iatTtl(): number | undefined;
        /**
         * @stability stable
         */
        set iatTtl(value: number | undefined);
        /**
         * @stability stable
         */
        resetIatTtl(): void;
        /**
         * @stability stable
         */
        get iatTtlInput(): number | undefined;
        private _issuer?;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        set issuer(value: string);
        /**
         * @stability stable
         */
        get issuerInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#app_id_client_regex AppsyncGraphqlApi#app_id_client_regex}.
         *
         * @stability stable
         */
        readonly appIdClientRegex?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#aws_region AppsyncGraphqlApi#aws_region}.
         *
         * @stability stable
         */
        readonly awsRegion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#user_pool_id AppsyncGraphqlApi#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
    }
    /**
     * @stability stable
     */
    class AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _appIdClientRegex?;
        /**
         * @stability stable
         */
        get appIdClientRegex(): string | undefined;
        /**
         * @stability stable
         */
        set appIdClientRegex(value: string | undefined);
        /**
         * @stability stable
         */
        resetAppIdClientRegex(): void;
        /**
         * @stability stable
         */
        get appIdClientRegexInput(): string | undefined;
        private _awsRegion?;
        /**
         * @stability stable
         */
        get awsRegion(): string | undefined;
        /**
         * @stability stable
         */
        set awsRegion(value: string | undefined);
        /**
         * @stability stable
         */
        resetAwsRegion(): void;
        /**
         * @stability stable
         */
        get awsRegionInput(): string | undefined;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncGraphqlApiAdditionalAuthenticationProvider {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#authentication_type AppsyncGraphqlApi#authentication_type}.
         *
         * @stability stable
         */
        readonly authenticationType: string;
        /**
         * openid_connect_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#openid_connect_config AppsyncGraphqlApi#openid_connect_config}
         *
         * @stability stable
         */
        readonly openidConnectConfig?: AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig;
        /**
         * user_pool_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#user_pool_config AppsyncGraphqlApi#user_pool_config}
         *
         * @stability stable
         */
        readonly userPoolConfig?: AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig;
    }
    /**
     * @stability stable
     */
    interface AppsyncGraphqlApiLogConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#cloudwatch_logs_role_arn AppsyncGraphqlApi#cloudwatch_logs_role_arn}.
         *
         * @stability stable
         */
        readonly cloudwatchLogsRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#exclude_verbose_content AppsyncGraphqlApi#exclude_verbose_content}.
         *
         * @stability stable
         */
        readonly excludeVerboseContent?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#field_log_level AppsyncGraphqlApi#field_log_level}.
         *
         * @stability stable
         */
        readonly fieldLogLevel: string;
    }
    /**
     * @stability stable
     */
    class AppsyncGraphqlApiLogConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cloudwatchLogsRoleArn?;
        /**
         * @stability stable
         */
        get cloudwatchLogsRoleArn(): string;
        /**
         * @stability stable
         */
        set cloudwatchLogsRoleArn(value: string);
        /**
         * @stability stable
         */
        get cloudwatchLogsRoleArnInput(): string | undefined;
        private _excludeVerboseContent?;
        /**
         * @stability stable
         */
        get excludeVerboseContent(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set excludeVerboseContent(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetExcludeVerboseContent(): void;
        /**
         * @stability stable
         */
        get excludeVerboseContentInput(): boolean | cdktf.IResolvable | undefined;
        private _fieldLogLevel?;
        /**
         * @stability stable
         */
        get fieldLogLevel(): string;
        /**
         * @stability stable
         */
        set fieldLogLevel(value: string);
        /**
         * @stability stable
         */
        get fieldLogLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncGraphqlApiOpenidConnectConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#auth_ttl AppsyncGraphqlApi#auth_ttl}.
         *
         * @stability stable
         */
        readonly authTtl?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#client_id AppsyncGraphqlApi#client_id}.
         *
         * @stability stable
         */
        readonly clientId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#iat_ttl AppsyncGraphqlApi#iat_ttl}.
         *
         * @stability stable
         */
        readonly iatTtl?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#issuer AppsyncGraphqlApi#issuer}.
         *
         * @stability stable
         */
        readonly issuer: string;
    }
    /**
     * @stability stable
     */
    class AppsyncGraphqlApiOpenidConnectConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authTtl?;
        /**
         * @stability stable
         */
        get authTtl(): number | undefined;
        /**
         * @stability stable
         */
        set authTtl(value: number | undefined);
        /**
         * @stability stable
         */
        resetAuthTtl(): void;
        /**
         * @stability stable
         */
        get authTtlInput(): number | undefined;
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string | undefined;
        /**
         * @stability stable
         */
        set clientId(value: string | undefined);
        /**
         * @stability stable
         */
        resetClientId(): void;
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _iatTtl?;
        /**
         * @stability stable
         */
        get iatTtl(): number | undefined;
        /**
         * @stability stable
         */
        set iatTtl(value: number | undefined);
        /**
         * @stability stable
         */
        resetIatTtl(): void;
        /**
         * @stability stable
         */
        get iatTtlInput(): number | undefined;
        private _issuer?;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        set issuer(value: string);
        /**
         * @stability stable
         */
        get issuerInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncGraphqlApiUserPoolConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#app_id_client_regex AppsyncGraphqlApi#app_id_client_regex}.
         *
         * @stability stable
         */
        readonly appIdClientRegex?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#aws_region AppsyncGraphqlApi#aws_region}.
         *
         * @stability stable
         */
        readonly awsRegion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#default_action AppsyncGraphqlApi#default_action}.
         *
         * @stability stable
         */
        readonly defaultAction: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html#user_pool_id AppsyncGraphqlApi#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
    }
    /**
     * @stability stable
     */
    class AppsyncGraphqlApiUserPoolConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _appIdClientRegex?;
        /**
         * @stability stable
         */
        get appIdClientRegex(): string | undefined;
        /**
         * @stability stable
         */
        set appIdClientRegex(value: string | undefined);
        /**
         * @stability stable
         */
        resetAppIdClientRegex(): void;
        /**
         * @stability stable
         */
        get appIdClientRegexInput(): string | undefined;
        private _awsRegion?;
        /**
         * @stability stable
         */
        get awsRegion(): string | undefined;
        /**
         * @stability stable
         */
        set awsRegion(value: string | undefined);
        /**
         * @stability stable
         */
        resetAwsRegion(): void;
        /**
         * @stability stable
         */
        get awsRegionInput(): string | undefined;
        private _defaultAction?;
        /**
         * @stability stable
         */
        get defaultAction(): string;
        /**
         * @stability stable
         */
        set defaultAction(value: string);
        /**
         * @stability stable
         */
        get defaultActionInput(): string | undefined;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html aws_appsync_graphql_api}.
     *
     * @stability stable
     */
    class AppsyncGraphqlApi extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_graphql_api.html aws_appsync_graphql_api} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AppsyncGraphqlApiConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _authenticationType?;
        /**
         * @stability stable
         */
        get authenticationType(): string;
        /**
         * @stability stable
         */
        set authenticationType(value: string);
        /**
         * @stability stable
         */
        get authenticationTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _schema?;
        /**
         * @stability stable
         */
        get schema(): string | undefined;
        /**
         * @stability stable
         */
        set schema(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchema(): void;
        /**
         * @stability stable
         */
        get schemaInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        uris(key: string): string;
        private _xrayEnabled?;
        /**
         * @stability stable
         */
        get xrayEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set xrayEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetXrayEnabled(): void;
        /**
         * @stability stable
         */
        get xrayEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _additionalAuthenticationProvider?;
        /**
         * @stability stable
         */
        get additionalAuthenticationProvider(): AppsyncGraphqlApiAdditionalAuthenticationProvider[] | undefined;
        /**
         * @stability stable
         */
        set additionalAuthenticationProvider(value: AppsyncGraphqlApiAdditionalAuthenticationProvider[] | undefined);
        /**
         * @stability stable
         */
        resetAdditionalAuthenticationProvider(): void;
        /**
         * @stability stable
         */
        get additionalAuthenticationProviderInput(): AppsyncGraphqlApiAdditionalAuthenticationProvider[] | undefined;
        private _logConfig?;
        private __logConfigOutput;
        /**
         * @stability stable
         */
        get logConfig(): AppsyncGraphqlApiLogConfigOutputReference;
        /**
         * @stability stable
         */
        putLogConfig(value: AppsyncGraphqlApiLogConfig | undefined): void;
        /**
         * @stability stable
         */
        resetLogConfig(): void;
        /**
         * @stability stable
         */
        get logConfigInput(): AppsyncGraphqlApiLogConfig | undefined;
        private _openidConnectConfig?;
        private __openidConnectConfigOutput;
        /**
         * @stability stable
         */
        get openidConnectConfig(): AppsyncGraphqlApiOpenidConnectConfigOutputReference;
        /**
         * @stability stable
         */
        putOpenidConnectConfig(value: AppsyncGraphqlApiOpenidConnectConfig | undefined): void;
        /**
         * @stability stable
         */
        resetOpenidConnectConfig(): void;
        /**
         * @stability stable
         */
        get openidConnectConfigInput(): AppsyncGraphqlApiOpenidConnectConfig | undefined;
        private _userPoolConfig?;
        private __userPoolConfigOutput;
        /**
         * @stability stable
         */
        get userPoolConfig(): AppsyncGraphqlApiUserPoolConfigOutputReference;
        /**
         * @stability stable
         */
        putUserPoolConfig(value: AppsyncGraphqlApiUserPoolConfig | undefined): void;
        /**
         * @stability stable
         */
        resetUserPoolConfig(): void;
        /**
         * @stability stable
         */
        get userPoolConfigInput(): AppsyncGraphqlApiUserPoolConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AppsyncResolverConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#api_id AppsyncResolver#api_id}.
         *
         * @stability stable
         */
        readonly apiId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#data_source AppsyncResolver#data_source}.
         *
         * @stability stable
         */
        readonly dataSource?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#field AppsyncResolver#field}.
         *
         * @stability stable
         */
        readonly field: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#kind AppsyncResolver#kind}.
         *
         * @stability stable
         */
        readonly kind?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#request_template AppsyncResolver#request_template}.
         *
         * @stability stable
         */
        readonly requestTemplate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#response_template AppsyncResolver#response_template}.
         *
         * @stability stable
         */
        readonly responseTemplate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#type AppsyncResolver#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * caching_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#caching_config AppsyncResolver#caching_config}
         *
         * @stability stable
         */
        readonly cachingConfig?: AppsyncResolverCachingConfig;
        /**
         * pipeline_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#pipeline_config AppsyncResolver#pipeline_config}
         *
         * @stability stable
         */
        readonly pipelineConfig?: AppsyncResolverPipelineConfig;
    }
    /**
     * @stability stable
     */
    interface AppsyncResolverCachingConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#caching_keys AppsyncResolver#caching_keys}.
         *
         * @stability stable
         */
        readonly cachingKeys?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#ttl AppsyncResolver#ttl}.
         *
         * @stability stable
         */
        readonly ttl?: number;
    }
    /**
     * @stability stable
     */
    class AppsyncResolverCachingConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cachingKeys?;
        /**
         * @stability stable
         */
        get cachingKeys(): string[] | undefined;
        /**
         * @stability stable
         */
        set cachingKeys(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCachingKeys(): void;
        /**
         * @stability stable
         */
        get cachingKeysInput(): string[] | undefined;
        private _ttl?;
        /**
         * @stability stable
         */
        get ttl(): number | undefined;
        /**
         * @stability stable
         */
        set ttl(value: number | undefined);
        /**
         * @stability stable
         */
        resetTtl(): void;
        /**
         * @stability stable
         */
        get ttlInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface AppsyncResolverPipelineConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html#functions AppsyncResolver#functions}.
         *
         * @stability stable
         */
        readonly functions?: string[];
    }
    /**
     * @stability stable
     */
    class AppsyncResolverPipelineConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _functions?;
        /**
         * @stability stable
         */
        get functions(): string[] | undefined;
        /**
         * @stability stable
         */
        set functions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetFunctions(): void;
        /**
         * @stability stable
         */
        get functionsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html aws_appsync_resolver}.
     *
     * @stability stable
     */
    class AppsyncResolver extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/appsync_resolver.html aws_appsync_resolver} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AppsyncResolverConfig);
        private _apiId?;
        /**
         * @stability stable
         */
        get apiId(): string;
        /**
         * @stability stable
         */
        set apiId(value: string);
        /**
         * @stability stable
         */
        get apiIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _dataSource?;
        /**
         * @stability stable
         */
        get dataSource(): string | undefined;
        /**
         * @stability stable
         */
        set dataSource(value: string | undefined);
        /**
         * @stability stable
         */
        resetDataSource(): void;
        /**
         * @stability stable
         */
        get dataSourceInput(): string | undefined;
        private _field?;
        /**
         * @stability stable
         */
        get field(): string;
        /**
         * @stability stable
         */
        set field(value: string);
        /**
         * @stability stable
         */
        get fieldInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kind?;
        /**
         * @stability stable
         */
        get kind(): string | undefined;
        /**
         * @stability stable
         */
        set kind(value: string | undefined);
        /**
         * @stability stable
         */
        resetKind(): void;
        /**
         * @stability stable
         */
        get kindInput(): string | undefined;
        private _requestTemplate?;
        /**
         * @stability stable
         */
        get requestTemplate(): string | undefined;
        /**
         * @stability stable
         */
        set requestTemplate(value: string | undefined);
        /**
         * @stability stable
         */
        resetRequestTemplate(): void;
        /**
         * @stability stable
         */
        get requestTemplateInput(): string | undefined;
        private _responseTemplate?;
        /**
         * @stability stable
         */
        get responseTemplate(): string | undefined;
        /**
         * @stability stable
         */
        set responseTemplate(value: string | undefined);
        /**
         * @stability stable
         */
        resetResponseTemplate(): void;
        /**
         * @stability stable
         */
        get responseTemplateInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _cachingConfig?;
        private __cachingConfigOutput;
        /**
         * @stability stable
         */
        get cachingConfig(): AppsyncResolverCachingConfigOutputReference;
        /**
         * @stability stable
         */
        putCachingConfig(value: AppsyncResolverCachingConfig | undefined): void;
        /**
         * @stability stable
         */
        resetCachingConfig(): void;
        /**
         * @stability stable
         */
        get cachingConfigInput(): AppsyncResolverCachingConfig | undefined;
        private _pipelineConfig?;
        private __pipelineConfigOutput;
        /**
         * @stability stable
         */
        get pipelineConfig(): AppsyncResolverPipelineConfigOutputReference;
        /**
         * @stability stable
         */
        putPipelineConfig(value: AppsyncResolverPipelineConfig | undefined): void;
        /**
         * @stability stable
         */
        resetPipelineConfig(): void;
        /**
         * @stability stable
         */
        get pipelineConfigInput(): AppsyncResolverPipelineConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
