import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* Amazon Athena
*/
export declare namespace Athena {
    /**
     * @stability stable
     */
    interface AthenaDatabaseConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html#bucket AthenaDatabase#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html#force_destroy AthenaDatabase#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html#name AthenaDatabase#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * encryption_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html#encryption_configuration AthenaDatabase#encryption_configuration}
         *
         * @stability stable
         */
        readonly encryptionConfiguration?: AthenaDatabaseEncryptionConfiguration;
    }
    /**
     * @stability stable
     */
    interface AthenaDatabaseEncryptionConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html#encryption_option AthenaDatabase#encryption_option}.
         *
         * @stability stable
         */
        readonly encryptionOption: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html#kms_key AthenaDatabase#kms_key}.
         *
         * @stability stable
         */
        readonly kmsKey?: string;
    }
    /**
     * @stability stable
     */
    class AthenaDatabaseEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _encryptionOption?;
        /**
         * @stability stable
         */
        get encryptionOption(): string;
        /**
         * @stability stable
         */
        set encryptionOption(value: string);
        /**
         * @stability stable
         */
        get encryptionOptionInput(): string | undefined;
        private _kmsKey?;
        /**
         * @stability stable
         */
        get kmsKey(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKey(): void;
        /**
         * @stability stable
         */
        get kmsKeyInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html aws_athena_database}.
     *
     * @stability stable
     */
    class AthenaDatabase extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/athena_database.html aws_athena_database} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AthenaDatabaseConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _encryptionConfiguration?;
        private __encryptionConfigurationOutput;
        /**
         * @stability stable
         */
        get encryptionConfiguration(): AthenaDatabaseEncryptionConfigurationOutputReference;
        /**
         * @stability stable
         */
        putEncryptionConfiguration(value: AthenaDatabaseEncryptionConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetEncryptionConfiguration(): void;
        /**
         * @stability stable
         */
        get encryptionConfigurationInput(): AthenaDatabaseEncryptionConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AthenaNamedQueryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_named_query.html#database AthenaNamedQuery#database}.
         *
         * @stability stable
         */
        readonly database: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_named_query.html#description AthenaNamedQuery#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_named_query.html#name AthenaNamedQuery#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_named_query.html#query AthenaNamedQuery#query}.
         *
         * @stability stable
         */
        readonly query: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_named_query.html#workgroup AthenaNamedQuery#workgroup}.
         *
         * @stability stable
         */
        readonly workgroup?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/athena_named_query.html aws_athena_named_query}.
     *
     * @stability stable
     */
    class AthenaNamedQuery extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/athena_named_query.html aws_athena_named_query} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AthenaNamedQueryConfig);
        private _database?;
        /**
         * @stability stable
         */
        get database(): string;
        /**
         * @stability stable
         */
        set database(value: string);
        /**
         * @stability stable
         */
        get databaseInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _query?;
        /**
         * @stability stable
         */
        get query(): string;
        /**
         * @stability stable
         */
        set query(value: string);
        /**
         * @stability stable
         */
        get queryInput(): string | undefined;
        private _workgroup?;
        /**
         * @stability stable
         */
        get workgroup(): string | undefined;
        /**
         * @stability stable
         */
        set workgroup(value: string | undefined);
        /**
         * @stability stable
         */
        resetWorkgroup(): void;
        /**
         * @stability stable
         */
        get workgroupInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AthenaWorkgroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#description AthenaWorkgroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#force_destroy AthenaWorkgroup#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#name AthenaWorkgroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#state AthenaWorkgroup#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#tags AthenaWorkgroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#tags_all AthenaWorkgroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#configuration AthenaWorkgroup#configuration}
         *
         * @stability stable
         */
        readonly configuration?: AthenaWorkgroupConfiguration;
    }
    /**
     * @stability stable
     */
    interface AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#encryption_option AthenaWorkgroup#encryption_option}.
         *
         * @stability stable
         */
        readonly encryptionOption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#kms_key_arn AthenaWorkgroup#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
    }
    /**
     * @stability stable
     */
    class AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _encryptionOption?;
        /**
         * @stability stable
         */
        get encryptionOption(): string | undefined;
        /**
         * @stability stable
         */
        set encryptionOption(value: string | undefined);
        /**
         * @stability stable
         */
        resetEncryptionOption(): void;
        /**
         * @stability stable
         */
        get encryptionOptionInput(): string | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AthenaWorkgroupConfigurationResultConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#output_location AthenaWorkgroup#output_location}.
         *
         * @stability stable
         */
        readonly outputLocation?: string;
        /**
         * encryption_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#encryption_configuration AthenaWorkgroup#encryption_configuration}
         *
         * @stability stable
         */
        readonly encryptionConfiguration?: AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration;
    }
    /**
     * @stability stable
     */
    class AthenaWorkgroupConfigurationResultConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _outputLocation?;
        /**
         * @stability stable
         */
        get outputLocation(): string | undefined;
        /**
         * @stability stable
         */
        set outputLocation(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutputLocation(): void;
        /**
         * @stability stable
         */
        get outputLocationInput(): string | undefined;
        private _encryptionConfiguration?;
        private __encryptionConfigurationOutput;
        /**
         * @stability stable
         */
        get encryptionConfiguration(): AthenaWorkgroupConfigurationResultConfigurationEncryptionConfigurationOutputReference;
        /**
         * @stability stable
         */
        putEncryptionConfiguration(value: AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetEncryptionConfiguration(): void;
        /**
         * @stability stable
         */
        get encryptionConfigurationInput(): AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration | undefined;
    }
    /**
     * @stability stable
     */
    interface AthenaWorkgroupConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#bytes_scanned_cutoff_per_query AthenaWorkgroup#bytes_scanned_cutoff_per_query}.
         *
         * @stability stable
         */
        readonly bytesScannedCutoffPerQuery?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#enforce_workgroup_configuration AthenaWorkgroup#enforce_workgroup_configuration}.
         *
         * @stability stable
         */
        readonly enforceWorkgroupConfiguration?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#publish_cloudwatch_metrics_enabled AthenaWorkgroup#publish_cloudwatch_metrics_enabled}.
         *
         * @stability stable
         */
        readonly publishCloudwatchMetricsEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#requester_pays_enabled AthenaWorkgroup#requester_pays_enabled}.
         *
         * @stability stable
         */
        readonly requesterPaysEnabled?: boolean | cdktf.IResolvable;
        /**
         * result_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html#result_configuration AthenaWorkgroup#result_configuration}
         *
         * @stability stable
         */
        readonly resultConfiguration?: AthenaWorkgroupConfigurationResultConfiguration;
    }
    /**
     * @stability stable
     */
    class AthenaWorkgroupConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bytesScannedCutoffPerQuery?;
        /**
         * @stability stable
         */
        get bytesScannedCutoffPerQuery(): number | undefined;
        /**
         * @stability stable
         */
        set bytesScannedCutoffPerQuery(value: number | undefined);
        /**
         * @stability stable
         */
        resetBytesScannedCutoffPerQuery(): void;
        /**
         * @stability stable
         */
        get bytesScannedCutoffPerQueryInput(): number | undefined;
        private _enforceWorkgroupConfiguration?;
        /**
         * @stability stable
         */
        get enforceWorkgroupConfiguration(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enforceWorkgroupConfiguration(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnforceWorkgroupConfiguration(): void;
        /**
         * @stability stable
         */
        get enforceWorkgroupConfigurationInput(): boolean | cdktf.IResolvable | undefined;
        private _publishCloudwatchMetricsEnabled?;
        /**
         * @stability stable
         */
        get publishCloudwatchMetricsEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set publishCloudwatchMetricsEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPublishCloudwatchMetricsEnabled(): void;
        /**
         * @stability stable
         */
        get publishCloudwatchMetricsEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _requesterPaysEnabled?;
        /**
         * @stability stable
         */
        get requesterPaysEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requesterPaysEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequesterPaysEnabled(): void;
        /**
         * @stability stable
         */
        get requesterPaysEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _resultConfiguration?;
        private __resultConfigurationOutput;
        /**
         * @stability stable
         */
        get resultConfiguration(): AthenaWorkgroupConfigurationResultConfigurationOutputReference;
        /**
         * @stability stable
         */
        putResultConfiguration(value: AthenaWorkgroupConfigurationResultConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetResultConfiguration(): void;
        /**
         * @stability stable
         */
        get resultConfigurationInput(): AthenaWorkgroupConfigurationResultConfiguration | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html aws_athena_workgroup}.
     *
     * @stability stable
     */
    class AthenaWorkgroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/athena_workgroup.html aws_athena_workgroup} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AthenaWorkgroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _configuration?;
        private __configurationOutput;
        /**
         * @stability stable
         */
        get configuration(): AthenaWorkgroupConfigurationOutputReference;
        /**
         * @stability stable
         */
        putConfiguration(value: AthenaWorkgroupConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetConfiguration(): void;
        /**
         * @stability stable
         */
        get configurationInput(): AthenaWorkgroupConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
