import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Auto Scaling
*/
export declare namespace AutoScaling {
    /**
     * @stability stable
     */
    interface AutoscalingAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_attachment.html#alb_target_group_arn AutoscalingAttachment#alb_target_group_arn}.
         *
         * @stability stable
         */
        readonly albTargetGroupArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_attachment.html#autoscaling_group_name AutoscalingAttachment#autoscaling_group_name}.
         *
         * @stability stable
         */
        readonly autoscalingGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_attachment.html#elb AutoscalingAttachment#elb}.
         *
         * @stability stable
         */
        readonly elb?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_attachment.html aws_autoscaling_attachment}.
     *
     * @stability stable
     */
    class AutoscalingAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_attachment.html aws_autoscaling_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AutoscalingAttachmentConfig);
        private _albTargetGroupArn?;
        /**
         * @stability stable
         */
        get albTargetGroupArn(): string | undefined;
        /**
         * @stability stable
         */
        set albTargetGroupArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetAlbTargetGroupArn(): void;
        /**
         * @stability stable
         */
        get albTargetGroupArnInput(): string | undefined;
        private _autoscalingGroupName?;
        /**
         * @stability stable
         */
        get autoscalingGroupName(): string;
        /**
         * @stability stable
         */
        set autoscalingGroupName(value: string);
        /**
         * @stability stable
         */
        get autoscalingGroupNameInput(): string | undefined;
        private _elb?;
        /**
         * @stability stable
         */
        get elb(): string | undefined;
        /**
         * @stability stable
         */
        set elb(value: string | undefined);
        /**
         * @stability stable
         */
        resetElb(): void;
        /**
         * @stability stable
         */
        get elbInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#availability_zones AutoscalingGroup#availability_zones}.
         *
         * @stability stable
         */
        readonly availabilityZones?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#capacity_rebalance AutoscalingGroup#capacity_rebalance}.
         *
         * @stability stable
         */
        readonly capacityRebalance?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#default_cooldown AutoscalingGroup#default_cooldown}.
         *
         * @stability stable
         */
        readonly defaultCooldown?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#desired_capacity AutoscalingGroup#desired_capacity}.
         *
         * @stability stable
         */
        readonly desiredCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#enabled_metrics AutoscalingGroup#enabled_metrics}.
         *
         * @stability stable
         */
        readonly enabledMetrics?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#force_delete AutoscalingGroup#force_delete}.
         *
         * @stability stable
         */
        readonly forceDelete?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#force_delete_warm_pool AutoscalingGroup#force_delete_warm_pool}.
         *
         * @stability stable
         */
        readonly forceDeleteWarmPool?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#health_check_grace_period AutoscalingGroup#health_check_grace_period}.
         *
         * @stability stable
         */
        readonly healthCheckGracePeriod?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#health_check_type AutoscalingGroup#health_check_type}.
         *
         * @stability stable
         */
        readonly healthCheckType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_configuration AutoscalingGroup#launch_configuration}.
         *
         * @stability stable
         */
        readonly launchConfiguration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#load_balancers AutoscalingGroup#load_balancers}.
         *
         * @stability stable
         */
        readonly loadBalancers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#max_instance_lifetime AutoscalingGroup#max_instance_lifetime}.
         *
         * @stability stable
         */
        readonly maxInstanceLifetime?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#max_size AutoscalingGroup#max_size}.
         *
         * @stability stable
         */
        readonly maxSize: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#metrics_granularity AutoscalingGroup#metrics_granularity}.
         *
         * @stability stable
         */
        readonly metricsGranularity?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#min_elb_capacity AutoscalingGroup#min_elb_capacity}.
         *
         * @stability stable
         */
        readonly minElbCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#min_size AutoscalingGroup#min_size}.
         *
         * @stability stable
         */
        readonly minSize: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#name AutoscalingGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#name_prefix AutoscalingGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#placement_group AutoscalingGroup#placement_group}.
         *
         * @stability stable
         */
        readonly placementGroup?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#protect_from_scale_in AutoscalingGroup#protect_from_scale_in}.
         *
         * @stability stable
         */
        readonly protectFromScaleIn?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#service_linked_role_arn AutoscalingGroup#service_linked_role_arn}.
         *
         * @stability stable
         */
        readonly serviceLinkedRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#suspended_processes AutoscalingGroup#suspended_processes}.
         *
         * @stability stable
         */
        readonly suspendedProcesses?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#tags AutoscalingGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#target_group_arns AutoscalingGroup#target_group_arns}.
         *
         * @stability stable
         */
        readonly targetGroupArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#termination_policies AutoscalingGroup#termination_policies}.
         *
         * @stability stable
         */
        readonly terminationPolicies?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#vpc_zone_identifier AutoscalingGroup#vpc_zone_identifier}.
         *
         * @stability stable
         */
        readonly vpcZoneIdentifier?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#wait_for_capacity_timeout AutoscalingGroup#wait_for_capacity_timeout}.
         *
         * @stability stable
         */
        readonly waitForCapacityTimeout?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#wait_for_elb_capacity AutoscalingGroup#wait_for_elb_capacity}.
         *
         * @stability stable
         */
        readonly waitForElbCapacity?: number;
        /**
         * initial_lifecycle_hook block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#initial_lifecycle_hook AutoscalingGroup#initial_lifecycle_hook}
         *
         * @stability stable
         */
        readonly initialLifecycleHook?: AutoscalingGroupInitialLifecycleHook[];
        /**
         * instance_refresh block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#instance_refresh AutoscalingGroup#instance_refresh}
         *
         * @stability stable
         */
        readonly instanceRefresh?: AutoscalingGroupInstanceRefresh;
        /**
         * launch_template block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template AutoscalingGroup#launch_template}
         *
         * @stability stable
         */
        readonly launchTemplate?: AutoscalingGroupLaunchTemplate;
        /**
         * mixed_instances_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#mixed_instances_policy AutoscalingGroup#mixed_instances_policy}
         *
         * @stability stable
         */
        readonly mixedInstancesPolicy?: AutoscalingGroupMixedInstancesPolicy;
        /**
         * tag block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#tag AutoscalingGroup#tag}
         *
         * @stability stable
         */
        readonly tag?: AutoscalingGroupTag[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#timeouts AutoscalingGroup#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: AutoscalingGroupTimeouts;
        /**
         * warm_pool block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#warm_pool AutoscalingGroup#warm_pool}
         *
         * @stability stable
         */
        readonly warmPool?: AutoscalingGroupWarmPool;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupInitialLifecycleHook {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#default_result AutoscalingGroup#default_result}.
         *
         * @stability stable
         */
        readonly defaultResult?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#heartbeat_timeout AutoscalingGroup#heartbeat_timeout}.
         *
         * @stability stable
         */
        readonly heartbeatTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#lifecycle_transition AutoscalingGroup#lifecycle_transition}.
         *
         * @stability stable
         */
        readonly lifecycleTransition: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#name AutoscalingGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#notification_metadata AutoscalingGroup#notification_metadata}.
         *
         * @stability stable
         */
        readonly notificationMetadata?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#notification_target_arn AutoscalingGroup#notification_target_arn}.
         *
         * @stability stable
         */
        readonly notificationTargetArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#role_arn AutoscalingGroup#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn?: string;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupInstanceRefreshPreferences {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#instance_warmup AutoscalingGroup#instance_warmup}.
         *
         * @stability stable
         */
        readonly instanceWarmup?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#min_healthy_percentage AutoscalingGroup#min_healthy_percentage}.
         *
         * @stability stable
         */
        readonly minHealthyPercentage?: number;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupInstanceRefreshPreferencesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceWarmup?;
        /**
         * @stability stable
         */
        get instanceWarmup(): string | undefined;
        /**
         * @stability stable
         */
        set instanceWarmup(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceWarmup(): void;
        /**
         * @stability stable
         */
        get instanceWarmupInput(): string | undefined;
        private _minHealthyPercentage?;
        /**
         * @stability stable
         */
        get minHealthyPercentage(): number | undefined;
        /**
         * @stability stable
         */
        set minHealthyPercentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinHealthyPercentage(): void;
        /**
         * @stability stable
         */
        get minHealthyPercentageInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupInstanceRefresh {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#strategy AutoscalingGroup#strategy}.
         *
         * @stability stable
         */
        readonly strategy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#triggers AutoscalingGroup#triggers}.
         *
         * @stability stable
         */
        readonly triggers?: string[];
        /**
         * preferences block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#preferences AutoscalingGroup#preferences}
         *
         * @stability stable
         */
        readonly preferences?: AutoscalingGroupInstanceRefreshPreferences;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupInstanceRefreshOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _strategy?;
        /**
         * @stability stable
         */
        get strategy(): string;
        /**
         * @stability stable
         */
        set strategy(value: string);
        /**
         * @stability stable
         */
        get strategyInput(): string | undefined;
        private _triggers?;
        /**
         * @stability stable
         */
        get triggers(): string[] | undefined;
        /**
         * @stability stable
         */
        set triggers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTriggers(): void;
        /**
         * @stability stable
         */
        get triggersInput(): string[] | undefined;
        private _preferences?;
        private __preferencesOutput;
        /**
         * @stability stable
         */
        get preferences(): AutoscalingGroupInstanceRefreshPreferencesOutputReference;
        /**
         * @stability stable
         */
        putPreferences(value: AutoscalingGroupInstanceRefreshPreferences | undefined): void;
        /**
         * @stability stable
         */
        resetPreferences(): void;
        /**
         * @stability stable
         */
        get preferencesInput(): AutoscalingGroupInstanceRefreshPreferences | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupLaunchTemplate {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#id AutoscalingGroup#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#name AutoscalingGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#version AutoscalingGroup#version}.
         *
         * @stability stable
         */
        readonly version?: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupLaunchTemplateOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupMixedInstancesPolicyInstancesDistribution {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#on_demand_allocation_strategy AutoscalingGroup#on_demand_allocation_strategy}.
         *
         * @stability stable
         */
        readonly onDemandAllocationStrategy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#on_demand_base_capacity AutoscalingGroup#on_demand_base_capacity}.
         *
         * @stability stable
         */
        readonly onDemandBaseCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#on_demand_percentage_above_base_capacity AutoscalingGroup#on_demand_percentage_above_base_capacity}.
         *
         * @stability stable
         */
        readonly onDemandPercentageAboveBaseCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#spot_allocation_strategy AutoscalingGroup#spot_allocation_strategy}.
         *
         * @stability stable
         */
        readonly spotAllocationStrategy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#spot_instance_pools AutoscalingGroup#spot_instance_pools}.
         *
         * @stability stable
         */
        readonly spotInstancePools?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#spot_max_price AutoscalingGroup#spot_max_price}.
         *
         * @stability stable
         */
        readonly spotMaxPrice?: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupMixedInstancesPolicyInstancesDistributionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _onDemandAllocationStrategy?;
        /**
         * @stability stable
         */
        get onDemandAllocationStrategy(): string | undefined;
        /**
         * @stability stable
         */
        set onDemandAllocationStrategy(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnDemandAllocationStrategy(): void;
        /**
         * @stability stable
         */
        get onDemandAllocationStrategyInput(): string | undefined;
        private _onDemandBaseCapacity?;
        /**
         * @stability stable
         */
        get onDemandBaseCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set onDemandBaseCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetOnDemandBaseCapacity(): void;
        /**
         * @stability stable
         */
        get onDemandBaseCapacityInput(): number | undefined;
        private _onDemandPercentageAboveBaseCapacity?;
        /**
         * @stability stable
         */
        get onDemandPercentageAboveBaseCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set onDemandPercentageAboveBaseCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetOnDemandPercentageAboveBaseCapacity(): void;
        /**
         * @stability stable
         */
        get onDemandPercentageAboveBaseCapacityInput(): number | undefined;
        private _spotAllocationStrategy?;
        /**
         * @stability stable
         */
        get spotAllocationStrategy(): string | undefined;
        /**
         * @stability stable
         */
        set spotAllocationStrategy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSpotAllocationStrategy(): void;
        /**
         * @stability stable
         */
        get spotAllocationStrategyInput(): string | undefined;
        private _spotInstancePools?;
        /**
         * @stability stable
         */
        get spotInstancePools(): number | undefined;
        /**
         * @stability stable
         */
        set spotInstancePools(value: number | undefined);
        /**
         * @stability stable
         */
        resetSpotInstancePools(): void;
        /**
         * @stability stable
         */
        get spotInstancePoolsInput(): number | undefined;
        private _spotMaxPrice?;
        /**
         * @stability stable
         */
        get spotMaxPrice(): string | undefined;
        /**
         * @stability stable
         */
        set spotMaxPrice(value: string | undefined);
        /**
         * @stability stable
         */
        resetSpotMaxPrice(): void;
        /**
         * @stability stable
         */
        get spotMaxPriceInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template_id AutoscalingGroup#launch_template_id}.
         *
         * @stability stable
         */
        readonly launchTemplateId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template_name AutoscalingGroup#launch_template_name}.
         *
         * @stability stable
         */
        readonly launchTemplateName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#version AutoscalingGroup#version}.
         *
         * @stability stable
         */
        readonly version?: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _launchTemplateId?;
        /**
         * @stability stable
         */
        get launchTemplateId(): string | undefined;
        /**
         * @stability stable
         */
        set launchTemplateId(value: string | undefined);
        /**
         * @stability stable
         */
        resetLaunchTemplateId(): void;
        /**
         * @stability stable
         */
        get launchTemplateIdInput(): string | undefined;
        private _launchTemplateName?;
        /**
         * @stability stable
         */
        get launchTemplateName(): string | undefined;
        /**
         * @stability stable
         */
        set launchTemplateName(value: string | undefined);
        /**
         * @stability stable
         */
        resetLaunchTemplateName(): void;
        /**
         * @stability stable
         */
        get launchTemplateNameInput(): string | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverrideLaunchTemplateSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template_id AutoscalingGroup#launch_template_id}.
         *
         * @stability stable
         */
        readonly launchTemplateId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template_name AutoscalingGroup#launch_template_name}.
         *
         * @stability stable
         */
        readonly launchTemplateName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#version AutoscalingGroup#version}.
         *
         * @stability stable
         */
        readonly version?: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverrideLaunchTemplateSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _launchTemplateId?;
        /**
         * @stability stable
         */
        get launchTemplateId(): string | undefined;
        /**
         * @stability stable
         */
        set launchTemplateId(value: string | undefined);
        /**
         * @stability stable
         */
        resetLaunchTemplateId(): void;
        /**
         * @stability stable
         */
        get launchTemplateIdInput(): string | undefined;
        private _launchTemplateName?;
        /**
         * @stability stable
         */
        get launchTemplateName(): string | undefined;
        /**
         * @stability stable
         */
        set launchTemplateName(value: string | undefined);
        /**
         * @stability stable
         */
        resetLaunchTemplateName(): void;
        /**
         * @stability stable
         */
        get launchTemplateNameInput(): string | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#instance_type AutoscalingGroup#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#weighted_capacity AutoscalingGroup#weighted_capacity}.
         *
         * @stability stable
         */
        readonly weightedCapacity?: string;
        /**
         * launch_template_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template_specification AutoscalingGroup#launch_template_specification}
         *
         * @stability stable
         */
        readonly launchTemplateSpecification?: AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverrideLaunchTemplateSpecification;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupMixedInstancesPolicyLaunchTemplate {
        /**
         * launch_template_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template_specification AutoscalingGroup#launch_template_specification}
         *
         * @stability stable
         */
        readonly launchTemplateSpecification: AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification;
        /**
         * override block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#override AutoscalingGroup#override}
         *
         * @stability stable
         */
        readonly override?: AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride[];
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupMixedInstancesPolicyLaunchTemplateOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _launchTemplateSpecification?;
        private __launchTemplateSpecificationOutput;
        /**
         * @stability stable
         */
        get launchTemplateSpecification(): AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecificationOutputReference;
        /**
         * @stability stable
         */
        putLaunchTemplateSpecification(value: AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification): void;
        /**
         * @stability stable
         */
        get launchTemplateSpecificationInput(): AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification | undefined;
        private _override?;
        /**
         * @stability stable
         */
        get override(): AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride[] | undefined;
        /**
         * @stability stable
         */
        set override(value: AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride[] | undefined);
        /**
         * @stability stable
         */
        resetOverride(): void;
        /**
         * @stability stable
         */
        get overrideInput(): AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupMixedInstancesPolicy {
        /**
         * instances_distribution block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#instances_distribution AutoscalingGroup#instances_distribution}
         *
         * @stability stable
         */
        readonly instancesDistribution?: AutoscalingGroupMixedInstancesPolicyInstancesDistribution;
        /**
         * launch_template block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#launch_template AutoscalingGroup#launch_template}
         *
         * @stability stable
         */
        readonly launchTemplate: AutoscalingGroupMixedInstancesPolicyLaunchTemplate;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupMixedInstancesPolicyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instancesDistribution?;
        private __instancesDistributionOutput;
        /**
         * @stability stable
         */
        get instancesDistribution(): AutoscalingGroupMixedInstancesPolicyInstancesDistributionOutputReference;
        /**
         * @stability stable
         */
        putInstancesDistribution(value: AutoscalingGroupMixedInstancesPolicyInstancesDistribution | undefined): void;
        /**
         * @stability stable
         */
        resetInstancesDistribution(): void;
        /**
         * @stability stable
         */
        get instancesDistributionInput(): AutoscalingGroupMixedInstancesPolicyInstancesDistribution | undefined;
        private _launchTemplate?;
        private __launchTemplateOutput;
        /**
         * @stability stable
         */
        get launchTemplate(): AutoscalingGroupMixedInstancesPolicyLaunchTemplateOutputReference;
        /**
         * @stability stable
         */
        putLaunchTemplate(value: AutoscalingGroupMixedInstancesPolicyLaunchTemplate): void;
        /**
         * @stability stable
         */
        get launchTemplateInput(): AutoscalingGroupMixedInstancesPolicyLaunchTemplate | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupTag {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#key AutoscalingGroup#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#propagate_at_launch AutoscalingGroup#propagate_at_launch}.
         *
         * @stability stable
         */
        readonly propagateAtLaunch: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#value AutoscalingGroup#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#delete AutoscalingGroup#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupWarmPool {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#max_group_prepared_capacity AutoscalingGroup#max_group_prepared_capacity}.
         *
         * @stability stable
         */
        readonly maxGroupPreparedCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#min_size AutoscalingGroup#min_size}.
         *
         * @stability stable
         */
        readonly minSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html#pool_state AutoscalingGroup#pool_state}.
         *
         * @stability stable
         */
        readonly poolState?: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupWarmPoolOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _maxGroupPreparedCapacity?;
        /**
         * @stability stable
         */
        get maxGroupPreparedCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set maxGroupPreparedCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxGroupPreparedCapacity(): void;
        /**
         * @stability stable
         */
        get maxGroupPreparedCapacityInput(): number | undefined;
        private _minSize?;
        /**
         * @stability stable
         */
        get minSize(): number | undefined;
        /**
         * @stability stable
         */
        set minSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinSize(): void;
        /**
         * @stability stable
         */
        get minSizeInput(): number | undefined;
        private _poolState?;
        /**
         * @stability stable
         */
        get poolState(): string | undefined;
        /**
         * @stability stable
         */
        set poolState(value: string | undefined);
        /**
         * @stability stable
         */
        resetPoolState(): void;
        /**
         * @stability stable
         */
        get poolStateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html aws_autoscaling_group}.
     *
     * @stability stable
     */
    class AutoscalingGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group.html aws_autoscaling_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AutoscalingGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _availabilityZones?;
        /**
         * @stability stable
         */
        get availabilityZones(): string[] | undefined;
        /**
         * @stability stable
         */
        set availabilityZones(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZones(): void;
        /**
         * @stability stable
         */
        get availabilityZonesInput(): string[] | undefined;
        private _capacityRebalance?;
        /**
         * @stability stable
         */
        get capacityRebalance(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set capacityRebalance(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCapacityRebalance(): void;
        /**
         * @stability stable
         */
        get capacityRebalanceInput(): boolean | cdktf.IResolvable | undefined;
        private _defaultCooldown?;
        /**
         * @stability stable
         */
        get defaultCooldown(): number | undefined;
        /**
         * @stability stable
         */
        set defaultCooldown(value: number | undefined);
        /**
         * @stability stable
         */
        resetDefaultCooldown(): void;
        /**
         * @stability stable
         */
        get defaultCooldownInput(): number | undefined;
        private _desiredCapacity?;
        /**
         * @stability stable
         */
        get desiredCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set desiredCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetDesiredCapacity(): void;
        /**
         * @stability stable
         */
        get desiredCapacityInput(): number | undefined;
        private _enabledMetrics?;
        /**
         * @stability stable
         */
        get enabledMetrics(): string[] | undefined;
        /**
         * @stability stable
         */
        set enabledMetrics(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEnabledMetrics(): void;
        /**
         * @stability stable
         */
        get enabledMetricsInput(): string[] | undefined;
        private _forceDelete?;
        /**
         * @stability stable
         */
        get forceDelete(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDelete(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDelete(): void;
        /**
         * @stability stable
         */
        get forceDeleteInput(): boolean | cdktf.IResolvable | undefined;
        private _forceDeleteWarmPool?;
        /**
         * @stability stable
         */
        get forceDeleteWarmPool(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDeleteWarmPool(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDeleteWarmPool(): void;
        /**
         * @stability stable
         */
        get forceDeleteWarmPoolInput(): boolean | cdktf.IResolvable | undefined;
        private _healthCheckGracePeriod?;
        /**
         * @stability stable
         */
        get healthCheckGracePeriod(): number | undefined;
        /**
         * @stability stable
         */
        set healthCheckGracePeriod(value: number | undefined);
        /**
         * @stability stable
         */
        resetHealthCheckGracePeriod(): void;
        /**
         * @stability stable
         */
        get healthCheckGracePeriodInput(): number | undefined;
        private _healthCheckType?;
        /**
         * @stability stable
         */
        get healthCheckType(): string | undefined;
        /**
         * @stability stable
         */
        set healthCheckType(value: string | undefined);
        /**
         * @stability stable
         */
        resetHealthCheckType(): void;
        /**
         * @stability stable
         */
        get healthCheckTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _launchConfiguration?;
        /**
         * @stability stable
         */
        get launchConfiguration(): string | undefined;
        /**
         * @stability stable
         */
        set launchConfiguration(value: string | undefined);
        /**
         * @stability stable
         */
        resetLaunchConfiguration(): void;
        /**
         * @stability stable
         */
        get launchConfigurationInput(): string | undefined;
        private _loadBalancers?;
        /**
         * @stability stable
         */
        get loadBalancers(): string[] | undefined;
        /**
         * @stability stable
         */
        set loadBalancers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancers(): void;
        /**
         * @stability stable
         */
        get loadBalancersInput(): string[] | undefined;
        private _maxInstanceLifetime?;
        /**
         * @stability stable
         */
        get maxInstanceLifetime(): number | undefined;
        /**
         * @stability stable
         */
        set maxInstanceLifetime(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxInstanceLifetime(): void;
        /**
         * @stability stable
         */
        get maxInstanceLifetimeInput(): number | undefined;
        private _maxSize?;
        /**
         * @stability stable
         */
        get maxSize(): number;
        /**
         * @stability stable
         */
        set maxSize(value: number);
        /**
         * @stability stable
         */
        get maxSizeInput(): number | undefined;
        private _metricsGranularity?;
        /**
         * @stability stable
         */
        get metricsGranularity(): string | undefined;
        /**
         * @stability stable
         */
        set metricsGranularity(value: string | undefined);
        /**
         * @stability stable
         */
        resetMetricsGranularity(): void;
        /**
         * @stability stable
         */
        get metricsGranularityInput(): string | undefined;
        private _minElbCapacity?;
        /**
         * @stability stable
         */
        get minElbCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set minElbCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinElbCapacity(): void;
        /**
         * @stability stable
         */
        get minElbCapacityInput(): number | undefined;
        private _minSize?;
        /**
         * @stability stable
         */
        get minSize(): number;
        /**
         * @stability stable
         */
        set minSize(value: number);
        /**
         * @stability stable
         */
        get minSizeInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _placementGroup?;
        /**
         * @stability stable
         */
        get placementGroup(): string | undefined;
        /**
         * @stability stable
         */
        set placementGroup(value: string | undefined);
        /**
         * @stability stable
         */
        resetPlacementGroup(): void;
        /**
         * @stability stable
         */
        get placementGroupInput(): string | undefined;
        private _protectFromScaleIn?;
        /**
         * @stability stable
         */
        get protectFromScaleIn(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set protectFromScaleIn(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetProtectFromScaleIn(): void;
        /**
         * @stability stable
         */
        get protectFromScaleInInput(): boolean | cdktf.IResolvable | undefined;
        private _serviceLinkedRoleArn?;
        /**
         * @stability stable
         */
        get serviceLinkedRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set serviceLinkedRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceLinkedRoleArn(): void;
        /**
         * @stability stable
         */
        get serviceLinkedRoleArnInput(): string | undefined;
        private _suspendedProcesses?;
        /**
         * @stability stable
         */
        get suspendedProcesses(): string[] | undefined;
        /**
         * @stability stable
         */
        set suspendedProcesses(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSuspendedProcesses(): void;
        /**
         * @stability stable
         */
        get suspendedProcessesInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetGroupArns?;
        /**
         * @stability stable
         */
        get targetGroupArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set targetGroupArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTargetGroupArns(): void;
        /**
         * @stability stable
         */
        get targetGroupArnsInput(): string[] | undefined;
        private _terminationPolicies?;
        /**
         * @stability stable
         */
        get terminationPolicies(): string[] | undefined;
        /**
         * @stability stable
         */
        set terminationPolicies(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTerminationPolicies(): void;
        /**
         * @stability stable
         */
        get terminationPoliciesInput(): string[] | undefined;
        private _vpcZoneIdentifier?;
        /**
         * @stability stable
         */
        get vpcZoneIdentifier(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcZoneIdentifier(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcZoneIdentifier(): void;
        /**
         * @stability stable
         */
        get vpcZoneIdentifierInput(): string[] | undefined;
        private _waitForCapacityTimeout?;
        /**
         * @stability stable
         */
        get waitForCapacityTimeout(): string | undefined;
        /**
         * @stability stable
         */
        set waitForCapacityTimeout(value: string | undefined);
        /**
         * @stability stable
         */
        resetWaitForCapacityTimeout(): void;
        /**
         * @stability stable
         */
        get waitForCapacityTimeoutInput(): string | undefined;
        private _waitForElbCapacity?;
        /**
         * @stability stable
         */
        get waitForElbCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set waitForElbCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetWaitForElbCapacity(): void;
        /**
         * @stability stable
         */
        get waitForElbCapacityInput(): number | undefined;
        private _initialLifecycleHook?;
        /**
         * @stability stable
         */
        get initialLifecycleHook(): AutoscalingGroupInitialLifecycleHook[] | undefined;
        /**
         * @stability stable
         */
        set initialLifecycleHook(value: AutoscalingGroupInitialLifecycleHook[] | undefined);
        /**
         * @stability stable
         */
        resetInitialLifecycleHook(): void;
        /**
         * @stability stable
         */
        get initialLifecycleHookInput(): AutoscalingGroupInitialLifecycleHook[] | undefined;
        private _instanceRefresh?;
        private __instanceRefreshOutput;
        /**
         * @stability stable
         */
        get instanceRefresh(): AutoscalingGroupInstanceRefreshOutputReference;
        /**
         * @stability stable
         */
        putInstanceRefresh(value: AutoscalingGroupInstanceRefresh | undefined): void;
        /**
         * @stability stable
         */
        resetInstanceRefresh(): void;
        /**
         * @stability stable
         */
        get instanceRefreshInput(): AutoscalingGroupInstanceRefresh | undefined;
        private _launchTemplate?;
        private __launchTemplateOutput;
        /**
         * @stability stable
         */
        get launchTemplate(): AutoscalingGroupLaunchTemplateOutputReference;
        /**
         * @stability stable
         */
        putLaunchTemplate(value: AutoscalingGroupLaunchTemplate | undefined): void;
        /**
         * @stability stable
         */
        resetLaunchTemplate(): void;
        /**
         * @stability stable
         */
        get launchTemplateInput(): AutoscalingGroupLaunchTemplate | undefined;
        private _mixedInstancesPolicy?;
        private __mixedInstancesPolicyOutput;
        /**
         * @stability stable
         */
        get mixedInstancesPolicy(): AutoscalingGroupMixedInstancesPolicyOutputReference;
        /**
         * @stability stable
         */
        putMixedInstancesPolicy(value: AutoscalingGroupMixedInstancesPolicy | undefined): void;
        /**
         * @stability stable
         */
        resetMixedInstancesPolicy(): void;
        /**
         * @stability stable
         */
        get mixedInstancesPolicyInput(): AutoscalingGroupMixedInstancesPolicy | undefined;
        private _tag?;
        /**
         * @stability stable
         */
        get tag(): AutoscalingGroupTag[] | undefined;
        /**
         * @stability stable
         */
        set tag(value: AutoscalingGroupTag[] | undefined);
        /**
         * @stability stable
         */
        resetTag(): void;
        /**
         * @stability stable
         */
        get tagInput(): AutoscalingGroupTag[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): AutoscalingGroupTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: AutoscalingGroupTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): AutoscalingGroupTimeouts | undefined;
        private _warmPool?;
        private __warmPoolOutput;
        /**
         * @stability stable
         */
        get warmPool(): AutoscalingGroupWarmPoolOutputReference;
        /**
         * @stability stable
         */
        putWarmPool(value: AutoscalingGroupWarmPool | undefined): void;
        /**
         * @stability stable
         */
        resetWarmPool(): void;
        /**
         * @stability stable
         */
        get warmPoolInput(): AutoscalingGroupWarmPool | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupTagAConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group_tag.html#autoscaling_group_name AutoscalingGroupTagA#autoscaling_group_name}.
         *
         * @stability stable
         */
        readonly autoscalingGroupName: string;
        /**
         * tag block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group_tag.html#tag AutoscalingGroupTagA#tag}
         *
         * @stability stable
         */
        readonly tag: AutoscalingGroupTagTag;
    }
    /**
     * @stability stable
     */
    interface AutoscalingGroupTagTag {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group_tag.html#key AutoscalingGroupTagA#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group_tag.html#propagate_at_launch AutoscalingGroupTagA#propagate_at_launch}.
         *
         * @stability stable
         */
        readonly propagateAtLaunch: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group_tag.html#value AutoscalingGroupTagA#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingGroupTagTagOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _key?;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        set key(value: string);
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _propagateAtLaunch?;
        /**
         * @stability stable
         */
        get propagateAtLaunch(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set propagateAtLaunch(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get propagateAtLaunchInput(): boolean | cdktf.IResolvable | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        set value(value: string);
        /**
         * @stability stable
         */
        get valueInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group_tag.html aws_autoscaling_group_tag}.
     *
     * @stability stable
     */
    class AutoscalingGroupTagA extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_group_tag.html aws_autoscaling_group_tag} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AutoscalingGroupTagAConfig);
        private _autoscalingGroupName?;
        /**
         * @stability stable
         */
        get autoscalingGroupName(): string;
        /**
         * @stability stable
         */
        set autoscalingGroupName(value: string);
        /**
         * @stability stable
         */
        get autoscalingGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tag?;
        private __tagOutput;
        /**
         * @stability stable
         */
        get tag(): AutoscalingGroupTagTagOutputReference;
        /**
         * @stability stable
         */
        putTag(value: AutoscalingGroupTagTag): void;
        /**
         * @stability stable
         */
        get tagInput(): AutoscalingGroupTagTag | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AutoscalingLifecycleHookConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#autoscaling_group_name AutoscalingLifecycleHook#autoscaling_group_name}.
         *
         * @stability stable
         */
        readonly autoscalingGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#default_result AutoscalingLifecycleHook#default_result}.
         *
         * @stability stable
         */
        readonly defaultResult?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#heartbeat_timeout AutoscalingLifecycleHook#heartbeat_timeout}.
         *
         * @stability stable
         */
        readonly heartbeatTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#lifecycle_transition AutoscalingLifecycleHook#lifecycle_transition}.
         *
         * @stability stable
         */
        readonly lifecycleTransition: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#name AutoscalingLifecycleHook#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#notification_metadata AutoscalingLifecycleHook#notification_metadata}.
         *
         * @stability stable
         */
        readonly notificationMetadata?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#notification_target_arn AutoscalingLifecycleHook#notification_target_arn}.
         *
         * @stability stable
         */
        readonly notificationTargetArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html#role_arn AutoscalingLifecycleHook#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html aws_autoscaling_lifecycle_hook}.
     *
     * @stability stable
     */
    class AutoscalingLifecycleHook extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_lifecycle_hook.html aws_autoscaling_lifecycle_hook} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AutoscalingLifecycleHookConfig);
        private _autoscalingGroupName?;
        /**
         * @stability stable
         */
        get autoscalingGroupName(): string;
        /**
         * @stability stable
         */
        set autoscalingGroupName(value: string);
        /**
         * @stability stable
         */
        get autoscalingGroupNameInput(): string | undefined;
        private _defaultResult?;
        /**
         * @stability stable
         */
        get defaultResult(): string | undefined;
        /**
         * @stability stable
         */
        set defaultResult(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefaultResult(): void;
        /**
         * @stability stable
         */
        get defaultResultInput(): string | undefined;
        private _heartbeatTimeout?;
        /**
         * @stability stable
         */
        get heartbeatTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set heartbeatTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetHeartbeatTimeout(): void;
        /**
         * @stability stable
         */
        get heartbeatTimeoutInput(): number | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _lifecycleTransition?;
        /**
         * @stability stable
         */
        get lifecycleTransition(): string;
        /**
         * @stability stable
         */
        set lifecycleTransition(value: string);
        /**
         * @stability stable
         */
        get lifecycleTransitionInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _notificationMetadata?;
        /**
         * @stability stable
         */
        get notificationMetadata(): string | undefined;
        /**
         * @stability stable
         */
        set notificationMetadata(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationMetadata(): void;
        /**
         * @stability stable
         */
        get notificationMetadataInput(): string | undefined;
        private _notificationTargetArn?;
        /**
         * @stability stable
         */
        get notificationTargetArn(): string | undefined;
        /**
         * @stability stable
         */
        set notificationTargetArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationTargetArn(): void;
        /**
         * @stability stable
         */
        get notificationTargetArnInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string | undefined;
        /**
         * @stability stable
         */
        set roleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetRoleArn(): void;
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AutoscalingNotificationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_notification.html#group_names AutoscalingNotification#group_names}.
         *
         * @stability stable
         */
        readonly groupNames: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_notification.html#notifications AutoscalingNotification#notifications}.
         *
         * @stability stable
         */
        readonly notifications: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_notification.html#topic_arn AutoscalingNotification#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_notification.html aws_autoscaling_notification}.
     *
     * @stability stable
     */
    class AutoscalingNotification extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_notification.html aws_autoscaling_notification} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AutoscalingNotificationConfig);
        private _groupNames?;
        /**
         * @stability stable
         */
        get groupNames(): string[];
        /**
         * @stability stable
         */
        set groupNames(value: string[]);
        /**
         * @stability stable
         */
        get groupNamesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _notifications?;
        /**
         * @stability stable
         */
        get notifications(): string[];
        /**
         * @stability stable
         */
        set notifications(value: string[]);
        /**
         * @stability stable
         */
        get notificationsInput(): string[] | undefined;
        private _topicArn?;
        /**
         * @stability stable
         */
        get topicArn(): string;
        /**
         * @stability stable
         */
        set topicArn(value: string);
        /**
         * @stability stable
         */
        get topicArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#adjustment_type AutoscalingPolicy#adjustment_type}.
         *
         * @stability stable
         */
        readonly adjustmentType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#autoscaling_group_name AutoscalingPolicy#autoscaling_group_name}.
         *
         * @stability stable
         */
        readonly autoscalingGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#cooldown AutoscalingPolicy#cooldown}.
         *
         * @stability stable
         */
        readonly cooldown?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#estimated_instance_warmup AutoscalingPolicy#estimated_instance_warmup}.
         *
         * @stability stable
         */
        readonly estimatedInstanceWarmup?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#metric_aggregation_type AutoscalingPolicy#metric_aggregation_type}.
         *
         * @stability stable
         */
        readonly metricAggregationType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#min_adjustment_magnitude AutoscalingPolicy#min_adjustment_magnitude}.
         *
         * @stability stable
         */
        readonly minAdjustmentMagnitude?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#name AutoscalingPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#policy_type AutoscalingPolicy#policy_type}.
         *
         * @stability stable
         */
        readonly policyType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#scaling_adjustment AutoscalingPolicy#scaling_adjustment}.
         *
         * @stability stable
         */
        readonly scalingAdjustment?: number;
        /**
         * predictive_scaling_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predictive_scaling_configuration AutoscalingPolicy#predictive_scaling_configuration}
         *
         * @stability stable
         */
        readonly predictiveScalingConfiguration?: AutoscalingPolicyPredictiveScalingConfiguration;
        /**
         * step_adjustment block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#step_adjustment AutoscalingPolicy#step_adjustment}
         *
         * @stability stable
         */
        readonly stepAdjustment?: AutoscalingPolicyStepAdjustment[];
        /**
         * target_tracking_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#target_tracking_configuration AutoscalingPolicy#target_tracking_configuration}
         *
         * @stability stable
         */
        readonly targetTrackingConfiguration?: AutoscalingPolicyTargetTrackingConfiguration;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedLoadMetricSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_metric_type AutoscalingPolicy#predefined_metric_type}.
         *
         * @stability stable
         */
        readonly predefinedMetricType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#resource_label AutoscalingPolicy#resource_label}.
         *
         * @stability stable
         */
        readonly resourceLabel: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedLoadMetricSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _predefinedMetricType?;
        /**
         * @stability stable
         */
        get predefinedMetricType(): string;
        /**
         * @stability stable
         */
        set predefinedMetricType(value: string);
        /**
         * @stability stable
         */
        get predefinedMetricTypeInput(): string | undefined;
        private _resourceLabel?;
        /**
         * @stability stable
         */
        get resourceLabel(): string;
        /**
         * @stability stable
         */
        set resourceLabel(value: string);
        /**
         * @stability stable
         */
        get resourceLabelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedMetricPairSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_metric_type AutoscalingPolicy#predefined_metric_type}.
         *
         * @stability stable
         */
        readonly predefinedMetricType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#resource_label AutoscalingPolicy#resource_label}.
         *
         * @stability stable
         */
        readonly resourceLabel: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedMetricPairSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _predefinedMetricType?;
        /**
         * @stability stable
         */
        get predefinedMetricType(): string;
        /**
         * @stability stable
         */
        set predefinedMetricType(value: string);
        /**
         * @stability stable
         */
        get predefinedMetricTypeInput(): string | undefined;
        private _resourceLabel?;
        /**
         * @stability stable
         */
        get resourceLabel(): string;
        /**
         * @stability stable
         */
        set resourceLabel(value: string);
        /**
         * @stability stable
         */
        get resourceLabelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedScalingMetricSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_metric_type AutoscalingPolicy#predefined_metric_type}.
         *
         * @stability stable
         */
        readonly predefinedMetricType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#resource_label AutoscalingPolicy#resource_label}.
         *
         * @stability stable
         */
        readonly resourceLabel: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedScalingMetricSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _predefinedMetricType?;
        /**
         * @stability stable
         */
        get predefinedMetricType(): string;
        /**
         * @stability stable
         */
        set predefinedMetricType(value: string);
        /**
         * @stability stable
         */
        get predefinedMetricTypeInput(): string | undefined;
        private _resourceLabel?;
        /**
         * @stability stable
         */
        get resourceLabel(): string;
        /**
         * @stability stable
         */
        set resourceLabel(value: string);
        /**
         * @stability stable
         */
        get resourceLabelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyPredictiveScalingConfigurationMetricSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#target_value AutoscalingPolicy#target_value}.
         *
         * @stability stable
         */
        readonly targetValue: number;
        /**
         * predefined_load_metric_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_load_metric_specification AutoscalingPolicy#predefined_load_metric_specification}
         *
         * @stability stable
         */
        readonly predefinedLoadMetricSpecification?: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedLoadMetricSpecification;
        /**
         * predefined_metric_pair_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_metric_pair_specification AutoscalingPolicy#predefined_metric_pair_specification}
         *
         * @stability stable
         */
        readonly predefinedMetricPairSpecification?: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedMetricPairSpecification;
        /**
         * predefined_scaling_metric_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_scaling_metric_specification AutoscalingPolicy#predefined_scaling_metric_specification}
         *
         * @stability stable
         */
        readonly predefinedScalingMetricSpecification?: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedScalingMetricSpecification;
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _targetValue?;
        /**
         * @stability stable
         */
        get targetValue(): number;
        /**
         * @stability stable
         */
        set targetValue(value: number);
        /**
         * @stability stable
         */
        get targetValueInput(): number | undefined;
        private _predefinedLoadMetricSpecification?;
        private __predefinedLoadMetricSpecificationOutput;
        /**
         * @stability stable
         */
        get predefinedLoadMetricSpecification(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedLoadMetricSpecificationOutputReference;
        /**
         * @stability stable
         */
        putPredefinedLoadMetricSpecification(value: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedLoadMetricSpecification | undefined): void;
        /**
         * @stability stable
         */
        resetPredefinedLoadMetricSpecification(): void;
        /**
         * @stability stable
         */
        get predefinedLoadMetricSpecificationInput(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedLoadMetricSpecification | undefined;
        private _predefinedMetricPairSpecification?;
        private __predefinedMetricPairSpecificationOutput;
        /**
         * @stability stable
         */
        get predefinedMetricPairSpecification(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedMetricPairSpecificationOutputReference;
        /**
         * @stability stable
         */
        putPredefinedMetricPairSpecification(value: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedMetricPairSpecification | undefined): void;
        /**
         * @stability stable
         */
        resetPredefinedMetricPairSpecification(): void;
        /**
         * @stability stable
         */
        get predefinedMetricPairSpecificationInput(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedMetricPairSpecification | undefined;
        private _predefinedScalingMetricSpecification?;
        private __predefinedScalingMetricSpecificationOutput;
        /**
         * @stability stable
         */
        get predefinedScalingMetricSpecification(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedScalingMetricSpecificationOutputReference;
        /**
         * @stability stable
         */
        putPredefinedScalingMetricSpecification(value: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedScalingMetricSpecification | undefined): void;
        /**
         * @stability stable
         */
        resetPredefinedScalingMetricSpecification(): void;
        /**
         * @stability stable
         */
        get predefinedScalingMetricSpecificationInput(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationPredefinedScalingMetricSpecification | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyPredictiveScalingConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#max_capacity_breach_behavior AutoscalingPolicy#max_capacity_breach_behavior}.
         *
         * @stability stable
         */
        readonly maxCapacityBreachBehavior?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#max_capacity_buffer AutoscalingPolicy#max_capacity_buffer}.
         *
         * @stability stable
         */
        readonly maxCapacityBuffer?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#mode AutoscalingPolicy#mode}.
         *
         * @stability stable
         */
        readonly mode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#scheduling_buffer_time AutoscalingPolicy#scheduling_buffer_time}.
         *
         * @stability stable
         */
        readonly schedulingBufferTime?: string;
        /**
         * metric_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#metric_specification AutoscalingPolicy#metric_specification}
         *
         * @stability stable
         */
        readonly metricSpecification: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecification;
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyPredictiveScalingConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _maxCapacityBreachBehavior?;
        /**
         * @stability stable
         */
        get maxCapacityBreachBehavior(): string | undefined;
        /**
         * @stability stable
         */
        set maxCapacityBreachBehavior(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxCapacityBreachBehavior(): void;
        /**
         * @stability stable
         */
        get maxCapacityBreachBehaviorInput(): string | undefined;
        private _maxCapacityBuffer?;
        /**
         * @stability stable
         */
        get maxCapacityBuffer(): string | undefined;
        /**
         * @stability stable
         */
        set maxCapacityBuffer(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxCapacityBuffer(): void;
        /**
         * @stability stable
         */
        get maxCapacityBufferInput(): string | undefined;
        private _mode?;
        /**
         * @stability stable
         */
        get mode(): string | undefined;
        /**
         * @stability stable
         */
        set mode(value: string | undefined);
        /**
         * @stability stable
         */
        resetMode(): void;
        /**
         * @stability stable
         */
        get modeInput(): string | undefined;
        private _schedulingBufferTime?;
        /**
         * @stability stable
         */
        get schedulingBufferTime(): string | undefined;
        /**
         * @stability stable
         */
        set schedulingBufferTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchedulingBufferTime(): void;
        /**
         * @stability stable
         */
        get schedulingBufferTimeInput(): string | undefined;
        private _metricSpecification?;
        private __metricSpecificationOutput;
        /**
         * @stability stable
         */
        get metricSpecification(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecificationOutputReference;
        /**
         * @stability stable
         */
        putMetricSpecification(value: AutoscalingPolicyPredictiveScalingConfigurationMetricSpecification): void;
        /**
         * @stability stable
         */
        get metricSpecificationInput(): AutoscalingPolicyPredictiveScalingConfigurationMetricSpecification | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyStepAdjustment {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#metric_interval_lower_bound AutoscalingPolicy#metric_interval_lower_bound}.
         *
         * @stability stable
         */
        readonly metricIntervalLowerBound?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#metric_interval_upper_bound AutoscalingPolicy#metric_interval_upper_bound}.
         *
         * @stability stable
         */
        readonly metricIntervalUpperBound?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#scaling_adjustment AutoscalingPolicy#scaling_adjustment}.
         *
         * @stability stable
         */
        readonly scalingAdjustment: number;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#name AutoscalingPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#value AutoscalingPolicy#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#metric_name AutoscalingPolicy#metric_name}.
         *
         * @stability stable
         */
        readonly metricName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#namespace AutoscalingPolicy#namespace}.
         *
         * @stability stable
         */
        readonly namespace: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#statistic AutoscalingPolicy#statistic}.
         *
         * @stability stable
         */
        readonly statistic: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#unit AutoscalingPolicy#unit}.
         *
         * @stability stable
         */
        readonly unit?: string;
        /**
         * metric_dimension block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#metric_dimension AutoscalingPolicy#metric_dimension}
         *
         * @stability stable
         */
        readonly metricDimension?: AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension[];
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _metricName?;
        /**
         * @stability stable
         */
        get metricName(): string;
        /**
         * @stability stable
         */
        set metricName(value: string);
        /**
         * @stability stable
         */
        get metricNameInput(): string | undefined;
        private _namespace?;
        /**
         * @stability stable
         */
        get namespace(): string;
        /**
         * @stability stable
         */
        set namespace(value: string);
        /**
         * @stability stable
         */
        get namespaceInput(): string | undefined;
        private _statistic?;
        /**
         * @stability stable
         */
        get statistic(): string;
        /**
         * @stability stable
         */
        set statistic(value: string);
        /**
         * @stability stable
         */
        get statisticInput(): string | undefined;
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string | undefined;
        /**
         * @stability stable
         */
        set unit(value: string | undefined);
        /**
         * @stability stable
         */
        resetUnit(): void;
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _metricDimension?;
        /**
         * @stability stable
         */
        get metricDimension(): AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension[] | undefined;
        /**
         * @stability stable
         */
        set metricDimension(value: AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension[] | undefined);
        /**
         * @stability stable
         */
        resetMetricDimension(): void;
        /**
         * @stability stable
         */
        get metricDimensionInput(): AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_metric_type AutoscalingPolicy#predefined_metric_type}.
         *
         * @stability stable
         */
        readonly predefinedMetricType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#resource_label AutoscalingPolicy#resource_label}.
         *
         * @stability stable
         */
        readonly resourceLabel?: string;
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _predefinedMetricType?;
        /**
         * @stability stable
         */
        get predefinedMetricType(): string;
        /**
         * @stability stable
         */
        set predefinedMetricType(value: string);
        /**
         * @stability stable
         */
        get predefinedMetricTypeInput(): string | undefined;
        private _resourceLabel?;
        /**
         * @stability stable
         */
        get resourceLabel(): string | undefined;
        /**
         * @stability stable
         */
        set resourceLabel(value: string | undefined);
        /**
         * @stability stable
         */
        resetResourceLabel(): void;
        /**
         * @stability stable
         */
        get resourceLabelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AutoscalingPolicyTargetTrackingConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#disable_scale_in AutoscalingPolicy#disable_scale_in}.
         *
         * @stability stable
         */
        readonly disableScaleIn?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#target_value AutoscalingPolicy#target_value}.
         *
         * @stability stable
         */
        readonly targetValue: number;
        /**
         * customized_metric_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#customized_metric_specification AutoscalingPolicy#customized_metric_specification}
         *
         * @stability stable
         */
        readonly customizedMetricSpecification?: AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification;
        /**
         * predefined_metric_specification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html#predefined_metric_specification AutoscalingPolicy#predefined_metric_specification}
         *
         * @stability stable
         */
        readonly predefinedMetricSpecification?: AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification;
    }
    /**
     * @stability stable
     */
    class AutoscalingPolicyTargetTrackingConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _disableScaleIn?;
        /**
         * @stability stable
         */
        get disableScaleIn(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set disableScaleIn(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDisableScaleIn(): void;
        /**
         * @stability stable
         */
        get disableScaleInInput(): boolean | cdktf.IResolvable | undefined;
        private _targetValue?;
        /**
         * @stability stable
         */
        get targetValue(): number;
        /**
         * @stability stable
         */
        set targetValue(value: number);
        /**
         * @stability stable
         */
        get targetValueInput(): number | undefined;
        private _customizedMetricSpecification?;
        private __customizedMetricSpecificationOutput;
        /**
         * @stability stable
         */
        get customizedMetricSpecification(): AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationOutputReference;
        /**
         * @stability stable
         */
        putCustomizedMetricSpecification(value: AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification | undefined): void;
        /**
         * @stability stable
         */
        resetCustomizedMetricSpecification(): void;
        /**
         * @stability stable
         */
        get customizedMetricSpecificationInput(): AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification | undefined;
        private _predefinedMetricSpecification?;
        private __predefinedMetricSpecificationOutput;
        /**
         * @stability stable
         */
        get predefinedMetricSpecification(): AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecificationOutputReference;
        /**
         * @stability stable
         */
        putPredefinedMetricSpecification(value: AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification | undefined): void;
        /**
         * @stability stable
         */
        resetPredefinedMetricSpecification(): void;
        /**
         * @stability stable
         */
        get predefinedMetricSpecificationInput(): AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html aws_autoscaling_policy}.
     *
     * @stability stable
     */
    class AutoscalingPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_policy.html aws_autoscaling_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AutoscalingPolicyConfig);
        private _adjustmentType?;
        /**
         * @stability stable
         */
        get adjustmentType(): string | undefined;
        /**
         * @stability stable
         */
        set adjustmentType(value: string | undefined);
        /**
         * @stability stable
         */
        resetAdjustmentType(): void;
        /**
         * @stability stable
         */
        get adjustmentTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoscalingGroupName?;
        /**
         * @stability stable
         */
        get autoscalingGroupName(): string;
        /**
         * @stability stable
         */
        set autoscalingGroupName(value: string);
        /**
         * @stability stable
         */
        get autoscalingGroupNameInput(): string | undefined;
        private _cooldown?;
        /**
         * @stability stable
         */
        get cooldown(): number | undefined;
        /**
         * @stability stable
         */
        set cooldown(value: number | undefined);
        /**
         * @stability stable
         */
        resetCooldown(): void;
        /**
         * @stability stable
         */
        get cooldownInput(): number | undefined;
        private _estimatedInstanceWarmup?;
        /**
         * @stability stable
         */
        get estimatedInstanceWarmup(): number | undefined;
        /**
         * @stability stable
         */
        set estimatedInstanceWarmup(value: number | undefined);
        /**
         * @stability stable
         */
        resetEstimatedInstanceWarmup(): void;
        /**
         * @stability stable
         */
        get estimatedInstanceWarmupInput(): number | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _metricAggregationType?;
        /**
         * @stability stable
         */
        get metricAggregationType(): string | undefined;
        /**
         * @stability stable
         */
        set metricAggregationType(value: string | undefined);
        /**
         * @stability stable
         */
        resetMetricAggregationType(): void;
        /**
         * @stability stable
         */
        get metricAggregationTypeInput(): string | undefined;
        private _minAdjustmentMagnitude?;
        /**
         * @stability stable
         */
        get minAdjustmentMagnitude(): number | undefined;
        /**
         * @stability stable
         */
        set minAdjustmentMagnitude(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinAdjustmentMagnitude(): void;
        /**
         * @stability stable
         */
        get minAdjustmentMagnitudeInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _policyType?;
        /**
         * @stability stable
         */
        get policyType(): string | undefined;
        /**
         * @stability stable
         */
        set policyType(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicyType(): void;
        /**
         * @stability stable
         */
        get policyTypeInput(): string | undefined;
        private _scalingAdjustment?;
        /**
         * @stability stable
         */
        get scalingAdjustment(): number | undefined;
        /**
         * @stability stable
         */
        set scalingAdjustment(value: number | undefined);
        /**
         * @stability stable
         */
        resetScalingAdjustment(): void;
        /**
         * @stability stable
         */
        get scalingAdjustmentInput(): number | undefined;
        private _predictiveScalingConfiguration?;
        private __predictiveScalingConfigurationOutput;
        /**
         * @stability stable
         */
        get predictiveScalingConfiguration(): AutoscalingPolicyPredictiveScalingConfigurationOutputReference;
        /**
         * @stability stable
         */
        putPredictiveScalingConfiguration(value: AutoscalingPolicyPredictiveScalingConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetPredictiveScalingConfiguration(): void;
        /**
         * @stability stable
         */
        get predictiveScalingConfigurationInput(): AutoscalingPolicyPredictiveScalingConfiguration | undefined;
        private _stepAdjustment?;
        /**
         * @stability stable
         */
        get stepAdjustment(): AutoscalingPolicyStepAdjustment[] | undefined;
        /**
         * @stability stable
         */
        set stepAdjustment(value: AutoscalingPolicyStepAdjustment[] | undefined);
        /**
         * @stability stable
         */
        resetStepAdjustment(): void;
        /**
         * @stability stable
         */
        get stepAdjustmentInput(): AutoscalingPolicyStepAdjustment[] | undefined;
        private _targetTrackingConfiguration?;
        private __targetTrackingConfigurationOutput;
        /**
         * @stability stable
         */
        get targetTrackingConfiguration(): AutoscalingPolicyTargetTrackingConfigurationOutputReference;
        /**
         * @stability stable
         */
        putTargetTrackingConfiguration(value: AutoscalingPolicyTargetTrackingConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetTargetTrackingConfiguration(): void;
        /**
         * @stability stable
         */
        get targetTrackingConfigurationInput(): AutoscalingPolicyTargetTrackingConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AutoscalingScheduleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#autoscaling_group_name AutoscalingSchedule#autoscaling_group_name}.
         *
         * @stability stable
         */
        readonly autoscalingGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#desired_capacity AutoscalingSchedule#desired_capacity}.
         *
         * @stability stable
         */
        readonly desiredCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#end_time AutoscalingSchedule#end_time}.
         *
         * @stability stable
         */
        readonly endTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#max_size AutoscalingSchedule#max_size}.
         *
         * @stability stable
         */
        readonly maxSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#min_size AutoscalingSchedule#min_size}.
         *
         * @stability stable
         */
        readonly minSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#recurrence AutoscalingSchedule#recurrence}.
         *
         * @stability stable
         */
        readonly recurrence?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#scheduled_action_name AutoscalingSchedule#scheduled_action_name}.
         *
         * @stability stable
         */
        readonly scheduledActionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#start_time AutoscalingSchedule#start_time}.
         *
         * @stability stable
         */
        readonly startTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html#time_zone AutoscalingSchedule#time_zone}.
         *
         * @stability stable
         */
        readonly timeZone?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html aws_autoscaling_schedule}.
     *
     * @stability stable
     */
    class AutoscalingSchedule extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/autoscaling_schedule.html aws_autoscaling_schedule} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AutoscalingScheduleConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoscalingGroupName?;
        /**
         * @stability stable
         */
        get autoscalingGroupName(): string;
        /**
         * @stability stable
         */
        set autoscalingGroupName(value: string);
        /**
         * @stability stable
         */
        get autoscalingGroupNameInput(): string | undefined;
        private _desiredCapacity?;
        /**
         * @stability stable
         */
        get desiredCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set desiredCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetDesiredCapacity(): void;
        /**
         * @stability stable
         */
        get desiredCapacityInput(): number | undefined;
        private _endTime?;
        /**
         * @stability stable
         */
        get endTime(): string | undefined;
        /**
         * @stability stable
         */
        set endTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetEndTime(): void;
        /**
         * @stability stable
         */
        get endTimeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _maxSize?;
        /**
         * @stability stable
         */
        get maxSize(): number | undefined;
        /**
         * @stability stable
         */
        set maxSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxSize(): void;
        /**
         * @stability stable
         */
        get maxSizeInput(): number | undefined;
        private _minSize?;
        /**
         * @stability stable
         */
        get minSize(): number | undefined;
        /**
         * @stability stable
         */
        set minSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinSize(): void;
        /**
         * @stability stable
         */
        get minSizeInput(): number | undefined;
        private _recurrence?;
        /**
         * @stability stable
         */
        get recurrence(): string | undefined;
        /**
         * @stability stable
         */
        set recurrence(value: string | undefined);
        /**
         * @stability stable
         */
        resetRecurrence(): void;
        /**
         * @stability stable
         */
        get recurrenceInput(): string | undefined;
        private _scheduledActionName?;
        /**
         * @stability stable
         */
        get scheduledActionName(): string;
        /**
         * @stability stable
         */
        set scheduledActionName(value: string);
        /**
         * @stability stable
         */
        get scheduledActionNameInput(): string | undefined;
        private _startTime?;
        /**
         * @stability stable
         */
        get startTime(): string | undefined;
        /**
         * @stability stable
         */
        set startTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetStartTime(): void;
        /**
         * @stability stable
         */
        get startTimeInput(): string | undefined;
        private _timeZone?;
        /**
         * @stability stable
         */
        get timeZone(): string | undefined;
        /**
         * @stability stable
         */
        set timeZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetTimeZone(): void;
        /**
         * @stability stable
         */
        get timeZoneInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAutoscalingGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_group.html#name DataAwsAutoscalingGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    class DataAwsAutoscalingGroupLaunchTemplate extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get version(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_group.html aws_autoscaling_group}.
     *
     * @stability stable
     */
    class DataAwsAutoscalingGroup extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_group.html aws_autoscaling_group} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsAutoscalingGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get defaultCooldown(): number;
        /**
         * @stability stable
         */
        get desiredCapacity(): number;
        /**
         * @stability stable
         */
        get healthCheckGracePeriod(): number;
        /**
         * @stability stable
         */
        get healthCheckType(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get launchConfiguration(): string;
        /**
         * @stability stable
         */
        launchTemplate(index: string): DataAwsAutoscalingGroupLaunchTemplate;
        /**
         * @stability stable
         */
        get loadBalancers(): string[];
        /**
         * @stability stable
         */
        get maxSize(): number;
        /**
         * @stability stable
         */
        get minSize(): number;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get newInstancesProtectedFromScaleIn(): any;
        /**
         * @stability stable
         */
        get placementGroup(): string;
        /**
         * @stability stable
         */
        get serviceLinkedRoleArn(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get targetGroupArns(): string[];
        /**
         * @stability stable
         */
        get terminationPolicies(): string[];
        /**
         * @stability stable
         */
        get vpcZoneIdentifier(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAutoscalingGroupsConfig extends cdktf.TerraformMetaArguments {
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_groups.html#filter DataAwsAutoscalingGroups#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsAutoscalingGroupsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsAutoscalingGroupsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_groups.html#name DataAwsAutoscalingGroups#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_groups.html#values DataAwsAutoscalingGroups#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_groups.html aws_autoscaling_groups}.
     *
     * @stability stable
     */
    class DataAwsAutoscalingGroups extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/autoscaling_groups.html aws_autoscaling_groups} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsAutoscalingGroupsConfig);
        /**
         * @stability stable
         */
        get arns(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get names(): string[];
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsAutoscalingGroupsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsAutoscalingGroupsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsAutoscalingGroupsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
