import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Backup
*/
export declare namespace Backup {
    /**
     * @stability stable
     */
    interface BackupGlobalSettingsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_global_settings.html#global_settings BackupGlobalSettings#global_settings}.
         *
         * @stability stable
         */
        readonly globalSettings: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_global_settings.html aws_backup_global_settings}.
     *
     * @stability stable
     */
    class BackupGlobalSettings extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_global_settings.html aws_backup_global_settings} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: BackupGlobalSettingsConfig);
        private _globalSettings?;
        /**
         * @stability stable
         */
        get globalSettings(): {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set globalSettings(value: {
            [key: string]: string;
        } | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get globalSettingsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface BackupPlanConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#name BackupPlan#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#tags BackupPlan#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#tags_all BackupPlan#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * advanced_backup_setting block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#advanced_backup_setting BackupPlan#advanced_backup_setting}
         *
         * @stability stable
         */
        readonly advancedBackupSetting?: BackupPlanAdvancedBackupSetting[];
        /**
         * rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#rule BackupPlan#rule}
         *
         * @stability stable
         */
        readonly rule: BackupPlanRule[];
    }
    /**
     * @stability stable
     */
    interface BackupPlanAdvancedBackupSetting {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#backup_options BackupPlan#backup_options}.
         *
         * @stability stable
         */
        readonly backupOptions: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#resource_type BackupPlan#resource_type}.
         *
         * @stability stable
         */
        readonly resourceType: string;
    }
    /**
     * @stability stable
     */
    interface BackupPlanRuleCopyActionLifecycle {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#cold_storage_after BackupPlan#cold_storage_after}.
         *
         * @stability stable
         */
        readonly coldStorageAfter?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#delete_after BackupPlan#delete_after}.
         *
         * @stability stable
         */
        readonly deleteAfter?: number;
    }
    /**
     * @stability stable
     */
    class BackupPlanRuleCopyActionLifecycleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _coldStorageAfter?;
        /**
         * @stability stable
         */
        get coldStorageAfter(): number | undefined;
        /**
         * @stability stable
         */
        set coldStorageAfter(value: number | undefined);
        /**
         * @stability stable
         */
        resetColdStorageAfter(): void;
        /**
         * @stability stable
         */
        get coldStorageAfterInput(): number | undefined;
        private _deleteAfter?;
        /**
         * @stability stable
         */
        get deleteAfter(): number | undefined;
        /**
         * @stability stable
         */
        set deleteAfter(value: number | undefined);
        /**
         * @stability stable
         */
        resetDeleteAfter(): void;
        /**
         * @stability stable
         */
        get deleteAfterInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface BackupPlanRuleCopyAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#destination_vault_arn BackupPlan#destination_vault_arn}.
         *
         * @stability stable
         */
        readonly destinationVaultArn: string;
        /**
         * lifecycle block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#lifecycle BackupPlan#lifecycle}
         *
         * @stability stable
         */
        readonly lifecycle?: BackupPlanRuleCopyActionLifecycle;
    }
    /**
     * @stability stable
     */
    interface BackupPlanRuleLifecycle {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#cold_storage_after BackupPlan#cold_storage_after}.
         *
         * @stability stable
         */
        readonly coldStorageAfter?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#delete_after BackupPlan#delete_after}.
         *
         * @stability stable
         */
        readonly deleteAfter?: number;
    }
    /**
     * @stability stable
     */
    class BackupPlanRuleLifecycleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _coldStorageAfter?;
        /**
         * @stability stable
         */
        get coldStorageAfter(): number | undefined;
        /**
         * @stability stable
         */
        set coldStorageAfter(value: number | undefined);
        /**
         * @stability stable
         */
        resetColdStorageAfter(): void;
        /**
         * @stability stable
         */
        get coldStorageAfterInput(): number | undefined;
        private _deleteAfter?;
        /**
         * @stability stable
         */
        get deleteAfter(): number | undefined;
        /**
         * @stability stable
         */
        set deleteAfter(value: number | undefined);
        /**
         * @stability stable
         */
        resetDeleteAfter(): void;
        /**
         * @stability stable
         */
        get deleteAfterInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface BackupPlanRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#completion_window BackupPlan#completion_window}.
         *
         * @stability stable
         */
        readonly completionWindow?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#enable_continuous_backup BackupPlan#enable_continuous_backup}.
         *
         * @stability stable
         */
        readonly enableContinuousBackup?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#recovery_point_tags BackupPlan#recovery_point_tags}.
         *
         * @stability stable
         */
        readonly recoveryPointTags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#rule_name BackupPlan#rule_name}.
         *
         * @stability stable
         */
        readonly ruleName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#schedule BackupPlan#schedule}.
         *
         * @stability stable
         */
        readonly schedule?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#start_window BackupPlan#start_window}.
         *
         * @stability stable
         */
        readonly startWindow?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#target_vault_name BackupPlan#target_vault_name}.
         *
         * @stability stable
         */
        readonly targetVaultName: string;
        /**
         * copy_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#copy_action BackupPlan#copy_action}
         *
         * @stability stable
         */
        readonly copyAction?: BackupPlanRuleCopyAction[];
        /**
         * lifecycle block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html#lifecycle BackupPlan#lifecycle}
         *
         * @stability stable
         */
        readonly lifecycle?: BackupPlanRuleLifecycle;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html aws_backup_plan}.
     *
     * @stability stable
     */
    class BackupPlan extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_plan.html aws_backup_plan} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: BackupPlanConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get version(): string;
        private _advancedBackupSetting?;
        /**
         * @stability stable
         */
        get advancedBackupSetting(): BackupPlanAdvancedBackupSetting[] | undefined;
        /**
         * @stability stable
         */
        set advancedBackupSetting(value: BackupPlanAdvancedBackupSetting[] | undefined);
        /**
         * @stability stable
         */
        resetAdvancedBackupSetting(): void;
        /**
         * @stability stable
         */
        get advancedBackupSettingInput(): BackupPlanAdvancedBackupSetting[] | undefined;
        private _rule?;
        /**
         * @stability stable
         */
        get rule(): BackupPlanRule[];
        /**
         * @stability stable
         */
        set rule(value: BackupPlanRule[]);
        /**
         * @stability stable
         */
        get ruleInput(): BackupPlanRule[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface BackupRegionSettingsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_region_settings.html#resource_type_opt_in_preference BackupRegionSettings#resource_type_opt_in_preference}.
         *
         * @stability stable
         */
        readonly resourceTypeOptInPreference: {
            [key: string]: boolean;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_region_settings.html aws_backup_region_settings}.
     *
     * @stability stable
     */
    class BackupRegionSettings extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_region_settings.html aws_backup_region_settings} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: BackupRegionSettingsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _resourceTypeOptInPreference?;
        /**
         * @stability stable
         */
        get resourceTypeOptInPreference(): {
            [key: string]: boolean;
        } | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set resourceTypeOptInPreference(value: {
            [key: string]: boolean;
        } | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get resourceTypeOptInPreferenceInput(): cdktf.IResolvable | {
            [key: string]: boolean;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface BackupSelectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#iam_role_arn BackupSelection#iam_role_arn}.
         *
         * @stability stable
         */
        readonly iamRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#name BackupSelection#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#plan_id BackupSelection#plan_id}.
         *
         * @stability stable
         */
        readonly planId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#resources BackupSelection#resources}.
         *
         * @stability stable
         */
        readonly resources?: string[];
        /**
         * selection_tag block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#selection_tag BackupSelection#selection_tag}
         *
         * @stability stable
         */
        readonly selectionTag?: BackupSelectionSelectionTag[];
    }
    /**
     * @stability stable
     */
    interface BackupSelectionSelectionTag {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#key BackupSelection#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#type BackupSelection#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html#value BackupSelection#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html aws_backup_selection}.
     *
     * @stability stable
     */
    class BackupSelection extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_selection.html aws_backup_selection} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: BackupSelectionConfig);
        private _iamRoleArn?;
        /**
         * @stability stable
         */
        get iamRoleArn(): string;
        /**
         * @stability stable
         */
        set iamRoleArn(value: string);
        /**
         * @stability stable
         */
        get iamRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _planId?;
        /**
         * @stability stable
         */
        get planId(): string;
        /**
         * @stability stable
         */
        set planId(value: string);
        /**
         * @stability stable
         */
        get planIdInput(): string | undefined;
        private _resources?;
        /**
         * @stability stable
         */
        get resources(): string[] | undefined;
        /**
         * @stability stable
         */
        set resources(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetResources(): void;
        /**
         * @stability stable
         */
        get resourcesInput(): string[] | undefined;
        private _selectionTag?;
        /**
         * @stability stable
         */
        get selectionTag(): BackupSelectionSelectionTag[] | undefined;
        /**
         * @stability stable
         */
        set selectionTag(value: BackupSelectionSelectionTag[] | undefined);
        /**
         * @stability stable
         */
        resetSelectionTag(): void;
        /**
         * @stability stable
         */
        get selectionTagInput(): BackupSelectionSelectionTag[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface BackupVaultConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault.html#kms_key_arn BackupVault#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault.html#name BackupVault#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault.html#tags BackupVault#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault.html#tags_all BackupVault#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_vault.html aws_backup_vault}.
     *
     * @stability stable
     */
    class BackupVault extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_vault.html aws_backup_vault} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: BackupVaultConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get recoveryPoints(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface BackupVaultNotificationsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_notifications.html#backup_vault_events BackupVaultNotifications#backup_vault_events}.
         *
         * @stability stable
         */
        readonly backupVaultEvents: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_notifications.html#backup_vault_name BackupVaultNotifications#backup_vault_name}.
         *
         * @stability stable
         */
        readonly backupVaultName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_notifications.html#sns_topic_arn BackupVaultNotifications#sns_topic_arn}.
         *
         * @stability stable
         */
        readonly snsTopicArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_notifications.html aws_backup_vault_notifications}.
     *
     * @stability stable
     */
    class BackupVaultNotifications extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_notifications.html aws_backup_vault_notifications} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: BackupVaultNotificationsConfig);
        /**
         * @stability stable
         */
        get backupVaultArn(): string;
        private _backupVaultEvents?;
        /**
         * @stability stable
         */
        get backupVaultEvents(): string[];
        /**
         * @stability stable
         */
        set backupVaultEvents(value: string[]);
        /**
         * @stability stable
         */
        get backupVaultEventsInput(): string[] | undefined;
        private _backupVaultName?;
        /**
         * @stability stable
         */
        get backupVaultName(): string;
        /**
         * @stability stable
         */
        set backupVaultName(value: string);
        /**
         * @stability stable
         */
        get backupVaultNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _snsTopicArn?;
        /**
         * @stability stable
         */
        get snsTopicArn(): string;
        /**
         * @stability stable
         */
        set snsTopicArn(value: string);
        /**
         * @stability stable
         */
        get snsTopicArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface BackupVaultPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_policy.html#backup_vault_name BackupVaultPolicy#backup_vault_name}.
         *
         * @stability stable
         */
        readonly backupVaultName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_policy.html#policy BackupVaultPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_policy.html aws_backup_vault_policy}.
     *
     * @stability stable
     */
    class BackupVaultPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/backup_vault_policy.html aws_backup_vault_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: BackupVaultPolicyConfig);
        /**
         * @stability stable
         */
        get backupVaultArn(): string;
        private _backupVaultName?;
        /**
         * @stability stable
         */
        get backupVaultName(): string;
        /**
         * @stability stable
         */
        set backupVaultName(value: string);
        /**
         * @stability stable
         */
        get backupVaultNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsBackupPlanConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/backup_plan.html#plan_id DataAwsBackupPlan#plan_id}.
         *
         * @stability stable
         */
        readonly planId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/backup_plan.html#tags DataAwsBackupPlan#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/backup_plan.html aws_backup_plan}.
     *
     * @stability stable
     */
    class DataAwsBackupPlan extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/backup_plan.html aws_backup_plan} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsBackupPlanConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        private _planId?;
        /**
         * @stability stable
         */
        get planId(): string;
        /**
         * @stability stable
         */
        set planId(value: string);
        /**
         * @stability stable
         */
        get planIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsBackupSelectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/backup_selection.html#plan_id DataAwsBackupSelection#plan_id}.
         *
         * @stability stable
         */
        readonly planId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/backup_selection.html#selection_id DataAwsBackupSelection#selection_id}.
         *
         * @stability stable
         */
        readonly selectionId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/backup_selection.html aws_backup_selection}.
     *
     * @stability stable
     */
    class DataAwsBackupSelection extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/backup_selection.html aws_backup_selection} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsBackupSelectionConfig);
        /**
         * @stability stable
         */
        get iamRoleArn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        private _planId?;
        /**
         * @stability stable
         */
        get planId(): string;
        /**
         * @stability stable
         */
        set planId(value: string);
        /**
         * @stability stable
         */
        get planIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get resources(): string[];
        private _selectionId?;
        /**
         * @stability stable
         */
        get selectionId(): string;
        /**
         * @stability stable
         */
        set selectionId(value: string);
        /**
         * @stability stable
         */
        get selectionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsBackupVaultConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/backup_vault.html#name DataAwsBackupVault#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/backup_vault.html#tags DataAwsBackupVault#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/backup_vault.html aws_backup_vault}.
     *
     * @stability stable
     */
    class DataAwsBackupVault extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/backup_vault.html aws_backup_vault} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsBackupVaultConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get recoveryPoints(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
