import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS CloudFormation
*/
export declare namespace CloudFormation {
    /**
     * @stability stable
     */
    interface CloudformationStackConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#capabilities CloudformationStack#capabilities}.
         *
         * @stability stable
         */
        readonly capabilities?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#disable_rollback CloudformationStack#disable_rollback}.
         *
         * @stability stable
         */
        readonly disableRollback?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#iam_role_arn CloudformationStack#iam_role_arn}.
         *
         * @stability stable
         */
        readonly iamRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#name CloudformationStack#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#notification_arns CloudformationStack#notification_arns}.
         *
         * @stability stable
         */
        readonly notificationArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#on_failure CloudformationStack#on_failure}.
         *
         * @stability stable
         */
        readonly onFailure?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#parameters CloudformationStack#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#policy_body CloudformationStack#policy_body}.
         *
         * @stability stable
         */
        readonly policyBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#policy_url CloudformationStack#policy_url}.
         *
         * @stability stable
         */
        readonly policyUrl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#tags CloudformationStack#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#tags_all CloudformationStack#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#template_body CloudformationStack#template_body}.
         *
         * @stability stable
         */
        readonly templateBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#template_url CloudformationStack#template_url}.
         *
         * @stability stable
         */
        readonly templateUrl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#timeout_in_minutes CloudformationStack#timeout_in_minutes}.
         *
         * @stability stable
         */
        readonly timeoutInMinutes?: number;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#timeouts CloudformationStack#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: CloudformationStackTimeouts;
    }
    /**
     * @stability stable
     */
    interface CloudformationStackTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#create CloudformationStack#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#delete CloudformationStack#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html#update CloudformationStack#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class CloudformationStackTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html aws_cloudformation_stack}.
     *
     * @stability stable
     */
    class CloudformationStack extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack.html aws_cloudformation_stack} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CloudformationStackConfig);
        private _capabilities?;
        /**
         * @stability stable
         */
        get capabilities(): string[] | undefined;
        /**
         * @stability stable
         */
        set capabilities(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCapabilities(): void;
        /**
         * @stability stable
         */
        get capabilitiesInput(): string[] | undefined;
        private _disableRollback?;
        /**
         * @stability stable
         */
        get disableRollback(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set disableRollback(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDisableRollback(): void;
        /**
         * @stability stable
         */
        get disableRollbackInput(): boolean | cdktf.IResolvable | undefined;
        private _iamRoleArn?;
        /**
         * @stability stable
         */
        get iamRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set iamRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetIamRoleArn(): void;
        /**
         * @stability stable
         */
        get iamRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _notificationArns?;
        /**
         * @stability stable
         */
        get notificationArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set notificationArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetNotificationArns(): void;
        /**
         * @stability stable
         */
        get notificationArnsInput(): string[] | undefined;
        private _onFailure?;
        /**
         * @stability stable
         */
        get onFailure(): string | undefined;
        /**
         * @stability stable
         */
        set onFailure(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnFailure(): void;
        /**
         * @stability stable
         */
        get onFailureInput(): string | undefined;
        /**
         * @stability stable
         */
        outputs(key: string): string;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _policyBody?;
        /**
         * @stability stable
         */
        get policyBody(): string | undefined;
        /**
         * @stability stable
         */
        set policyBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicyBody(): void;
        /**
         * @stability stable
         */
        get policyBodyInput(): string | undefined;
        private _policyUrl?;
        /**
         * @stability stable
         */
        get policyUrl(): string | undefined;
        /**
         * @stability stable
         */
        set policyUrl(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicyUrl(): void;
        /**
         * @stability stable
         */
        get policyUrlInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _templateBody?;
        /**
         * @stability stable
         */
        get templateBody(): string | undefined;
        /**
         * @stability stable
         */
        set templateBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetTemplateBody(): void;
        /**
         * @stability stable
         */
        get templateBodyInput(): string | undefined;
        private _templateUrl?;
        /**
         * @stability stable
         */
        get templateUrl(): string | undefined;
        /**
         * @stability stable
         */
        set templateUrl(value: string | undefined);
        /**
         * @stability stable
         */
        resetTemplateUrl(): void;
        /**
         * @stability stable
         */
        get templateUrlInput(): string | undefined;
        private _timeoutInMinutes?;
        /**
         * @stability stable
         */
        get timeoutInMinutes(): number | undefined;
        /**
         * @stability stable
         */
        set timeoutInMinutes(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeoutInMinutes(): void;
        /**
         * @stability stable
         */
        get timeoutInMinutesInput(): number | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): CloudformationStackTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: CloudformationStackTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): CloudformationStackTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CloudformationStackSetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#administration_role_arn CloudformationStackSet#administration_role_arn}.
         *
         * @stability stable
         */
        readonly administrationRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#capabilities CloudformationStackSet#capabilities}.
         *
         * @stability stable
         */
        readonly capabilities?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#description CloudformationStackSet#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#execution_role_name CloudformationStackSet#execution_role_name}.
         *
         * @stability stable
         */
        readonly executionRoleName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#name CloudformationStackSet#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#parameters CloudformationStackSet#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#permission_model CloudformationStackSet#permission_model}.
         *
         * @stability stable
         */
        readonly permissionModel?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#tags CloudformationStackSet#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#tags_all CloudformationStackSet#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#template_body CloudformationStackSet#template_body}.
         *
         * @stability stable
         */
        readonly templateBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#template_url CloudformationStackSet#template_url}.
         *
         * @stability stable
         */
        readonly templateUrl?: string;
        /**
         * auto_deployment block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#auto_deployment CloudformationStackSet#auto_deployment}
         *
         * @stability stable
         */
        readonly autoDeployment?: CloudformationStackSetAutoDeployment;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#timeouts CloudformationStackSet#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: CloudformationStackSetTimeouts;
    }
    /**
     * @stability stable
     */
    interface CloudformationStackSetAutoDeployment {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#enabled CloudformationStackSet#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#retain_stacks_on_account_removal CloudformationStackSet#retain_stacks_on_account_removal}.
         *
         * @stability stable
         */
        readonly retainStacksOnAccountRemoval?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class CloudformationStackSetAutoDeploymentOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _retainStacksOnAccountRemoval?;
        /**
         * @stability stable
         */
        get retainStacksOnAccountRemoval(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set retainStacksOnAccountRemoval(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRetainStacksOnAccountRemoval(): void;
        /**
         * @stability stable
         */
        get retainStacksOnAccountRemovalInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface CloudformationStackSetTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html#update CloudformationStackSet#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class CloudformationStackSetTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html aws_cloudformation_stack_set}.
     *
     * @stability stable
     */
    class CloudformationStackSet extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set.html aws_cloudformation_stack_set} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CloudformationStackSetConfig);
        private _administrationRoleArn?;
        /**
         * @stability stable
         */
        get administrationRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set administrationRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetAdministrationRoleArn(): void;
        /**
         * @stability stable
         */
        get administrationRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _capabilities?;
        /**
         * @stability stable
         */
        get capabilities(): string[] | undefined;
        /**
         * @stability stable
         */
        set capabilities(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCapabilities(): void;
        /**
         * @stability stable
         */
        get capabilitiesInput(): string[] | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _executionRoleName?;
        /**
         * @stability stable
         */
        get executionRoleName(): string | undefined;
        /**
         * @stability stable
         */
        set executionRoleName(value: string | undefined);
        /**
         * @stability stable
         */
        resetExecutionRoleName(): void;
        /**
         * @stability stable
         */
        get executionRoleNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _permissionModel?;
        /**
         * @stability stable
         */
        get permissionModel(): string | undefined;
        /**
         * @stability stable
         */
        set permissionModel(value: string | undefined);
        /**
         * @stability stable
         */
        resetPermissionModel(): void;
        /**
         * @stability stable
         */
        get permissionModelInput(): string | undefined;
        /**
         * @stability stable
         */
        get stackSetId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _templateBody?;
        /**
         * @stability stable
         */
        get templateBody(): string | undefined;
        /**
         * @stability stable
         */
        set templateBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetTemplateBody(): void;
        /**
         * @stability stable
         */
        get templateBodyInput(): string | undefined;
        private _templateUrl?;
        /**
         * @stability stable
         */
        get templateUrl(): string | undefined;
        /**
         * @stability stable
         */
        set templateUrl(value: string | undefined);
        /**
         * @stability stable
         */
        resetTemplateUrl(): void;
        /**
         * @stability stable
         */
        get templateUrlInput(): string | undefined;
        private _autoDeployment?;
        private __autoDeploymentOutput;
        /**
         * @stability stable
         */
        get autoDeployment(): CloudformationStackSetAutoDeploymentOutputReference;
        /**
         * @stability stable
         */
        putAutoDeployment(value: CloudformationStackSetAutoDeployment | undefined): void;
        /**
         * @stability stable
         */
        resetAutoDeployment(): void;
        /**
         * @stability stable
         */
        get autoDeploymentInput(): CloudformationStackSetAutoDeployment | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): CloudformationStackSetTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: CloudformationStackSetTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): CloudformationStackSetTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CloudformationStackSetInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#account_id CloudformationStackSetInstance#account_id}.
         *
         * @stability stable
         */
        readonly accountId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#parameter_overrides CloudformationStackSetInstance#parameter_overrides}.
         *
         * @stability stable
         */
        readonly parameterOverrides?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#region CloudformationStackSetInstance#region}.
         *
         * @stability stable
         */
        readonly region?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#retain_stack CloudformationStackSetInstance#retain_stack}.
         *
         * @stability stable
         */
        readonly retainStack?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#stack_set_name CloudformationStackSetInstance#stack_set_name}.
         *
         * @stability stable
         */
        readonly stackSetName: string;
        /**
         * deployment_targets block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#deployment_targets CloudformationStackSetInstance#deployment_targets}
         *
         * @stability stable
         */
        readonly deploymentTargets?: CloudformationStackSetInstanceDeploymentTargets;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#timeouts CloudformationStackSetInstance#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: CloudformationStackSetInstanceTimeouts;
    }
    /**
     * @stability stable
     */
    interface CloudformationStackSetInstanceDeploymentTargets {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#organizational_unit_ids CloudformationStackSetInstance#organizational_unit_ids}.
         *
         * @stability stable
         */
        readonly organizationalUnitIds?: string[];
    }
    /**
     * @stability stable
     */
    class CloudformationStackSetInstanceDeploymentTargetsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _organizationalUnitIds?;
        /**
         * @stability stable
         */
        get organizationalUnitIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set organizationalUnitIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetOrganizationalUnitIds(): void;
        /**
         * @stability stable
         */
        get organizationalUnitIdsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface CloudformationStackSetInstanceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#create CloudformationStackSetInstance#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#delete CloudformationStackSetInstance#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html#update CloudformationStackSetInstance#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class CloudformationStackSetInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html aws_cloudformation_stack_set_instance}.
     *
     * @stability stable
     */
    class CloudformationStackSetInstance extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_stack_set_instance.html aws_cloudformation_stack_set_instance} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CloudformationStackSetInstanceConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string | undefined;
        /**
         * @stability stable
         */
        set accountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccountId(): void;
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get organizationalUnitId(): string;
        private _parameterOverrides?;
        /**
         * @stability stable
         */
        get parameterOverrides(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameterOverrides(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameterOverrides(): void;
        /**
         * @stability stable
         */
        get parameterOverridesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _region?;
        /**
         * @stability stable
         */
        get region(): string | undefined;
        /**
         * @stability stable
         */
        set region(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegion(): void;
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
        private _retainStack?;
        /**
         * @stability stable
         */
        get retainStack(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set retainStack(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRetainStack(): void;
        /**
         * @stability stable
         */
        get retainStackInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get stackId(): string;
        private _stackSetName?;
        /**
         * @stability stable
         */
        get stackSetName(): string;
        /**
         * @stability stable
         */
        set stackSetName(value: string);
        /**
         * @stability stable
         */
        get stackSetNameInput(): string | undefined;
        private _deploymentTargets?;
        private __deploymentTargetsOutput;
        /**
         * @stability stable
         */
        get deploymentTargets(): CloudformationStackSetInstanceDeploymentTargetsOutputReference;
        /**
         * @stability stable
         */
        putDeploymentTargets(value: CloudformationStackSetInstanceDeploymentTargets | undefined): void;
        /**
         * @stability stable
         */
        resetDeploymentTargets(): void;
        /**
         * @stability stable
         */
        get deploymentTargetsInput(): CloudformationStackSetInstanceDeploymentTargets | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): CloudformationStackSetInstanceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: CloudformationStackSetInstanceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): CloudformationStackSetInstanceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CloudformationTypeConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#execution_role_arn CloudformationType#execution_role_arn}.
         *
         * @stability stable
         */
        readonly executionRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#schema_handler_package CloudformationType#schema_handler_package}.
         *
         * @stability stable
         */
        readonly schemaHandlerPackage: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#type CloudformationType#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#type_name CloudformationType#type_name}.
         *
         * @stability stable
         */
        readonly typeName: string;
        /**
         * logging_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#logging_config CloudformationType#logging_config}
         *
         * @stability stable
         */
        readonly loggingConfig?: CloudformationTypeLoggingConfig;
    }
    /**
     * @stability stable
     */
    interface CloudformationTypeLoggingConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#log_group_name CloudformationType#log_group_name}.
         *
         * @stability stable
         */
        readonly logGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html#log_role_arn CloudformationType#log_role_arn}.
         *
         * @stability stable
         */
        readonly logRoleArn: string;
    }
    /**
     * @stability stable
     */
    class CloudformationTypeLoggingConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _logGroupName?;
        /**
         * @stability stable
         */
        get logGroupName(): string;
        /**
         * @stability stable
         */
        set logGroupName(value: string);
        /**
         * @stability stable
         */
        get logGroupNameInput(): string | undefined;
        private _logRoleArn?;
        /**
         * @stability stable
         */
        get logRoleArn(): string;
        /**
         * @stability stable
         */
        set logRoleArn(value: string);
        /**
         * @stability stable
         */
        get logRoleArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html aws_cloudformation_type}.
     *
     * @stability stable
     */
    class CloudformationType extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudformation_type.html aws_cloudformation_type} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CloudformationTypeConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get defaultVersionId(): string;
        /**
         * @stability stable
         */
        get deprecatedStatus(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get documentationUrl(): string;
        private _executionRoleArn?;
        /**
         * @stability stable
         */
        get executionRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set executionRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetExecutionRoleArn(): void;
        /**
         * @stability stable
         */
        get executionRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get isDefaultVersion(): any;
        /**
         * @stability stable
         */
        get provisioningType(): string;
        /**
         * @stability stable
         */
        get schema(): string;
        private _schemaHandlerPackage?;
        /**
         * @stability stable
         */
        get schemaHandlerPackage(): string;
        /**
         * @stability stable
         */
        set schemaHandlerPackage(value: string);
        /**
         * @stability stable
         */
        get schemaHandlerPackageInput(): string | undefined;
        /**
         * @stability stable
         */
        get sourceUrl(): string;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        /**
         * @stability stable
         */
        get typeArn(): string;
        private _typeName?;
        /**
         * @stability stable
         */
        get typeName(): string;
        /**
         * @stability stable
         */
        set typeName(value: string);
        /**
         * @stability stable
         */
        get typeNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get versionId(): string;
        /**
         * @stability stable
         */
        get visibility(): string;
        private _loggingConfig?;
        private __loggingConfigOutput;
        /**
         * @stability stable
         */
        get loggingConfig(): CloudformationTypeLoggingConfigOutputReference;
        /**
         * @stability stable
         */
        putLoggingConfig(value: CloudformationTypeLoggingConfig | undefined): void;
        /**
         * @stability stable
         */
        resetLoggingConfig(): void;
        /**
         * @stability stable
         */
        get loggingConfigInput(): CloudformationTypeLoggingConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCloudformationExportConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_export.html#name DataAwsCloudformationExport#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_export.html aws_cloudformation_export}.
     *
     * @stability stable
     */
    class DataAwsCloudformationExport extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_export.html aws_cloudformation_export} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsCloudformationExportConfig);
        /**
         * @stability stable
         */
        get exportingStackId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCloudformationStackConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_stack.html#name DataAwsCloudformationStack#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_stack.html#tags DataAwsCloudformationStack#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_stack.html aws_cloudformation_stack}.
     *
     * @stability stable
     */
    class DataAwsCloudformationStack extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_stack.html aws_cloudformation_stack} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsCloudformationStackConfig);
        /**
         * @stability stable
         */
        get capabilities(): string[];
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get disableRollback(): any;
        /**
         * @stability stable
         */
        get iamRoleArn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get notificationArns(): string[];
        /**
         * @stability stable
         */
        outputs(key: string): string;
        /**
         * @stability stable
         */
        parameters(key: string): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get templateBody(): string;
        /**
         * @stability stable
         */
        get timeoutInMinutes(): number;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCloudformationTypeConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_type.html#type DataAwsCloudformationType#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_type.html#type_name DataAwsCloudformationType#type_name}.
         *
         * @stability stable
         */
        readonly typeName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_type.html#version_id DataAwsCloudformationType#version_id}.
         *
         * @stability stable
         */
        readonly versionId?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsCloudformationTypeLoggingConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get logGroupName(): string;
        /**
         * @stability stable
         */
        get logRoleArn(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_type.html aws_cloudformation_type}.
     *
     * @stability stable
     */
    class DataAwsCloudformationType extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/cloudformation_type.html aws_cloudformation_type} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsCloudformationTypeConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get defaultVersionId(): string;
        /**
         * @stability stable
         */
        get deprecatedStatus(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get documentationUrl(): string;
        /**
         * @stability stable
         */
        get executionRoleArn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get isDefaultVersion(): any;
        /**
         * @stability stable
         */
        loggingConfig(index: string): DataAwsCloudformationTypeLoggingConfig;
        /**
         * @stability stable
         */
        get provisioningType(): string;
        /**
         * @stability stable
         */
        get schema(): string;
        /**
         * @stability stable
         */
        get sourceUrl(): string;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        /**
         * @stability stable
         */
        get typeArn(): string;
        private _typeName?;
        /**
         * @stability stable
         */
        get typeName(): string | undefined;
        /**
         * @stability stable
         */
        set typeName(value: string | undefined);
        /**
         * @stability stable
         */
        resetTypeName(): void;
        /**
         * @stability stable
         */
        get typeNameInput(): string | undefined;
        private _versionId?;
        /**
         * @stability stable
         */
        get versionId(): string | undefined;
        /**
         * @stability stable
         */
        set versionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersionId(): void;
        /**
         * @stability stable
         */
        get versionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get visibility(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
