import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS CloudHSM
*/
export declare namespace CloudHSM {
    /**
     * @stability stable
     */
    interface CloudhsmV2ClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#hsm_type CloudhsmV2Cluster#hsm_type}.
         *
         * @stability stable
         */
        readonly hsmType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#source_backup_identifier CloudhsmV2Cluster#source_backup_identifier}.
         *
         * @stability stable
         */
        readonly sourceBackupIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#subnet_ids CloudhsmV2Cluster#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#tags CloudhsmV2Cluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#tags_all CloudhsmV2Cluster#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#timeouts CloudhsmV2Cluster#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: CloudhsmV2ClusterTimeouts;
    }
    /**
     * @stability stable
     */
    class CloudhsmV2ClusterClusterCertificates extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get awsHardwareCertificate(): string;
        /**
         * @stability stable
         */
        get clusterCertificate(): string;
        /**
         * @stability stable
         */
        get clusterCsr(): string;
        /**
         * @stability stable
         */
        get hsmCertificate(): string;
        /**
         * @stability stable
         */
        get manufacturerHardwareCertificate(): string;
    }
    /**
     * @stability stable
     */
    interface CloudhsmV2ClusterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#create CloudhsmV2Cluster#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#delete CloudhsmV2Cluster#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html#update CloudhsmV2Cluster#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class CloudhsmV2ClusterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html aws_cloudhsm_v2_cluster}.
     *
     * @stability stable
     */
    class CloudhsmV2Cluster extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_cluster.html aws_cloudhsm_v2_cluster} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CloudhsmV2ClusterConfig);
        /**
         * @stability stable
         */
        clusterCertificates(index: string): CloudhsmV2ClusterClusterCertificates;
        /**
         * @stability stable
         */
        get clusterId(): string;
        /**
         * @stability stable
         */
        get clusterState(): string;
        private _hsmType?;
        /**
         * @stability stable
         */
        get hsmType(): string;
        /**
         * @stability stable
         */
        set hsmType(value: string);
        /**
         * @stability stable
         */
        get hsmTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get securityGroupId(): string;
        private _sourceBackupIdentifier?;
        /**
         * @stability stable
         */
        get sourceBackupIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set sourceBackupIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceBackupIdentifier(): void;
        /**
         * @stability stable
         */
        get sourceBackupIdentifierInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): CloudhsmV2ClusterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: CloudhsmV2ClusterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): CloudhsmV2ClusterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CloudhsmV2HsmConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html#availability_zone CloudhsmV2Hsm#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html#cluster_id CloudhsmV2Hsm#cluster_id}.
         *
         * @stability stable
         */
        readonly clusterId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html#ip_address CloudhsmV2Hsm#ip_address}.
         *
         * @stability stable
         */
        readonly ipAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html#subnet_id CloudhsmV2Hsm#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html#timeouts CloudhsmV2Hsm#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: CloudhsmV2HsmTimeouts;
    }
    /**
     * @stability stable
     */
    interface CloudhsmV2HsmTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html#create CloudhsmV2Hsm#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html#delete CloudhsmV2Hsm#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class CloudhsmV2HsmTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html aws_cloudhsm_v2_hsm}.
     *
     * @stability stable
     */
    class CloudhsmV2Hsm extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cloudhsm_v2_hsm.html aws_cloudhsm_v2_hsm} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CloudhsmV2HsmConfig);
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _clusterId?;
        /**
         * @stability stable
         */
        get clusterId(): string;
        /**
         * @stability stable
         */
        set clusterId(value: string);
        /**
         * @stability stable
         */
        get clusterIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get hsmEniId(): string;
        /**
         * @stability stable
         */
        get hsmId(): string;
        /**
         * @stability stable
         */
        get hsmState(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipAddress?;
        /**
         * @stability stable
         */
        get ipAddress(): string | undefined;
        /**
         * @stability stable
         */
        set ipAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpAddress(): void;
        /**
         * @stability stable
         */
        get ipAddressInput(): string | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): CloudhsmV2HsmTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: CloudhsmV2HsmTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): CloudhsmV2HsmTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCloudhsmV2ClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudhsm_v2_cluster.html#cluster_id DataAwsCloudhsmV2Cluster#cluster_id}.
         *
         * @stability stable
         */
        readonly clusterId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cloudhsm_v2_cluster.html#cluster_state DataAwsCloudhsmV2Cluster#cluster_state}.
         *
         * @stability stable
         */
        readonly clusterState?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsCloudhsmV2ClusterClusterCertificates extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get awsHardwareCertificate(): string;
        /**
         * @stability stable
         */
        get clusterCertificate(): string;
        /**
         * @stability stable
         */
        get clusterCsr(): string;
        /**
         * @stability stable
         */
        get hsmCertificate(): string;
        /**
         * @stability stable
         */
        get manufacturerHardwareCertificate(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/cloudhsm_v2_cluster.html aws_cloudhsm_v2_cluster}.
     *
     * @stability stable
     */
    class DataAwsCloudhsmV2Cluster extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/cloudhsm_v2_cluster.html aws_cloudhsm_v2_cluster} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsCloudhsmV2ClusterConfig);
        /**
         * @stability stable
         */
        clusterCertificates(index: string): DataAwsCloudhsmV2ClusterClusterCertificates;
        private _clusterId?;
        /**
         * @stability stable
         */
        get clusterId(): string;
        /**
         * @stability stable
         */
        set clusterId(value: string);
        /**
         * @stability stable
         */
        get clusterIdInput(): string | undefined;
        private _clusterState?;
        /**
         * @stability stable
         */
        get clusterState(): string | undefined;
        /**
         * @stability stable
         */
        set clusterState(value: string | undefined);
        /**
         * @stability stable
         */
        resetClusterState(): void;
        /**
         * @stability stable
         */
        get clusterStateInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get securityGroupId(): string;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
