import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS CodeArtifact
*/
export declare namespace CodeArtifact {
    /**
     * @stability stable
     */
    interface CodeartifactDomainConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain.html#domain CodeartifactDomain#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain.html#encryption_key CodeartifactDomain#encryption_key}.
         *
         * @stability stable
         */
        readonly encryptionKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain.html#tags CodeartifactDomain#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain.html#tags_all CodeartifactDomain#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain.html aws_codeartifact_domain}.
     *
     * @stability stable
     */
    class CodeartifactDomain extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain.html aws_codeartifact_domain} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodeartifactDomainConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get assetSizeBytes(): number;
        /**
         * @stability stable
         */
        get createdTime(): string;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        private _encryptionKey?;
        /**
         * @stability stable
         */
        get encryptionKey(): string | undefined;
        /**
         * @stability stable
         */
        set encryptionKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetEncryptionKey(): void;
        /**
         * @stability stable
         */
        get encryptionKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get owner(): string;
        /**
         * @stability stable
         */
        get repositoryCount(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CodeartifactDomainPermissionsPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain_permissions_policy.html#domain CodeartifactDomainPermissionsPolicy#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain_permissions_policy.html#domain_owner CodeartifactDomainPermissionsPolicy#domain_owner}.
         *
         * @stability stable
         */
        readonly domainOwner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain_permissions_policy.html#policy_document CodeartifactDomainPermissionsPolicy#policy_document}.
         *
         * @stability stable
         */
        readonly policyDocument: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain_permissions_policy.html#policy_revision CodeartifactDomainPermissionsPolicy#policy_revision}.
         *
         * @stability stable
         */
        readonly policyRevision?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain_permissions_policy.html aws_codeartifact_domain_permissions_policy}.
     *
     * @stability stable
     */
    class CodeartifactDomainPermissionsPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_domain_permissions_policy.html aws_codeartifact_domain_permissions_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodeartifactDomainPermissionsPolicyConfig);
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        private _domainOwner?;
        /**
         * @stability stable
         */
        get domainOwner(): string | undefined;
        /**
         * @stability stable
         */
        set domainOwner(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainOwner(): void;
        /**
         * @stability stable
         */
        get domainOwnerInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policyDocument?;
        /**
         * @stability stable
         */
        get policyDocument(): string;
        /**
         * @stability stable
         */
        set policyDocument(value: string);
        /**
         * @stability stable
         */
        get policyDocumentInput(): string | undefined;
        private _policyRevision?;
        /**
         * @stability stable
         */
        get policyRevision(): string | undefined;
        /**
         * @stability stable
         */
        set policyRevision(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicyRevision(): void;
        /**
         * @stability stable
         */
        get policyRevisionInput(): string | undefined;
        /**
         * @stability stable
         */
        get resourceArn(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CodeartifactRepositoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#description CodeartifactRepository#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#domain CodeartifactRepository#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#domain_owner CodeartifactRepository#domain_owner}.
         *
         * @stability stable
         */
        readonly domainOwner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#repository CodeartifactRepository#repository}.
         *
         * @stability stable
         */
        readonly repository: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#tags CodeartifactRepository#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#tags_all CodeartifactRepository#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * external_connections block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#external_connections CodeartifactRepository#external_connections}
         *
         * @stability stable
         */
        readonly externalConnections?: CodeartifactRepositoryExternalConnections;
        /**
         * upstream block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#upstream CodeartifactRepository#upstream}
         *
         * @stability stable
         */
        readonly upstream?: CodeartifactRepositoryUpstream[];
    }
    /**
     * @stability stable
     */
    interface CodeartifactRepositoryExternalConnections {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#external_connection_name CodeartifactRepository#external_connection_name}.
         *
         * @stability stable
         */
        readonly externalConnectionName: string;
    }
    /**
     * @stability stable
     */
    class CodeartifactRepositoryExternalConnectionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _externalConnectionName?;
        /**
         * @stability stable
         */
        get externalConnectionName(): string;
        /**
         * @stability stable
         */
        set externalConnectionName(value: string);
        /**
         * @stability stable
         */
        get externalConnectionNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CodeartifactRepositoryUpstream {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html#repository_name CodeartifactRepository#repository_name}.
         *
         * @stability stable
         */
        readonly repositoryName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html aws_codeartifact_repository}.
     *
     * @stability stable
     */
    class CodeartifactRepository extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository.html aws_codeartifact_repository} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodeartifactRepositoryConfig);
        /**
         * @stability stable
         */
        get administratorAccount(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        private _domainOwner?;
        /**
         * @stability stable
         */
        get domainOwner(): string | undefined;
        /**
         * @stability stable
         */
        set domainOwner(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainOwner(): void;
        /**
         * @stability stable
         */
        get domainOwnerInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _repository?;
        /**
         * @stability stable
         */
        get repository(): string;
        /**
         * @stability stable
         */
        set repository(value: string);
        /**
         * @stability stable
         */
        get repositoryInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _externalConnections?;
        private __externalConnectionsOutput;
        /**
         * @stability stable
         */
        get externalConnections(): CodeartifactRepositoryExternalConnectionsOutputReference;
        /**
         * @stability stable
         */
        putExternalConnections(value: CodeartifactRepositoryExternalConnections | undefined): void;
        /**
         * @stability stable
         */
        resetExternalConnections(): void;
        /**
         * @stability stable
         */
        get externalConnectionsInput(): CodeartifactRepositoryExternalConnections | undefined;
        private _upstream?;
        /**
         * @stability stable
         */
        get upstream(): CodeartifactRepositoryUpstream[] | undefined;
        /**
         * @stability stable
         */
        set upstream(value: CodeartifactRepositoryUpstream[] | undefined);
        /**
         * @stability stable
         */
        resetUpstream(): void;
        /**
         * @stability stable
         */
        get upstreamInput(): CodeartifactRepositoryUpstream[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CodeartifactRepositoryPermissionsPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository_permissions_policy.html#domain CodeartifactRepositoryPermissionsPolicy#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository_permissions_policy.html#domain_owner CodeartifactRepositoryPermissionsPolicy#domain_owner}.
         *
         * @stability stable
         */
        readonly domainOwner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository_permissions_policy.html#policy_document CodeartifactRepositoryPermissionsPolicy#policy_document}.
         *
         * @stability stable
         */
        readonly policyDocument: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository_permissions_policy.html#policy_revision CodeartifactRepositoryPermissionsPolicy#policy_revision}.
         *
         * @stability stable
         */
        readonly policyRevision?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository_permissions_policy.html#repository CodeartifactRepositoryPermissionsPolicy#repository}.
         *
         * @stability stable
         */
        readonly repository: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository_permissions_policy.html aws_codeartifact_repository_permissions_policy}.
     *
     * @stability stable
     */
    class CodeartifactRepositoryPermissionsPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codeartifact_repository_permissions_policy.html aws_codeartifact_repository_permissions_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodeartifactRepositoryPermissionsPolicyConfig);
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        private _domainOwner?;
        /**
         * @stability stable
         */
        get domainOwner(): string | undefined;
        /**
         * @stability stable
         */
        set domainOwner(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainOwner(): void;
        /**
         * @stability stable
         */
        get domainOwnerInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policyDocument?;
        /**
         * @stability stable
         */
        get policyDocument(): string;
        /**
         * @stability stable
         */
        set policyDocument(value: string);
        /**
         * @stability stable
         */
        get policyDocumentInput(): string | undefined;
        private _policyRevision?;
        /**
         * @stability stable
         */
        get policyRevision(): string | undefined;
        /**
         * @stability stable
         */
        set policyRevision(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicyRevision(): void;
        /**
         * @stability stable
         */
        get policyRevisionInput(): string | undefined;
        private _repository?;
        /**
         * @stability stable
         */
        get repository(): string;
        /**
         * @stability stable
         */
        set repository(value: string);
        /**
         * @stability stable
         */
        get repositoryInput(): string | undefined;
        /**
         * @stability stable
         */
        get resourceArn(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCodeartifactAuthorizationTokenConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_authorization_token.html#domain DataAwsCodeartifactAuthorizationToken#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_authorization_token.html#domain_owner DataAwsCodeartifactAuthorizationToken#domain_owner}.
         *
         * @stability stable
         */
        readonly domainOwner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_authorization_token.html#duration_seconds DataAwsCodeartifactAuthorizationToken#duration_seconds}.
         *
         * @stability stable
         */
        readonly durationSeconds?: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_authorization_token.html aws_codeartifact_authorization_token}.
     *
     * @stability stable
     */
    class DataAwsCodeartifactAuthorizationToken extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_authorization_token.html aws_codeartifact_authorization_token} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsCodeartifactAuthorizationTokenConfig);
        /**
         * @stability stable
         */
        get authorizationToken(): string;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        private _domainOwner?;
        /**
         * @stability stable
         */
        get domainOwner(): string | undefined;
        /**
         * @stability stable
         */
        set domainOwner(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainOwner(): void;
        /**
         * @stability stable
         */
        get domainOwnerInput(): string | undefined;
        private _durationSeconds?;
        /**
         * @stability stable
         */
        get durationSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set durationSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetDurationSeconds(): void;
        /**
         * @stability stable
         */
        get durationSecondsInput(): number | undefined;
        /**
         * @stability stable
         */
        get expiration(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCodeartifactRepositoryEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_repository_endpoint.html#domain DataAwsCodeartifactRepositoryEndpoint#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_repository_endpoint.html#domain_owner DataAwsCodeartifactRepositoryEndpoint#domain_owner}.
         *
         * @stability stable
         */
        readonly domainOwner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_repository_endpoint.html#format DataAwsCodeartifactRepositoryEndpoint#format}.
         *
         * @stability stable
         */
        readonly format: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_repository_endpoint.html#repository DataAwsCodeartifactRepositoryEndpoint#repository}.
         *
         * @stability stable
         */
        readonly repository: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_repository_endpoint.html aws_codeartifact_repository_endpoint}.
     *
     * @stability stable
     */
    class DataAwsCodeartifactRepositoryEndpoint extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/codeartifact_repository_endpoint.html aws_codeartifact_repository_endpoint} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsCodeartifactRepositoryEndpointConfig);
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        private _domainOwner?;
        /**
         * @stability stable
         */
        get domainOwner(): string | undefined;
        /**
         * @stability stable
         */
        set domainOwner(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainOwner(): void;
        /**
         * @stability stable
         */
        get domainOwnerInput(): string | undefined;
        private _format?;
        /**
         * @stability stable
         */
        get format(): string;
        /**
         * @stability stable
         */
        set format(value: string);
        /**
         * @stability stable
         */
        get formatInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _repository?;
        /**
         * @stability stable
         */
        get repository(): string;
        /**
         * @stability stable
         */
        set repository(value: string);
        /**
         * @stability stable
         */
        get repositoryInput(): string | undefined;
        /**
         * @stability stable
         */
        get repositoryEndpoint(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
