import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS CodeDeploy
*/
export declare namespace CodeDeploy {
    /**
     * @stability stable
     */
    interface CodedeployAppConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_app.html#compute_platform CodedeployApp#compute_platform}.
         *
         * @stability stable
         */
        readonly computePlatform?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_app.html#name CodedeployApp#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_app.html#tags CodedeployApp#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_app.html#tags_all CodedeployApp#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_app.html aws_codedeploy_app}.
     *
     * @stability stable
     */
    class CodedeployApp extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_app.html aws_codedeploy_app} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodedeployAppConfig);
        /**
         * @stability stable
         */
        get applicationId(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        private _computePlatform?;
        /**
         * @stability stable
         */
        get computePlatform(): string | undefined;
        /**
         * @stability stable
         */
        set computePlatform(value: string | undefined);
        /**
         * @stability stable
         */
        resetComputePlatform(): void;
        /**
         * @stability stable
         */
        get computePlatformInput(): string | undefined;
        /**
         * @stability stable
         */
        get githubAccountName(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get linkedToGithub(): any;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#compute_platform CodedeployDeploymentConfig#compute_platform}.
         *
         * @stability stable
         */
        readonly computePlatform?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#deployment_config_name CodedeployDeploymentConfig#deployment_config_name}.
         *
         * @stability stable
         */
        readonly deploymentConfigName: string;
        /**
         * minimum_healthy_hosts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#minimum_healthy_hosts CodedeployDeploymentConfig#minimum_healthy_hosts}
         *
         * @stability stable
         */
        readonly minimumHealthyHosts?: CodedeployDeploymentConfigMinimumHealthyHosts;
        /**
         * traffic_routing_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#traffic_routing_config CodedeployDeploymentConfig#traffic_routing_config}
         *
         * @stability stable
         */
        readonly trafficRoutingConfig?: CodedeployDeploymentConfigTrafficRoutingConfig;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentConfigMinimumHealthyHosts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#type CodedeployDeploymentConfig#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#value CodedeployDeploymentConfig#value}.
         *
         * @stability stable
         */
        readonly value?: number;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentConfigMinimumHealthyHostsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number | undefined;
        /**
         * @stability stable
         */
        set value(value: number | undefined);
        /**
         * @stability stable
         */
        resetValue(): void;
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#interval CodedeployDeploymentConfig#interval}.
         *
         * @stability stable
         */
        readonly interval?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#percentage CodedeployDeploymentConfig#percentage}.
         *
         * @stability stable
         */
        readonly percentage?: number;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanaryOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _interval?;
        /**
         * @stability stable
         */
        get interval(): number | undefined;
        /**
         * @stability stable
         */
        set interval(value: number | undefined);
        /**
         * @stability stable
         */
        resetInterval(): void;
        /**
         * @stability stable
         */
        get intervalInput(): number | undefined;
        private _percentage?;
        /**
         * @stability stable
         */
        get percentage(): number | undefined;
        /**
         * @stability stable
         */
        set percentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetPercentage(): void;
        /**
         * @stability stable
         */
        get percentageInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#interval CodedeployDeploymentConfig#interval}.
         *
         * @stability stable
         */
        readonly interval?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#percentage CodedeployDeploymentConfig#percentage}.
         *
         * @stability stable
         */
        readonly percentage?: number;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinearOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _interval?;
        /**
         * @stability stable
         */
        get interval(): number | undefined;
        /**
         * @stability stable
         */
        set interval(value: number | undefined);
        /**
         * @stability stable
         */
        resetInterval(): void;
        /**
         * @stability stable
         */
        get intervalInput(): number | undefined;
        private _percentage?;
        /**
         * @stability stable
         */
        get percentage(): number | undefined;
        /**
         * @stability stable
         */
        set percentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetPercentage(): void;
        /**
         * @stability stable
         */
        get percentageInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentConfigTrafficRoutingConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#type CodedeployDeploymentConfig#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * time_based_canary block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#time_based_canary CodedeployDeploymentConfig#time_based_canary}
         *
         * @stability stable
         */
        readonly timeBasedCanary?: CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary;
        /**
         * time_based_linear block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html#time_based_linear CodedeployDeploymentConfig#time_based_linear}
         *
         * @stability stable
         */
        readonly timeBasedLinear?: CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentConfigTrafficRoutingConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _timeBasedCanary?;
        private __timeBasedCanaryOutput;
        /**
         * @stability stable
         */
        get timeBasedCanary(): CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanaryOutputReference;
        /**
         * @stability stable
         */
        putTimeBasedCanary(value: CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary | undefined): void;
        /**
         * @stability stable
         */
        resetTimeBasedCanary(): void;
        /**
         * @stability stable
         */
        get timeBasedCanaryInput(): CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary | undefined;
        private _timeBasedLinear?;
        private __timeBasedLinearOutput;
        /**
         * @stability stable
         */
        get timeBasedLinear(): CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinearOutputReference;
        /**
         * @stability stable
         */
        putTimeBasedLinear(value: CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear | undefined): void;
        /**
         * @stability stable
         */
        resetTimeBasedLinear(): void;
        /**
         * @stability stable
         */
        get timeBasedLinearInput(): CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html aws_codedeploy_deployment_config}.
     *
     * @stability stable
     */
    class CodedeployDeploymentConfig extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_config.html aws_codedeploy_deployment_config} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodedeployDeploymentConfigConfig);
        private _computePlatform?;
        /**
         * @stability stable
         */
        get computePlatform(): string | undefined;
        /**
         * @stability stable
         */
        set computePlatform(value: string | undefined);
        /**
         * @stability stable
         */
        resetComputePlatform(): void;
        /**
         * @stability stable
         */
        get computePlatformInput(): string | undefined;
        /**
         * @stability stable
         */
        get deploymentConfigId(): string;
        private _deploymentConfigName?;
        /**
         * @stability stable
         */
        get deploymentConfigName(): string;
        /**
         * @stability stable
         */
        set deploymentConfigName(value: string);
        /**
         * @stability stable
         */
        get deploymentConfigNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _minimumHealthyHosts?;
        private __minimumHealthyHostsOutput;
        /**
         * @stability stable
         */
        get minimumHealthyHosts(): CodedeployDeploymentConfigMinimumHealthyHostsOutputReference;
        /**
         * @stability stable
         */
        putMinimumHealthyHosts(value: CodedeployDeploymentConfigMinimumHealthyHosts | undefined): void;
        /**
         * @stability stable
         */
        resetMinimumHealthyHosts(): void;
        /**
         * @stability stable
         */
        get minimumHealthyHostsInput(): CodedeployDeploymentConfigMinimumHealthyHosts | undefined;
        private _trafficRoutingConfig?;
        private __trafficRoutingConfigOutput;
        /**
         * @stability stable
         */
        get trafficRoutingConfig(): CodedeployDeploymentConfigTrafficRoutingConfigOutputReference;
        /**
         * @stability stable
         */
        putTrafficRoutingConfig(value: CodedeployDeploymentConfigTrafficRoutingConfig | undefined): void;
        /**
         * @stability stable
         */
        resetTrafficRoutingConfig(): void;
        /**
         * @stability stable
         */
        get trafficRoutingConfigInput(): CodedeployDeploymentConfigTrafficRoutingConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#app_name CodedeployDeploymentGroup#app_name}.
         *
         * @stability stable
         */
        readonly appName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#autoscaling_groups CodedeployDeploymentGroup#autoscaling_groups}.
         *
         * @stability stable
         */
        readonly autoscalingGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#deployment_config_name CodedeployDeploymentGroup#deployment_config_name}.
         *
         * @stability stable
         */
        readonly deploymentConfigName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#deployment_group_name CodedeployDeploymentGroup#deployment_group_name}.
         *
         * @stability stable
         */
        readonly deploymentGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#service_role_arn CodedeployDeploymentGroup#service_role_arn}.
         *
         * @stability stable
         */
        readonly serviceRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#tags CodedeployDeploymentGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#tags_all CodedeployDeploymentGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * alarm_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#alarm_configuration CodedeployDeploymentGroup#alarm_configuration}
         *
         * @stability stable
         */
        readonly alarmConfiguration?: CodedeployDeploymentGroupAlarmConfiguration;
        /**
         * auto_rollback_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#auto_rollback_configuration CodedeployDeploymentGroup#auto_rollback_configuration}
         *
         * @stability stable
         */
        readonly autoRollbackConfiguration?: CodedeployDeploymentGroupAutoRollbackConfiguration;
        /**
         * blue_green_deployment_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#blue_green_deployment_config CodedeployDeploymentGroup#blue_green_deployment_config}
         *
         * @stability stable
         */
        readonly blueGreenDeploymentConfig?: CodedeployDeploymentGroupBlueGreenDeploymentConfig;
        /**
         * deployment_style block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#deployment_style CodedeployDeploymentGroup#deployment_style}
         *
         * @stability stable
         */
        readonly deploymentStyle?: CodedeployDeploymentGroupDeploymentStyle;
        /**
         * ec2_tag_filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#ec2_tag_filter CodedeployDeploymentGroup#ec2_tag_filter}
         *
         * @stability stable
         */
        readonly ec2TagFilter?: CodedeployDeploymentGroupEc2TagFilter[];
        /**
         * ec2_tag_set block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#ec2_tag_set CodedeployDeploymentGroup#ec2_tag_set}
         *
         * @stability stable
         */
        readonly ec2TagSet?: CodedeployDeploymentGroupEc2TagSet[];
        /**
         * ecs_service block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#ecs_service CodedeployDeploymentGroup#ecs_service}
         *
         * @stability stable
         */
        readonly ecsService?: CodedeployDeploymentGroupEcsService;
        /**
         * load_balancer_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#load_balancer_info CodedeployDeploymentGroup#load_balancer_info}
         *
         * @stability stable
         */
        readonly loadBalancerInfo?: CodedeployDeploymentGroupLoadBalancerInfo;
        /**
         * on_premises_instance_tag_filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#on_premises_instance_tag_filter CodedeployDeploymentGroup#on_premises_instance_tag_filter}
         *
         * @stability stable
         */
        readonly onPremisesInstanceTagFilter?: CodedeployDeploymentGroupOnPremisesInstanceTagFilter[];
        /**
         * trigger_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#trigger_configuration CodedeployDeploymentGroup#trigger_configuration}
         *
         * @stability stable
         */
        readonly triggerConfiguration?: CodedeployDeploymentGroupTriggerConfiguration[];
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupAlarmConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#alarms CodedeployDeploymentGroup#alarms}.
         *
         * @stability stable
         */
        readonly alarms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#enabled CodedeployDeploymentGroup#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#ignore_poll_alarm_failure CodedeployDeploymentGroup#ignore_poll_alarm_failure}.
         *
         * @stability stable
         */
        readonly ignorePollAlarmFailure?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupAlarmConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _alarms?;
        /**
         * @stability stable
         */
        get alarms(): string[] | undefined;
        /**
         * @stability stable
         */
        set alarms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAlarms(): void;
        /**
         * @stability stable
         */
        get alarmsInput(): string[] | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _ignorePollAlarmFailure?;
        /**
         * @stability stable
         */
        get ignorePollAlarmFailure(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set ignorePollAlarmFailure(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIgnorePollAlarmFailure(): void;
        /**
         * @stability stable
         */
        get ignorePollAlarmFailureInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupAutoRollbackConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#enabled CodedeployDeploymentGroup#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#events CodedeployDeploymentGroup#events}.
         *
         * @stability stable
         */
        readonly events?: string[];
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupAutoRollbackConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _events?;
        /**
         * @stability stable
         */
        get events(): string[] | undefined;
        /**
         * @stability stable
         */
        set events(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEvents(): void;
        /**
         * @stability stable
         */
        get eventsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#action_on_timeout CodedeployDeploymentGroup#action_on_timeout}.
         *
         * @stability stable
         */
        readonly actionOnTimeout?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#wait_time_in_minutes CodedeployDeploymentGroup#wait_time_in_minutes}.
         *
         * @stability stable
         */
        readonly waitTimeInMinutes?: number;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _actionOnTimeout?;
        /**
         * @stability stable
         */
        get actionOnTimeout(): string | undefined;
        /**
         * @stability stable
         */
        set actionOnTimeout(value: string | undefined);
        /**
         * @stability stable
         */
        resetActionOnTimeout(): void;
        /**
         * @stability stable
         */
        get actionOnTimeoutInput(): string | undefined;
        private _waitTimeInMinutes?;
        /**
         * @stability stable
         */
        get waitTimeInMinutes(): number | undefined;
        /**
         * @stability stable
         */
        set waitTimeInMinutes(value: number | undefined);
        /**
         * @stability stable
         */
        resetWaitTimeInMinutes(): void;
        /**
         * @stability stable
         */
        get waitTimeInMinutesInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#action CodedeployDeploymentGroup#action}.
         *
         * @stability stable
         */
        readonly action?: string;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _action?;
        /**
         * @stability stable
         */
        get action(): string | undefined;
        /**
         * @stability stable
         */
        set action(value: string | undefined);
        /**
         * @stability stable
         */
        resetAction(): void;
        /**
         * @stability stable
         */
        get actionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#action CodedeployDeploymentGroup#action}.
         *
         * @stability stable
         */
        readonly action?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#termination_wait_time_in_minutes CodedeployDeploymentGroup#termination_wait_time_in_minutes}.
         *
         * @stability stable
         */
        readonly terminationWaitTimeInMinutes?: number;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _action?;
        /**
         * @stability stable
         */
        get action(): string | undefined;
        /**
         * @stability stable
         */
        set action(value: string | undefined);
        /**
         * @stability stable
         */
        resetAction(): void;
        /**
         * @stability stable
         */
        get actionInput(): string | undefined;
        private _terminationWaitTimeInMinutes?;
        /**
         * @stability stable
         */
        get terminationWaitTimeInMinutes(): number | undefined;
        /**
         * @stability stable
         */
        set terminationWaitTimeInMinutes(value: number | undefined);
        /**
         * @stability stable
         */
        resetTerminationWaitTimeInMinutes(): void;
        /**
         * @stability stable
         */
        get terminationWaitTimeInMinutesInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupBlueGreenDeploymentConfig {
        /**
         * deployment_ready_option block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#deployment_ready_option CodedeployDeploymentGroup#deployment_ready_option}
         *
         * @stability stable
         */
        readonly deploymentReadyOption?: CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption;
        /**
         * green_fleet_provisioning_option block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#green_fleet_provisioning_option CodedeployDeploymentGroup#green_fleet_provisioning_option}
         *
         * @stability stable
         */
        readonly greenFleetProvisioningOption?: CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption;
        /**
         * terminate_blue_instances_on_deployment_success block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#terminate_blue_instances_on_deployment_success CodedeployDeploymentGroup#terminate_blue_instances_on_deployment_success}
         *
         * @stability stable
         */
        readonly terminateBlueInstancesOnDeploymentSuccess?: CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupBlueGreenDeploymentConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _deploymentReadyOption?;
        private __deploymentReadyOptionOutput;
        /**
         * @stability stable
         */
        get deploymentReadyOption(): CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOptionOutputReference;
        /**
         * @stability stable
         */
        putDeploymentReadyOption(value: CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption | undefined): void;
        /**
         * @stability stable
         */
        resetDeploymentReadyOption(): void;
        /**
         * @stability stable
         */
        get deploymentReadyOptionInput(): CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption | undefined;
        private _greenFleetProvisioningOption?;
        private __greenFleetProvisioningOptionOutput;
        /**
         * @stability stable
         */
        get greenFleetProvisioningOption(): CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOptionOutputReference;
        /**
         * @stability stable
         */
        putGreenFleetProvisioningOption(value: CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption | undefined): void;
        /**
         * @stability stable
         */
        resetGreenFleetProvisioningOption(): void;
        /**
         * @stability stable
         */
        get greenFleetProvisioningOptionInput(): CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption | undefined;
        private _terminateBlueInstancesOnDeploymentSuccess?;
        private __terminateBlueInstancesOnDeploymentSuccessOutput;
        /**
         * @stability stable
         */
        get terminateBlueInstancesOnDeploymentSuccess(): CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccessOutputReference;
        /**
         * @stability stable
         */
        putTerminateBlueInstancesOnDeploymentSuccess(value: CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess | undefined): void;
        /**
         * @stability stable
         */
        resetTerminateBlueInstancesOnDeploymentSuccess(): void;
        /**
         * @stability stable
         */
        get terminateBlueInstancesOnDeploymentSuccessInput(): CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupDeploymentStyle {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#deployment_option CodedeployDeploymentGroup#deployment_option}.
         *
         * @stability stable
         */
        readonly deploymentOption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#deployment_type CodedeployDeploymentGroup#deployment_type}.
         *
         * @stability stable
         */
        readonly deploymentType?: string;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupDeploymentStyleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _deploymentOption?;
        /**
         * @stability stable
         */
        get deploymentOption(): string | undefined;
        /**
         * @stability stable
         */
        set deploymentOption(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeploymentOption(): void;
        /**
         * @stability stable
         */
        get deploymentOptionInput(): string | undefined;
        private _deploymentType?;
        /**
         * @stability stable
         */
        get deploymentType(): string | undefined;
        /**
         * @stability stable
         */
        set deploymentType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeploymentType(): void;
        /**
         * @stability stable
         */
        get deploymentTypeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupEc2TagFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#key CodedeployDeploymentGroup#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#type CodedeployDeploymentGroup#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#value CodedeployDeploymentGroup#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupEc2TagSetEc2TagFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#key CodedeployDeploymentGroup#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#type CodedeployDeploymentGroup#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#value CodedeployDeploymentGroup#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupEc2TagSet {
        /**
         * ec2_tag_filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#ec2_tag_filter CodedeployDeploymentGroup#ec2_tag_filter}
         *
         * @stability stable
         */
        readonly ec2TagFilter?: CodedeployDeploymentGroupEc2TagSetEc2TagFilter[];
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupEcsService {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#cluster_name CodedeployDeploymentGroup#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#service_name CodedeployDeploymentGroup#service_name}.
         *
         * @stability stable
         */
        readonly serviceName: string;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupEcsServiceOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        private _serviceName?;
        /**
         * @stability stable
         */
        get serviceName(): string;
        /**
         * @stability stable
         */
        set serviceName(value: string);
        /**
         * @stability stable
         */
        get serviceNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupLoadBalancerInfoElbInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#name CodedeployDeploymentGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#name CodedeployDeploymentGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#listener_arns CodedeployDeploymentGroup#listener_arns}.
         *
         * @stability stable
         */
        readonly listenerArns: string[];
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRouteOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _listenerArns?;
        /**
         * @stability stable
         */
        get listenerArns(): string[];
        /**
         * @stability stable
         */
        set listenerArns(value: string[]);
        /**
         * @stability stable
         */
        get listenerArnsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#name CodedeployDeploymentGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#listener_arns CodedeployDeploymentGroup#listener_arns}.
         *
         * @stability stable
         */
        readonly listenerArns: string[];
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _listenerArns?;
        /**
         * @stability stable
         */
        get listenerArns(): string[];
        /**
         * @stability stable
         */
        set listenerArns(value: string[]);
        /**
         * @stability stable
         */
        get listenerArnsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo {
        /**
         * prod_traffic_route block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#prod_traffic_route CodedeployDeploymentGroup#prod_traffic_route}
         *
         * @stability stable
         */
        readonly prodTrafficRoute: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute;
        /**
         * target_group block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#target_group CodedeployDeploymentGroup#target_group}
         *
         * @stability stable
         */
        readonly targetGroup: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup[];
        /**
         * test_traffic_route block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#test_traffic_route CodedeployDeploymentGroup#test_traffic_route}
         *
         * @stability stable
         */
        readonly testTrafficRoute?: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _prodTrafficRoute?;
        private __prodTrafficRouteOutput;
        /**
         * @stability stable
         */
        get prodTrafficRoute(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRouteOutputReference;
        /**
         * @stability stable
         */
        putProdTrafficRoute(value: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute): void;
        /**
         * @stability stable
         */
        get prodTrafficRouteInput(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute | undefined;
        private _targetGroup?;
        /**
         * @stability stable
         */
        get targetGroup(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup[];
        /**
         * @stability stable
         */
        set targetGroup(value: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup[]);
        /**
         * @stability stable
         */
        get targetGroupInput(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup[] | undefined;
        private _testTrafficRoute?;
        private __testTrafficRouteOutput;
        /**
         * @stability stable
         */
        get testTrafficRoute(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRouteOutputReference;
        /**
         * @stability stable
         */
        putTestTrafficRoute(value: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute | undefined): void;
        /**
         * @stability stable
         */
        resetTestTrafficRoute(): void;
        /**
         * @stability stable
         */
        get testTrafficRouteInput(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupLoadBalancerInfo {
        /**
         * elb_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#elb_info CodedeployDeploymentGroup#elb_info}
         *
         * @stability stable
         */
        readonly elbInfo?: CodedeployDeploymentGroupLoadBalancerInfoElbInfo[];
        /**
         * target_group_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#target_group_info CodedeployDeploymentGroup#target_group_info}
         *
         * @stability stable
         */
        readonly targetGroupInfo?: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo[];
        /**
         * target_group_pair_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#target_group_pair_info CodedeployDeploymentGroup#target_group_pair_info}
         *
         * @stability stable
         */
        readonly targetGroupPairInfo?: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo;
    }
    /**
     * @stability stable
     */
    class CodedeployDeploymentGroupLoadBalancerInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _elbInfo?;
        /**
         * @stability stable
         */
        get elbInfo(): CodedeployDeploymentGroupLoadBalancerInfoElbInfo[] | undefined;
        /**
         * @stability stable
         */
        set elbInfo(value: CodedeployDeploymentGroupLoadBalancerInfoElbInfo[] | undefined);
        /**
         * @stability stable
         */
        resetElbInfo(): void;
        /**
         * @stability stable
         */
        get elbInfoInput(): CodedeployDeploymentGroupLoadBalancerInfoElbInfo[] | undefined;
        private _targetGroupInfo?;
        /**
         * @stability stable
         */
        get targetGroupInfo(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo[] | undefined;
        /**
         * @stability stable
         */
        set targetGroupInfo(value: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo[] | undefined);
        /**
         * @stability stable
         */
        resetTargetGroupInfo(): void;
        /**
         * @stability stable
         */
        get targetGroupInfoInput(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo[] | undefined;
        private _targetGroupPairInfo?;
        private __targetGroupPairInfoOutput;
        /**
         * @stability stable
         */
        get targetGroupPairInfo(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoOutputReference;
        /**
         * @stability stable
         */
        putTargetGroupPairInfo(value: CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo | undefined): void;
        /**
         * @stability stable
         */
        resetTargetGroupPairInfo(): void;
        /**
         * @stability stable
         */
        get targetGroupPairInfoInput(): CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo | undefined;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupOnPremisesInstanceTagFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#key CodedeployDeploymentGroup#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#type CodedeployDeploymentGroup#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#value CodedeployDeploymentGroup#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * @stability stable
     */
    interface CodedeployDeploymentGroupTriggerConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#trigger_events CodedeployDeploymentGroup#trigger_events}.
         *
         * @stability stable
         */
        readonly triggerEvents: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#trigger_name CodedeployDeploymentGroup#trigger_name}.
         *
         * @stability stable
         */
        readonly triggerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html#trigger_target_arn CodedeployDeploymentGroup#trigger_target_arn}.
         *
         * @stability stable
         */
        readonly triggerTargetArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html aws_codedeploy_deployment_group}.
     *
     * @stability stable
     */
    class CodedeployDeploymentGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codedeploy_deployment_group.html aws_codedeploy_deployment_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodedeployDeploymentGroupConfig);
        private _appName?;
        /**
         * @stability stable
         */
        get appName(): string;
        /**
         * @stability stable
         */
        set appName(value: string);
        /**
         * @stability stable
         */
        get appNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoscalingGroups?;
        /**
         * @stability stable
         */
        get autoscalingGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set autoscalingGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAutoscalingGroups(): void;
        /**
         * @stability stable
         */
        get autoscalingGroupsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get computePlatform(): string;
        private _deploymentConfigName?;
        /**
         * @stability stable
         */
        get deploymentConfigName(): string | undefined;
        /**
         * @stability stable
         */
        set deploymentConfigName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeploymentConfigName(): void;
        /**
         * @stability stable
         */
        get deploymentConfigNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get deploymentGroupId(): string;
        private _deploymentGroupName?;
        /**
         * @stability stable
         */
        get deploymentGroupName(): string;
        /**
         * @stability stable
         */
        set deploymentGroupName(value: string);
        /**
         * @stability stable
         */
        get deploymentGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _serviceRoleArn?;
        /**
         * @stability stable
         */
        get serviceRoleArn(): string;
        /**
         * @stability stable
         */
        set serviceRoleArn(value: string);
        /**
         * @stability stable
         */
        get serviceRoleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _alarmConfiguration?;
        private __alarmConfigurationOutput;
        /**
         * @stability stable
         */
        get alarmConfiguration(): CodedeployDeploymentGroupAlarmConfigurationOutputReference;
        /**
         * @stability stable
         */
        putAlarmConfiguration(value: CodedeployDeploymentGroupAlarmConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetAlarmConfiguration(): void;
        /**
         * @stability stable
         */
        get alarmConfigurationInput(): CodedeployDeploymentGroupAlarmConfiguration | undefined;
        private _autoRollbackConfiguration?;
        private __autoRollbackConfigurationOutput;
        /**
         * @stability stable
         */
        get autoRollbackConfiguration(): CodedeployDeploymentGroupAutoRollbackConfigurationOutputReference;
        /**
         * @stability stable
         */
        putAutoRollbackConfiguration(value: CodedeployDeploymentGroupAutoRollbackConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetAutoRollbackConfiguration(): void;
        /**
         * @stability stable
         */
        get autoRollbackConfigurationInput(): CodedeployDeploymentGroupAutoRollbackConfiguration | undefined;
        private _blueGreenDeploymentConfig?;
        private __blueGreenDeploymentConfigOutput;
        /**
         * @stability stable
         */
        get blueGreenDeploymentConfig(): CodedeployDeploymentGroupBlueGreenDeploymentConfigOutputReference;
        /**
         * @stability stable
         */
        putBlueGreenDeploymentConfig(value: CodedeployDeploymentGroupBlueGreenDeploymentConfig | undefined): void;
        /**
         * @stability stable
         */
        resetBlueGreenDeploymentConfig(): void;
        /**
         * @stability stable
         */
        get blueGreenDeploymentConfigInput(): CodedeployDeploymentGroupBlueGreenDeploymentConfig | undefined;
        private _deploymentStyle?;
        private __deploymentStyleOutput;
        /**
         * @stability stable
         */
        get deploymentStyle(): CodedeployDeploymentGroupDeploymentStyleOutputReference;
        /**
         * @stability stable
         */
        putDeploymentStyle(value: CodedeployDeploymentGroupDeploymentStyle | undefined): void;
        /**
         * @stability stable
         */
        resetDeploymentStyle(): void;
        /**
         * @stability stable
         */
        get deploymentStyleInput(): CodedeployDeploymentGroupDeploymentStyle | undefined;
        private _ec2TagFilter?;
        /**
         * @stability stable
         */
        get ec2TagFilter(): CodedeployDeploymentGroupEc2TagFilter[] | undefined;
        /**
         * @stability stable
         */
        set ec2TagFilter(value: CodedeployDeploymentGroupEc2TagFilter[] | undefined);
        /**
         * @stability stable
         */
        resetEc2TagFilter(): void;
        /**
         * @stability stable
         */
        get ec2TagFilterInput(): CodedeployDeploymentGroupEc2TagFilter[] | undefined;
        private _ec2TagSet?;
        /**
         * @stability stable
         */
        get ec2TagSet(): CodedeployDeploymentGroupEc2TagSet[] | undefined;
        /**
         * @stability stable
         */
        set ec2TagSet(value: CodedeployDeploymentGroupEc2TagSet[] | undefined);
        /**
         * @stability stable
         */
        resetEc2TagSet(): void;
        /**
         * @stability stable
         */
        get ec2TagSetInput(): CodedeployDeploymentGroupEc2TagSet[] | undefined;
        private _ecsService?;
        private __ecsServiceOutput;
        /**
         * @stability stable
         */
        get ecsService(): CodedeployDeploymentGroupEcsServiceOutputReference;
        /**
         * @stability stable
         */
        putEcsService(value: CodedeployDeploymentGroupEcsService | undefined): void;
        /**
         * @stability stable
         */
        resetEcsService(): void;
        /**
         * @stability stable
         */
        get ecsServiceInput(): CodedeployDeploymentGroupEcsService | undefined;
        private _loadBalancerInfo?;
        private __loadBalancerInfoOutput;
        /**
         * @stability stable
         */
        get loadBalancerInfo(): CodedeployDeploymentGroupLoadBalancerInfoOutputReference;
        /**
         * @stability stable
         */
        putLoadBalancerInfo(value: CodedeployDeploymentGroupLoadBalancerInfo | undefined): void;
        /**
         * @stability stable
         */
        resetLoadBalancerInfo(): void;
        /**
         * @stability stable
         */
        get loadBalancerInfoInput(): CodedeployDeploymentGroupLoadBalancerInfo | undefined;
        private _onPremisesInstanceTagFilter?;
        /**
         * @stability stable
         */
        get onPremisesInstanceTagFilter(): CodedeployDeploymentGroupOnPremisesInstanceTagFilter[] | undefined;
        /**
         * @stability stable
         */
        set onPremisesInstanceTagFilter(value: CodedeployDeploymentGroupOnPremisesInstanceTagFilter[] | undefined);
        /**
         * @stability stable
         */
        resetOnPremisesInstanceTagFilter(): void;
        /**
         * @stability stable
         */
        get onPremisesInstanceTagFilterInput(): CodedeployDeploymentGroupOnPremisesInstanceTagFilter[] | undefined;
        private _triggerConfiguration?;
        /**
         * @stability stable
         */
        get triggerConfiguration(): CodedeployDeploymentGroupTriggerConfiguration[] | undefined;
        /**
         * @stability stable
         */
        set triggerConfiguration(value: CodedeployDeploymentGroupTriggerConfiguration[] | undefined);
        /**
         * @stability stable
         */
        resetTriggerConfiguration(): void;
        /**
         * @stability stable
         */
        get triggerConfigurationInput(): CodedeployDeploymentGroupTriggerConfiguration[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
