import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS CodePipeline
*/
export declare namespace CodePipeline {
    /**
     * @stability stable
     */
    interface CodepipelineConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#name Codepipeline#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#role_arn Codepipeline#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#tags Codepipeline#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#tags_all Codepipeline#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * artifact_store block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#artifact_store Codepipeline#artifact_store}
         *
         * @stability stable
         */
        readonly artifactStore: CodepipelineArtifactStore[];
        /**
         * stage block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#stage Codepipeline#stage}
         *
         * @stability stable
         */
        readonly stage: CodepipelineStage[];
    }
    /**
     * @stability stable
     */
    interface CodepipelineArtifactStoreEncryptionKey {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#id Codepipeline#id}.
         *
         * @stability stable
         */
        readonly id: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#type Codepipeline#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    class CodepipelineArtifactStoreEncryptionKeyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _id?;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        set id(value: string);
        /**
         * @stability stable
         */
        get idInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CodepipelineArtifactStore {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#location Codepipeline#location}.
         *
         * @stability stable
         */
        readonly location: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#region Codepipeline#region}.
         *
         * @stability stable
         */
        readonly region?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#type Codepipeline#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * encryption_key block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#encryption_key Codepipeline#encryption_key}
         *
         * @stability stable
         */
        readonly encryptionKey?: CodepipelineArtifactStoreEncryptionKey;
    }
    /**
     * @stability stable
     */
    interface CodepipelineStageAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#category Codepipeline#category}.
         *
         * @stability stable
         */
        readonly category: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#configuration Codepipeline#configuration}.
         *
         * @stability stable
         */
        readonly configuration?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#input_artifacts Codepipeline#input_artifacts}.
         *
         * @stability stable
         */
        readonly inputArtifacts?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#name Codepipeline#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#namespace Codepipeline#namespace}.
         *
         * @stability stable
         */
        readonly namespace?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#output_artifacts Codepipeline#output_artifacts}.
         *
         * @stability stable
         */
        readonly outputArtifacts?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#owner Codepipeline#owner}.
         *
         * @stability stable
         */
        readonly owner: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#provider Codepipeline#provider}.
         *
         * @stability stable
         */
        readonly provider: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#region Codepipeline#region}.
         *
         * @stability stable
         */
        readonly region?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#role_arn Codepipeline#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#run_order Codepipeline#run_order}.
         *
         * @stability stable
         */
        readonly runOrder?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#version Codepipeline#version}.
         *
         * @stability stable
         */
        readonly version: string;
    }
    /**
     * @stability stable
     */
    interface CodepipelineStage {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#name Codepipeline#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html#action Codepipeline#action}
         *
         * @stability stable
         */
        readonly action: CodepipelineStageAction[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html aws_codepipeline}.
     *
     * @stability stable
     */
    class Codepipeline extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codepipeline.html aws_codepipeline} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodepipelineConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _artifactStore?;
        /**
         * @stability stable
         */
        get artifactStore(): CodepipelineArtifactStore[];
        /**
         * @stability stable
         */
        set artifactStore(value: CodepipelineArtifactStore[]);
        /**
         * @stability stable
         */
        get artifactStoreInput(): CodepipelineArtifactStore[] | undefined;
        private _stage?;
        /**
         * @stability stable
         */
        get stage(): CodepipelineStage[];
        /**
         * @stability stable
         */
        set stage(value: CodepipelineStage[]);
        /**
         * @stability stable
         */
        get stageInput(): CodepipelineStage[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CodepipelineWebhookConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#authentication CodepipelineWebhook#authentication}.
         *
         * @stability stable
         */
        readonly authentication: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#name CodepipelineWebhook#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#tags CodepipelineWebhook#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#tags_all CodepipelineWebhook#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#target_action CodepipelineWebhook#target_action}.
         *
         * @stability stable
         */
        readonly targetAction: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#target_pipeline CodepipelineWebhook#target_pipeline}.
         *
         * @stability stable
         */
        readonly targetPipeline: string;
        /**
         * authentication_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#authentication_configuration CodepipelineWebhook#authentication_configuration}
         *
         * @stability stable
         */
        readonly authenticationConfiguration?: CodepipelineWebhookAuthenticationConfiguration;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#filter CodepipelineWebhook#filter}
         *
         * @stability stable
         */
        readonly filter: CodepipelineWebhookFilter[];
    }
    /**
     * @stability stable
     */
    interface CodepipelineWebhookAuthenticationConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#allowed_ip_range CodepipelineWebhook#allowed_ip_range}.
         *
         * @stability stable
         */
        readonly allowedIpRange?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#secret_token CodepipelineWebhook#secret_token}.
         *
         * @stability stable
         */
        readonly secretToken?: string;
    }
    /**
     * @stability stable
     */
    class CodepipelineWebhookAuthenticationConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowedIpRange?;
        /**
         * @stability stable
         */
        get allowedIpRange(): string | undefined;
        /**
         * @stability stable
         */
        set allowedIpRange(value: string | undefined);
        /**
         * @stability stable
         */
        resetAllowedIpRange(): void;
        /**
         * @stability stable
         */
        get allowedIpRangeInput(): string | undefined;
        private _secretToken?;
        /**
         * @stability stable
         */
        get secretToken(): string | undefined;
        /**
         * @stability stable
         */
        set secretToken(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecretToken(): void;
        /**
         * @stability stable
         */
        get secretTokenInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CodepipelineWebhookFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#json_path CodepipelineWebhook#json_path}.
         *
         * @stability stable
         */
        readonly jsonPath: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html#match_equals CodepipelineWebhook#match_equals}.
         *
         * @stability stable
         */
        readonly matchEquals: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html aws_codepipeline_webhook}.
     *
     * @stability stable
     */
    class CodepipelineWebhook extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/codepipeline_webhook.html aws_codepipeline_webhook} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CodepipelineWebhookConfig);
        private _authentication?;
        /**
         * @stability stable
         */
        get authentication(): string;
        /**
         * @stability stable
         */
        set authentication(value: string);
        /**
         * @stability stable
         */
        get authenticationInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetAction?;
        /**
         * @stability stable
         */
        get targetAction(): string;
        /**
         * @stability stable
         */
        set targetAction(value: string);
        /**
         * @stability stable
         */
        get targetActionInput(): string | undefined;
        private _targetPipeline?;
        /**
         * @stability stable
         */
        get targetPipeline(): string;
        /**
         * @stability stable
         */
        set targetPipeline(value: string);
        /**
         * @stability stable
         */
        get targetPipelineInput(): string | undefined;
        /**
         * @stability stable
         */
        get url(): string;
        private _authenticationConfiguration?;
        private __authenticationConfigurationOutput;
        /**
         * @stability stable
         */
        get authenticationConfiguration(): CodepipelineWebhookAuthenticationConfigurationOutputReference;
        /**
         * @stability stable
         */
        putAuthenticationConfiguration(value: CodepipelineWebhookAuthenticationConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetAuthenticationConfiguration(): void;
        /**
         * @stability stable
         */
        get authenticationConfigurationInput(): CodepipelineWebhookAuthenticationConfiguration | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): CodepipelineWebhookFilter[];
        /**
         * @stability stable
         */
        set filter(value: CodepipelineWebhookFilter[]);
        /**
         * @stability stable
         */
        get filterInput(): CodepipelineWebhookFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
