import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Cognito
*/
export declare namespace Cognito {
    /**
     * @stability stable
     */
    interface CognitoIdentityPoolConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#allow_classic_flow CognitoIdentityPool#allow_classic_flow}.
         *
         * @stability stable
         */
        readonly allowClassicFlow?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#allow_unauthenticated_identities CognitoIdentityPool#allow_unauthenticated_identities}.
         *
         * @stability stable
         */
        readonly allowUnauthenticatedIdentities?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#developer_provider_name CognitoIdentityPool#developer_provider_name}.
         *
         * @stability stable
         */
        readonly developerProviderName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#identity_pool_name CognitoIdentityPool#identity_pool_name}.
         *
         * @stability stable
         */
        readonly identityPoolName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#openid_connect_provider_arns CognitoIdentityPool#openid_connect_provider_arns}.
         *
         * @stability stable
         */
        readonly openidConnectProviderArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#saml_provider_arns CognitoIdentityPool#saml_provider_arns}.
         *
         * @stability stable
         */
        readonly samlProviderArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#supported_login_providers CognitoIdentityPool#supported_login_providers}.
         *
         * @stability stable
         */
        readonly supportedLoginProviders?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#tags CognitoIdentityPool#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#tags_all CognitoIdentityPool#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * cognito_identity_providers block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#cognito_identity_providers CognitoIdentityPool#cognito_identity_providers}
         *
         * @stability stable
         */
        readonly cognitoIdentityProviders?: CognitoIdentityPoolCognitoIdentityProviders[];
    }
    /**
     * @stability stable
     */
    interface CognitoIdentityPoolCognitoIdentityProviders {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#client_id CognitoIdentityPool#client_id}.
         *
         * @stability stable
         */
        readonly clientId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#provider_name CognitoIdentityPool#provider_name}.
         *
         * @stability stable
         */
        readonly providerName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html#server_side_token_check CognitoIdentityPool#server_side_token_check}.
         *
         * @stability stable
         */
        readonly serverSideTokenCheck?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html aws_cognito_identity_pool}.
     *
     * @stability stable
     */
    class CognitoIdentityPool extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool.html aws_cognito_identity_pool} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoIdentityPoolConfig);
        private _allowClassicFlow?;
        /**
         * @stability stable
         */
        get allowClassicFlow(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowClassicFlow(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowClassicFlow(): void;
        /**
         * @stability stable
         */
        get allowClassicFlowInput(): boolean | cdktf.IResolvable | undefined;
        private _allowUnauthenticatedIdentities?;
        /**
         * @stability stable
         */
        get allowUnauthenticatedIdentities(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowUnauthenticatedIdentities(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowUnauthenticatedIdentities(): void;
        /**
         * @stability stable
         */
        get allowUnauthenticatedIdentitiesInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _developerProviderName?;
        /**
         * @stability stable
         */
        get developerProviderName(): string | undefined;
        /**
         * @stability stable
         */
        set developerProviderName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeveloperProviderName(): void;
        /**
         * @stability stable
         */
        get developerProviderNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _identityPoolName?;
        /**
         * @stability stable
         */
        get identityPoolName(): string;
        /**
         * @stability stable
         */
        set identityPoolName(value: string);
        /**
         * @stability stable
         */
        get identityPoolNameInput(): string | undefined;
        private _openidConnectProviderArns?;
        /**
         * @stability stable
         */
        get openidConnectProviderArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set openidConnectProviderArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetOpenidConnectProviderArns(): void;
        /**
         * @stability stable
         */
        get openidConnectProviderArnsInput(): string[] | undefined;
        private _samlProviderArns?;
        /**
         * @stability stable
         */
        get samlProviderArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set samlProviderArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSamlProviderArns(): void;
        /**
         * @stability stable
         */
        get samlProviderArnsInput(): string[] | undefined;
        private _supportedLoginProviders?;
        /**
         * @stability stable
         */
        get supportedLoginProviders(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportedLoginProviders(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportedLoginProviders(): void;
        /**
         * @stability stable
         */
        get supportedLoginProvidersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _cognitoIdentityProviders?;
        /**
         * @stability stable
         */
        get cognitoIdentityProviders(): CognitoIdentityPoolCognitoIdentityProviders[] | undefined;
        /**
         * @stability stable
         */
        set cognitoIdentityProviders(value: CognitoIdentityPoolCognitoIdentityProviders[] | undefined);
        /**
         * @stability stable
         */
        resetCognitoIdentityProviders(): void;
        /**
         * @stability stable
         */
        get cognitoIdentityProvidersInput(): CognitoIdentityPoolCognitoIdentityProviders[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoIdentityPoolRolesAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#identity_pool_id CognitoIdentityPoolRolesAttachment#identity_pool_id}.
         *
         * @stability stable
         */
        readonly identityPoolId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#roles CognitoIdentityPoolRolesAttachment#roles}.
         *
         * @stability stable
         */
        readonly roles: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * role_mapping block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#role_mapping CognitoIdentityPoolRolesAttachment#role_mapping}
         *
         * @stability stable
         */
        readonly roleMapping?: CognitoIdentityPoolRolesAttachmentRoleMapping[];
    }
    /**
     * @stability stable
     */
    interface CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#claim CognitoIdentityPoolRolesAttachment#claim}.
         *
         * @stability stable
         */
        readonly claim: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#match_type CognitoIdentityPoolRolesAttachment#match_type}.
         *
         * @stability stable
         */
        readonly matchType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#role_arn CognitoIdentityPoolRolesAttachment#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#value CognitoIdentityPoolRolesAttachment#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface CognitoIdentityPoolRolesAttachmentRoleMapping {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#ambiguous_role_resolution CognitoIdentityPoolRolesAttachment#ambiguous_role_resolution}.
         *
         * @stability stable
         */
        readonly ambiguousRoleResolution?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#identity_provider CognitoIdentityPoolRolesAttachment#identity_provider}.
         *
         * @stability stable
         */
        readonly identityProvider: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#type CognitoIdentityPoolRolesAttachment#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * mapping_rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html#mapping_rule CognitoIdentityPoolRolesAttachment#mapping_rule}
         *
         * @stability stable
         */
        readonly mappingRule?: CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html aws_cognito_identity_pool_roles_attachment}.
     *
     * @stability stable
     */
    class CognitoIdentityPoolRolesAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_pool_roles_attachment.html aws_cognito_identity_pool_roles_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoIdentityPoolRolesAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _identityPoolId?;
        /**
         * @stability stable
         */
        get identityPoolId(): string;
        /**
         * @stability stable
         */
        set identityPoolId(value: string);
        /**
         * @stability stable
         */
        get identityPoolIdInput(): string | undefined;
        private _roles?;
        /**
         * @stability stable
         */
        get roles(): {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set roles(value: {
            [key: string]: string;
        } | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get rolesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _roleMapping?;
        /**
         * @stability stable
         */
        get roleMapping(): CognitoIdentityPoolRolesAttachmentRoleMapping[] | undefined;
        /**
         * @stability stable
         */
        set roleMapping(value: CognitoIdentityPoolRolesAttachmentRoleMapping[] | undefined);
        /**
         * @stability stable
         */
        resetRoleMapping(): void;
        /**
         * @stability stable
         */
        get roleMappingInput(): CognitoIdentityPoolRolesAttachmentRoleMapping[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoIdentityProviderConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html#attribute_mapping CognitoIdentityProvider#attribute_mapping}.
         *
         * @stability stable
         */
        readonly attributeMapping?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html#idp_identifiers CognitoIdentityProvider#idp_identifiers}.
         *
         * @stability stable
         */
        readonly idpIdentifiers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html#provider_details CognitoIdentityProvider#provider_details}.
         *
         * @stability stable
         */
        readonly providerDetails: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html#provider_name CognitoIdentityProvider#provider_name}.
         *
         * @stability stable
         */
        readonly providerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html#provider_type CognitoIdentityProvider#provider_type}.
         *
         * @stability stable
         */
        readonly providerType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html#user_pool_id CognitoIdentityProvider#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html aws_cognito_identity_provider}.
     *
     * @stability stable
     */
    class CognitoIdentityProvider extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_identity_provider.html aws_cognito_identity_provider} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoIdentityProviderConfig);
        private _attributeMapping?;
        /**
         * @stability stable
         */
        get attributeMapping(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set attributeMapping(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAttributeMapping(): void;
        /**
         * @stability stable
         */
        get attributeMappingInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _idpIdentifiers?;
        /**
         * @stability stable
         */
        get idpIdentifiers(): string[] | undefined;
        /**
         * @stability stable
         */
        set idpIdentifiers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetIdpIdentifiers(): void;
        /**
         * @stability stable
         */
        get idpIdentifiersInput(): string[] | undefined;
        private _providerDetails?;
        /**
         * @stability stable
         */
        get providerDetails(): {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set providerDetails(value: {
            [key: string]: string;
        } | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get providerDetailsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _providerName?;
        /**
         * @stability stable
         */
        get providerName(): string;
        /**
         * @stability stable
         */
        set providerName(value: string);
        /**
         * @stability stable
         */
        get providerNameInput(): string | undefined;
        private _providerType?;
        /**
         * @stability stable
         */
        get providerType(): string;
        /**
         * @stability stable
         */
        set providerType(value: string);
        /**
         * @stability stable
         */
        get providerTypeInput(): string | undefined;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoResourceServerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html#identifier CognitoResourceServer#identifier}.
         *
         * @stability stable
         */
        readonly identifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html#name CognitoResourceServer#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html#user_pool_id CognitoResourceServer#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
        /**
         * scope block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html#scope CognitoResourceServer#scope}
         *
         * @stability stable
         */
        readonly scope?: CognitoResourceServerScope[];
    }
    /**
     * @stability stable
     */
    interface CognitoResourceServerScope {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html#scope_description CognitoResourceServer#scope_description}.
         *
         * @stability stable
         */
        readonly scopeDescription: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html#scope_name CognitoResourceServer#scope_name}.
         *
         * @stability stable
         */
        readonly scopeName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html aws_cognito_resource_server}.
     *
     * @stability stable
     */
    class CognitoResourceServer extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_resource_server.html aws_cognito_resource_server} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoResourceServerConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _identifier?;
        /**
         * @stability stable
         */
        get identifier(): string;
        /**
         * @stability stable
         */
        set identifier(value: string);
        /**
         * @stability stable
         */
        get identifierInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get scopeIdentifiers(): string[];
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): CognitoResourceServerScope[] | undefined;
        /**
         * @stability stable
         */
        set scope(value: CognitoResourceServerScope[] | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): CognitoResourceServerScope[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoUserGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_group.html#description CognitoUserGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_group.html#name CognitoUserGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_group.html#precedence CognitoUserGroup#precedence}.
         *
         * @stability stable
         */
        readonly precedence?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_group.html#role_arn CognitoUserGroup#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_group.html#user_pool_id CognitoUserGroup#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_group.html aws_cognito_user_group}.
     *
     * @stability stable
     */
    class CognitoUserGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_group.html aws_cognito_user_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoUserGroupConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _precedence?;
        /**
         * @stability stable
         */
        get precedence(): number | undefined;
        /**
         * @stability stable
         */
        set precedence(value: number | undefined);
        /**
         * @stability stable
         */
        resetPrecedence(): void;
        /**
         * @stability stable
         */
        get precedenceInput(): number | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string | undefined;
        /**
         * @stability stable
         */
        set roleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetRoleArn(): void;
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#alias_attributes CognitoUserPool#alias_attributes}.
         *
         * @stability stable
         */
        readonly aliasAttributes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#auto_verified_attributes CognitoUserPool#auto_verified_attributes}.
         *
         * @stability stable
         */
        readonly autoVerifiedAttributes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_verification_message CognitoUserPool#email_verification_message}.
         *
         * @stability stable
         */
        readonly emailVerificationMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_verification_subject CognitoUserPool#email_verification_subject}.
         *
         * @stability stable
         */
        readonly emailVerificationSubject?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#mfa_configuration CognitoUserPool#mfa_configuration}.
         *
         * @stability stable
         */
        readonly mfaConfiguration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#name CognitoUserPool#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#sms_authentication_message CognitoUserPool#sms_authentication_message}.
         *
         * @stability stable
         */
        readonly smsAuthenticationMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#sms_verification_message CognitoUserPool#sms_verification_message}.
         *
         * @stability stable
         */
        readonly smsVerificationMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#tags CognitoUserPool#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#tags_all CognitoUserPool#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#username_attributes CognitoUserPool#username_attributes}.
         *
         * @stability stable
         */
        readonly usernameAttributes?: string[];
        /**
         * account_recovery_setting block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#account_recovery_setting CognitoUserPool#account_recovery_setting}
         *
         * @stability stable
         */
        readonly accountRecoverySetting?: CognitoUserPoolAccountRecoverySetting;
        /**
         * admin_create_user_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#admin_create_user_config CognitoUserPool#admin_create_user_config}
         *
         * @stability stable
         */
        readonly adminCreateUserConfig?: CognitoUserPoolAdminCreateUserConfig;
        /**
         * device_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#device_configuration CognitoUserPool#device_configuration}
         *
         * @stability stable
         */
        readonly deviceConfiguration?: CognitoUserPoolDeviceConfiguration;
        /**
         * email_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_configuration CognitoUserPool#email_configuration}
         *
         * @stability stable
         */
        readonly emailConfiguration?: CognitoUserPoolEmailConfiguration;
        /**
         * lambda_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#lambda_config CognitoUserPool#lambda_config}
         *
         * @stability stable
         */
        readonly lambdaConfig?: CognitoUserPoolLambdaConfig;
        /**
         * password_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#password_policy CognitoUserPool#password_policy}
         *
         * @stability stable
         */
        readonly passwordPolicy?: CognitoUserPoolPasswordPolicy;
        /**
         * schema block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#schema CognitoUserPool#schema}
         *
         * @stability stable
         */
        readonly schema?: CognitoUserPoolSchema[];
        /**
         * sms_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#sms_configuration CognitoUserPool#sms_configuration}
         *
         * @stability stable
         */
        readonly smsConfiguration?: CognitoUserPoolSmsConfiguration;
        /**
         * software_token_mfa_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#software_token_mfa_configuration CognitoUserPool#software_token_mfa_configuration}
         *
         * @stability stable
         */
        readonly softwareTokenMfaConfiguration?: CognitoUserPoolSoftwareTokenMfaConfiguration;
        /**
         * user_pool_add_ons block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#user_pool_add_ons CognitoUserPool#user_pool_add_ons}
         *
         * @stability stable
         */
        readonly userPoolAddOns?: CognitoUserPoolUserPoolAddOns;
        /**
         * username_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#username_configuration CognitoUserPool#username_configuration}
         *
         * @stability stable
         */
        readonly usernameConfiguration?: CognitoUserPoolUsernameConfiguration;
        /**
         * verification_message_template block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#verification_message_template CognitoUserPool#verification_message_template}
         *
         * @stability stable
         */
        readonly verificationMessageTemplate?: CognitoUserPoolVerificationMessageTemplate;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolAccountRecoverySettingRecoveryMechanism {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#name CognitoUserPool#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#priority CognitoUserPool#priority}.
         *
         * @stability stable
         */
        readonly priority: number;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolAccountRecoverySetting {
        /**
         * recovery_mechanism block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#recovery_mechanism CognitoUserPool#recovery_mechanism}
         *
         * @stability stable
         */
        readonly recoveryMechanism: CognitoUserPoolAccountRecoverySettingRecoveryMechanism[];
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolAccountRecoverySettingOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _recoveryMechanism?;
        /**
         * @stability stable
         */
        get recoveryMechanism(): CognitoUserPoolAccountRecoverySettingRecoveryMechanism[];
        /**
         * @stability stable
         */
        set recoveryMechanism(value: CognitoUserPoolAccountRecoverySettingRecoveryMechanism[]);
        /**
         * @stability stable
         */
        get recoveryMechanismInput(): CognitoUserPoolAccountRecoverySettingRecoveryMechanism[] | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_message CognitoUserPool#email_message}.
         *
         * @stability stable
         */
        readonly emailMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_subject CognitoUserPool#email_subject}.
         *
         * @stability stable
         */
        readonly emailSubject?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#sms_message CognitoUserPool#sms_message}.
         *
         * @stability stable
         */
        readonly smsMessage?: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolAdminCreateUserConfigInviteMessageTemplateOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _emailMessage?;
        /**
         * @stability stable
         */
        get emailMessage(): string | undefined;
        /**
         * @stability stable
         */
        set emailMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailMessage(): void;
        /**
         * @stability stable
         */
        get emailMessageInput(): string | undefined;
        private _emailSubject?;
        /**
         * @stability stable
         */
        get emailSubject(): string | undefined;
        /**
         * @stability stable
         */
        set emailSubject(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailSubject(): void;
        /**
         * @stability stable
         */
        get emailSubjectInput(): string | undefined;
        private _smsMessage?;
        /**
         * @stability stable
         */
        get smsMessage(): string | undefined;
        /**
         * @stability stable
         */
        set smsMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetSmsMessage(): void;
        /**
         * @stability stable
         */
        get smsMessageInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolAdminCreateUserConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#allow_admin_create_user_only CognitoUserPool#allow_admin_create_user_only}.
         *
         * @stability stable
         */
        readonly allowAdminCreateUserOnly?: boolean | cdktf.IResolvable;
        /**
         * invite_message_template block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#invite_message_template CognitoUserPool#invite_message_template}
         *
         * @stability stable
         */
        readonly inviteMessageTemplate?: CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolAdminCreateUserConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowAdminCreateUserOnly?;
        /**
         * @stability stable
         */
        get allowAdminCreateUserOnly(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowAdminCreateUserOnly(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowAdminCreateUserOnly(): void;
        /**
         * @stability stable
         */
        get allowAdminCreateUserOnlyInput(): boolean | cdktf.IResolvable | undefined;
        private _inviteMessageTemplate?;
        private __inviteMessageTemplateOutput;
        /**
         * @stability stable
         */
        get inviteMessageTemplate(): CognitoUserPoolAdminCreateUserConfigInviteMessageTemplateOutputReference;
        /**
         * @stability stable
         */
        putInviteMessageTemplate(value: CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate | undefined): void;
        /**
         * @stability stable
         */
        resetInviteMessageTemplate(): void;
        /**
         * @stability stable
         */
        get inviteMessageTemplateInput(): CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolDeviceConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#challenge_required_on_new_device CognitoUserPool#challenge_required_on_new_device}.
         *
         * @stability stable
         */
        readonly challengeRequiredOnNewDevice?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#device_only_remembered_on_user_prompt CognitoUserPool#device_only_remembered_on_user_prompt}.
         *
         * @stability stable
         */
        readonly deviceOnlyRememberedOnUserPrompt?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolDeviceConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _challengeRequiredOnNewDevice?;
        /**
         * @stability stable
         */
        get challengeRequiredOnNewDevice(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set challengeRequiredOnNewDevice(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetChallengeRequiredOnNewDevice(): void;
        /**
         * @stability stable
         */
        get challengeRequiredOnNewDeviceInput(): boolean | cdktf.IResolvable | undefined;
        private _deviceOnlyRememberedOnUserPrompt?;
        /**
         * @stability stable
         */
        get deviceOnlyRememberedOnUserPrompt(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deviceOnlyRememberedOnUserPrompt(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeviceOnlyRememberedOnUserPrompt(): void;
        /**
         * @stability stable
         */
        get deviceOnlyRememberedOnUserPromptInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolEmailConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#configuration_set CognitoUserPool#configuration_set}.
         *
         * @stability stable
         */
        readonly configurationSet?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_sending_account CognitoUserPool#email_sending_account}.
         *
         * @stability stable
         */
        readonly emailSendingAccount?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#from_email_address CognitoUserPool#from_email_address}.
         *
         * @stability stable
         */
        readonly fromEmailAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#reply_to_email_address CognitoUserPool#reply_to_email_address}.
         *
         * @stability stable
         */
        readonly replyToEmailAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#source_arn CognitoUserPool#source_arn}.
         *
         * @stability stable
         */
        readonly sourceArn?: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolEmailConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _configurationSet?;
        /**
         * @stability stable
         */
        get configurationSet(): string | undefined;
        /**
         * @stability stable
         */
        set configurationSet(value: string | undefined);
        /**
         * @stability stable
         */
        resetConfigurationSet(): void;
        /**
         * @stability stable
         */
        get configurationSetInput(): string | undefined;
        private _emailSendingAccount?;
        /**
         * @stability stable
         */
        get emailSendingAccount(): string | undefined;
        /**
         * @stability stable
         */
        set emailSendingAccount(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailSendingAccount(): void;
        /**
         * @stability stable
         */
        get emailSendingAccountInput(): string | undefined;
        private _fromEmailAddress?;
        /**
         * @stability stable
         */
        get fromEmailAddress(): string | undefined;
        /**
         * @stability stable
         */
        set fromEmailAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetFromEmailAddress(): void;
        /**
         * @stability stable
         */
        get fromEmailAddressInput(): string | undefined;
        private _replyToEmailAddress?;
        /**
         * @stability stable
         */
        get replyToEmailAddress(): string | undefined;
        /**
         * @stability stable
         */
        set replyToEmailAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetReplyToEmailAddress(): void;
        /**
         * @stability stable
         */
        get replyToEmailAddressInput(): string | undefined;
        private _sourceArn?;
        /**
         * @stability stable
         */
        get sourceArn(): string | undefined;
        /**
         * @stability stable
         */
        set sourceArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceArn(): void;
        /**
         * @stability stable
         */
        get sourceArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolLambdaConfigCustomEmailSender {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#lambda_arn CognitoUserPool#lambda_arn}.
         *
         * @stability stable
         */
        readonly lambdaArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#lambda_version CognitoUserPool#lambda_version}.
         *
         * @stability stable
         */
        readonly lambdaVersion: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolLambdaConfigCustomEmailSenderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _lambdaArn?;
        /**
         * @stability stable
         */
        get lambdaArn(): string;
        /**
         * @stability stable
         */
        set lambdaArn(value: string);
        /**
         * @stability stable
         */
        get lambdaArnInput(): string | undefined;
        private _lambdaVersion?;
        /**
         * @stability stable
         */
        get lambdaVersion(): string;
        /**
         * @stability stable
         */
        set lambdaVersion(value: string);
        /**
         * @stability stable
         */
        get lambdaVersionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolLambdaConfigCustomSmsSender {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#lambda_arn CognitoUserPool#lambda_arn}.
         *
         * @stability stable
         */
        readonly lambdaArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#lambda_version CognitoUserPool#lambda_version}.
         *
         * @stability stable
         */
        readonly lambdaVersion: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolLambdaConfigCustomSmsSenderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _lambdaArn?;
        /**
         * @stability stable
         */
        get lambdaArn(): string;
        /**
         * @stability stable
         */
        set lambdaArn(value: string);
        /**
         * @stability stable
         */
        get lambdaArnInput(): string | undefined;
        private _lambdaVersion?;
        /**
         * @stability stable
         */
        get lambdaVersion(): string;
        /**
         * @stability stable
         */
        set lambdaVersion(value: string);
        /**
         * @stability stable
         */
        get lambdaVersionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolLambdaConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#create_auth_challenge CognitoUserPool#create_auth_challenge}.
         *
         * @stability stable
         */
        readonly createAuthChallenge?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#custom_message CognitoUserPool#custom_message}.
         *
         * @stability stable
         */
        readonly customMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#define_auth_challenge CognitoUserPool#define_auth_challenge}.
         *
         * @stability stable
         */
        readonly defineAuthChallenge?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#kms_key_id CognitoUserPool#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#post_authentication CognitoUserPool#post_authentication}.
         *
         * @stability stable
         */
        readonly postAuthentication?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#post_confirmation CognitoUserPool#post_confirmation}.
         *
         * @stability stable
         */
        readonly postConfirmation?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#pre_authentication CognitoUserPool#pre_authentication}.
         *
         * @stability stable
         */
        readonly preAuthentication?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#pre_sign_up CognitoUserPool#pre_sign_up}.
         *
         * @stability stable
         */
        readonly preSignUp?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#pre_token_generation CognitoUserPool#pre_token_generation}.
         *
         * @stability stable
         */
        readonly preTokenGeneration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#user_migration CognitoUserPool#user_migration}.
         *
         * @stability stable
         */
        readonly userMigration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#verify_auth_challenge_response CognitoUserPool#verify_auth_challenge_response}.
         *
         * @stability stable
         */
        readonly verifyAuthChallengeResponse?: string;
        /**
         * custom_email_sender block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#custom_email_sender CognitoUserPool#custom_email_sender}
         *
         * @stability stable
         */
        readonly customEmailSender?: CognitoUserPoolLambdaConfigCustomEmailSender;
        /**
         * custom_sms_sender block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#custom_sms_sender CognitoUserPool#custom_sms_sender}
         *
         * @stability stable
         */
        readonly customSmsSender?: CognitoUserPoolLambdaConfigCustomSmsSender;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolLambdaConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _createAuthChallenge?;
        /**
         * @stability stable
         */
        get createAuthChallenge(): string | undefined;
        /**
         * @stability stable
         */
        set createAuthChallenge(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreateAuthChallenge(): void;
        /**
         * @stability stable
         */
        get createAuthChallengeInput(): string | undefined;
        private _customMessage?;
        /**
         * @stability stable
         */
        get customMessage(): string | undefined;
        /**
         * @stability stable
         */
        set customMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomMessage(): void;
        /**
         * @stability stable
         */
        get customMessageInput(): string | undefined;
        private _defineAuthChallenge?;
        /**
         * @stability stable
         */
        get defineAuthChallenge(): string | undefined;
        /**
         * @stability stable
         */
        set defineAuthChallenge(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefineAuthChallenge(): void;
        /**
         * @stability stable
         */
        get defineAuthChallengeInput(): string | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _postAuthentication?;
        /**
         * @stability stable
         */
        get postAuthentication(): string | undefined;
        /**
         * @stability stable
         */
        set postAuthentication(value: string | undefined);
        /**
         * @stability stable
         */
        resetPostAuthentication(): void;
        /**
         * @stability stable
         */
        get postAuthenticationInput(): string | undefined;
        private _postConfirmation?;
        /**
         * @stability stable
         */
        get postConfirmation(): string | undefined;
        /**
         * @stability stable
         */
        set postConfirmation(value: string | undefined);
        /**
         * @stability stable
         */
        resetPostConfirmation(): void;
        /**
         * @stability stable
         */
        get postConfirmationInput(): string | undefined;
        private _preAuthentication?;
        /**
         * @stability stable
         */
        get preAuthentication(): string | undefined;
        /**
         * @stability stable
         */
        set preAuthentication(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreAuthentication(): void;
        /**
         * @stability stable
         */
        get preAuthenticationInput(): string | undefined;
        private _preSignUp?;
        /**
         * @stability stable
         */
        get preSignUp(): string | undefined;
        /**
         * @stability stable
         */
        set preSignUp(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreSignUp(): void;
        /**
         * @stability stable
         */
        get preSignUpInput(): string | undefined;
        private _preTokenGeneration?;
        /**
         * @stability stable
         */
        get preTokenGeneration(): string | undefined;
        /**
         * @stability stable
         */
        set preTokenGeneration(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreTokenGeneration(): void;
        /**
         * @stability stable
         */
        get preTokenGenerationInput(): string | undefined;
        private _userMigration?;
        /**
         * @stability stable
         */
        get userMigration(): string | undefined;
        /**
         * @stability stable
         */
        set userMigration(value: string | undefined);
        /**
         * @stability stable
         */
        resetUserMigration(): void;
        /**
         * @stability stable
         */
        get userMigrationInput(): string | undefined;
        private _verifyAuthChallengeResponse?;
        /**
         * @stability stable
         */
        get verifyAuthChallengeResponse(): string | undefined;
        /**
         * @stability stable
         */
        set verifyAuthChallengeResponse(value: string | undefined);
        /**
         * @stability stable
         */
        resetVerifyAuthChallengeResponse(): void;
        /**
         * @stability stable
         */
        get verifyAuthChallengeResponseInput(): string | undefined;
        private _customEmailSender?;
        private __customEmailSenderOutput;
        /**
         * @stability stable
         */
        get customEmailSender(): CognitoUserPoolLambdaConfigCustomEmailSenderOutputReference;
        /**
         * @stability stable
         */
        putCustomEmailSender(value: CognitoUserPoolLambdaConfigCustomEmailSender | undefined): void;
        /**
         * @stability stable
         */
        resetCustomEmailSender(): void;
        /**
         * @stability stable
         */
        get customEmailSenderInput(): CognitoUserPoolLambdaConfigCustomEmailSender | undefined;
        private _customSmsSender?;
        private __customSmsSenderOutput;
        /**
         * @stability stable
         */
        get customSmsSender(): CognitoUserPoolLambdaConfigCustomSmsSenderOutputReference;
        /**
         * @stability stable
         */
        putCustomSmsSender(value: CognitoUserPoolLambdaConfigCustomSmsSender | undefined): void;
        /**
         * @stability stable
         */
        resetCustomSmsSender(): void;
        /**
         * @stability stable
         */
        get customSmsSenderInput(): CognitoUserPoolLambdaConfigCustomSmsSender | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolPasswordPolicy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#minimum_length CognitoUserPool#minimum_length}.
         *
         * @stability stable
         */
        readonly minimumLength?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#require_lowercase CognitoUserPool#require_lowercase}.
         *
         * @stability stable
         */
        readonly requireLowercase?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#require_numbers CognitoUserPool#require_numbers}.
         *
         * @stability stable
         */
        readonly requireNumbers?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#require_symbols CognitoUserPool#require_symbols}.
         *
         * @stability stable
         */
        readonly requireSymbols?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#require_uppercase CognitoUserPool#require_uppercase}.
         *
         * @stability stable
         */
        readonly requireUppercase?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#temporary_password_validity_days CognitoUserPool#temporary_password_validity_days}.
         *
         * @stability stable
         */
        readonly temporaryPasswordValidityDays?: number;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolPasswordPolicyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _minimumLength?;
        /**
         * @stability stable
         */
        get minimumLength(): number | undefined;
        /**
         * @stability stable
         */
        set minimumLength(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinimumLength(): void;
        /**
         * @stability stable
         */
        get minimumLengthInput(): number | undefined;
        private _requireLowercase?;
        /**
         * @stability stable
         */
        get requireLowercase(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireLowercase(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireLowercase(): void;
        /**
         * @stability stable
         */
        get requireLowercaseInput(): boolean | cdktf.IResolvable | undefined;
        private _requireNumbers?;
        /**
         * @stability stable
         */
        get requireNumbers(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireNumbers(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireNumbers(): void;
        /**
         * @stability stable
         */
        get requireNumbersInput(): boolean | cdktf.IResolvable | undefined;
        private _requireSymbols?;
        /**
         * @stability stable
         */
        get requireSymbols(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireSymbols(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireSymbols(): void;
        /**
         * @stability stable
         */
        get requireSymbolsInput(): boolean | cdktf.IResolvable | undefined;
        private _requireUppercase?;
        /**
         * @stability stable
         */
        get requireUppercase(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireUppercase(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireUppercase(): void;
        /**
         * @stability stable
         */
        get requireUppercaseInput(): boolean | cdktf.IResolvable | undefined;
        private _temporaryPasswordValidityDays?;
        /**
         * @stability stable
         */
        get temporaryPasswordValidityDays(): number | undefined;
        /**
         * @stability stable
         */
        set temporaryPasswordValidityDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetTemporaryPasswordValidityDays(): void;
        /**
         * @stability stable
         */
        get temporaryPasswordValidityDaysInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolSchemaNumberAttributeConstraints {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#max_value CognitoUserPool#max_value}.
         *
         * @stability stable
         */
        readonly maxValue?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#min_value CognitoUserPool#min_value}.
         *
         * @stability stable
         */
        readonly minValue?: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolSchemaNumberAttributeConstraintsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _maxValue?;
        /**
         * @stability stable
         */
        get maxValue(): string | undefined;
        /**
         * @stability stable
         */
        set maxValue(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxValue(): void;
        /**
         * @stability stable
         */
        get maxValueInput(): string | undefined;
        private _minValue?;
        /**
         * @stability stable
         */
        get minValue(): string | undefined;
        /**
         * @stability stable
         */
        set minValue(value: string | undefined);
        /**
         * @stability stable
         */
        resetMinValue(): void;
        /**
         * @stability stable
         */
        get minValueInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolSchemaStringAttributeConstraints {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#max_length CognitoUserPool#max_length}.
         *
         * @stability stable
         */
        readonly maxLength?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#min_length CognitoUserPool#min_length}.
         *
         * @stability stable
         */
        readonly minLength?: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolSchemaStringAttributeConstraintsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _maxLength?;
        /**
         * @stability stable
         */
        get maxLength(): string | undefined;
        /**
         * @stability stable
         */
        set maxLength(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxLength(): void;
        /**
         * @stability stable
         */
        get maxLengthInput(): string | undefined;
        private _minLength?;
        /**
         * @stability stable
         */
        get minLength(): string | undefined;
        /**
         * @stability stable
         */
        set minLength(value: string | undefined);
        /**
         * @stability stable
         */
        resetMinLength(): void;
        /**
         * @stability stable
         */
        get minLengthInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolSchema {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#attribute_data_type CognitoUserPool#attribute_data_type}.
         *
         * @stability stable
         */
        readonly attributeDataType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#developer_only_attribute CognitoUserPool#developer_only_attribute}.
         *
         * @stability stable
         */
        readonly developerOnlyAttribute?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#mutable CognitoUserPool#mutable}.
         *
         * @stability stable
         */
        readonly mutable?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#name CognitoUserPool#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#required CognitoUserPool#required}.
         *
         * @stability stable
         */
        readonly required?: boolean | cdktf.IResolvable;
        /**
         * number_attribute_constraints block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#number_attribute_constraints CognitoUserPool#number_attribute_constraints}
         *
         * @stability stable
         */
        readonly numberAttributeConstraints?: CognitoUserPoolSchemaNumberAttributeConstraints;
        /**
         * string_attribute_constraints block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#string_attribute_constraints CognitoUserPool#string_attribute_constraints}
         *
         * @stability stable
         */
        readonly stringAttributeConstraints?: CognitoUserPoolSchemaStringAttributeConstraints;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolSmsConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#external_id CognitoUserPool#external_id}.
         *
         * @stability stable
         */
        readonly externalId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#sns_caller_arn CognitoUserPool#sns_caller_arn}.
         *
         * @stability stable
         */
        readonly snsCallerArn: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolSmsConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _externalId?;
        /**
         * @stability stable
         */
        get externalId(): string;
        /**
         * @stability stable
         */
        set externalId(value: string);
        /**
         * @stability stable
         */
        get externalIdInput(): string | undefined;
        private _snsCallerArn?;
        /**
         * @stability stable
         */
        get snsCallerArn(): string;
        /**
         * @stability stable
         */
        set snsCallerArn(value: string);
        /**
         * @stability stable
         */
        get snsCallerArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolSoftwareTokenMfaConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#enabled CognitoUserPool#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolSoftwareTokenMfaConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolUserPoolAddOns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#advanced_security_mode CognitoUserPool#advanced_security_mode}.
         *
         * @stability stable
         */
        readonly advancedSecurityMode: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolUserPoolAddOnsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _advancedSecurityMode?;
        /**
         * @stability stable
         */
        get advancedSecurityMode(): string;
        /**
         * @stability stable
         */
        set advancedSecurityMode(value: string);
        /**
         * @stability stable
         */
        get advancedSecurityModeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolUsernameConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#case_sensitive CognitoUserPool#case_sensitive}.
         *
         * @stability stable
         */
        readonly caseSensitive: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolUsernameConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _caseSensitive?;
        /**
         * @stability stable
         */
        get caseSensitive(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set caseSensitive(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get caseSensitiveInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolVerificationMessageTemplate {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#default_email_option CognitoUserPool#default_email_option}.
         *
         * @stability stable
         */
        readonly defaultEmailOption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_message CognitoUserPool#email_message}.
         *
         * @stability stable
         */
        readonly emailMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_message_by_link CognitoUserPool#email_message_by_link}.
         *
         * @stability stable
         */
        readonly emailMessageByLink?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_subject CognitoUserPool#email_subject}.
         *
         * @stability stable
         */
        readonly emailSubject?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#email_subject_by_link CognitoUserPool#email_subject_by_link}.
         *
         * @stability stable
         */
        readonly emailSubjectByLink?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html#sms_message CognitoUserPool#sms_message}.
         *
         * @stability stable
         */
        readonly smsMessage?: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolVerificationMessageTemplateOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _defaultEmailOption?;
        /**
         * @stability stable
         */
        get defaultEmailOption(): string | undefined;
        /**
         * @stability stable
         */
        set defaultEmailOption(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefaultEmailOption(): void;
        /**
         * @stability stable
         */
        get defaultEmailOptionInput(): string | undefined;
        private _emailMessage?;
        /**
         * @stability stable
         */
        get emailMessage(): string | undefined;
        /**
         * @stability stable
         */
        set emailMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailMessage(): void;
        /**
         * @stability stable
         */
        get emailMessageInput(): string | undefined;
        private _emailMessageByLink?;
        /**
         * @stability stable
         */
        get emailMessageByLink(): string | undefined;
        /**
         * @stability stable
         */
        set emailMessageByLink(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailMessageByLink(): void;
        /**
         * @stability stable
         */
        get emailMessageByLinkInput(): string | undefined;
        private _emailSubject?;
        /**
         * @stability stable
         */
        get emailSubject(): string | undefined;
        /**
         * @stability stable
         */
        set emailSubject(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailSubject(): void;
        /**
         * @stability stable
         */
        get emailSubjectInput(): string | undefined;
        private _emailSubjectByLink?;
        /**
         * @stability stable
         */
        get emailSubjectByLink(): string | undefined;
        /**
         * @stability stable
         */
        set emailSubjectByLink(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailSubjectByLink(): void;
        /**
         * @stability stable
         */
        get emailSubjectByLinkInput(): string | undefined;
        private _smsMessage?;
        /**
         * @stability stable
         */
        get smsMessage(): string | undefined;
        /**
         * @stability stable
         */
        set smsMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetSmsMessage(): void;
        /**
         * @stability stable
         */
        get smsMessageInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html aws_cognito_user_pool}.
     *
     * @stability stable
     */
    class CognitoUserPool extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool.html aws_cognito_user_pool} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoUserPoolConfig);
        private _aliasAttributes?;
        /**
         * @stability stable
         */
        get aliasAttributes(): string[] | undefined;
        /**
         * @stability stable
         */
        set aliasAttributes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAliasAttributes(): void;
        /**
         * @stability stable
         */
        get aliasAttributesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoVerifiedAttributes?;
        /**
         * @stability stable
         */
        get autoVerifiedAttributes(): string[] | undefined;
        /**
         * @stability stable
         */
        set autoVerifiedAttributes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAutoVerifiedAttributes(): void;
        /**
         * @stability stable
         */
        get autoVerifiedAttributesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get creationDate(): string;
        /**
         * @stability stable
         */
        get customDomain(): string;
        /**
         * @stability stable
         */
        get domain(): string;
        private _emailVerificationMessage?;
        /**
         * @stability stable
         */
        get emailVerificationMessage(): string | undefined;
        /**
         * @stability stable
         */
        set emailVerificationMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailVerificationMessage(): void;
        /**
         * @stability stable
         */
        get emailVerificationMessageInput(): string | undefined;
        private _emailVerificationSubject?;
        /**
         * @stability stable
         */
        get emailVerificationSubject(): string | undefined;
        /**
         * @stability stable
         */
        set emailVerificationSubject(value: string | undefined);
        /**
         * @stability stable
         */
        resetEmailVerificationSubject(): void;
        /**
         * @stability stable
         */
        get emailVerificationSubjectInput(): string | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get estimatedNumberOfUsers(): number;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastModifiedDate(): string;
        private _mfaConfiguration?;
        /**
         * @stability stable
         */
        get mfaConfiguration(): string | undefined;
        /**
         * @stability stable
         */
        set mfaConfiguration(value: string | undefined);
        /**
         * @stability stable
         */
        resetMfaConfiguration(): void;
        /**
         * @stability stable
         */
        get mfaConfigurationInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _smsAuthenticationMessage?;
        /**
         * @stability stable
         */
        get smsAuthenticationMessage(): string | undefined;
        /**
         * @stability stable
         */
        set smsAuthenticationMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetSmsAuthenticationMessage(): void;
        /**
         * @stability stable
         */
        get smsAuthenticationMessageInput(): string | undefined;
        private _smsVerificationMessage?;
        /**
         * @stability stable
         */
        get smsVerificationMessage(): string | undefined;
        /**
         * @stability stable
         */
        set smsVerificationMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetSmsVerificationMessage(): void;
        /**
         * @stability stable
         */
        get smsVerificationMessageInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _usernameAttributes?;
        /**
         * @stability stable
         */
        get usernameAttributes(): string[] | undefined;
        /**
         * @stability stable
         */
        set usernameAttributes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetUsernameAttributes(): void;
        /**
         * @stability stable
         */
        get usernameAttributesInput(): string[] | undefined;
        private _accountRecoverySetting?;
        private __accountRecoverySettingOutput;
        /**
         * @stability stable
         */
        get accountRecoverySetting(): CognitoUserPoolAccountRecoverySettingOutputReference;
        /**
         * @stability stable
         */
        putAccountRecoverySetting(value: CognitoUserPoolAccountRecoverySetting | undefined): void;
        /**
         * @stability stable
         */
        resetAccountRecoverySetting(): void;
        /**
         * @stability stable
         */
        get accountRecoverySettingInput(): CognitoUserPoolAccountRecoverySetting | undefined;
        private _adminCreateUserConfig?;
        private __adminCreateUserConfigOutput;
        /**
         * @stability stable
         */
        get adminCreateUserConfig(): CognitoUserPoolAdminCreateUserConfigOutputReference;
        /**
         * @stability stable
         */
        putAdminCreateUserConfig(value: CognitoUserPoolAdminCreateUserConfig | undefined): void;
        /**
         * @stability stable
         */
        resetAdminCreateUserConfig(): void;
        /**
         * @stability stable
         */
        get adminCreateUserConfigInput(): CognitoUserPoolAdminCreateUserConfig | undefined;
        private _deviceConfiguration?;
        private __deviceConfigurationOutput;
        /**
         * @stability stable
         */
        get deviceConfiguration(): CognitoUserPoolDeviceConfigurationOutputReference;
        /**
         * @stability stable
         */
        putDeviceConfiguration(value: CognitoUserPoolDeviceConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetDeviceConfiguration(): void;
        /**
         * @stability stable
         */
        get deviceConfigurationInput(): CognitoUserPoolDeviceConfiguration | undefined;
        private _emailConfiguration?;
        private __emailConfigurationOutput;
        /**
         * @stability stable
         */
        get emailConfiguration(): CognitoUserPoolEmailConfigurationOutputReference;
        /**
         * @stability stable
         */
        putEmailConfiguration(value: CognitoUserPoolEmailConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetEmailConfiguration(): void;
        /**
         * @stability stable
         */
        get emailConfigurationInput(): CognitoUserPoolEmailConfiguration | undefined;
        private _lambdaConfig?;
        private __lambdaConfigOutput;
        /**
         * @stability stable
         */
        get lambdaConfig(): CognitoUserPoolLambdaConfigOutputReference;
        /**
         * @stability stable
         */
        putLambdaConfig(value: CognitoUserPoolLambdaConfig | undefined): void;
        /**
         * @stability stable
         */
        resetLambdaConfig(): void;
        /**
         * @stability stable
         */
        get lambdaConfigInput(): CognitoUserPoolLambdaConfig | undefined;
        private _passwordPolicy?;
        private __passwordPolicyOutput;
        /**
         * @stability stable
         */
        get passwordPolicy(): CognitoUserPoolPasswordPolicyOutputReference;
        /**
         * @stability stable
         */
        putPasswordPolicy(value: CognitoUserPoolPasswordPolicy | undefined): void;
        /**
         * @stability stable
         */
        resetPasswordPolicy(): void;
        /**
         * @stability stable
         */
        get passwordPolicyInput(): CognitoUserPoolPasswordPolicy | undefined;
        private _schema?;
        /**
         * @stability stable
         */
        get schema(): CognitoUserPoolSchema[] | undefined;
        /**
         * @stability stable
         */
        set schema(value: CognitoUserPoolSchema[] | undefined);
        /**
         * @stability stable
         */
        resetSchema(): void;
        /**
         * @stability stable
         */
        get schemaInput(): CognitoUserPoolSchema[] | undefined;
        private _smsConfiguration?;
        private __smsConfigurationOutput;
        /**
         * @stability stable
         */
        get smsConfiguration(): CognitoUserPoolSmsConfigurationOutputReference;
        /**
         * @stability stable
         */
        putSmsConfiguration(value: CognitoUserPoolSmsConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetSmsConfiguration(): void;
        /**
         * @stability stable
         */
        get smsConfigurationInput(): CognitoUserPoolSmsConfiguration | undefined;
        private _softwareTokenMfaConfiguration?;
        private __softwareTokenMfaConfigurationOutput;
        /**
         * @stability stable
         */
        get softwareTokenMfaConfiguration(): CognitoUserPoolSoftwareTokenMfaConfigurationOutputReference;
        /**
         * @stability stable
         */
        putSoftwareTokenMfaConfiguration(value: CognitoUserPoolSoftwareTokenMfaConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetSoftwareTokenMfaConfiguration(): void;
        /**
         * @stability stable
         */
        get softwareTokenMfaConfigurationInput(): CognitoUserPoolSoftwareTokenMfaConfiguration | undefined;
        private _userPoolAddOns?;
        private __userPoolAddOnsOutput;
        /**
         * @stability stable
         */
        get userPoolAddOns(): CognitoUserPoolUserPoolAddOnsOutputReference;
        /**
         * @stability stable
         */
        putUserPoolAddOns(value: CognitoUserPoolUserPoolAddOns | undefined): void;
        /**
         * @stability stable
         */
        resetUserPoolAddOns(): void;
        /**
         * @stability stable
         */
        get userPoolAddOnsInput(): CognitoUserPoolUserPoolAddOns | undefined;
        private _usernameConfiguration?;
        private __usernameConfigurationOutput;
        /**
         * @stability stable
         */
        get usernameConfiguration(): CognitoUserPoolUsernameConfigurationOutputReference;
        /**
         * @stability stable
         */
        putUsernameConfiguration(value: CognitoUserPoolUsernameConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetUsernameConfiguration(): void;
        /**
         * @stability stable
         */
        get usernameConfigurationInput(): CognitoUserPoolUsernameConfiguration | undefined;
        private _verificationMessageTemplate?;
        private __verificationMessageTemplateOutput;
        /**
         * @stability stable
         */
        get verificationMessageTemplate(): CognitoUserPoolVerificationMessageTemplateOutputReference;
        /**
         * @stability stable
         */
        putVerificationMessageTemplate(value: CognitoUserPoolVerificationMessageTemplate | undefined): void;
        /**
         * @stability stable
         */
        resetVerificationMessageTemplate(): void;
        /**
         * @stability stable
         */
        get verificationMessageTemplateInput(): CognitoUserPoolVerificationMessageTemplate | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolClientConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#access_token_validity CognitoUserPoolClient#access_token_validity}.
         *
         * @stability stable
         */
        readonly accessTokenValidity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#allowed_oauth_flows CognitoUserPoolClient#allowed_oauth_flows}.
         *
         * @stability stable
         */
        readonly allowedOauthFlows?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#allowed_oauth_flows_user_pool_client CognitoUserPoolClient#allowed_oauth_flows_user_pool_client}.
         *
         * @stability stable
         */
        readonly allowedOauthFlowsUserPoolClient?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#allowed_oauth_scopes CognitoUserPoolClient#allowed_oauth_scopes}.
         *
         * @stability stable
         */
        readonly allowedOauthScopes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#callback_urls CognitoUserPoolClient#callback_urls}.
         *
         * @stability stable
         */
        readonly callbackUrls?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#default_redirect_uri CognitoUserPoolClient#default_redirect_uri}.
         *
         * @stability stable
         */
        readonly defaultRedirectUri?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#enable_token_revocation CognitoUserPoolClient#enable_token_revocation}.
         *
         * @stability stable
         */
        readonly enableTokenRevocation?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#explicit_auth_flows CognitoUserPoolClient#explicit_auth_flows}.
         *
         * @stability stable
         */
        readonly explicitAuthFlows?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#generate_secret CognitoUserPoolClient#generate_secret}.
         *
         * @stability stable
         */
        readonly generateSecret?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#id_token_validity CognitoUserPoolClient#id_token_validity}.
         *
         * @stability stable
         */
        readonly idTokenValidity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#logout_urls CognitoUserPoolClient#logout_urls}.
         *
         * @stability stable
         */
        readonly logoutUrls?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#name CognitoUserPoolClient#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#prevent_user_existence_errors CognitoUserPoolClient#prevent_user_existence_errors}.
         *
         * @stability stable
         */
        readonly preventUserExistenceErrors?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#read_attributes CognitoUserPoolClient#read_attributes}.
         *
         * @stability stable
         */
        readonly readAttributes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#refresh_token_validity CognitoUserPoolClient#refresh_token_validity}.
         *
         * @stability stable
         */
        readonly refreshTokenValidity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#supported_identity_providers CognitoUserPoolClient#supported_identity_providers}.
         *
         * @stability stable
         */
        readonly supportedIdentityProviders?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#user_pool_id CognitoUserPoolClient#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#write_attributes CognitoUserPoolClient#write_attributes}.
         *
         * @stability stable
         */
        readonly writeAttributes?: string[];
        /**
         * analytics_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#analytics_configuration CognitoUserPoolClient#analytics_configuration}
         *
         * @stability stable
         */
        readonly analyticsConfiguration?: CognitoUserPoolClientAnalyticsConfiguration;
        /**
         * token_validity_units block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#token_validity_units CognitoUserPoolClient#token_validity_units}
         *
         * @stability stable
         */
        readonly tokenValidityUnits?: CognitoUserPoolClientTokenValidityUnits;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolClientAnalyticsConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#application_arn CognitoUserPoolClient#application_arn}.
         *
         * @stability stable
         */
        readonly applicationArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#application_id CognitoUserPoolClient#application_id}.
         *
         * @stability stable
         */
        readonly applicationId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#external_id CognitoUserPoolClient#external_id}.
         *
         * @stability stable
         */
        readonly externalId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#role_arn CognitoUserPoolClient#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#user_data_shared CognitoUserPoolClient#user_data_shared}.
         *
         * @stability stable
         */
        readonly userDataShared?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolClientAnalyticsConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _applicationArn?;
        /**
         * @stability stable
         */
        get applicationArn(): string | undefined;
        /**
         * @stability stable
         */
        set applicationArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetApplicationArn(): void;
        /**
         * @stability stable
         */
        get applicationArnInput(): string | undefined;
        private _applicationId?;
        /**
         * @stability stable
         */
        get applicationId(): string | undefined;
        /**
         * @stability stable
         */
        set applicationId(value: string | undefined);
        /**
         * @stability stable
         */
        resetApplicationId(): void;
        /**
         * @stability stable
         */
        get applicationIdInput(): string | undefined;
        private _externalId?;
        /**
         * @stability stable
         */
        get externalId(): string | undefined;
        /**
         * @stability stable
         */
        set externalId(value: string | undefined);
        /**
         * @stability stable
         */
        resetExternalId(): void;
        /**
         * @stability stable
         */
        get externalIdInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string | undefined;
        /**
         * @stability stable
         */
        set roleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetRoleArn(): void;
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _userDataShared?;
        /**
         * @stability stable
         */
        get userDataShared(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set userDataShared(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetUserDataShared(): void;
        /**
         * @stability stable
         */
        get userDataSharedInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolClientTokenValidityUnits {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#access_token CognitoUserPoolClient#access_token}.
         *
         * @stability stable
         */
        readonly accessToken?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#id_token CognitoUserPoolClient#id_token}.
         *
         * @stability stable
         */
        readonly idToken?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html#refresh_token CognitoUserPoolClient#refresh_token}.
         *
         * @stability stable
         */
        readonly refreshToken?: string;
    }
    /**
     * @stability stable
     */
    class CognitoUserPoolClientTokenValidityUnitsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _accessToken?;
        /**
         * @stability stable
         */
        get accessToken(): string | undefined;
        /**
         * @stability stable
         */
        set accessToken(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccessToken(): void;
        /**
         * @stability stable
         */
        get accessTokenInput(): string | undefined;
        private _idToken?;
        /**
         * @stability stable
         */
        get idToken(): string | undefined;
        /**
         * @stability stable
         */
        set idToken(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdToken(): void;
        /**
         * @stability stable
         */
        get idTokenInput(): string | undefined;
        private _refreshToken?;
        /**
         * @stability stable
         */
        get refreshToken(): string | undefined;
        /**
         * @stability stable
         */
        set refreshToken(value: string | undefined);
        /**
         * @stability stable
         */
        resetRefreshToken(): void;
        /**
         * @stability stable
         */
        get refreshTokenInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html aws_cognito_user_pool_client}.
     *
     * @stability stable
     */
    class CognitoUserPoolClient extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_client.html aws_cognito_user_pool_client} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoUserPoolClientConfig);
        private _accessTokenValidity?;
        /**
         * @stability stable
         */
        get accessTokenValidity(): number | undefined;
        /**
         * @stability stable
         */
        set accessTokenValidity(value: number | undefined);
        /**
         * @stability stable
         */
        resetAccessTokenValidity(): void;
        /**
         * @stability stable
         */
        get accessTokenValidityInput(): number | undefined;
        private _allowedOauthFlows?;
        /**
         * @stability stable
         */
        get allowedOauthFlows(): string[] | undefined;
        /**
         * @stability stable
         */
        set allowedOauthFlows(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAllowedOauthFlows(): void;
        /**
         * @stability stable
         */
        get allowedOauthFlowsInput(): string[] | undefined;
        private _allowedOauthFlowsUserPoolClient?;
        /**
         * @stability stable
         */
        get allowedOauthFlowsUserPoolClient(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowedOauthFlowsUserPoolClient(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowedOauthFlowsUserPoolClient(): void;
        /**
         * @stability stable
         */
        get allowedOauthFlowsUserPoolClientInput(): boolean | cdktf.IResolvable | undefined;
        private _allowedOauthScopes?;
        /**
         * @stability stable
         */
        get allowedOauthScopes(): string[] | undefined;
        /**
         * @stability stable
         */
        set allowedOauthScopes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAllowedOauthScopes(): void;
        /**
         * @stability stable
         */
        get allowedOauthScopesInput(): string[] | undefined;
        private _callbackUrls?;
        /**
         * @stability stable
         */
        get callbackUrls(): string[] | undefined;
        /**
         * @stability stable
         */
        set callbackUrls(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCallbackUrls(): void;
        /**
         * @stability stable
         */
        get callbackUrlsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        private _defaultRedirectUri?;
        /**
         * @stability stable
         */
        get defaultRedirectUri(): string | undefined;
        /**
         * @stability stable
         */
        set defaultRedirectUri(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefaultRedirectUri(): void;
        /**
         * @stability stable
         */
        get defaultRedirectUriInput(): string | undefined;
        private _enableTokenRevocation?;
        /**
         * @stability stable
         */
        get enableTokenRevocation(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableTokenRevocation(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableTokenRevocation(): void;
        /**
         * @stability stable
         */
        get enableTokenRevocationInput(): boolean | cdktf.IResolvable | undefined;
        private _explicitAuthFlows?;
        /**
         * @stability stable
         */
        get explicitAuthFlows(): string[] | undefined;
        /**
         * @stability stable
         */
        set explicitAuthFlows(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetExplicitAuthFlows(): void;
        /**
         * @stability stable
         */
        get explicitAuthFlowsInput(): string[] | undefined;
        private _generateSecret?;
        /**
         * @stability stable
         */
        get generateSecret(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set generateSecret(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetGenerateSecret(): void;
        /**
         * @stability stable
         */
        get generateSecretInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _idTokenValidity?;
        /**
         * @stability stable
         */
        get idTokenValidity(): number | undefined;
        /**
         * @stability stable
         */
        set idTokenValidity(value: number | undefined);
        /**
         * @stability stable
         */
        resetIdTokenValidity(): void;
        /**
         * @stability stable
         */
        get idTokenValidityInput(): number | undefined;
        private _logoutUrls?;
        /**
         * @stability stable
         */
        get logoutUrls(): string[] | undefined;
        /**
         * @stability stable
         */
        set logoutUrls(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetLogoutUrls(): void;
        /**
         * @stability stable
         */
        get logoutUrlsInput(): string[] | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _preventUserExistenceErrors?;
        /**
         * @stability stable
         */
        get preventUserExistenceErrors(): string | undefined;
        /**
         * @stability stable
         */
        set preventUserExistenceErrors(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreventUserExistenceErrors(): void;
        /**
         * @stability stable
         */
        get preventUserExistenceErrorsInput(): string | undefined;
        private _readAttributes?;
        /**
         * @stability stable
         */
        get readAttributes(): string[] | undefined;
        /**
         * @stability stable
         */
        set readAttributes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetReadAttributes(): void;
        /**
         * @stability stable
         */
        get readAttributesInput(): string[] | undefined;
        private _refreshTokenValidity?;
        /**
         * @stability stable
         */
        get refreshTokenValidity(): number | undefined;
        /**
         * @stability stable
         */
        set refreshTokenValidity(value: number | undefined);
        /**
         * @stability stable
         */
        resetRefreshTokenValidity(): void;
        /**
         * @stability stable
         */
        get refreshTokenValidityInput(): number | undefined;
        private _supportedIdentityProviders?;
        /**
         * @stability stable
         */
        get supportedIdentityProviders(): string[] | undefined;
        /**
         * @stability stable
         */
        set supportedIdentityProviders(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSupportedIdentityProviders(): void;
        /**
         * @stability stable
         */
        get supportedIdentityProvidersInput(): string[] | undefined;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
        private _writeAttributes?;
        /**
         * @stability stable
         */
        get writeAttributes(): string[] | undefined;
        /**
         * @stability stable
         */
        set writeAttributes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetWriteAttributes(): void;
        /**
         * @stability stable
         */
        get writeAttributesInput(): string[] | undefined;
        private _analyticsConfiguration?;
        private __analyticsConfigurationOutput;
        /**
         * @stability stable
         */
        get analyticsConfiguration(): CognitoUserPoolClientAnalyticsConfigurationOutputReference;
        /**
         * @stability stable
         */
        putAnalyticsConfiguration(value: CognitoUserPoolClientAnalyticsConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetAnalyticsConfiguration(): void;
        /**
         * @stability stable
         */
        get analyticsConfigurationInput(): CognitoUserPoolClientAnalyticsConfiguration | undefined;
        private _tokenValidityUnits?;
        private __tokenValidityUnitsOutput;
        /**
         * @stability stable
         */
        get tokenValidityUnits(): CognitoUserPoolClientTokenValidityUnitsOutputReference;
        /**
         * @stability stable
         */
        putTokenValidityUnits(value: CognitoUserPoolClientTokenValidityUnits | undefined): void;
        /**
         * @stability stable
         */
        resetTokenValidityUnits(): void;
        /**
         * @stability stable
         */
        get tokenValidityUnitsInput(): CognitoUserPoolClientTokenValidityUnits | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolDomainConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_domain.html#certificate_arn CognitoUserPoolDomain#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_domain.html#domain CognitoUserPoolDomain#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_domain.html#user_pool_id CognitoUserPoolDomain#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_domain.html aws_cognito_user_pool_domain}.
     *
     * @stability stable
     */
    class CognitoUserPoolDomain extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_domain.html aws_cognito_user_pool_domain} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoUserPoolDomainConfig);
        /**
         * @stability stable
         */
        get awsAccountId(): string;
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set certificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateArn(): void;
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get cloudfrontDistributionArn(): string;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get s3Bucket(): string;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface CognitoUserPoolUiCustomizationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_ui_customization.html#client_id CognitoUserPoolUiCustomization#client_id}.
         *
         * @stability stable
         */
        readonly clientId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_ui_customization.html#css CognitoUserPoolUiCustomization#css}.
         *
         * @stability stable
         */
        readonly css?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_ui_customization.html#image_file CognitoUserPoolUiCustomization#image_file}.
         *
         * @stability stable
         */
        readonly imageFile?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_ui_customization.html#user_pool_id CognitoUserPoolUiCustomization#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_ui_customization.html aws_cognito_user_pool_ui_customization}.
     *
     * @stability stable
     */
    class CognitoUserPoolUiCustomization extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/cognito_user_pool_ui_customization.html aws_cognito_user_pool_ui_customization} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CognitoUserPoolUiCustomizationConfig);
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string | undefined;
        /**
         * @stability stable
         */
        set clientId(value: string | undefined);
        /**
         * @stability stable
         */
        resetClientId(): void;
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get creationDate(): string;
        private _css?;
        /**
         * @stability stable
         */
        get css(): string | undefined;
        /**
         * @stability stable
         */
        set css(value: string | undefined);
        /**
         * @stability stable
         */
        resetCss(): void;
        /**
         * @stability stable
         */
        get cssInput(): string | undefined;
        /**
         * @stability stable
         */
        get cssVersion(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _imageFile?;
        /**
         * @stability stable
         */
        get imageFile(): string | undefined;
        /**
         * @stability stable
         */
        set imageFile(value: string | undefined);
        /**
         * @stability stable
         */
        resetImageFile(): void;
        /**
         * @stability stable
         */
        get imageFileInput(): string | undefined;
        /**
         * @stability stable
         */
        get imageUrl(): string;
        /**
         * @stability stable
         */
        get lastModifiedDate(): string;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCognitoUserPoolsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/cognito_user_pools.html#name DataAwsCognitoUserPools#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/cognito_user_pools.html aws_cognito_user_pools}.
     *
     * @stability stable
     */
    class DataAwsCognitoUserPools extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/cognito_user_pools.html aws_cognito_user_pools} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsCognitoUserPoolsConfig);
        /**
         * @stability stable
         */
        get arns(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
