import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS DynamoDB Accelerator
*/
export declare namespace DAX {
    /**
     * @stability stable
     */
    interface DaxClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#availability_zones DaxCluster#availability_zones}.
         *
         * @stability stable
         */
        readonly availabilityZones?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#cluster_name DaxCluster#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#description DaxCluster#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#iam_role_arn DaxCluster#iam_role_arn}.
         *
         * @stability stable
         */
        readonly iamRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#maintenance_window DaxCluster#maintenance_window}.
         *
         * @stability stable
         */
        readonly maintenanceWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#node_type DaxCluster#node_type}.
         *
         * @stability stable
         */
        readonly nodeType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#notification_topic_arn DaxCluster#notification_topic_arn}.
         *
         * @stability stable
         */
        readonly notificationTopicArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#parameter_group_name DaxCluster#parameter_group_name}.
         *
         * @stability stable
         */
        readonly parameterGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#replication_factor DaxCluster#replication_factor}.
         *
         * @stability stable
         */
        readonly replicationFactor: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#security_group_ids DaxCluster#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#subnet_group_name DaxCluster#subnet_group_name}.
         *
         * @stability stable
         */
        readonly subnetGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#tags DaxCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#tags_all DaxCluster#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * server_side_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#server_side_encryption DaxCluster#server_side_encryption}
         *
         * @stability stable
         */
        readonly serverSideEncryption?: DaxClusterServerSideEncryption;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#timeouts DaxCluster#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DaxClusterTimeouts;
    }
    /**
     * @stability stable
     */
    class DaxClusterNodes extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get address(): string;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get port(): number;
    }
    /**
     * @stability stable
     */
    interface DaxClusterServerSideEncryption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#enabled DaxCluster#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DaxClusterServerSideEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface DaxClusterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#create DaxCluster#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#delete DaxCluster#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html#update DaxCluster#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DaxClusterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html aws_dax_cluster}.
     *
     * @stability stable
     */
    class DaxCluster extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dax_cluster.html aws_dax_cluster} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DaxClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _availabilityZones?;
        /**
         * @stability stable
         */
        get availabilityZones(): string[] | undefined;
        /**
         * @stability stable
         */
        set availabilityZones(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZones(): void;
        /**
         * @stability stable
         */
        get availabilityZonesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get clusterAddress(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get configurationEndpoint(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _iamRoleArn?;
        /**
         * @stability stable
         */
        get iamRoleArn(): string;
        /**
         * @stability stable
         */
        set iamRoleArn(value: string);
        /**
         * @stability stable
         */
        get iamRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _maintenanceWindow?;
        /**
         * @stability stable
         */
        get maintenanceWindow(): string | undefined;
        /**
         * @stability stable
         */
        set maintenanceWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaintenanceWindow(): void;
        /**
         * @stability stable
         */
        get maintenanceWindowInput(): string | undefined;
        private _nodeType?;
        /**
         * @stability stable
         */
        get nodeType(): string;
        /**
         * @stability stable
         */
        set nodeType(value: string);
        /**
         * @stability stable
         */
        get nodeTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        nodes(index: string): DaxClusterNodes;
        private _notificationTopicArn?;
        /**
         * @stability stable
         */
        get notificationTopicArn(): string | undefined;
        /**
         * @stability stable
         */
        set notificationTopicArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationTopicArn(): void;
        /**
         * @stability stable
         */
        get notificationTopicArnInput(): string | undefined;
        private _parameterGroupName?;
        /**
         * @stability stable
         */
        get parameterGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set parameterGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetParameterGroupName(): void;
        /**
         * @stability stable
         */
        get parameterGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get port(): number;
        private _replicationFactor?;
        /**
         * @stability stable
         */
        get replicationFactor(): number;
        /**
         * @stability stable
         */
        set replicationFactor(value: number);
        /**
         * @stability stable
         */
        get replicationFactorInput(): number | undefined;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _subnetGroupName?;
        /**
         * @stability stable
         */
        get subnetGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set subnetGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetGroupName(): void;
        /**
         * @stability stable
         */
        get subnetGroupNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _serverSideEncryption?;
        private __serverSideEncryptionOutput;
        /**
         * @stability stable
         */
        get serverSideEncryption(): DaxClusterServerSideEncryptionOutputReference;
        /**
         * @stability stable
         */
        putServerSideEncryption(value: DaxClusterServerSideEncryption | undefined): void;
        /**
         * @stability stable
         */
        resetServerSideEncryption(): void;
        /**
         * @stability stable
         */
        get serverSideEncryptionInput(): DaxClusterServerSideEncryption | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DaxClusterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DaxClusterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DaxClusterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DaxParameterGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_parameter_group.html#description DaxParameterGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_parameter_group.html#name DaxParameterGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_parameter_group.html#parameters DaxParameterGroup#parameters}
         *
         * @stability stable
         */
        readonly parameters?: DaxParameterGroupParameters[];
    }
    /**
     * @stability stable
     */
    interface DaxParameterGroupParameters {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_parameter_group.html#name DaxParameterGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_parameter_group.html#value DaxParameterGroup#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dax_parameter_group.html aws_dax_parameter_group}.
     *
     * @stability stable
     */
    class DaxParameterGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dax_parameter_group.html aws_dax_parameter_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DaxParameterGroupConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): DaxParameterGroupParameters[] | undefined;
        /**
         * @stability stable
         */
        set parameters(value: DaxParameterGroupParameters[] | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): DaxParameterGroupParameters[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DaxSubnetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_subnet_group.html#description DaxSubnetGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_subnet_group.html#name DaxSubnetGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dax_subnet_group.html#subnet_ids DaxSubnetGroup#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dax_subnet_group.html aws_dax_subnet_group}.
     *
     * @stability stable
     */
    class DaxSubnetGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dax_subnet_group.html aws_dax_subnet_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DaxSubnetGroupConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
