import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Database Migration Service
*/
export declare namespace DMS {
    /**
     * @stability stable
     */
    interface DmsCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_certificate.html#certificate_id DmsCertificate#certificate_id}.
         *
         * @stability stable
         */
        readonly certificateId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_certificate.html#certificate_pem DmsCertificate#certificate_pem}.
         *
         * @stability stable
         */
        readonly certificatePem?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_certificate.html#certificate_wallet DmsCertificate#certificate_wallet}.
         *
         * @stability stable
         */
        readonly certificateWallet?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_certificate.html#tags DmsCertificate#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_certificate.html#tags_all DmsCertificate#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dms_certificate.html aws_dms_certificate}.
     *
     * @stability stable
     */
    class DmsCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_certificate.html aws_dms_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DmsCertificateConfig);
        /**
         * @stability stable
         */
        get certificateArn(): string;
        private _certificateId?;
        /**
         * @stability stable
         */
        get certificateId(): string;
        /**
         * @stability stable
         */
        set certificateId(value: string);
        /**
         * @stability stable
         */
        get certificateIdInput(): string | undefined;
        private _certificatePem?;
        /**
         * @stability stable
         */
        get certificatePem(): string | undefined;
        /**
         * @stability stable
         */
        set certificatePem(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificatePem(): void;
        /**
         * @stability stable
         */
        get certificatePemInput(): string | undefined;
        private _certificateWallet?;
        /**
         * @stability stable
         */
        get certificateWallet(): string | undefined;
        /**
         * @stability stable
         */
        set certificateWallet(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateWallet(): void;
        /**
         * @stability stable
         */
        get certificateWalletInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DmsEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#certificate_arn DmsEndpoint#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#database_name DmsEndpoint#database_name}.
         *
         * @stability stable
         */
        readonly databaseName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#endpoint_id DmsEndpoint#endpoint_id}.
         *
         * @stability stable
         */
        readonly endpointId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#endpoint_type DmsEndpoint#endpoint_type}.
         *
         * @stability stable
         */
        readonly endpointType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#engine_name DmsEndpoint#engine_name}.
         *
         * @stability stable
         */
        readonly engineName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#extra_connection_attributes DmsEndpoint#extra_connection_attributes}.
         *
         * @stability stable
         */
        readonly extraConnectionAttributes?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#kms_key_arn DmsEndpoint#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#password DmsEndpoint#password}.
         *
         * @stability stable
         */
        readonly password?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#port DmsEndpoint#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#server_name DmsEndpoint#server_name}.
         *
         * @stability stable
         */
        readonly serverName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#service_access_role DmsEndpoint#service_access_role}.
         *
         * @stability stable
         */
        readonly serviceAccessRole?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#ssl_mode DmsEndpoint#ssl_mode}.
         *
         * @stability stable
         */
        readonly sslMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#tags DmsEndpoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#tags_all DmsEndpoint#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#username DmsEndpoint#username}.
         *
         * @stability stable
         */
        readonly username?: string;
        /**
         * elasticsearch_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#elasticsearch_settings DmsEndpoint#elasticsearch_settings}
         *
         * @stability stable
         */
        readonly elasticsearchSettings?: DmsEndpointElasticsearchSettings;
        /**
         * kafka_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#kafka_settings DmsEndpoint#kafka_settings}
         *
         * @stability stable
         */
        readonly kafkaSettings?: DmsEndpointKafkaSettings;
        /**
         * kinesis_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#kinesis_settings DmsEndpoint#kinesis_settings}
         *
         * @stability stable
         */
        readonly kinesisSettings?: DmsEndpointKinesisSettings;
        /**
         * mongodb_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#mongodb_settings DmsEndpoint#mongodb_settings}
         *
         * @stability stable
         */
        readonly mongodbSettings?: DmsEndpointMongodbSettings;
        /**
         * s3_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#s3_settings DmsEndpoint#s3_settings}
         *
         * @stability stable
         */
        readonly s3Settings?: DmsEndpointS3Settings;
    }
    /**
     * @stability stable
     */
    interface DmsEndpointElasticsearchSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#endpoint_uri DmsEndpoint#endpoint_uri}.
         *
         * @stability stable
         */
        readonly endpointUri: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#error_retry_duration DmsEndpoint#error_retry_duration}.
         *
         * @stability stable
         */
        readonly errorRetryDuration?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#full_load_error_percentage DmsEndpoint#full_load_error_percentage}.
         *
         * @stability stable
         */
        readonly fullLoadErrorPercentage?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#service_access_role_arn DmsEndpoint#service_access_role_arn}.
         *
         * @stability stable
         */
        readonly serviceAccessRoleArn: string;
    }
    /**
     * @stability stable
     */
    class DmsEndpointElasticsearchSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _endpointUri?;
        /**
         * @stability stable
         */
        get endpointUri(): string;
        /**
         * @stability stable
         */
        set endpointUri(value: string);
        /**
         * @stability stable
         */
        get endpointUriInput(): string | undefined;
        private _errorRetryDuration?;
        /**
         * @stability stable
         */
        get errorRetryDuration(): number | undefined;
        /**
         * @stability stable
         */
        set errorRetryDuration(value: number | undefined);
        /**
         * @stability stable
         */
        resetErrorRetryDuration(): void;
        /**
         * @stability stable
         */
        get errorRetryDurationInput(): number | undefined;
        private _fullLoadErrorPercentage?;
        /**
         * @stability stable
         */
        get fullLoadErrorPercentage(): number | undefined;
        /**
         * @stability stable
         */
        set fullLoadErrorPercentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetFullLoadErrorPercentage(): void;
        /**
         * @stability stable
         */
        get fullLoadErrorPercentageInput(): number | undefined;
        private _serviceAccessRoleArn?;
        /**
         * @stability stable
         */
        get serviceAccessRoleArn(): string;
        /**
         * @stability stable
         */
        set serviceAccessRoleArn(value: string);
        /**
         * @stability stable
         */
        get serviceAccessRoleArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DmsEndpointKafkaSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#broker DmsEndpoint#broker}.
         *
         * @stability stable
         */
        readonly broker: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#include_control_details DmsEndpoint#include_control_details}.
         *
         * @stability stable
         */
        readonly includeControlDetails?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#include_null_and_empty DmsEndpoint#include_null_and_empty}.
         *
         * @stability stable
         */
        readonly includeNullAndEmpty?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#include_partition_value DmsEndpoint#include_partition_value}.
         *
         * @stability stable
         */
        readonly includePartitionValue?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#include_table_alter_operations DmsEndpoint#include_table_alter_operations}.
         *
         * @stability stable
         */
        readonly includeTableAlterOperations?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#include_transaction_details DmsEndpoint#include_transaction_details}.
         *
         * @stability stable
         */
        readonly includeTransactionDetails?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#message_format DmsEndpoint#message_format}.
         *
         * @stability stable
         */
        readonly messageFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#message_max_bytes DmsEndpoint#message_max_bytes}.
         *
         * @stability stable
         */
        readonly messageMaxBytes?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#no_hex_prefix DmsEndpoint#no_hex_prefix}.
         *
         * @stability stable
         */
        readonly noHexPrefix?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#partition_include_schema_table DmsEndpoint#partition_include_schema_table}.
         *
         * @stability stable
         */
        readonly partitionIncludeSchemaTable?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#sasl_password DmsEndpoint#sasl_password}.
         *
         * @stability stable
         */
        readonly saslPassword?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#sasl_username DmsEndpoint#sasl_username}.
         *
         * @stability stable
         */
        readonly saslUsername?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#security_protocol DmsEndpoint#security_protocol}.
         *
         * @stability stable
         */
        readonly securityProtocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#ssl_ca_certificate_arn DmsEndpoint#ssl_ca_certificate_arn}.
         *
         * @stability stable
         */
        readonly sslCaCertificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#ssl_client_certificate_arn DmsEndpoint#ssl_client_certificate_arn}.
         *
         * @stability stable
         */
        readonly sslClientCertificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#ssl_client_key_arn DmsEndpoint#ssl_client_key_arn}.
         *
         * @stability stable
         */
        readonly sslClientKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#ssl_client_key_password DmsEndpoint#ssl_client_key_password}.
         *
         * @stability stable
         */
        readonly sslClientKeyPassword?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#topic DmsEndpoint#topic}.
         *
         * @stability stable
         */
        readonly topic?: string;
    }
    /**
     * @stability stable
     */
    class DmsEndpointKafkaSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _broker?;
        /**
         * @stability stable
         */
        get broker(): string;
        /**
         * @stability stable
         */
        set broker(value: string);
        /**
         * @stability stable
         */
        get brokerInput(): string | undefined;
        private _includeControlDetails?;
        /**
         * @stability stable
         */
        get includeControlDetails(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeControlDetails(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeControlDetails(): void;
        /**
         * @stability stable
         */
        get includeControlDetailsInput(): boolean | cdktf.IResolvable | undefined;
        private _includeNullAndEmpty?;
        /**
         * @stability stable
         */
        get includeNullAndEmpty(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeNullAndEmpty(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeNullAndEmpty(): void;
        /**
         * @stability stable
         */
        get includeNullAndEmptyInput(): boolean | cdktf.IResolvable | undefined;
        private _includePartitionValue?;
        /**
         * @stability stable
         */
        get includePartitionValue(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includePartitionValue(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludePartitionValue(): void;
        /**
         * @stability stable
         */
        get includePartitionValueInput(): boolean | cdktf.IResolvable | undefined;
        private _includeTableAlterOperations?;
        /**
         * @stability stable
         */
        get includeTableAlterOperations(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeTableAlterOperations(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeTableAlterOperations(): void;
        /**
         * @stability stable
         */
        get includeTableAlterOperationsInput(): boolean | cdktf.IResolvable | undefined;
        private _includeTransactionDetails?;
        /**
         * @stability stable
         */
        get includeTransactionDetails(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeTransactionDetails(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeTransactionDetails(): void;
        /**
         * @stability stable
         */
        get includeTransactionDetailsInput(): boolean | cdktf.IResolvable | undefined;
        private _messageFormat?;
        /**
         * @stability stable
         */
        get messageFormat(): string | undefined;
        /**
         * @stability stable
         */
        set messageFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageFormat(): void;
        /**
         * @stability stable
         */
        get messageFormatInput(): string | undefined;
        private _messageMaxBytes?;
        /**
         * @stability stable
         */
        get messageMaxBytes(): number | undefined;
        /**
         * @stability stable
         */
        set messageMaxBytes(value: number | undefined);
        /**
         * @stability stable
         */
        resetMessageMaxBytes(): void;
        /**
         * @stability stable
         */
        get messageMaxBytesInput(): number | undefined;
        private _noHexPrefix?;
        /**
         * @stability stable
         */
        get noHexPrefix(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set noHexPrefix(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetNoHexPrefix(): void;
        /**
         * @stability stable
         */
        get noHexPrefixInput(): boolean | cdktf.IResolvable | undefined;
        private _partitionIncludeSchemaTable?;
        /**
         * @stability stable
         */
        get partitionIncludeSchemaTable(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set partitionIncludeSchemaTable(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPartitionIncludeSchemaTable(): void;
        /**
         * @stability stable
         */
        get partitionIncludeSchemaTableInput(): boolean | cdktf.IResolvable | undefined;
        private _saslPassword?;
        /**
         * @stability stable
         */
        get saslPassword(): string | undefined;
        /**
         * @stability stable
         */
        set saslPassword(value: string | undefined);
        /**
         * @stability stable
         */
        resetSaslPassword(): void;
        /**
         * @stability stable
         */
        get saslPasswordInput(): string | undefined;
        private _saslUsername?;
        /**
         * @stability stable
         */
        get saslUsername(): string | undefined;
        /**
         * @stability stable
         */
        set saslUsername(value: string | undefined);
        /**
         * @stability stable
         */
        resetSaslUsername(): void;
        /**
         * @stability stable
         */
        get saslUsernameInput(): string | undefined;
        private _securityProtocol?;
        /**
         * @stability stable
         */
        get securityProtocol(): string | undefined;
        /**
         * @stability stable
         */
        set securityProtocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecurityProtocol(): void;
        /**
         * @stability stable
         */
        get securityProtocolInput(): string | undefined;
        private _sslCaCertificateArn?;
        /**
         * @stability stable
         */
        get sslCaCertificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set sslCaCertificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSslCaCertificateArn(): void;
        /**
         * @stability stable
         */
        get sslCaCertificateArnInput(): string | undefined;
        private _sslClientCertificateArn?;
        /**
         * @stability stable
         */
        get sslClientCertificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set sslClientCertificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSslClientCertificateArn(): void;
        /**
         * @stability stable
         */
        get sslClientCertificateArnInput(): string | undefined;
        private _sslClientKeyArn?;
        /**
         * @stability stable
         */
        get sslClientKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set sslClientKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSslClientKeyArn(): void;
        /**
         * @stability stable
         */
        get sslClientKeyArnInput(): string | undefined;
        private _sslClientKeyPassword?;
        /**
         * @stability stable
         */
        get sslClientKeyPassword(): string | undefined;
        /**
         * @stability stable
         */
        set sslClientKeyPassword(value: string | undefined);
        /**
         * @stability stable
         */
        resetSslClientKeyPassword(): void;
        /**
         * @stability stable
         */
        get sslClientKeyPasswordInput(): string | undefined;
        private _topic?;
        /**
         * @stability stable
         */
        get topic(): string | undefined;
        /**
         * @stability stable
         */
        set topic(value: string | undefined);
        /**
         * @stability stable
         */
        resetTopic(): void;
        /**
         * @stability stable
         */
        get topicInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DmsEndpointKinesisSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#message_format DmsEndpoint#message_format}.
         *
         * @stability stable
         */
        readonly messageFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#service_access_role_arn DmsEndpoint#service_access_role_arn}.
         *
         * @stability stable
         */
        readonly serviceAccessRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#stream_arn DmsEndpoint#stream_arn}.
         *
         * @stability stable
         */
        readonly streamArn?: string;
    }
    /**
     * @stability stable
     */
    class DmsEndpointKinesisSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _messageFormat?;
        /**
         * @stability stable
         */
        get messageFormat(): string | undefined;
        /**
         * @stability stable
         */
        set messageFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageFormat(): void;
        /**
         * @stability stable
         */
        get messageFormatInput(): string | undefined;
        private _serviceAccessRoleArn?;
        /**
         * @stability stable
         */
        get serviceAccessRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set serviceAccessRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceAccessRoleArn(): void;
        /**
         * @stability stable
         */
        get serviceAccessRoleArnInput(): string | undefined;
        private _streamArn?;
        /**
         * @stability stable
         */
        get streamArn(): string | undefined;
        /**
         * @stability stable
         */
        set streamArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetStreamArn(): void;
        /**
         * @stability stable
         */
        get streamArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DmsEndpointMongodbSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#auth_mechanism DmsEndpoint#auth_mechanism}.
         *
         * @stability stable
         */
        readonly authMechanism?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#auth_source DmsEndpoint#auth_source}.
         *
         * @stability stable
         */
        readonly authSource?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#auth_type DmsEndpoint#auth_type}.
         *
         * @stability stable
         */
        readonly authType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#docs_to_investigate DmsEndpoint#docs_to_investigate}.
         *
         * @stability stable
         */
        readonly docsToInvestigate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#extract_doc_id DmsEndpoint#extract_doc_id}.
         *
         * @stability stable
         */
        readonly extractDocId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#nesting_level DmsEndpoint#nesting_level}.
         *
         * @stability stable
         */
        readonly nestingLevel?: string;
    }
    /**
     * @stability stable
     */
    class DmsEndpointMongodbSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authMechanism?;
        /**
         * @stability stable
         */
        get authMechanism(): string | undefined;
        /**
         * @stability stable
         */
        set authMechanism(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuthMechanism(): void;
        /**
         * @stability stable
         */
        get authMechanismInput(): string | undefined;
        private _authSource?;
        /**
         * @stability stable
         */
        get authSource(): string | undefined;
        /**
         * @stability stable
         */
        set authSource(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuthSource(): void;
        /**
         * @stability stable
         */
        get authSourceInput(): string | undefined;
        private _authType?;
        /**
         * @stability stable
         */
        get authType(): string | undefined;
        /**
         * @stability stable
         */
        set authType(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuthType(): void;
        /**
         * @stability stable
         */
        get authTypeInput(): string | undefined;
        private _docsToInvestigate?;
        /**
         * @stability stable
         */
        get docsToInvestigate(): string | undefined;
        /**
         * @stability stable
         */
        set docsToInvestigate(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocsToInvestigate(): void;
        /**
         * @stability stable
         */
        get docsToInvestigateInput(): string | undefined;
        private _extractDocId?;
        /**
         * @stability stable
         */
        get extractDocId(): string | undefined;
        /**
         * @stability stable
         */
        set extractDocId(value: string | undefined);
        /**
         * @stability stable
         */
        resetExtractDocId(): void;
        /**
         * @stability stable
         */
        get extractDocIdInput(): string | undefined;
        private _nestingLevel?;
        /**
         * @stability stable
         */
        get nestingLevel(): string | undefined;
        /**
         * @stability stable
         */
        set nestingLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetNestingLevel(): void;
        /**
         * @stability stable
         */
        get nestingLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DmsEndpointS3Settings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#bucket_folder DmsEndpoint#bucket_folder}.
         *
         * @stability stable
         */
        readonly bucketFolder?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#bucket_name DmsEndpoint#bucket_name}.
         *
         * @stability stable
         */
        readonly bucketName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#compression_type DmsEndpoint#compression_type}.
         *
         * @stability stable
         */
        readonly compressionType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#csv_delimiter DmsEndpoint#csv_delimiter}.
         *
         * @stability stable
         */
        readonly csvDelimiter?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#csv_row_delimiter DmsEndpoint#csv_row_delimiter}.
         *
         * @stability stable
         */
        readonly csvRowDelimiter?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#data_format DmsEndpoint#data_format}.
         *
         * @stability stable
         */
        readonly dataFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#date_partition_enabled DmsEndpoint#date_partition_enabled}.
         *
         * @stability stable
         */
        readonly datePartitionEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#encryption_mode DmsEndpoint#encryption_mode}.
         *
         * @stability stable
         */
        readonly encryptionMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#external_table_definition DmsEndpoint#external_table_definition}.
         *
         * @stability stable
         */
        readonly externalTableDefinition?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#parquet_timestamp_in_millisecond DmsEndpoint#parquet_timestamp_in_millisecond}.
         *
         * @stability stable
         */
        readonly parquetTimestampInMillisecond?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#parquet_version DmsEndpoint#parquet_version}.
         *
         * @stability stable
         */
        readonly parquetVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#server_side_encryption_kms_key_id DmsEndpoint#server_side_encryption_kms_key_id}.
         *
         * @stability stable
         */
        readonly serverSideEncryptionKmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html#service_access_role_arn DmsEndpoint#service_access_role_arn}.
         *
         * @stability stable
         */
        readonly serviceAccessRoleArn?: string;
    }
    /**
     * @stability stable
     */
    class DmsEndpointS3SettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketFolder?;
        /**
         * @stability stable
         */
        get bucketFolder(): string | undefined;
        /**
         * @stability stable
         */
        set bucketFolder(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketFolder(): void;
        /**
         * @stability stable
         */
        get bucketFolderInput(): string | undefined;
        private _bucketName?;
        /**
         * @stability stable
         */
        get bucketName(): string | undefined;
        /**
         * @stability stable
         */
        set bucketName(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketName(): void;
        /**
         * @stability stable
         */
        get bucketNameInput(): string | undefined;
        private _compressionType?;
        /**
         * @stability stable
         */
        get compressionType(): string | undefined;
        /**
         * @stability stable
         */
        set compressionType(value: string | undefined);
        /**
         * @stability stable
         */
        resetCompressionType(): void;
        /**
         * @stability stable
         */
        get compressionTypeInput(): string | undefined;
        private _csvDelimiter?;
        /**
         * @stability stable
         */
        get csvDelimiter(): string | undefined;
        /**
         * @stability stable
         */
        set csvDelimiter(value: string | undefined);
        /**
         * @stability stable
         */
        resetCsvDelimiter(): void;
        /**
         * @stability stable
         */
        get csvDelimiterInput(): string | undefined;
        private _csvRowDelimiter?;
        /**
         * @stability stable
         */
        get csvRowDelimiter(): string | undefined;
        /**
         * @stability stable
         */
        set csvRowDelimiter(value: string | undefined);
        /**
         * @stability stable
         */
        resetCsvRowDelimiter(): void;
        /**
         * @stability stable
         */
        get csvRowDelimiterInput(): string | undefined;
        private _dataFormat?;
        /**
         * @stability stable
         */
        get dataFormat(): string | undefined;
        /**
         * @stability stable
         */
        set dataFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetDataFormat(): void;
        /**
         * @stability stable
         */
        get dataFormatInput(): string | undefined;
        private _datePartitionEnabled?;
        /**
         * @stability stable
         */
        get datePartitionEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set datePartitionEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDatePartitionEnabled(): void;
        /**
         * @stability stable
         */
        get datePartitionEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _encryptionMode?;
        /**
         * @stability stable
         */
        get encryptionMode(): string | undefined;
        /**
         * @stability stable
         */
        set encryptionMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetEncryptionMode(): void;
        /**
         * @stability stable
         */
        get encryptionModeInput(): string | undefined;
        private _externalTableDefinition?;
        /**
         * @stability stable
         */
        get externalTableDefinition(): string | undefined;
        /**
         * @stability stable
         */
        set externalTableDefinition(value: string | undefined);
        /**
         * @stability stable
         */
        resetExternalTableDefinition(): void;
        /**
         * @stability stable
         */
        get externalTableDefinitionInput(): string | undefined;
        private _parquetTimestampInMillisecond?;
        /**
         * @stability stable
         */
        get parquetTimestampInMillisecond(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parquetTimestampInMillisecond(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParquetTimestampInMillisecond(): void;
        /**
         * @stability stable
         */
        get parquetTimestampInMillisecondInput(): boolean | cdktf.IResolvable | undefined;
        private _parquetVersion?;
        /**
         * @stability stable
         */
        get parquetVersion(): string | undefined;
        /**
         * @stability stable
         */
        set parquetVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetParquetVersion(): void;
        /**
         * @stability stable
         */
        get parquetVersionInput(): string | undefined;
        private _serverSideEncryptionKmsKeyId?;
        /**
         * @stability stable
         */
        get serverSideEncryptionKmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set serverSideEncryptionKmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetServerSideEncryptionKmsKeyId(): void;
        /**
         * @stability stable
         */
        get serverSideEncryptionKmsKeyIdInput(): string | undefined;
        private _serviceAccessRoleArn?;
        /**
         * @stability stable
         */
        get serviceAccessRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set serviceAccessRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceAccessRoleArn(): void;
        /**
         * @stability stable
         */
        get serviceAccessRoleArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html aws_dms_endpoint}.
     *
     * @stability stable
     */
    class DmsEndpoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_endpoint.html aws_dms_endpoint} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DmsEndpointConfig);
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set certificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateArn(): void;
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string | undefined;
        /**
         * @stability stable
         */
        set databaseName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDatabaseName(): void;
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get endpointArn(): string;
        private _endpointId?;
        /**
         * @stability stable
         */
        get endpointId(): string;
        /**
         * @stability stable
         */
        set endpointId(value: string);
        /**
         * @stability stable
         */
        get endpointIdInput(): string | undefined;
        private _endpointType?;
        /**
         * @stability stable
         */
        get endpointType(): string;
        /**
         * @stability stable
         */
        set endpointType(value: string);
        /**
         * @stability stable
         */
        get endpointTypeInput(): string | undefined;
        private _engineName?;
        /**
         * @stability stable
         */
        get engineName(): string;
        /**
         * @stability stable
         */
        set engineName(value: string);
        /**
         * @stability stable
         */
        get engineNameInput(): string | undefined;
        private _extraConnectionAttributes?;
        /**
         * @stability stable
         */
        get extraConnectionAttributes(): string | undefined;
        /**
         * @stability stable
         */
        set extraConnectionAttributes(value: string | undefined);
        /**
         * @stability stable
         */
        resetExtraConnectionAttributes(): void;
        /**
         * @stability stable
         */
        get extraConnectionAttributesInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _password?;
        /**
         * @stability stable
         */
        get password(): string | undefined;
        /**
         * @stability stable
         */
        set password(value: string | undefined);
        /**
         * @stability stable
         */
        resetPassword(): void;
        /**
         * @stability stable
         */
        get passwordInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _serverName?;
        /**
         * @stability stable
         */
        get serverName(): string | undefined;
        /**
         * @stability stable
         */
        set serverName(value: string | undefined);
        /**
         * @stability stable
         */
        resetServerName(): void;
        /**
         * @stability stable
         */
        get serverNameInput(): string | undefined;
        private _serviceAccessRole?;
        /**
         * @stability stable
         */
        get serviceAccessRole(): string | undefined;
        /**
         * @stability stable
         */
        set serviceAccessRole(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceAccessRole(): void;
        /**
         * @stability stable
         */
        get serviceAccessRoleInput(): string | undefined;
        private _sslMode?;
        /**
         * @stability stable
         */
        get sslMode(): string | undefined;
        /**
         * @stability stable
         */
        set sslMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetSslMode(): void;
        /**
         * @stability stable
         */
        get sslModeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _username?;
        /**
         * @stability stable
         */
        get username(): string | undefined;
        /**
         * @stability stable
         */
        set username(value: string | undefined);
        /**
         * @stability stable
         */
        resetUsername(): void;
        /**
         * @stability stable
         */
        get usernameInput(): string | undefined;
        private _elasticsearchSettings?;
        private __elasticsearchSettingsOutput;
        /**
         * @stability stable
         */
        get elasticsearchSettings(): DmsEndpointElasticsearchSettingsOutputReference;
        /**
         * @stability stable
         */
        putElasticsearchSettings(value: DmsEndpointElasticsearchSettings | undefined): void;
        /**
         * @stability stable
         */
        resetElasticsearchSettings(): void;
        /**
         * @stability stable
         */
        get elasticsearchSettingsInput(): DmsEndpointElasticsearchSettings | undefined;
        private _kafkaSettings?;
        private __kafkaSettingsOutput;
        /**
         * @stability stable
         */
        get kafkaSettings(): DmsEndpointKafkaSettingsOutputReference;
        /**
         * @stability stable
         */
        putKafkaSettings(value: DmsEndpointKafkaSettings | undefined): void;
        /**
         * @stability stable
         */
        resetKafkaSettings(): void;
        /**
         * @stability stable
         */
        get kafkaSettingsInput(): DmsEndpointKafkaSettings | undefined;
        private _kinesisSettings?;
        private __kinesisSettingsOutput;
        /**
         * @stability stable
         */
        get kinesisSettings(): DmsEndpointKinesisSettingsOutputReference;
        /**
         * @stability stable
         */
        putKinesisSettings(value: DmsEndpointKinesisSettings | undefined): void;
        /**
         * @stability stable
         */
        resetKinesisSettings(): void;
        /**
         * @stability stable
         */
        get kinesisSettingsInput(): DmsEndpointKinesisSettings | undefined;
        private _mongodbSettings?;
        private __mongodbSettingsOutput;
        /**
         * @stability stable
         */
        get mongodbSettings(): DmsEndpointMongodbSettingsOutputReference;
        /**
         * @stability stable
         */
        putMongodbSettings(value: DmsEndpointMongodbSettings | undefined): void;
        /**
         * @stability stable
         */
        resetMongodbSettings(): void;
        /**
         * @stability stable
         */
        get mongodbSettingsInput(): DmsEndpointMongodbSettings | undefined;
        private _s3Settings?;
        private __s3SettingsOutput;
        /**
         * @stability stable
         */
        get s3Settings(): DmsEndpointS3SettingsOutputReference;
        /**
         * @stability stable
         */
        putS3Settings(value: DmsEndpointS3Settings | undefined): void;
        /**
         * @stability stable
         */
        resetS3Settings(): void;
        /**
         * @stability stable
         */
        get s3SettingsInput(): DmsEndpointS3Settings | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DmsEventSubscriptionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#enabled DmsEventSubscription#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#event_categories DmsEventSubscription#event_categories}.
         *
         * @stability stable
         */
        readonly eventCategories: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#name DmsEventSubscription#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#sns_topic_arn DmsEventSubscription#sns_topic_arn}.
         *
         * @stability stable
         */
        readonly snsTopicArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#source_ids DmsEventSubscription#source_ids}.
         *
         * @stability stable
         */
        readonly sourceIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#source_type DmsEventSubscription#source_type}.
         *
         * @stability stable
         */
        readonly sourceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#tags DmsEventSubscription#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#tags_all DmsEventSubscription#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#timeouts DmsEventSubscription#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DmsEventSubscriptionTimeouts;
    }
    /**
     * @stability stable
     */
    interface DmsEventSubscriptionTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#create DmsEventSubscription#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#delete DmsEventSubscription#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html#update DmsEventSubscription#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DmsEventSubscriptionTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html aws_dms_event_subscription}.
     *
     * @stability stable
     */
    class DmsEventSubscription extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_event_subscription.html aws_dms_event_subscription} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DmsEventSubscriptionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _eventCategories?;
        /**
         * @stability stable
         */
        get eventCategories(): string[];
        /**
         * @stability stable
         */
        set eventCategories(value: string[]);
        /**
         * @stability stable
         */
        get eventCategoriesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _snsTopicArn?;
        /**
         * @stability stable
         */
        get snsTopicArn(): string;
        /**
         * @stability stable
         */
        set snsTopicArn(value: string);
        /**
         * @stability stable
         */
        get snsTopicArnInput(): string | undefined;
        private _sourceIds?;
        /**
         * @stability stable
         */
        get sourceIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set sourceIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSourceIds(): void;
        /**
         * @stability stable
         */
        get sourceIdsInput(): string[] | undefined;
        private _sourceType?;
        /**
         * @stability stable
         */
        get sourceType(): string | undefined;
        /**
         * @stability stable
         */
        set sourceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceType(): void;
        /**
         * @stability stable
         */
        get sourceTypeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DmsEventSubscriptionTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DmsEventSubscriptionTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DmsEventSubscriptionTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DmsReplicationInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#allocated_storage DmsReplicationInstance#allocated_storage}.
         *
         * @stability stable
         */
        readonly allocatedStorage?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#allow_major_version_upgrade DmsReplicationInstance#allow_major_version_upgrade}.
         *
         * @stability stable
         */
        readonly allowMajorVersionUpgrade?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#apply_immediately DmsReplicationInstance#apply_immediately}.
         *
         * @stability stable
         */
        readonly applyImmediately?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#auto_minor_version_upgrade DmsReplicationInstance#auto_minor_version_upgrade}.
         *
         * @stability stable
         */
        readonly autoMinorVersionUpgrade?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#availability_zone DmsReplicationInstance#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#engine_version DmsReplicationInstance#engine_version}.
         *
         * @stability stable
         */
        readonly engineVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#kms_key_arn DmsReplicationInstance#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#multi_az DmsReplicationInstance#multi_az}.
         *
         * @stability stable
         */
        readonly multiAz?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#preferred_maintenance_window DmsReplicationInstance#preferred_maintenance_window}.
         *
         * @stability stable
         */
        readonly preferredMaintenanceWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#publicly_accessible DmsReplicationInstance#publicly_accessible}.
         *
         * @stability stable
         */
        readonly publiclyAccessible?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#replication_instance_class DmsReplicationInstance#replication_instance_class}.
         *
         * @stability stable
         */
        readonly replicationInstanceClass: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#replication_instance_id DmsReplicationInstance#replication_instance_id}.
         *
         * @stability stable
         */
        readonly replicationInstanceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#replication_subnet_group_id DmsReplicationInstance#replication_subnet_group_id}.
         *
         * @stability stable
         */
        readonly replicationSubnetGroupId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#tags DmsReplicationInstance#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#tags_all DmsReplicationInstance#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#vpc_security_group_ids DmsReplicationInstance#vpc_security_group_ids}.
         *
         * @stability stable
         */
        readonly vpcSecurityGroupIds?: string[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#timeouts DmsReplicationInstance#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DmsReplicationInstanceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DmsReplicationInstanceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#create DmsReplicationInstance#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#delete DmsReplicationInstance#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html#update DmsReplicationInstance#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DmsReplicationInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html aws_dms_replication_instance}.
     *
     * @stability stable
     */
    class DmsReplicationInstance extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_instance.html aws_dms_replication_instance} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DmsReplicationInstanceConfig);
        private _allocatedStorage?;
        /**
         * @stability stable
         */
        get allocatedStorage(): number | undefined;
        /**
         * @stability stable
         */
        set allocatedStorage(value: number | undefined);
        /**
         * @stability stable
         */
        resetAllocatedStorage(): void;
        /**
         * @stability stable
         */
        get allocatedStorageInput(): number | undefined;
        private _allowMajorVersionUpgrade?;
        /**
         * @stability stable
         */
        get allowMajorVersionUpgrade(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowMajorVersionUpgrade(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowMajorVersionUpgrade(): void;
        /**
         * @stability stable
         */
        get allowMajorVersionUpgradeInput(): boolean | cdktf.IResolvable | undefined;
        private _applyImmediately?;
        /**
         * @stability stable
         */
        get applyImmediately(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set applyImmediately(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetApplyImmediately(): void;
        /**
         * @stability stable
         */
        get applyImmediatelyInput(): boolean | cdktf.IResolvable | undefined;
        private _autoMinorVersionUpgrade?;
        /**
         * @stability stable
         */
        get autoMinorVersionUpgrade(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoMinorVersionUpgrade(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoMinorVersionUpgrade(): void;
        /**
         * @stability stable
         */
        get autoMinorVersionUpgradeInput(): boolean | cdktf.IResolvable | undefined;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _engineVersion?;
        /**
         * @stability stable
         */
        get engineVersion(): string | undefined;
        /**
         * @stability stable
         */
        set engineVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngineVersion(): void;
        /**
         * @stability stable
         */
        get engineVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _multiAz?;
        /**
         * @stability stable
         */
        get multiAz(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set multiAz(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMultiAz(): void;
        /**
         * @stability stable
         */
        get multiAzInput(): boolean | cdktf.IResolvable | undefined;
        private _preferredMaintenanceWindow?;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindow(): string | undefined;
        /**
         * @stability stable
         */
        set preferredMaintenanceWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreferredMaintenanceWindow(): void;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindowInput(): string | undefined;
        private _publiclyAccessible?;
        /**
         * @stability stable
         */
        get publiclyAccessible(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set publiclyAccessible(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPubliclyAccessible(): void;
        /**
         * @stability stable
         */
        get publiclyAccessibleInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get replicationInstanceArn(): string;
        private _replicationInstanceClass?;
        /**
         * @stability stable
         */
        get replicationInstanceClass(): string;
        /**
         * @stability stable
         */
        set replicationInstanceClass(value: string);
        /**
         * @stability stable
         */
        get replicationInstanceClassInput(): string | undefined;
        private _replicationInstanceId?;
        /**
         * @stability stable
         */
        get replicationInstanceId(): string;
        /**
         * @stability stable
         */
        set replicationInstanceId(value: string);
        /**
         * @stability stable
         */
        get replicationInstanceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get replicationInstancePrivateIps(): string[];
        /**
         * @stability stable
         */
        get replicationInstancePublicIps(): string[];
        private _replicationSubnetGroupId?;
        /**
         * @stability stable
         */
        get replicationSubnetGroupId(): string | undefined;
        /**
         * @stability stable
         */
        set replicationSubnetGroupId(value: string | undefined);
        /**
         * @stability stable
         */
        resetReplicationSubnetGroupId(): void;
        /**
         * @stability stable
         */
        get replicationSubnetGroupIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcSecurityGroupIds?;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcSecurityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIdsInput(): string[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DmsReplicationInstanceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DmsReplicationInstanceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DmsReplicationInstanceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DmsReplicationSubnetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_subnet_group.html#replication_subnet_group_description DmsReplicationSubnetGroup#replication_subnet_group_description}.
         *
         * @stability stable
         */
        readonly replicationSubnetGroupDescription: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_subnet_group.html#replication_subnet_group_id DmsReplicationSubnetGroup#replication_subnet_group_id}.
         *
         * @stability stable
         */
        readonly replicationSubnetGroupId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_subnet_group.html#subnet_ids DmsReplicationSubnetGroup#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_subnet_group.html#tags DmsReplicationSubnetGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_subnet_group.html#tags_all DmsReplicationSubnetGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_subnet_group.html aws_dms_replication_subnet_group}.
     *
     * @stability stable
     */
    class DmsReplicationSubnetGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_subnet_group.html aws_dms_replication_subnet_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DmsReplicationSubnetGroupConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get replicationSubnetGroupArn(): string;
        private _replicationSubnetGroupDescription?;
        /**
         * @stability stable
         */
        get replicationSubnetGroupDescription(): string;
        /**
         * @stability stable
         */
        set replicationSubnetGroupDescription(value: string);
        /**
         * @stability stable
         */
        get replicationSubnetGroupDescriptionInput(): string | undefined;
        private _replicationSubnetGroupId?;
        /**
         * @stability stable
         */
        get replicationSubnetGroupId(): string;
        /**
         * @stability stable
         */
        set replicationSubnetGroupId(value: string);
        /**
         * @stability stable
         */
        get replicationSubnetGroupIdInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DmsReplicationTaskConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#cdc_start_position DmsReplicationTask#cdc_start_position}.
         *
         * @stability stable
         */
        readonly cdcStartPosition?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#cdc_start_time DmsReplicationTask#cdc_start_time}.
         *
         * @stability stable
         */
        readonly cdcStartTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#migration_type DmsReplicationTask#migration_type}.
         *
         * @stability stable
         */
        readonly migrationType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#replication_instance_arn DmsReplicationTask#replication_instance_arn}.
         *
         * @stability stable
         */
        readonly replicationInstanceArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#replication_task_id DmsReplicationTask#replication_task_id}.
         *
         * @stability stable
         */
        readonly replicationTaskId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#replication_task_settings DmsReplicationTask#replication_task_settings}.
         *
         * @stability stable
         */
        readonly replicationTaskSettings?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#source_endpoint_arn DmsReplicationTask#source_endpoint_arn}.
         *
         * @stability stable
         */
        readonly sourceEndpointArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#table_mappings DmsReplicationTask#table_mappings}.
         *
         * @stability stable
         */
        readonly tableMappings: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#tags DmsReplicationTask#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#tags_all DmsReplicationTask#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html#target_endpoint_arn DmsReplicationTask#target_endpoint_arn}.
         *
         * @stability stable
         */
        readonly targetEndpointArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html aws_dms_replication_task}.
     *
     * @stability stable
     */
    class DmsReplicationTask extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dms_replication_task.html aws_dms_replication_task} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DmsReplicationTaskConfig);
        private _cdcStartPosition?;
        /**
         * @stability stable
         */
        get cdcStartPosition(): string | undefined;
        /**
         * @stability stable
         */
        set cdcStartPosition(value: string | undefined);
        /**
         * @stability stable
         */
        resetCdcStartPosition(): void;
        /**
         * @stability stable
         */
        get cdcStartPositionInput(): string | undefined;
        private _cdcStartTime?;
        /**
         * @stability stable
         */
        get cdcStartTime(): string | undefined;
        /**
         * @stability stable
         */
        set cdcStartTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetCdcStartTime(): void;
        /**
         * @stability stable
         */
        get cdcStartTimeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _migrationType?;
        /**
         * @stability stable
         */
        get migrationType(): string;
        /**
         * @stability stable
         */
        set migrationType(value: string);
        /**
         * @stability stable
         */
        get migrationTypeInput(): string | undefined;
        private _replicationInstanceArn?;
        /**
         * @stability stable
         */
        get replicationInstanceArn(): string;
        /**
         * @stability stable
         */
        set replicationInstanceArn(value: string);
        /**
         * @stability stable
         */
        get replicationInstanceArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get replicationTaskArn(): string;
        private _replicationTaskId?;
        /**
         * @stability stable
         */
        get replicationTaskId(): string;
        /**
         * @stability stable
         */
        set replicationTaskId(value: string);
        /**
         * @stability stable
         */
        get replicationTaskIdInput(): string | undefined;
        private _replicationTaskSettings?;
        /**
         * @stability stable
         */
        get replicationTaskSettings(): string | undefined;
        /**
         * @stability stable
         */
        set replicationTaskSettings(value: string | undefined);
        /**
         * @stability stable
         */
        resetReplicationTaskSettings(): void;
        /**
         * @stability stable
         */
        get replicationTaskSettingsInput(): string | undefined;
        private _sourceEndpointArn?;
        /**
         * @stability stable
         */
        get sourceEndpointArn(): string;
        /**
         * @stability stable
         */
        set sourceEndpointArn(value: string);
        /**
         * @stability stable
         */
        get sourceEndpointArnInput(): string | undefined;
        private _tableMappings?;
        /**
         * @stability stable
         */
        get tableMappings(): string;
        /**
         * @stability stable
         */
        set tableMappings(value: string);
        /**
         * @stability stable
         */
        get tableMappingsInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetEndpointArn?;
        /**
         * @stability stable
         */
        get targetEndpointArn(): string;
        /**
         * @stability stable
         */
        set targetEndpointArn(value: string);
        /**
         * @stability stable
         */
        get targetEndpointArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
