import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Data Sources
*/
export declare namespace DataSources {
    /**
     * @stability stable
     */
    interface ElbConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#availability_zones Elb#availability_zones}.
         *
         * @stability stable
         */
        readonly availabilityZones?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#connection_draining Elb#connection_draining}.
         *
         * @stability stable
         */
        readonly connectionDraining?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#connection_draining_timeout Elb#connection_draining_timeout}.
         *
         * @stability stable
         */
        readonly connectionDrainingTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#cross_zone_load_balancing Elb#cross_zone_load_balancing}.
         *
         * @stability stable
         */
        readonly crossZoneLoadBalancing?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#idle_timeout Elb#idle_timeout}.
         *
         * @stability stable
         */
        readonly idleTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#instances Elb#instances}.
         *
         * @stability stable
         */
        readonly instances?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#internal Elb#internal}.
         *
         * @stability stable
         */
        readonly internal?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#name Elb#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#name_prefix Elb#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#security_groups Elb#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#source_security_group Elb#source_security_group}.
         *
         * @stability stable
         */
        readonly sourceSecurityGroup?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#subnets Elb#subnets}.
         *
         * @stability stable
         */
        readonly subnets?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#tags Elb#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#tags_all Elb#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * access_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#access_logs Elb#access_logs}
         *
         * @stability stable
         */
        readonly accessLogs?: ElbAccessLogs;
        /**
         * health_check block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#health_check Elb#health_check}
         *
         * @stability stable
         */
        readonly healthCheck?: ElbHealthCheck;
        /**
         * listener block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#listener Elb#listener}
         *
         * @stability stable
         */
        readonly listener: ElbListener[];
    }
    /**
     * @stability stable
     */
    interface ElbAccessLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#bucket Elb#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#bucket_prefix Elb#bucket_prefix}.
         *
         * @stability stable
         */
        readonly bucketPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#enabled Elb#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#interval Elb#interval}.
         *
         * @stability stable
         */
        readonly interval?: number;
    }
    /**
     * @stability stable
     */
    class ElbAccessLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _bucketPrefix?;
        /**
         * @stability stable
         */
        get bucketPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set bucketPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketPrefix(): void;
        /**
         * @stability stable
         */
        get bucketPrefixInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _interval?;
        /**
         * @stability stable
         */
        get interval(): number | undefined;
        /**
         * @stability stable
         */
        set interval(value: number | undefined);
        /**
         * @stability stable
         */
        resetInterval(): void;
        /**
         * @stability stable
         */
        get intervalInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface ElbHealthCheck {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#healthy_threshold Elb#healthy_threshold}.
         *
         * @stability stable
         */
        readonly healthyThreshold: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#interval Elb#interval}.
         *
         * @stability stable
         */
        readonly interval: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#target Elb#target}.
         *
         * @stability stable
         */
        readonly target: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#timeout Elb#timeout}.
         *
         * @stability stable
         */
        readonly timeout: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#unhealthy_threshold Elb#unhealthy_threshold}.
         *
         * @stability stable
         */
        readonly unhealthyThreshold: number;
    }
    /**
     * @stability stable
     */
    class ElbHealthCheckOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _healthyThreshold?;
        /**
         * @stability stable
         */
        get healthyThreshold(): number;
        /**
         * @stability stable
         */
        set healthyThreshold(value: number);
        /**
         * @stability stable
         */
        get healthyThresholdInput(): number | undefined;
        private _interval?;
        /**
         * @stability stable
         */
        get interval(): number;
        /**
         * @stability stable
         */
        set interval(value: number);
        /**
         * @stability stable
         */
        get intervalInput(): number | undefined;
        private _target?;
        /**
         * @stability stable
         */
        get target(): string;
        /**
         * @stability stable
         */
        set target(value: string);
        /**
         * @stability stable
         */
        get targetInput(): string | undefined;
        private _timeout?;
        /**
         * @stability stable
         */
        get timeout(): number;
        /**
         * @stability stable
         */
        set timeout(value: number);
        /**
         * @stability stable
         */
        get timeoutInput(): number | undefined;
        private _unhealthyThreshold?;
        /**
         * @stability stable
         */
        get unhealthyThreshold(): number;
        /**
         * @stability stable
         */
        set unhealthyThreshold(value: number);
        /**
         * @stability stable
         */
        get unhealthyThresholdInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface ElbListener {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#instance_port Elb#instance_port}.
         *
         * @stability stable
         */
        readonly instancePort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#instance_protocol Elb#instance_protocol}.
         *
         * @stability stable
         */
        readonly instanceProtocol: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#lb_port Elb#lb_port}.
         *
         * @stability stable
         */
        readonly lbPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#lb_protocol Elb#lb_protocol}.
         *
         * @stability stable
         */
        readonly lbProtocol: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb.html#ssl_certificate_id Elb#ssl_certificate_id}.
         *
         * @stability stable
         */
        readonly sslCertificateId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elb.html aws_elb}.
     *
     * @stability stable
     */
    class Elb extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elb.html aws_elb} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ElbConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _availabilityZones?;
        /**
         * @stability stable
         */
        get availabilityZones(): string[] | undefined;
        /**
         * @stability stable
         */
        set availabilityZones(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZones(): void;
        /**
         * @stability stable
         */
        get availabilityZonesInput(): string[] | undefined;
        private _connectionDraining?;
        /**
         * @stability stable
         */
        get connectionDraining(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set connectionDraining(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetConnectionDraining(): void;
        /**
         * @stability stable
         */
        get connectionDrainingInput(): boolean | cdktf.IResolvable | undefined;
        private _connectionDrainingTimeout?;
        /**
         * @stability stable
         */
        get connectionDrainingTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set connectionDrainingTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetConnectionDrainingTimeout(): void;
        /**
         * @stability stable
         */
        get connectionDrainingTimeoutInput(): number | undefined;
        private _crossZoneLoadBalancing?;
        /**
         * @stability stable
         */
        get crossZoneLoadBalancing(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set crossZoneLoadBalancing(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCrossZoneLoadBalancing(): void;
        /**
         * @stability stable
         */
        get crossZoneLoadBalancingInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _idleTimeout?;
        /**
         * @stability stable
         */
        get idleTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set idleTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetIdleTimeout(): void;
        /**
         * @stability stable
         */
        get idleTimeoutInput(): number | undefined;
        private _instances?;
        /**
         * @stability stable
         */
        get instances(): string[] | undefined;
        /**
         * @stability stable
         */
        set instances(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetInstances(): void;
        /**
         * @stability stable
         */
        get instancesInput(): string[] | undefined;
        private _internal?;
        /**
         * @stability stable
         */
        get internal(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set internal(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInternal(): void;
        /**
         * @stability stable
         */
        get internalInput(): boolean | cdktf.IResolvable | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _sourceSecurityGroup?;
        /**
         * @stability stable
         */
        get sourceSecurityGroup(): string | undefined;
        /**
         * @stability stable
         */
        set sourceSecurityGroup(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceSecurityGroup(): void;
        /**
         * @stability stable
         */
        get sourceSecurityGroupInput(): string | undefined;
        /**
         * @stability stable
         */
        get sourceSecurityGroupId(): string;
        private _subnets?;
        /**
         * @stability stable
         */
        get subnets(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnets(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnets(): void;
        /**
         * @stability stable
         */
        get subnetsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get zoneId(): string;
        private _accessLogs?;
        private __accessLogsOutput;
        /**
         * @stability stable
         */
        get accessLogs(): ElbAccessLogsOutputReference;
        /**
         * @stability stable
         */
        putAccessLogs(value: ElbAccessLogs | undefined): void;
        /**
         * @stability stable
         */
        resetAccessLogs(): void;
        /**
         * @stability stable
         */
        get accessLogsInput(): ElbAccessLogs | undefined;
        private _healthCheck?;
        private __healthCheckOutput;
        /**
         * @stability stable
         */
        get healthCheck(): ElbHealthCheckOutputReference;
        /**
         * @stability stable
         */
        putHealthCheck(value: ElbHealthCheck | undefined): void;
        /**
         * @stability stable
         */
        resetHealthCheck(): void;
        /**
         * @stability stable
         */
        get healthCheckInput(): ElbHealthCheck | undefined;
        private _listener?;
        /**
         * @stability stable
         */
        get listener(): ElbListener[];
        /**
         * @stability stable
         */
        set listener(value: ElbListener[]);
        /**
         * @stability stable
         */
        get listenerInput(): ElbListener[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ElbAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb_attachment.html#elb ElbAttachment#elb}.
         *
         * @stability stable
         */
        readonly elb: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elb_attachment.html#instance ElbAttachment#instance}.
         *
         * @stability stable
         */
        readonly instance: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elb_attachment.html aws_elb_attachment}.
     *
     * @stability stable
     */
    class ElbAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elb_attachment.html aws_elb_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ElbAttachmentConfig);
        private _elb?;
        /**
         * @stability stable
         */
        get elb(): string;
        /**
         * @stability stable
         */
        set elb(value: string);
        /**
         * @stability stable
         */
        get elbInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instance?;
        /**
         * @stability stable
         */
        get instance(): string;
        /**
         * @stability stable
         */
        set instance(value: string);
        /**
         * @stability stable
         */
        get instanceInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LaunchConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#associate_public_ip_address LaunchConfiguration#associate_public_ip_address}.
         *
         * @stability stable
         */
        readonly associatePublicIpAddress?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#ebs_optimized LaunchConfiguration#ebs_optimized}.
         *
         * @stability stable
         */
        readonly ebsOptimized?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#enable_monitoring LaunchConfiguration#enable_monitoring}.
         *
         * @stability stable
         */
        readonly enableMonitoring?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#iam_instance_profile LaunchConfiguration#iam_instance_profile}.
         *
         * @stability stable
         */
        readonly iamInstanceProfile?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#image_id LaunchConfiguration#image_id}.
         *
         * @stability stable
         */
        readonly imageId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#instance_type LaunchConfiguration#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#key_name LaunchConfiguration#key_name}.
         *
         * @stability stable
         */
        readonly keyName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#name LaunchConfiguration#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#name_prefix LaunchConfiguration#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#placement_tenancy LaunchConfiguration#placement_tenancy}.
         *
         * @stability stable
         */
        readonly placementTenancy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#security_groups LaunchConfiguration#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#spot_price LaunchConfiguration#spot_price}.
         *
         * @stability stable
         */
        readonly spotPrice?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#user_data LaunchConfiguration#user_data}.
         *
         * @stability stable
         */
        readonly userData?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#user_data_base64 LaunchConfiguration#user_data_base64}.
         *
         * @stability stable
         */
        readonly userDataBase64?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#vpc_classic_link_id LaunchConfiguration#vpc_classic_link_id}.
         *
         * @stability stable
         */
        readonly vpcClassicLinkId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#vpc_classic_link_security_groups LaunchConfiguration#vpc_classic_link_security_groups}.
         *
         * @stability stable
         */
        readonly vpcClassicLinkSecurityGroups?: string[];
        /**
         * ebs_block_device block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#ebs_block_device LaunchConfiguration#ebs_block_device}
         *
         * @stability stable
         */
        readonly ebsBlockDevice?: LaunchConfigurationEbsBlockDevice[];
        /**
         * ephemeral_block_device block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#ephemeral_block_device LaunchConfiguration#ephemeral_block_device}
         *
         * @stability stable
         */
        readonly ephemeralBlockDevice?: LaunchConfigurationEphemeralBlockDevice[];
        /**
         * metadata_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#metadata_options LaunchConfiguration#metadata_options}
         *
         * @stability stable
         */
        readonly metadataOptions?: LaunchConfigurationMetadataOptions;
        /**
         * root_block_device block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#root_block_device LaunchConfiguration#root_block_device}
         *
         * @stability stable
         */
        readonly rootBlockDevice?: LaunchConfigurationRootBlockDevice;
    }
    /**
     * @stability stable
     */
    interface LaunchConfigurationEbsBlockDevice {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#delete_on_termination LaunchConfiguration#delete_on_termination}.
         *
         * @stability stable
         */
        readonly deleteOnTermination?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#device_name LaunchConfiguration#device_name}.
         *
         * @stability stable
         */
        readonly deviceName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#encrypted LaunchConfiguration#encrypted}.
         *
         * @stability stable
         */
        readonly encrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#iops LaunchConfiguration#iops}.
         *
         * @stability stable
         */
        readonly iops?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#no_device LaunchConfiguration#no_device}.
         *
         * @stability stable
         */
        readonly noDevice?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#snapshot_id LaunchConfiguration#snapshot_id}.
         *
         * @stability stable
         */
        readonly snapshotId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#throughput LaunchConfiguration#throughput}.
         *
         * @stability stable
         */
        readonly throughput?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#volume_size LaunchConfiguration#volume_size}.
         *
         * @stability stable
         */
        readonly volumeSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#volume_type LaunchConfiguration#volume_type}.
         *
         * @stability stable
         */
        readonly volumeType?: string;
    }
    /**
     * @stability stable
     */
    interface LaunchConfigurationEphemeralBlockDevice {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#device_name LaunchConfiguration#device_name}.
         *
         * @stability stable
         */
        readonly deviceName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#virtual_name LaunchConfiguration#virtual_name}.
         *
         * @stability stable
         */
        readonly virtualName: string;
    }
    /**
     * @stability stable
     */
    interface LaunchConfigurationMetadataOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#http_endpoint LaunchConfiguration#http_endpoint}.
         *
         * @stability stable
         */
        readonly httpEndpoint?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#http_put_response_hop_limit LaunchConfiguration#http_put_response_hop_limit}.
         *
         * @stability stable
         */
        readonly httpPutResponseHopLimit?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#http_tokens LaunchConfiguration#http_tokens}.
         *
         * @stability stable
         */
        readonly httpTokens?: string;
    }
    /**
     * @stability stable
     */
    class LaunchConfigurationMetadataOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _httpEndpoint?;
        /**
         * @stability stable
         */
        get httpEndpoint(): string | undefined;
        /**
         * @stability stable
         */
        set httpEndpoint(value: string | undefined);
        /**
         * @stability stable
         */
        resetHttpEndpoint(): void;
        /**
         * @stability stable
         */
        get httpEndpointInput(): string | undefined;
        private _httpPutResponseHopLimit?;
        /**
         * @stability stable
         */
        get httpPutResponseHopLimit(): number | undefined;
        /**
         * @stability stable
         */
        set httpPutResponseHopLimit(value: number | undefined);
        /**
         * @stability stable
         */
        resetHttpPutResponseHopLimit(): void;
        /**
         * @stability stable
         */
        get httpPutResponseHopLimitInput(): number | undefined;
        private _httpTokens?;
        /**
         * @stability stable
         */
        get httpTokens(): string | undefined;
        /**
         * @stability stable
         */
        set httpTokens(value: string | undefined);
        /**
         * @stability stable
         */
        resetHttpTokens(): void;
        /**
         * @stability stable
         */
        get httpTokensInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LaunchConfigurationRootBlockDevice {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#delete_on_termination LaunchConfiguration#delete_on_termination}.
         *
         * @stability stable
         */
        readonly deleteOnTermination?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#encrypted LaunchConfiguration#encrypted}.
         *
         * @stability stable
         */
        readonly encrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#iops LaunchConfiguration#iops}.
         *
         * @stability stable
         */
        readonly iops?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#throughput LaunchConfiguration#throughput}.
         *
         * @stability stable
         */
        readonly throughput?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#volume_size LaunchConfiguration#volume_size}.
         *
         * @stability stable
         */
        readonly volumeSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html#volume_type LaunchConfiguration#volume_type}.
         *
         * @stability stable
         */
        readonly volumeType?: string;
    }
    /**
     * @stability stable
     */
    class LaunchConfigurationRootBlockDeviceOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _deleteOnTermination?;
        /**
         * @stability stable
         */
        get deleteOnTermination(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deleteOnTermination(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeleteOnTermination(): void;
        /**
         * @stability stable
         */
        get deleteOnTerminationInput(): boolean | cdktf.IResolvable | undefined;
        private _encrypted?;
        /**
         * @stability stable
         */
        get encrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set encrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEncrypted(): void;
        /**
         * @stability stable
         */
        get encryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _iops?;
        /**
         * @stability stable
         */
        get iops(): number | undefined;
        /**
         * @stability stable
         */
        set iops(value: number | undefined);
        /**
         * @stability stable
         */
        resetIops(): void;
        /**
         * @stability stable
         */
        get iopsInput(): number | undefined;
        private _throughput?;
        /**
         * @stability stable
         */
        get throughput(): number | undefined;
        /**
         * @stability stable
         */
        set throughput(value: number | undefined);
        /**
         * @stability stable
         */
        resetThroughput(): void;
        /**
         * @stability stable
         */
        get throughputInput(): number | undefined;
        private _volumeSize?;
        /**
         * @stability stable
         */
        get volumeSize(): number | undefined;
        /**
         * @stability stable
         */
        set volumeSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetVolumeSize(): void;
        /**
         * @stability stable
         */
        get volumeSizeInput(): number | undefined;
        private _volumeType?;
        /**
         * @stability stable
         */
        get volumeType(): string | undefined;
        /**
         * @stability stable
         */
        set volumeType(value: string | undefined);
        /**
         * @stability stable
         */
        resetVolumeType(): void;
        /**
         * @stability stable
         */
        get volumeTypeInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html aws_launch_configuration}.
     *
     * @stability stable
     */
    class LaunchConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/launch_configuration.html aws_launch_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LaunchConfigurationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _associatePublicIpAddress?;
        /**
         * @stability stable
         */
        get associatePublicIpAddress(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set associatePublicIpAddress(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAssociatePublicIpAddress(): void;
        /**
         * @stability stable
         */
        get associatePublicIpAddressInput(): boolean | cdktf.IResolvable | undefined;
        private _ebsOptimized?;
        /**
         * @stability stable
         */
        get ebsOptimized(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set ebsOptimized(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEbsOptimized(): void;
        /**
         * @stability stable
         */
        get ebsOptimizedInput(): boolean | cdktf.IResolvable | undefined;
        private _enableMonitoring?;
        /**
         * @stability stable
         */
        get enableMonitoring(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableMonitoring(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableMonitoring(): void;
        /**
         * @stability stable
         */
        get enableMonitoringInput(): boolean | cdktf.IResolvable | undefined;
        private _iamInstanceProfile?;
        /**
         * @stability stable
         */
        get iamInstanceProfile(): string | undefined;
        /**
         * @stability stable
         */
        set iamInstanceProfile(value: string | undefined);
        /**
         * @stability stable
         */
        resetIamInstanceProfile(): void;
        /**
         * @stability stable
         */
        get iamInstanceProfileInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _imageId?;
        /**
         * @stability stable
         */
        get imageId(): string;
        /**
         * @stability stable
         */
        set imageId(value: string);
        /**
         * @stability stable
         */
        get imageIdInput(): string | undefined;
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string;
        /**
         * @stability stable
         */
        set instanceType(value: string);
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _keyName?;
        /**
         * @stability stable
         */
        get keyName(): string | undefined;
        /**
         * @stability stable
         */
        set keyName(value: string | undefined);
        /**
         * @stability stable
         */
        resetKeyName(): void;
        /**
         * @stability stable
         */
        get keyNameInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _placementTenancy?;
        /**
         * @stability stable
         */
        get placementTenancy(): string | undefined;
        /**
         * @stability stable
         */
        set placementTenancy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPlacementTenancy(): void;
        /**
         * @stability stable
         */
        get placementTenancyInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _spotPrice?;
        /**
         * @stability stable
         */
        get spotPrice(): string | undefined;
        /**
         * @stability stable
         */
        set spotPrice(value: string | undefined);
        /**
         * @stability stable
         */
        resetSpotPrice(): void;
        /**
         * @stability stable
         */
        get spotPriceInput(): string | undefined;
        private _userData?;
        /**
         * @stability stable
         */
        get userData(): string | undefined;
        /**
         * @stability stable
         */
        set userData(value: string | undefined);
        /**
         * @stability stable
         */
        resetUserData(): void;
        /**
         * @stability stable
         */
        get userDataInput(): string | undefined;
        private _userDataBase64?;
        /**
         * @stability stable
         */
        get userDataBase64(): string | undefined;
        /**
         * @stability stable
         */
        set userDataBase64(value: string | undefined);
        /**
         * @stability stable
         */
        resetUserDataBase64(): void;
        /**
         * @stability stable
         */
        get userDataBase64Input(): string | undefined;
        private _vpcClassicLinkId?;
        /**
         * @stability stable
         */
        get vpcClassicLinkId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcClassicLinkId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcClassicLinkId(): void;
        /**
         * @stability stable
         */
        get vpcClassicLinkIdInput(): string | undefined;
        private _vpcClassicLinkSecurityGroups?;
        /**
         * @stability stable
         */
        get vpcClassicLinkSecurityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcClassicLinkSecurityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcClassicLinkSecurityGroups(): void;
        /**
         * @stability stable
         */
        get vpcClassicLinkSecurityGroupsInput(): string[] | undefined;
        private _ebsBlockDevice?;
        /**
         * @stability stable
         */
        get ebsBlockDevice(): LaunchConfigurationEbsBlockDevice[] | undefined;
        /**
         * @stability stable
         */
        set ebsBlockDevice(value: LaunchConfigurationEbsBlockDevice[] | undefined);
        /**
         * @stability stable
         */
        resetEbsBlockDevice(): void;
        /**
         * @stability stable
         */
        get ebsBlockDeviceInput(): LaunchConfigurationEbsBlockDevice[] | undefined;
        private _ephemeralBlockDevice?;
        /**
         * @stability stable
         */
        get ephemeralBlockDevice(): LaunchConfigurationEphemeralBlockDevice[] | undefined;
        /**
         * @stability stable
         */
        set ephemeralBlockDevice(value: LaunchConfigurationEphemeralBlockDevice[] | undefined);
        /**
         * @stability stable
         */
        resetEphemeralBlockDevice(): void;
        /**
         * @stability stable
         */
        get ephemeralBlockDeviceInput(): LaunchConfigurationEphemeralBlockDevice[] | undefined;
        private _metadataOptions?;
        private __metadataOptionsOutput;
        /**
         * @stability stable
         */
        get metadataOptions(): LaunchConfigurationMetadataOptionsOutputReference;
        /**
         * @stability stable
         */
        putMetadataOptions(value: LaunchConfigurationMetadataOptions | undefined): void;
        /**
         * @stability stable
         */
        resetMetadataOptions(): void;
        /**
         * @stability stable
         */
        get metadataOptionsInput(): LaunchConfigurationMetadataOptions | undefined;
        private _rootBlockDevice?;
        private __rootBlockDeviceOutput;
        /**
         * @stability stable
         */
        get rootBlockDevice(): LaunchConfigurationRootBlockDeviceOutputReference;
        /**
         * @stability stable
         */
        putRootBlockDevice(value: LaunchConfigurationRootBlockDevice | undefined): void;
        /**
         * @stability stable
         */
        resetRootBlockDevice(): void;
        /**
         * @stability stable
         */
        get rootBlockDeviceInput(): LaunchConfigurationRootBlockDevice | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsArnConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/arn.html#arn DataAwsArn#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/arn.html aws_arn}.
     *
     * @stability stable
     */
    class DataAwsArn extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/arn.html aws_arn} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsArnConfig);
        /**
         * @stability stable
         */
        get account(): string;
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get partition(): string;
        /**
         * @stability stable
         */
        get region(): string;
        /**
         * @stability stable
         */
        get resource(): string;
        /**
         * @stability stable
         */
        get service(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAvailabilityZoneConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html#all_availability_zones DataAwsAvailabilityZone#all_availability_zones}.
         *
         * @stability stable
         */
        readonly allAvailabilityZones?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html#name DataAwsAvailabilityZone#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html#state DataAwsAvailabilityZone#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html#zone_id DataAwsAvailabilityZone#zone_id}.
         *
         * @stability stable
         */
        readonly zoneId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html#filter DataAwsAvailabilityZone#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsAvailabilityZoneFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsAvailabilityZoneFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html#name DataAwsAvailabilityZone#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html#values DataAwsAvailabilityZone#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html aws_availability_zone}.
     *
     * @stability stable
     */
    class DataAwsAvailabilityZone extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/availability_zone.html aws_availability_zone} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsAvailabilityZoneConfig);
        private _allAvailabilityZones?;
        /**
         * @stability stable
         */
        get allAvailabilityZones(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allAvailabilityZones(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllAvailabilityZones(): void;
        /**
         * @stability stable
         */
        get allAvailabilityZonesInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get groupName(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get nameSuffix(): string;
        /**
         * @stability stable
         */
        get networkBorderGroup(): string;
        /**
         * @stability stable
         */
        get optInStatus(): string;
        /**
         * @stability stable
         */
        get parentZoneId(): string;
        /**
         * @stability stable
         */
        get parentZoneName(): string;
        /**
         * @stability stable
         */
        get region(): string;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        private _zoneId?;
        /**
         * @stability stable
         */
        get zoneId(): string | undefined;
        /**
         * @stability stable
         */
        set zoneId(value: string | undefined);
        /**
         * @stability stable
         */
        resetZoneId(): void;
        /**
         * @stability stable
         */
        get zoneIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get zoneType(): string;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsAvailabilityZoneFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsAvailabilityZoneFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsAvailabilityZoneFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAvailabilityZonesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html#all_availability_zones DataAwsAvailabilityZones#all_availability_zones}.
         *
         * @stability stable
         */
        readonly allAvailabilityZones?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html#exclude_names DataAwsAvailabilityZones#exclude_names}.
         *
         * @stability stable
         */
        readonly excludeNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html#exclude_zone_ids DataAwsAvailabilityZones#exclude_zone_ids}.
         *
         * @stability stable
         */
        readonly excludeZoneIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html#state DataAwsAvailabilityZones#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html#filter DataAwsAvailabilityZones#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsAvailabilityZonesFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsAvailabilityZonesFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html#name DataAwsAvailabilityZones#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html#values DataAwsAvailabilityZones#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html aws_availability_zones}.
     *
     * @stability stable
     */
    class DataAwsAvailabilityZones extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/availability_zones.html aws_availability_zones} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsAvailabilityZonesConfig);
        private _allAvailabilityZones?;
        /**
         * @stability stable
         */
        get allAvailabilityZones(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allAvailabilityZones(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllAvailabilityZones(): void;
        /**
         * @stability stable
         */
        get allAvailabilityZonesInput(): boolean | cdktf.IResolvable | undefined;
        private _excludeNames?;
        /**
         * @stability stable
         */
        get excludeNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set excludeNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetExcludeNames(): void;
        /**
         * @stability stable
         */
        get excludeNamesInput(): string[] | undefined;
        private _excludeZoneIds?;
        /**
         * @stability stable
         */
        get excludeZoneIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set excludeZoneIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetExcludeZoneIds(): void;
        /**
         * @stability stable
         */
        get excludeZoneIdsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get groupNames(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get names(): string[];
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        /**
         * @stability stable
         */
        get zoneIds(): string[];
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsAvailabilityZonesFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsAvailabilityZonesFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsAvailabilityZonesFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsBillingServiceAccountConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/billing_service_account.html aws_billing_service_account}.
     *
     * @stability stable
     */
    class DataAwsBillingServiceAccount extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/billing_service_account.html aws_billing_service_account} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsBillingServiceAccountConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCallerIdentityConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/caller_identity.html aws_caller_identity}.
     *
     * @stability stable
     */
    class DataAwsCallerIdentity extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/caller_identity.html aws_caller_identity} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsCallerIdentityConfig);
        /**
         * @stability stable
         */
        get accountId(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get userId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCanonicalUserIdConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/canonical_user_id.html aws_canonical_user_id}.
     *
     * @stability stable
     */
    class DataAwsCanonicalUserId extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/canonical_user_id.html aws_canonical_user_id} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsCanonicalUserIdConfig);
        /**
         * @stability stable
         */
        get displayName(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsElbConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/elb.html#name DataAwsElb#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/elb.html#tags DataAwsElb#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsElbAccessLogs extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        get bucketPrefix(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get interval(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsElbHealthCheck extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get healthyThreshold(): number;
        /**
         * @stability stable
         */
        get interval(): number;
        /**
         * @stability stable
         */
        get target(): string;
        /**
         * @stability stable
         */
        get timeout(): number;
        /**
         * @stability stable
         */
        get unhealthyThreshold(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsElbListener extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get instancePort(): number;
        /**
         * @stability stable
         */
        get instanceProtocol(): string;
        /**
         * @stability stable
         */
        get lbPort(): number;
        /**
         * @stability stable
         */
        get lbProtocol(): string;
        /**
         * @stability stable
         */
        get sslCertificateId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/elb.html aws_elb}.
     *
     * @stability stable
     */
    class DataAwsElb extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/elb.html aws_elb} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsElbConfig);
        /**
         * @stability stable
         */
        accessLogs(index: string): DataAwsElbAccessLogs;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get connectionDraining(): any;
        /**
         * @stability stable
         */
        get connectionDrainingTimeout(): number;
        /**
         * @stability stable
         */
        get crossZoneLoadBalancing(): any;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        healthCheck(index: string): DataAwsElbHealthCheck;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get idleTimeout(): number;
        /**
         * @stability stable
         */
        get instances(): string[];
        /**
         * @stability stable
         */
        get internal(): any;
        /**
         * @stability stable
         */
        listener(index: string): DataAwsElbListener;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get securityGroups(): string[];
        /**
         * @stability stable
         */
        get sourceSecurityGroup(): string;
        /**
         * @stability stable
         */
        get sourceSecurityGroupId(): string;
        /**
         * @stability stable
         */
        get subnets(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get zoneId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsElbHostedZoneIdConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/elb_hosted_zone_id.html#region DataAwsElbHostedZoneId#region}.
         *
         * @stability stable
         */
        readonly region?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/elb_hosted_zone_id.html aws_elb_hosted_zone_id}.
     *
     * @stability stable
     */
    class DataAwsElbHostedZoneId extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/elb_hosted_zone_id.html aws_elb_hosted_zone_id} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsElbHostedZoneIdConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _region?;
        /**
         * @stability stable
         */
        get region(): string | undefined;
        /**
         * @stability stable
         */
        set region(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegion(): void;
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsElbServiceAccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/elb_service_account.html#region DataAwsElbServiceAccount#region}.
         *
         * @stability stable
         */
        readonly region?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/elb_service_account.html aws_elb_service_account}.
     *
     * @stability stable
     */
    class DataAwsElbServiceAccount extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/elb_service_account.html aws_elb_service_account} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsElbServiceAccountConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _region?;
        /**
         * @stability stable
         */
        get region(): string | undefined;
        /**
         * @stability stable
         */
        set region(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegion(): void;
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIpRangesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ip_ranges.html#regions DataAwsIpRanges#regions}.
         *
         * @stability stable
         */
        readonly regions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ip_ranges.html#services DataAwsIpRanges#services}.
         *
         * @stability stable
         */
        readonly services: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ip_ranges.html#url DataAwsIpRanges#url}.
         *
         * @stability stable
         */
        readonly url?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ip_ranges.html aws_ip_ranges}.
     *
     * @stability stable
     */
    class DataAwsIpRanges extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ip_ranges.html aws_ip_ranges} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsIpRangesConfig);
        /**
         * @stability stable
         */
        get cidrBlocks(): string[];
        /**
         * @stability stable
         */
        get createDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipv6CidrBlocks(): string[];
        private _regions?;
        /**
         * @stability stable
         */
        get regions(): string[] | undefined;
        /**
         * @stability stable
         */
        set regions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetRegions(): void;
        /**
         * @stability stable
         */
        get regionsInput(): string[] | undefined;
        private _services?;
        /**
         * @stability stable
         */
        get services(): string[];
        /**
         * @stability stable
         */
        set services(value: string[]);
        /**
         * @stability stable
         */
        get servicesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get syncToken(): number;
        private _url?;
        /**
         * @stability stable
         */
        get url(): string | undefined;
        /**
         * @stability stable
         */
        set url(value: string | undefined);
        /**
         * @stability stable
         */
        resetUrl(): void;
        /**
         * @stability stable
         */
        get urlInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLaunchConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration.html#name DataAwsLaunchConfiguration#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    class DataAwsLaunchConfigurationEbsBlockDevice extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get deleteOnTermination(): any;
        /**
         * @stability stable
         */
        get deviceName(): string;
        /**
         * @stability stable
         */
        get encrypted(): any;
        /**
         * @stability stable
         */
        get iops(): number;
        /**
         * @stability stable
         */
        get noDevice(): any;
        /**
         * @stability stable
         */
        get snapshotId(): string;
        /**
         * @stability stable
         */
        get throughput(): any;
        /**
         * @stability stable
         */
        get volumeSize(): number;
        /**
         * @stability stable
         */
        get volumeType(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLaunchConfigurationEphemeralBlockDevice extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get deviceName(): string;
        /**
         * @stability stable
         */
        get virtualName(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLaunchConfigurationMetadataOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get httpEndpoint(): string;
        /**
         * @stability stable
         */
        get httpPutResponseHopLimit(): number;
        /**
         * @stability stable
         */
        get httpTokens(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLaunchConfigurationRootBlockDevice extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get deleteOnTermination(): any;
        /**
         * @stability stable
         */
        get encrypted(): any;
        /**
         * @stability stable
         */
        get iops(): number;
        /**
         * @stability stable
         */
        get throughput(): any;
        /**
         * @stability stable
         */
        get volumeSize(): number;
        /**
         * @stability stable
         */
        get volumeType(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration.html aws_launch_configuration}.
     *
     * @stability stable
     */
    class DataAwsLaunchConfiguration extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/launch_configuration.html aws_launch_configuration} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLaunchConfigurationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get associatePublicIpAddress(): any;
        /**
         * @stability stable
         */
        ebsBlockDevice(index: string): DataAwsLaunchConfigurationEbsBlockDevice;
        /**
         * @stability stable
         */
        get ebsOptimized(): any;
        /**
         * @stability stable
         */
        get enableMonitoring(): any;
        /**
         * @stability stable
         */
        ephemeralBlockDevice(index: string): DataAwsLaunchConfigurationEphemeralBlockDevice;
        /**
         * @stability stable
         */
        get iamInstanceProfile(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get imageId(): string;
        /**
         * @stability stable
         */
        get instanceType(): string;
        /**
         * @stability stable
         */
        get keyName(): string;
        /**
         * @stability stable
         */
        metadataOptions(index: string): DataAwsLaunchConfigurationMetadataOptions;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get placementTenancy(): string;
        /**
         * @stability stable
         */
        rootBlockDevice(index: string): DataAwsLaunchConfigurationRootBlockDevice;
        /**
         * @stability stable
         */
        get securityGroups(): string[];
        /**
         * @stability stable
         */
        get spotPrice(): string;
        /**
         * @stability stable
         */
        get userData(): string;
        /**
         * @stability stable
         */
        get vpcClassicLinkId(): string;
        /**
         * @stability stable
         */
        get vpcClassicLinkSecurityGroups(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsPartitionConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/partition.html aws_partition}.
     *
     * @stability stable
     */
    class DataAwsPartition extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/partition.html aws_partition} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsPartitionConfig);
        /**
         * @stability stable
         */
        get dnsSuffix(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get partition(): string;
        /**
         * @stability stable
         */
        get reverseDnsPrefix(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsPrefixListConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/prefix_list.html#name DataAwsPrefixList#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/prefix_list.html#prefix_list_id DataAwsPrefixList#prefix_list_id}.
         *
         * @stability stable
         */
        readonly prefixListId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/prefix_list.html#filter DataAwsPrefixList#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsPrefixListFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsPrefixListFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/prefix_list.html#name DataAwsPrefixList#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/prefix_list.html#values DataAwsPrefixList#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/prefix_list.html aws_prefix_list}.
     *
     * @stability stable
     */
    class DataAwsPrefixList extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/prefix_list.html aws_prefix_list} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsPrefixListConfig);
        /**
         * @stability stable
         */
        get cidrBlocks(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _prefixListId?;
        /**
         * @stability stable
         */
        get prefixListId(): string | undefined;
        /**
         * @stability stable
         */
        set prefixListId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefixListId(): void;
        /**
         * @stability stable
         */
        get prefixListIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsPrefixListFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsPrefixListFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsPrefixListFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRegionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/region.html#endpoint DataAwsRegion#endpoint}.
         *
         * @stability stable
         */
        readonly endpoint?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/region.html#name DataAwsRegion#name}.
         *
         * @stability stable
         */
        readonly name?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/region.html aws_region}.
     *
     * @stability stable
     */
    class DataAwsRegion extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/region.html aws_region} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsRegionConfig);
        /**
         * @stability stable
         */
        get description(): string;
        private _endpoint?;
        /**
         * @stability stable
         */
        get endpoint(): string | undefined;
        /**
         * @stability stable
         */
        set endpoint(value: string | undefined);
        /**
         * @stability stable
         */
        resetEndpoint(): void;
        /**
         * @stability stable
         */
        get endpointInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRegionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/regions.html#all_regions DataAwsRegions#all_regions}.
         *
         * @stability stable
         */
        readonly allRegions?: boolean | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/regions.html#filter DataAwsRegions#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsRegionsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsRegionsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/regions.html#name DataAwsRegions#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/regions.html#values DataAwsRegions#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/regions.html aws_regions}.
     *
     * @stability stable
     */
    class DataAwsRegions extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/regions.html aws_regions} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsRegionsConfig);
        private _allRegions?;
        /**
         * @stability stable
         */
        get allRegions(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allRegions(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllRegions(): void;
        /**
         * @stability stable
         */
        get allRegionsInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get names(): string[];
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsRegionsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsRegionsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsRegionsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
