import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Direct Connect
*/
export declare namespace DirectConnect {
    /**
     * @stability stable
     */
    interface DxBgpPeerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#address_family DxBgpPeer#address_family}.
         *
         * @stability stable
         */
        readonly addressFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#amazon_address DxBgpPeer#amazon_address}.
         *
         * @stability stable
         */
        readonly amazonAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#bgp_asn DxBgpPeer#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#bgp_auth_key DxBgpPeer#bgp_auth_key}.
         *
         * @stability stable
         */
        readonly bgpAuthKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#customer_address DxBgpPeer#customer_address}.
         *
         * @stability stable
         */
        readonly customerAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#virtual_interface_id DxBgpPeer#virtual_interface_id}.
         *
         * @stability stable
         */
        readonly virtualInterfaceId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#timeouts DxBgpPeer#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxBgpPeerTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxBgpPeerTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#create DxBgpPeer#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html#delete DxBgpPeer#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxBgpPeerTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html aws_dx_bgp_peer}.
     *
     * @stability stable
     */
    class DxBgpPeer extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_bgp_peer.html aws_dx_bgp_peer} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxBgpPeerConfig);
        private _addressFamily?;
        /**
         * @stability stable
         */
        get addressFamily(): string;
        /**
         * @stability stable
         */
        set addressFamily(value: string);
        /**
         * @stability stable
         */
        get addressFamilyInput(): string | undefined;
        private _amazonAddress?;
        /**
         * @stability stable
         */
        get amazonAddress(): string | undefined;
        /**
         * @stability stable
         */
        set amazonAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonAddress(): void;
        /**
         * @stability stable
         */
        get amazonAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        set bgpAsn(value: number);
        /**
         * @stability stable
         */
        get bgpAsnInput(): number | undefined;
        private _bgpAuthKey?;
        /**
         * @stability stable
         */
        get bgpAuthKey(): string | undefined;
        /**
         * @stability stable
         */
        set bgpAuthKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetBgpAuthKey(): void;
        /**
         * @stability stable
         */
        get bgpAuthKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get bgpPeerId(): string;
        /**
         * @stability stable
         */
        get bgpStatus(): string;
        private _customerAddress?;
        /**
         * @stability stable
         */
        get customerAddress(): string | undefined;
        /**
         * @stability stable
         */
        set customerAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAddress(): void;
        /**
         * @stability stable
         */
        get customerAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _virtualInterfaceId?;
        /**
         * @stability stable
         */
        get virtualInterfaceId(): string;
        /**
         * @stability stable
         */
        set virtualInterfaceId(value: string);
        /**
         * @stability stable
         */
        get virtualInterfaceIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxBgpPeerTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxBgpPeerTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxBgpPeerTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html#bandwidth DxConnection#bandwidth}.
         *
         * @stability stable
         */
        readonly bandwidth: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html#location DxConnection#location}.
         *
         * @stability stable
         */
        readonly location: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html#name DxConnection#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html#provider_name DxConnection#provider_name}.
         *
         * @stability stable
         */
        readonly providerName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html#tags DxConnection#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html#tags_all DxConnection#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html aws_dx_connection}.
     *
     * @stability stable
     */
    class DxConnection extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_connection.html aws_dx_connection} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxConnectionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bandwidth?;
        /**
         * @stability stable
         */
        get bandwidth(): string;
        /**
         * @stability stable
         */
        set bandwidth(value: string);
        /**
         * @stability stable
         */
        get bandwidthInput(): string | undefined;
        /**
         * @stability stable
         */
        get hasLogicalRedundancy(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get jumboFrameCapable(): any;
        private _location?;
        /**
         * @stability stable
         */
        get location(): string;
        /**
         * @stability stable
         */
        set location(value: string);
        /**
         * @stability stable
         */
        get locationInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        private _providerName?;
        /**
         * @stability stable
         */
        get providerName(): string | undefined;
        /**
         * @stability stable
         */
        set providerName(value: string | undefined);
        /**
         * @stability stable
         */
        resetProviderName(): void;
        /**
         * @stability stable
         */
        get providerNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxConnectionAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection_association.html#connection_id DxConnectionAssociation#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection_association.html#lag_id DxConnectionAssociation#lag_id}.
         *
         * @stability stable
         */
        readonly lagId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_connection_association.html aws_dx_connection_association}.
     *
     * @stability stable
     */
    class DxConnectionAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_connection_association.html aws_dx_connection_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxConnectionAssociationConfig);
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _lagId?;
        /**
         * @stability stable
         */
        get lagId(): string;
        /**
         * @stability stable
         */
        set lagId(value: string);
        /**
         * @stability stable
         */
        get lagIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxConnectionConfirmationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_connection_confirmation.html#connection_id DxConnectionConfirmation#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_connection_confirmation.html aws_dx_connection_confirmation}.
     *
     * @stability stable
     */
    class DxConnectionConfirmation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_connection_confirmation.html aws_dx_connection_confirmation} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxConnectionConfirmationConfig);
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway.html#amazon_side_asn DxGateway#amazon_side_asn}.
         *
         * @stability stable
         */
        readonly amazonSideAsn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway.html#name DxGateway#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway.html#timeouts DxGateway#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxGatewayTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxGatewayTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway.html#create DxGateway#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway.html#delete DxGateway#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxGatewayTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway.html aws_dx_gateway}.
     *
     * @stability stable
     */
    class DxGateway extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway.html aws_dx_gateway} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxGatewayConfig);
        private _amazonSideAsn?;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        set amazonSideAsn(value: string);
        /**
         * @stability stable
         */
        get amazonSideAsnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxGatewayTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxGatewayTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxGatewayTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxGatewayAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#allowed_prefixes DxGatewayAssociation#allowed_prefixes}.
         *
         * @stability stable
         */
        readonly allowedPrefixes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#associated_gateway_id DxGatewayAssociation#associated_gateway_id}.
         *
         * @stability stable
         */
        readonly associatedGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#associated_gateway_owner_account_id DxGatewayAssociation#associated_gateway_owner_account_id}.
         *
         * @stability stable
         */
        readonly associatedGatewayOwnerAccountId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#dx_gateway_id DxGatewayAssociation#dx_gateway_id}.
         *
         * @stability stable
         */
        readonly dxGatewayId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#proposal_id DxGatewayAssociation#proposal_id}.
         *
         * @stability stable
         */
        readonly proposalId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#vpn_gateway_id DxGatewayAssociation#vpn_gateway_id}.
         *
         * @stability stable
         */
        readonly vpnGatewayId?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#timeouts DxGatewayAssociation#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxGatewayAssociationTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxGatewayAssociationTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#create DxGatewayAssociation#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#delete DxGatewayAssociation#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html#update DxGatewayAssociation#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DxGatewayAssociationTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html aws_dx_gateway_association}.
     *
     * @stability stable
     */
    class DxGatewayAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association.html aws_dx_gateway_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxGatewayAssociationConfig);
        private _allowedPrefixes?;
        /**
         * @stability stable
         */
        get allowedPrefixes(): string[] | undefined;
        /**
         * @stability stable
         */
        set allowedPrefixes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAllowedPrefixes(): void;
        /**
         * @stability stable
         */
        get allowedPrefixesInput(): string[] | undefined;
        private _associatedGatewayId?;
        /**
         * @stability stable
         */
        get associatedGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set associatedGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAssociatedGatewayId(): void;
        /**
         * @stability stable
         */
        get associatedGatewayIdInput(): string | undefined;
        private _associatedGatewayOwnerAccountId?;
        /**
         * @stability stable
         */
        get associatedGatewayOwnerAccountId(): string | undefined;
        /**
         * @stability stable
         */
        set associatedGatewayOwnerAccountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAssociatedGatewayOwnerAccountId(): void;
        /**
         * @stability stable
         */
        get associatedGatewayOwnerAccountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get associatedGatewayType(): string;
        /**
         * @stability stable
         */
        get dxGatewayAssociationId(): string;
        private _dxGatewayId?;
        /**
         * @stability stable
         */
        get dxGatewayId(): string;
        /**
         * @stability stable
         */
        set dxGatewayId(value: string);
        /**
         * @stability stable
         */
        get dxGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get dxGatewayOwnerAccountId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _proposalId?;
        /**
         * @stability stable
         */
        get proposalId(): string | undefined;
        /**
         * @stability stable
         */
        set proposalId(value: string | undefined);
        /**
         * @stability stable
         */
        resetProposalId(): void;
        /**
         * @stability stable
         */
        get proposalIdInput(): string | undefined;
        private _vpnGatewayId?;
        /**
         * @stability stable
         */
        get vpnGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set vpnGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpnGatewayId(): void;
        /**
         * @stability stable
         */
        get vpnGatewayIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxGatewayAssociationTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxGatewayAssociationTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxGatewayAssociationTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxGatewayAssociationProposalConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association_proposal.html#allowed_prefixes DxGatewayAssociationProposal#allowed_prefixes}.
         *
         * @stability stable
         */
        readonly allowedPrefixes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association_proposal.html#associated_gateway_id DxGatewayAssociationProposal#associated_gateway_id}.
         *
         * @stability stable
         */
        readonly associatedGatewayId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association_proposal.html#dx_gateway_id DxGatewayAssociationProposal#dx_gateway_id}.
         *
         * @stability stable
         */
        readonly dxGatewayId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association_proposal.html#dx_gateway_owner_account_id DxGatewayAssociationProposal#dx_gateway_owner_account_id}.
         *
         * @stability stable
         */
        readonly dxGatewayOwnerAccountId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association_proposal.html aws_dx_gateway_association_proposal}.
     *
     * @stability stable
     */
    class DxGatewayAssociationProposal extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_gateway_association_proposal.html aws_dx_gateway_association_proposal} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxGatewayAssociationProposalConfig);
        private _allowedPrefixes?;
        /**
         * @stability stable
         */
        get allowedPrefixes(): string[] | undefined;
        /**
         * @stability stable
         */
        set allowedPrefixes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAllowedPrefixes(): void;
        /**
         * @stability stable
         */
        get allowedPrefixesInput(): string[] | undefined;
        private _associatedGatewayId?;
        /**
         * @stability stable
         */
        get associatedGatewayId(): string;
        /**
         * @stability stable
         */
        set associatedGatewayId(value: string);
        /**
         * @stability stable
         */
        get associatedGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get associatedGatewayOwnerAccountId(): string;
        /**
         * @stability stable
         */
        get associatedGatewayType(): string;
        private _dxGatewayId?;
        /**
         * @stability stable
         */
        get dxGatewayId(): string;
        /**
         * @stability stable
         */
        set dxGatewayId(value: string);
        /**
         * @stability stable
         */
        get dxGatewayIdInput(): string | undefined;
        private _dxGatewayOwnerAccountId?;
        /**
         * @stability stable
         */
        get dxGatewayOwnerAccountId(): string;
        /**
         * @stability stable
         */
        set dxGatewayOwnerAccountId(value: string);
        /**
         * @stability stable
         */
        get dxGatewayOwnerAccountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxHostedConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_connection.html#bandwidth DxHostedConnection#bandwidth}.
         *
         * @stability stable
         */
        readonly bandwidth: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_connection.html#connection_id DxHostedConnection#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_connection.html#name DxHostedConnection#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_connection.html#owner_account_id DxHostedConnection#owner_account_id}.
         *
         * @stability stable
         */
        readonly ownerAccountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_connection.html#vlan DxHostedConnection#vlan}.
         *
         * @stability stable
         */
        readonly vlan: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_connection.html aws_dx_hosted_connection}.
     *
     * @stability stable
     */
    class DxHostedConnection extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_connection.html aws_dx_hosted_connection} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxHostedConnectionConfig);
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bandwidth?;
        /**
         * @stability stable
         */
        get bandwidth(): string;
        /**
         * @stability stable
         */
        set bandwidth(value: string);
        /**
         * @stability stable
         */
        get bandwidthInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get hasLogicalRedundancy(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get jumboFrameCapable(): any;
        /**
         * @stability stable
         */
        get lagId(): string;
        /**
         * @stability stable
         */
        get loaIssueTime(): string;
        /**
         * @stability stable
         */
        get location(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _ownerAccountId?;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        /**
         * @stability stable
         */
        set ownerAccountId(value: string);
        /**
         * @stability stable
         */
        get ownerAccountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get partnerName(): string;
        /**
         * @stability stable
         */
        get providerName(): string;
        /**
         * @stability stable
         */
        get region(): string;
        /**
         * @stability stable
         */
        get state(): string;
        private _vlan?;
        /**
         * @stability stable
         */
        get vlan(): number;
        /**
         * @stability stable
         */
        set vlan(value: number);
        /**
         * @stability stable
         */
        get vlanInput(): number | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxHostedPrivateVirtualInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#address_family DxHostedPrivateVirtualInterface#address_family}.
         *
         * @stability stable
         */
        readonly addressFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#amazon_address DxHostedPrivateVirtualInterface#amazon_address}.
         *
         * @stability stable
         */
        readonly amazonAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#bgp_asn DxHostedPrivateVirtualInterface#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#bgp_auth_key DxHostedPrivateVirtualInterface#bgp_auth_key}.
         *
         * @stability stable
         */
        readonly bgpAuthKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#connection_id DxHostedPrivateVirtualInterface#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#customer_address DxHostedPrivateVirtualInterface#customer_address}.
         *
         * @stability stable
         */
        readonly customerAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#mtu DxHostedPrivateVirtualInterface#mtu}.
         *
         * @stability stable
         */
        readonly mtu?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#name DxHostedPrivateVirtualInterface#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#owner_account_id DxHostedPrivateVirtualInterface#owner_account_id}.
         *
         * @stability stable
         */
        readonly ownerAccountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#vlan DxHostedPrivateVirtualInterface#vlan}.
         *
         * @stability stable
         */
        readonly vlan: number;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#timeouts DxHostedPrivateVirtualInterface#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxHostedPrivateVirtualInterfaceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxHostedPrivateVirtualInterfaceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#create DxHostedPrivateVirtualInterface#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html#delete DxHostedPrivateVirtualInterface#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxHostedPrivateVirtualInterfaceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html aws_dx_hosted_private_virtual_interface}.
     *
     * @stability stable
     */
    class DxHostedPrivateVirtualInterface extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface.html aws_dx_hosted_private_virtual_interface} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxHostedPrivateVirtualInterfaceConfig);
        private _addressFamily?;
        /**
         * @stability stable
         */
        get addressFamily(): string;
        /**
         * @stability stable
         */
        set addressFamily(value: string);
        /**
         * @stability stable
         */
        get addressFamilyInput(): string | undefined;
        private _amazonAddress?;
        /**
         * @stability stable
         */
        get amazonAddress(): string | undefined;
        /**
         * @stability stable
         */
        set amazonAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonAddress(): void;
        /**
         * @stability stable
         */
        get amazonAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        set bgpAsn(value: number);
        /**
         * @stability stable
         */
        get bgpAsnInput(): number | undefined;
        private _bgpAuthKey?;
        /**
         * @stability stable
         */
        get bgpAuthKey(): string | undefined;
        /**
         * @stability stable
         */
        set bgpAuthKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetBgpAuthKey(): void;
        /**
         * @stability stable
         */
        get bgpAuthKeyInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _customerAddress?;
        /**
         * @stability stable
         */
        get customerAddress(): string | undefined;
        /**
         * @stability stable
         */
        set customerAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAddress(): void;
        /**
         * @stability stable
         */
        get customerAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get jumboFrameCapable(): any;
        private _mtu?;
        /**
         * @stability stable
         */
        get mtu(): number | undefined;
        /**
         * @stability stable
         */
        set mtu(value: number | undefined);
        /**
         * @stability stable
         */
        resetMtu(): void;
        /**
         * @stability stable
         */
        get mtuInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _ownerAccountId?;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        /**
         * @stability stable
         */
        set ownerAccountId(value: string);
        /**
         * @stability stable
         */
        get ownerAccountIdInput(): string | undefined;
        private _vlan?;
        /**
         * @stability stable
         */
        get vlan(): number;
        /**
         * @stability stable
         */
        set vlan(value: number);
        /**
         * @stability stable
         */
        get vlanInput(): number | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxHostedPrivateVirtualInterfaceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxHostedPrivateVirtualInterfaceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxHostedPrivateVirtualInterfaceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxHostedPrivateVirtualInterfaceAccepterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#dx_gateway_id DxHostedPrivateVirtualInterfaceAccepter#dx_gateway_id}.
         *
         * @stability stable
         */
        readonly dxGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#tags DxHostedPrivateVirtualInterfaceAccepter#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#tags_all DxHostedPrivateVirtualInterfaceAccepter#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#virtual_interface_id DxHostedPrivateVirtualInterfaceAccepter#virtual_interface_id}.
         *
         * @stability stable
         */
        readonly virtualInterfaceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#vpn_gateway_id DxHostedPrivateVirtualInterfaceAccepter#vpn_gateway_id}.
         *
         * @stability stable
         */
        readonly vpnGatewayId?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#timeouts DxHostedPrivateVirtualInterfaceAccepter#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxHostedPrivateVirtualInterfaceAccepterTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxHostedPrivateVirtualInterfaceAccepterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#create DxHostedPrivateVirtualInterfaceAccepter#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html#delete DxHostedPrivateVirtualInterfaceAccepter#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxHostedPrivateVirtualInterfaceAccepterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html aws_dx_hosted_private_virtual_interface_accepter}.
     *
     * @stability stable
     */
    class DxHostedPrivateVirtualInterfaceAccepter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_private_virtual_interface_accepter.html aws_dx_hosted_private_virtual_interface_accepter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxHostedPrivateVirtualInterfaceAccepterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _dxGatewayId?;
        /**
         * @stability stable
         */
        get dxGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set dxGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDxGatewayId(): void;
        /**
         * @stability stable
         */
        get dxGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _virtualInterfaceId?;
        /**
         * @stability stable
         */
        get virtualInterfaceId(): string;
        /**
         * @stability stable
         */
        set virtualInterfaceId(value: string);
        /**
         * @stability stable
         */
        get virtualInterfaceIdInput(): string | undefined;
        private _vpnGatewayId?;
        /**
         * @stability stable
         */
        get vpnGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set vpnGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpnGatewayId(): void;
        /**
         * @stability stable
         */
        get vpnGatewayIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxHostedPrivateVirtualInterfaceAccepterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxHostedPrivateVirtualInterfaceAccepterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxHostedPrivateVirtualInterfaceAccepterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxHostedPublicVirtualInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#address_family DxHostedPublicVirtualInterface#address_family}.
         *
         * @stability stable
         */
        readonly addressFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#amazon_address DxHostedPublicVirtualInterface#amazon_address}.
         *
         * @stability stable
         */
        readonly amazonAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#bgp_asn DxHostedPublicVirtualInterface#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#bgp_auth_key DxHostedPublicVirtualInterface#bgp_auth_key}.
         *
         * @stability stable
         */
        readonly bgpAuthKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#connection_id DxHostedPublicVirtualInterface#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#customer_address DxHostedPublicVirtualInterface#customer_address}.
         *
         * @stability stable
         */
        readonly customerAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#name DxHostedPublicVirtualInterface#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#owner_account_id DxHostedPublicVirtualInterface#owner_account_id}.
         *
         * @stability stable
         */
        readonly ownerAccountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#route_filter_prefixes DxHostedPublicVirtualInterface#route_filter_prefixes}.
         *
         * @stability stable
         */
        readonly routeFilterPrefixes: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#vlan DxHostedPublicVirtualInterface#vlan}.
         *
         * @stability stable
         */
        readonly vlan: number;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#timeouts DxHostedPublicVirtualInterface#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxHostedPublicVirtualInterfaceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxHostedPublicVirtualInterfaceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#create DxHostedPublicVirtualInterface#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html#delete DxHostedPublicVirtualInterface#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxHostedPublicVirtualInterfaceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html aws_dx_hosted_public_virtual_interface}.
     *
     * @stability stable
     */
    class DxHostedPublicVirtualInterface extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface.html aws_dx_hosted_public_virtual_interface} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxHostedPublicVirtualInterfaceConfig);
        private _addressFamily?;
        /**
         * @stability stable
         */
        get addressFamily(): string;
        /**
         * @stability stable
         */
        set addressFamily(value: string);
        /**
         * @stability stable
         */
        get addressFamilyInput(): string | undefined;
        private _amazonAddress?;
        /**
         * @stability stable
         */
        get amazonAddress(): string | undefined;
        /**
         * @stability stable
         */
        set amazonAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonAddress(): void;
        /**
         * @stability stable
         */
        get amazonAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        set bgpAsn(value: number);
        /**
         * @stability stable
         */
        get bgpAsnInput(): number | undefined;
        private _bgpAuthKey?;
        /**
         * @stability stable
         */
        get bgpAuthKey(): string | undefined;
        /**
         * @stability stable
         */
        set bgpAuthKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetBgpAuthKey(): void;
        /**
         * @stability stable
         */
        get bgpAuthKeyInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _customerAddress?;
        /**
         * @stability stable
         */
        get customerAddress(): string | undefined;
        /**
         * @stability stable
         */
        set customerAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAddress(): void;
        /**
         * @stability stable
         */
        get customerAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _ownerAccountId?;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        /**
         * @stability stable
         */
        set ownerAccountId(value: string);
        /**
         * @stability stable
         */
        get ownerAccountIdInput(): string | undefined;
        private _routeFilterPrefixes?;
        /**
         * @stability stable
         */
        get routeFilterPrefixes(): string[];
        /**
         * @stability stable
         */
        set routeFilterPrefixes(value: string[]);
        /**
         * @stability stable
         */
        get routeFilterPrefixesInput(): string[] | undefined;
        private _vlan?;
        /**
         * @stability stable
         */
        get vlan(): number;
        /**
         * @stability stable
         */
        set vlan(value: number);
        /**
         * @stability stable
         */
        get vlanInput(): number | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxHostedPublicVirtualInterfaceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxHostedPublicVirtualInterfaceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxHostedPublicVirtualInterfaceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxHostedPublicVirtualInterfaceAccepterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html#tags DxHostedPublicVirtualInterfaceAccepter#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html#tags_all DxHostedPublicVirtualInterfaceAccepter#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html#virtual_interface_id DxHostedPublicVirtualInterfaceAccepter#virtual_interface_id}.
         *
         * @stability stable
         */
        readonly virtualInterfaceId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html#timeouts DxHostedPublicVirtualInterfaceAccepter#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxHostedPublicVirtualInterfaceAccepterTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxHostedPublicVirtualInterfaceAccepterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html#create DxHostedPublicVirtualInterfaceAccepter#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html#delete DxHostedPublicVirtualInterfaceAccepter#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxHostedPublicVirtualInterfaceAccepterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html aws_dx_hosted_public_virtual_interface_accepter}.
     *
     * @stability stable
     */
    class DxHostedPublicVirtualInterfaceAccepter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_public_virtual_interface_accepter.html aws_dx_hosted_public_virtual_interface_accepter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxHostedPublicVirtualInterfaceAccepterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _virtualInterfaceId?;
        /**
         * @stability stable
         */
        get virtualInterfaceId(): string;
        /**
         * @stability stable
         */
        set virtualInterfaceId(value: string);
        /**
         * @stability stable
         */
        get virtualInterfaceIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxHostedPublicVirtualInterfaceAccepterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxHostedPublicVirtualInterfaceAccepterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxHostedPublicVirtualInterfaceAccepterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxHostedTransitVirtualInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#address_family DxHostedTransitVirtualInterface#address_family}.
         *
         * @stability stable
         */
        readonly addressFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#amazon_address DxHostedTransitVirtualInterface#amazon_address}.
         *
         * @stability stable
         */
        readonly amazonAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#bgp_asn DxHostedTransitVirtualInterface#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#bgp_auth_key DxHostedTransitVirtualInterface#bgp_auth_key}.
         *
         * @stability stable
         */
        readonly bgpAuthKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#connection_id DxHostedTransitVirtualInterface#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#customer_address DxHostedTransitVirtualInterface#customer_address}.
         *
         * @stability stable
         */
        readonly customerAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#mtu DxHostedTransitVirtualInterface#mtu}.
         *
         * @stability stable
         */
        readonly mtu?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#name DxHostedTransitVirtualInterface#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#owner_account_id DxHostedTransitVirtualInterface#owner_account_id}.
         *
         * @stability stable
         */
        readonly ownerAccountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#vlan DxHostedTransitVirtualInterface#vlan}.
         *
         * @stability stable
         */
        readonly vlan: number;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#timeouts DxHostedTransitVirtualInterface#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxHostedTransitVirtualInterfaceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxHostedTransitVirtualInterfaceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#create DxHostedTransitVirtualInterface#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html#delete DxHostedTransitVirtualInterface#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxHostedTransitVirtualInterfaceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html aws_dx_hosted_transit_virtual_interface}.
     *
     * @stability stable
     */
    class DxHostedTransitVirtualInterface extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface.html aws_dx_hosted_transit_virtual_interface} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxHostedTransitVirtualInterfaceConfig);
        private _addressFamily?;
        /**
         * @stability stable
         */
        get addressFamily(): string;
        /**
         * @stability stable
         */
        set addressFamily(value: string);
        /**
         * @stability stable
         */
        get addressFamilyInput(): string | undefined;
        private _amazonAddress?;
        /**
         * @stability stable
         */
        get amazonAddress(): string | undefined;
        /**
         * @stability stable
         */
        set amazonAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonAddress(): void;
        /**
         * @stability stable
         */
        get amazonAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        set bgpAsn(value: number);
        /**
         * @stability stable
         */
        get bgpAsnInput(): number | undefined;
        private _bgpAuthKey?;
        /**
         * @stability stable
         */
        get bgpAuthKey(): string | undefined;
        /**
         * @stability stable
         */
        set bgpAuthKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetBgpAuthKey(): void;
        /**
         * @stability stable
         */
        get bgpAuthKeyInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _customerAddress?;
        /**
         * @stability stable
         */
        get customerAddress(): string | undefined;
        /**
         * @stability stable
         */
        set customerAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAddress(): void;
        /**
         * @stability stable
         */
        get customerAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get jumboFrameCapable(): any;
        private _mtu?;
        /**
         * @stability stable
         */
        get mtu(): number | undefined;
        /**
         * @stability stable
         */
        set mtu(value: number | undefined);
        /**
         * @stability stable
         */
        resetMtu(): void;
        /**
         * @stability stable
         */
        get mtuInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _ownerAccountId?;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        /**
         * @stability stable
         */
        set ownerAccountId(value: string);
        /**
         * @stability stable
         */
        get ownerAccountIdInput(): string | undefined;
        private _vlan?;
        /**
         * @stability stable
         */
        get vlan(): number;
        /**
         * @stability stable
         */
        set vlan(value: number);
        /**
         * @stability stable
         */
        get vlanInput(): number | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxHostedTransitVirtualInterfaceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxHostedTransitVirtualInterfaceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxHostedTransitVirtualInterfaceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxHostedTransitVirtualInterfaceAccepterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html#dx_gateway_id DxHostedTransitVirtualInterfaceAccepter#dx_gateway_id}.
         *
         * @stability stable
         */
        readonly dxGatewayId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html#tags DxHostedTransitVirtualInterfaceAccepter#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html#tags_all DxHostedTransitVirtualInterfaceAccepter#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html#virtual_interface_id DxHostedTransitVirtualInterfaceAccepter#virtual_interface_id}.
         *
         * @stability stable
         */
        readonly virtualInterfaceId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html#timeouts DxHostedTransitVirtualInterfaceAccepter#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxHostedTransitVirtualInterfaceAccepterTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxHostedTransitVirtualInterfaceAccepterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html#create DxHostedTransitVirtualInterfaceAccepter#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html#delete DxHostedTransitVirtualInterfaceAccepter#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxHostedTransitVirtualInterfaceAccepterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html aws_dx_hosted_transit_virtual_interface_accepter}.
     *
     * @stability stable
     */
    class DxHostedTransitVirtualInterfaceAccepter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_hosted_transit_virtual_interface_accepter.html aws_dx_hosted_transit_virtual_interface_accepter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxHostedTransitVirtualInterfaceAccepterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _dxGatewayId?;
        /**
         * @stability stable
         */
        get dxGatewayId(): string;
        /**
         * @stability stable
         */
        set dxGatewayId(value: string);
        /**
         * @stability stable
         */
        get dxGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _virtualInterfaceId?;
        /**
         * @stability stable
         */
        get virtualInterfaceId(): string;
        /**
         * @stability stable
         */
        set virtualInterfaceId(value: string);
        /**
         * @stability stable
         */
        get virtualInterfaceIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxHostedTransitVirtualInterfaceAccepterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxHostedTransitVirtualInterfaceAccepterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxHostedTransitVirtualInterfaceAccepterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxLagConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#connection_id DxLag#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#connections_bandwidth DxLag#connections_bandwidth}.
         *
         * @stability stable
         */
        readonly connectionsBandwidth: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#force_destroy DxLag#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#location DxLag#location}.
         *
         * @stability stable
         */
        readonly location: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#name DxLag#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#provider_name DxLag#provider_name}.
         *
         * @stability stable
         */
        readonly providerName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#tags DxLag#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html#tags_all DxLag#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html aws_dx_lag}.
     *
     * @stability stable
     */
    class DxLag extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_lag.html aws_dx_lag} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxLagConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string | undefined;
        /**
         * @stability stable
         */
        set connectionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetConnectionId(): void;
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _connectionsBandwidth?;
        /**
         * @stability stable
         */
        get connectionsBandwidth(): string;
        /**
         * @stability stable
         */
        set connectionsBandwidth(value: string);
        /**
         * @stability stable
         */
        get connectionsBandwidthInput(): string | undefined;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get hasLogicalRedundancy(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get jumboFrameCapable(): any;
        private _location?;
        /**
         * @stability stable
         */
        get location(): string;
        /**
         * @stability stable
         */
        set location(value: string);
        /**
         * @stability stable
         */
        get locationInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        private _providerName?;
        /**
         * @stability stable
         */
        get providerName(): string | undefined;
        /**
         * @stability stable
         */
        set providerName(value: string | undefined);
        /**
         * @stability stable
         */
        resetProviderName(): void;
        /**
         * @stability stable
         */
        get providerNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxPrivateVirtualInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#address_family DxPrivateVirtualInterface#address_family}.
         *
         * @stability stable
         */
        readonly addressFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#amazon_address DxPrivateVirtualInterface#amazon_address}.
         *
         * @stability stable
         */
        readonly amazonAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#bgp_asn DxPrivateVirtualInterface#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#bgp_auth_key DxPrivateVirtualInterface#bgp_auth_key}.
         *
         * @stability stable
         */
        readonly bgpAuthKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#connection_id DxPrivateVirtualInterface#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#customer_address DxPrivateVirtualInterface#customer_address}.
         *
         * @stability stable
         */
        readonly customerAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#dx_gateway_id DxPrivateVirtualInterface#dx_gateway_id}.
         *
         * @stability stable
         */
        readonly dxGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#mtu DxPrivateVirtualInterface#mtu}.
         *
         * @stability stable
         */
        readonly mtu?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#name DxPrivateVirtualInterface#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#tags DxPrivateVirtualInterface#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#tags_all DxPrivateVirtualInterface#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#vlan DxPrivateVirtualInterface#vlan}.
         *
         * @stability stable
         */
        readonly vlan: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#vpn_gateway_id DxPrivateVirtualInterface#vpn_gateway_id}.
         *
         * @stability stable
         */
        readonly vpnGatewayId?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#timeouts DxPrivateVirtualInterface#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxPrivateVirtualInterfaceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxPrivateVirtualInterfaceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#create DxPrivateVirtualInterface#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#delete DxPrivateVirtualInterface#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html#update DxPrivateVirtualInterface#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DxPrivateVirtualInterfaceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html aws_dx_private_virtual_interface}.
     *
     * @stability stable
     */
    class DxPrivateVirtualInterface extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_private_virtual_interface.html aws_dx_private_virtual_interface} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxPrivateVirtualInterfaceConfig);
        private _addressFamily?;
        /**
         * @stability stable
         */
        get addressFamily(): string;
        /**
         * @stability stable
         */
        set addressFamily(value: string);
        /**
         * @stability stable
         */
        get addressFamilyInput(): string | undefined;
        private _amazonAddress?;
        /**
         * @stability stable
         */
        get amazonAddress(): string | undefined;
        /**
         * @stability stable
         */
        set amazonAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonAddress(): void;
        /**
         * @stability stable
         */
        get amazonAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        set bgpAsn(value: number);
        /**
         * @stability stable
         */
        get bgpAsnInput(): number | undefined;
        private _bgpAuthKey?;
        /**
         * @stability stable
         */
        get bgpAuthKey(): string | undefined;
        /**
         * @stability stable
         */
        set bgpAuthKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetBgpAuthKey(): void;
        /**
         * @stability stable
         */
        get bgpAuthKeyInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _customerAddress?;
        /**
         * @stability stable
         */
        get customerAddress(): string | undefined;
        /**
         * @stability stable
         */
        set customerAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAddress(): void;
        /**
         * @stability stable
         */
        get customerAddressInput(): string | undefined;
        private _dxGatewayId?;
        /**
         * @stability stable
         */
        get dxGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set dxGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDxGatewayId(): void;
        /**
         * @stability stable
         */
        get dxGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get jumboFrameCapable(): any;
        private _mtu?;
        /**
         * @stability stable
         */
        get mtu(): number | undefined;
        /**
         * @stability stable
         */
        set mtu(value: number | undefined);
        /**
         * @stability stable
         */
        resetMtu(): void;
        /**
         * @stability stable
         */
        get mtuInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vlan?;
        /**
         * @stability stable
         */
        get vlan(): number;
        /**
         * @stability stable
         */
        set vlan(value: number);
        /**
         * @stability stable
         */
        get vlanInput(): number | undefined;
        private _vpnGatewayId?;
        /**
         * @stability stable
         */
        get vpnGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set vpnGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpnGatewayId(): void;
        /**
         * @stability stable
         */
        get vpnGatewayIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxPrivateVirtualInterfaceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxPrivateVirtualInterfaceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxPrivateVirtualInterfaceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxPublicVirtualInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#address_family DxPublicVirtualInterface#address_family}.
         *
         * @stability stable
         */
        readonly addressFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#amazon_address DxPublicVirtualInterface#amazon_address}.
         *
         * @stability stable
         */
        readonly amazonAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#bgp_asn DxPublicVirtualInterface#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#bgp_auth_key DxPublicVirtualInterface#bgp_auth_key}.
         *
         * @stability stable
         */
        readonly bgpAuthKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#connection_id DxPublicVirtualInterface#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#customer_address DxPublicVirtualInterface#customer_address}.
         *
         * @stability stable
         */
        readonly customerAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#name DxPublicVirtualInterface#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#route_filter_prefixes DxPublicVirtualInterface#route_filter_prefixes}.
         *
         * @stability stable
         */
        readonly routeFilterPrefixes: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#tags DxPublicVirtualInterface#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#tags_all DxPublicVirtualInterface#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#vlan DxPublicVirtualInterface#vlan}.
         *
         * @stability stable
         */
        readonly vlan: number;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#timeouts DxPublicVirtualInterface#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxPublicVirtualInterfaceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxPublicVirtualInterfaceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#create DxPublicVirtualInterface#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html#delete DxPublicVirtualInterface#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DxPublicVirtualInterfaceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html aws_dx_public_virtual_interface}.
     *
     * @stability stable
     */
    class DxPublicVirtualInterface extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_public_virtual_interface.html aws_dx_public_virtual_interface} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxPublicVirtualInterfaceConfig);
        private _addressFamily?;
        /**
         * @stability stable
         */
        get addressFamily(): string;
        /**
         * @stability stable
         */
        set addressFamily(value: string);
        /**
         * @stability stable
         */
        get addressFamilyInput(): string | undefined;
        private _amazonAddress?;
        /**
         * @stability stable
         */
        get amazonAddress(): string | undefined;
        /**
         * @stability stable
         */
        set amazonAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonAddress(): void;
        /**
         * @stability stable
         */
        get amazonAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        set bgpAsn(value: number);
        /**
         * @stability stable
         */
        get bgpAsnInput(): number | undefined;
        private _bgpAuthKey?;
        /**
         * @stability stable
         */
        get bgpAuthKey(): string | undefined;
        /**
         * @stability stable
         */
        set bgpAuthKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetBgpAuthKey(): void;
        /**
         * @stability stable
         */
        get bgpAuthKeyInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _customerAddress?;
        /**
         * @stability stable
         */
        get customerAddress(): string | undefined;
        /**
         * @stability stable
         */
        set customerAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAddress(): void;
        /**
         * @stability stable
         */
        get customerAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _routeFilterPrefixes?;
        /**
         * @stability stable
         */
        get routeFilterPrefixes(): string[];
        /**
         * @stability stable
         */
        set routeFilterPrefixes(value: string[]);
        /**
         * @stability stable
         */
        get routeFilterPrefixesInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vlan?;
        /**
         * @stability stable
         */
        get vlan(): number;
        /**
         * @stability stable
         */
        set vlan(value: number);
        /**
         * @stability stable
         */
        get vlanInput(): number | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxPublicVirtualInterfaceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxPublicVirtualInterfaceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxPublicVirtualInterfaceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DxTransitVirtualInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#address_family DxTransitVirtualInterface#address_family}.
         *
         * @stability stable
         */
        readonly addressFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#amazon_address DxTransitVirtualInterface#amazon_address}.
         *
         * @stability stable
         */
        readonly amazonAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#bgp_asn DxTransitVirtualInterface#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#bgp_auth_key DxTransitVirtualInterface#bgp_auth_key}.
         *
         * @stability stable
         */
        readonly bgpAuthKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#connection_id DxTransitVirtualInterface#connection_id}.
         *
         * @stability stable
         */
        readonly connectionId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#customer_address DxTransitVirtualInterface#customer_address}.
         *
         * @stability stable
         */
        readonly customerAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#dx_gateway_id DxTransitVirtualInterface#dx_gateway_id}.
         *
         * @stability stable
         */
        readonly dxGatewayId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#mtu DxTransitVirtualInterface#mtu}.
         *
         * @stability stable
         */
        readonly mtu?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#name DxTransitVirtualInterface#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#tags DxTransitVirtualInterface#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#tags_all DxTransitVirtualInterface#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#vlan DxTransitVirtualInterface#vlan}.
         *
         * @stability stable
         */
        readonly vlan: number;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#timeouts DxTransitVirtualInterface#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DxTransitVirtualInterfaceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DxTransitVirtualInterfaceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#create DxTransitVirtualInterface#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#delete DxTransitVirtualInterface#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html#update DxTransitVirtualInterface#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DxTransitVirtualInterfaceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html aws_dx_transit_virtual_interface}.
     *
     * @stability stable
     */
    class DxTransitVirtualInterface extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dx_transit_virtual_interface.html aws_dx_transit_virtual_interface} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DxTransitVirtualInterfaceConfig);
        private _addressFamily?;
        /**
         * @stability stable
         */
        get addressFamily(): string;
        /**
         * @stability stable
         */
        set addressFamily(value: string);
        /**
         * @stability stable
         */
        get addressFamilyInput(): string | undefined;
        private _amazonAddress?;
        /**
         * @stability stable
         */
        get amazonAddress(): string | undefined;
        /**
         * @stability stable
         */
        set amazonAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonAddress(): void;
        /**
         * @stability stable
         */
        get amazonAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        set bgpAsn(value: number);
        /**
         * @stability stable
         */
        get bgpAsnInput(): number | undefined;
        private _bgpAuthKey?;
        /**
         * @stability stable
         */
        get bgpAuthKey(): string | undefined;
        /**
         * @stability stable
         */
        set bgpAuthKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetBgpAuthKey(): void;
        /**
         * @stability stable
         */
        get bgpAuthKeyInput(): string | undefined;
        private _connectionId?;
        /**
         * @stability stable
         */
        get connectionId(): string;
        /**
         * @stability stable
         */
        set connectionId(value: string);
        /**
         * @stability stable
         */
        get connectionIdInput(): string | undefined;
        private _customerAddress?;
        /**
         * @stability stable
         */
        get customerAddress(): string | undefined;
        /**
         * @stability stable
         */
        set customerAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAddress(): void;
        /**
         * @stability stable
         */
        get customerAddressInput(): string | undefined;
        private _dxGatewayId?;
        /**
         * @stability stable
         */
        get dxGatewayId(): string;
        /**
         * @stability stable
         */
        set dxGatewayId(value: string);
        /**
         * @stability stable
         */
        get dxGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get jumboFrameCapable(): any;
        private _mtu?;
        /**
         * @stability stable
         */
        get mtu(): number | undefined;
        /**
         * @stability stable
         */
        set mtu(value: number | undefined);
        /**
         * @stability stable
         */
        resetMtu(): void;
        /**
         * @stability stable
         */
        get mtuInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vlan?;
        /**
         * @stability stable
         */
        get vlan(): number;
        /**
         * @stability stable
         */
        set vlan(value: number);
        /**
         * @stability stable
         */
        get vlanInput(): number | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DxTransitVirtualInterfaceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DxTransitVirtualInterfaceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DxTransitVirtualInterfaceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDxConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dx_connection.html#name DataAwsDxConnection#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dx_connection.html#tags DataAwsDxConnection#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/dx_connection.html aws_dx_connection}.
     *
     * @stability stable
     */
    class DataAwsDxConnection extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/dx_connection.html aws_dx_connection} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDxConnectionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsDevice(): string;
        /**
         * @stability stable
         */
        get bandwidth(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get location(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        /**
         * @stability stable
         */
        get providerName(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDxGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dx_gateway.html#name DataAwsDxGateway#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/dx_gateway.html aws_dx_gateway}.
     *
     * @stability stable
     */
    class DataAwsDxGateway extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/dx_gateway.html aws_dx_gateway} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDxGatewayConfig);
        /**
         * @stability stable
         */
        get amazonSideAsn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerAccountId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDxLocationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dx_location.html#location_code DataAwsDxLocation#location_code}.
         *
         * @stability stable
         */
        readonly locationCode: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/dx_location.html aws_dx_location}.
     *
     * @stability stable
     */
    class DataAwsDxLocation extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/dx_location.html aws_dx_location} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDxLocationConfig);
        /**
         * @stability stable
         */
        get availablePortSpeeds(): string[];
        /**
         * @stability stable
         */
        get availableProviders(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        private _locationCode?;
        /**
         * @stability stable
         */
        get locationCode(): string;
        /**
         * @stability stable
         */
        set locationCode(value: string);
        /**
         * @stability stable
         */
        get locationCodeInput(): string | undefined;
        /**
         * @stability stable
         */
        get locationName(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDxLocationsConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/dx_locations.html aws_dx_locations}.
     *
     * @stability stable
     */
    class DataAwsDxLocations extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/dx_locations.html aws_dx_locations} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsDxLocationsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get locationCodes(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
