import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Directory Service
*/
export declare namespace DirectoryService {
    /**
     * @stability stable
     */
    interface DirectoryServiceConditionalForwarderConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_conditional_forwarder.html#directory_id DirectoryServiceConditionalForwarder#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_conditional_forwarder.html#dns_ips DirectoryServiceConditionalForwarder#dns_ips}.
         *
         * @stability stable
         */
        readonly dnsIps: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_conditional_forwarder.html#remote_domain_name DirectoryServiceConditionalForwarder#remote_domain_name}.
         *
         * @stability stable
         */
        readonly remoteDomainName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/directory_service_conditional_forwarder.html aws_directory_service_conditional_forwarder}.
     *
     * @stability stable
     */
    class DirectoryServiceConditionalForwarder extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/directory_service_conditional_forwarder.html aws_directory_service_conditional_forwarder} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DirectoryServiceConditionalForwarderConfig);
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string;
        /**
         * @stability stable
         */
        set directoryId(value: string);
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        private _dnsIps?;
        /**
         * @stability stable
         */
        get dnsIps(): string[];
        /**
         * @stability stable
         */
        set dnsIps(value: string[]);
        /**
         * @stability stable
         */
        get dnsIpsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _remoteDomainName?;
        /**
         * @stability stable
         */
        get remoteDomainName(): string;
        /**
         * @stability stable
         */
        set remoteDomainName(value: string);
        /**
         * @stability stable
         */
        get remoteDomainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DirectoryServiceDirectoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#alias DirectoryServiceDirectory#alias}.
         *
         * @stability stable
         */
        readonly alias?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#description DirectoryServiceDirectory#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#edition DirectoryServiceDirectory#edition}.
         *
         * @stability stable
         */
        readonly edition?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#enable_sso DirectoryServiceDirectory#enable_sso}.
         *
         * @stability stable
         */
        readonly enableSso?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#name DirectoryServiceDirectory#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#password DirectoryServiceDirectory#password}.
         *
         * @stability stable
         */
        readonly password: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#short_name DirectoryServiceDirectory#short_name}.
         *
         * @stability stable
         */
        readonly shortName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#size DirectoryServiceDirectory#size}.
         *
         * @stability stable
         */
        readonly size?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#tags DirectoryServiceDirectory#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#tags_all DirectoryServiceDirectory#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#type DirectoryServiceDirectory#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * connect_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#connect_settings DirectoryServiceDirectory#connect_settings}
         *
         * @stability stable
         */
        readonly connectSettings?: DirectoryServiceDirectoryConnectSettings;
        /**
         * vpc_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#vpc_settings DirectoryServiceDirectory#vpc_settings}
         *
         * @stability stable
         */
        readonly vpcSettings?: DirectoryServiceDirectoryVpcSettings;
    }
    /**
     * @stability stable
     */
    interface DirectoryServiceDirectoryConnectSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#customer_dns_ips DirectoryServiceDirectory#customer_dns_ips}.
         *
         * @stability stable
         */
        readonly customerDnsIps: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#customer_username DirectoryServiceDirectory#customer_username}.
         *
         * @stability stable
         */
        readonly customerUsername: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#subnet_ids DirectoryServiceDirectory#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#vpc_id DirectoryServiceDirectory#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
    }
    /**
     * @stability stable
     */
    class DirectoryServiceDirectoryConnectSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _customerDnsIps?;
        /**
         * @stability stable
         */
        get customerDnsIps(): string[];
        /**
         * @stability stable
         */
        set customerDnsIps(value: string[]);
        /**
         * @stability stable
         */
        get customerDnsIpsInput(): string[] | undefined;
        private _customerUsername?;
        /**
         * @stability stable
         */
        get customerUsername(): string;
        /**
         * @stability stable
         */
        set customerUsername(value: string);
        /**
         * @stability stable
         */
        get customerUsernameInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DirectoryServiceDirectoryVpcSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#subnet_ids DirectoryServiceDirectory#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html#vpc_id DirectoryServiceDirectory#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
    }
    /**
     * @stability stable
     */
    class DirectoryServiceDirectoryVpcSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html aws_directory_service_directory}.
     *
     * @stability stable
     */
    class DirectoryServiceDirectory extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/directory_service_directory.html aws_directory_service_directory} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DirectoryServiceDirectoryConfig);
        /**
         * @stability stable
         */
        get accessUrl(): string;
        private _alias?;
        /**
         * @stability stable
         */
        get alias(): string | undefined;
        /**
         * @stability stable
         */
        set alias(value: string | undefined);
        /**
         * @stability stable
         */
        resetAlias(): void;
        /**
         * @stability stable
         */
        get aliasInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsIpAddresses(): string[];
        private _edition?;
        /**
         * @stability stable
         */
        get edition(): string | undefined;
        /**
         * @stability stable
         */
        set edition(value: string | undefined);
        /**
         * @stability stable
         */
        resetEdition(): void;
        /**
         * @stability stable
         */
        get editionInput(): string | undefined;
        private _enableSso?;
        /**
         * @stability stable
         */
        get enableSso(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableSso(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableSso(): void;
        /**
         * @stability stable
         */
        get enableSsoInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _password?;
        /**
         * @stability stable
         */
        get password(): string;
        /**
         * @stability stable
         */
        set password(value: string);
        /**
         * @stability stable
         */
        get passwordInput(): string | undefined;
        /**
         * @stability stable
         */
        get securityGroupId(): string;
        private _shortName?;
        /**
         * @stability stable
         */
        get shortName(): string | undefined;
        /**
         * @stability stable
         */
        set shortName(value: string | undefined);
        /**
         * @stability stable
         */
        resetShortName(): void;
        /**
         * @stability stable
         */
        get shortNameInput(): string | undefined;
        private _size?;
        /**
         * @stability stable
         */
        get size(): string | undefined;
        /**
         * @stability stable
         */
        set size(value: string | undefined);
        /**
         * @stability stable
         */
        resetSize(): void;
        /**
         * @stability stable
         */
        get sizeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _connectSettings?;
        private __connectSettingsOutput;
        /**
         * @stability stable
         */
        get connectSettings(): DirectoryServiceDirectoryConnectSettingsOutputReference;
        /**
         * @stability stable
         */
        putConnectSettings(value: DirectoryServiceDirectoryConnectSettings | undefined): void;
        /**
         * @stability stable
         */
        resetConnectSettings(): void;
        /**
         * @stability stable
         */
        get connectSettingsInput(): DirectoryServiceDirectoryConnectSettings | undefined;
        private _vpcSettings?;
        private __vpcSettingsOutput;
        /**
         * @stability stable
         */
        get vpcSettings(): DirectoryServiceDirectoryVpcSettingsOutputReference;
        /**
         * @stability stable
         */
        putVpcSettings(value: DirectoryServiceDirectoryVpcSettings | undefined): void;
        /**
         * @stability stable
         */
        resetVpcSettings(): void;
        /**
         * @stability stable
         */
        get vpcSettingsInput(): DirectoryServiceDirectoryVpcSettings | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DirectoryServiceLogSubscriptionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_log_subscription.html#directory_id DirectoryServiceLogSubscription#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/directory_service_log_subscription.html#log_group_name DirectoryServiceLogSubscription#log_group_name}.
         *
         * @stability stable
         */
        readonly logGroupName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/directory_service_log_subscription.html aws_directory_service_log_subscription}.
     *
     * @stability stable
     */
    class DirectoryServiceLogSubscription extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/directory_service_log_subscription.html aws_directory_service_log_subscription} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DirectoryServiceLogSubscriptionConfig);
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string;
        /**
         * @stability stable
         */
        set directoryId(value: string);
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _logGroupName?;
        /**
         * @stability stable
         */
        get logGroupName(): string;
        /**
         * @stability stable
         */
        set logGroupName(value: string);
        /**
         * @stability stable
         */
        get logGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDirectoryServiceDirectoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory.html#directory_id DataAwsDirectoryServiceDirectory#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory.html#tags DataAwsDirectoryServiceDirectory#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsDirectoryServiceDirectoryConnectSettings extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get connectIps(): string[];
        /**
         * @stability stable
         */
        get customerDnsIps(): string[];
        /**
         * @stability stable
         */
        get customerUsername(): string;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        get vpcId(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsDirectoryServiceDirectoryVpcSettings extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        get vpcId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory.html aws_directory_service_directory}.
     *
     * @stability stable
     */
    class DataAwsDirectoryServiceDirectory extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/directory_service_directory.html aws_directory_service_directory} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDirectoryServiceDirectoryConfig);
        /**
         * @stability stable
         */
        get accessUrl(): string;
        /**
         * @stability stable
         */
        get alias(): string;
        /**
         * @stability stable
         */
        connectSettings(index: string): DataAwsDirectoryServiceDirectoryConnectSettings;
        /**
         * @stability stable
         */
        get description(): string;
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string;
        /**
         * @stability stable
         */
        set directoryId(value: string);
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsIpAddresses(): string[];
        /**
         * @stability stable
         */
        get edition(): string;
        /**
         * @stability stable
         */
        get enableSso(): any;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get securityGroupId(): string;
        /**
         * @stability stable
         */
        get shortName(): string;
        /**
         * @stability stable
         */
        get size(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        vpcSettings(index: string): DataAwsDirectoryServiceDirectoryVpcSettings;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
