import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS DynamoDB
*/
export declare namespace DynamoDB {
    /**
     * @stability stable
     */
    interface DynamodbGlobalTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html#name DynamodbGlobalTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * replica block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html#replica DynamodbGlobalTable#replica}
         *
         * @stability stable
         */
        readonly replica: DynamodbGlobalTableReplica[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html#timeouts DynamodbGlobalTable#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DynamodbGlobalTableTimeouts;
    }
    /**
     * @stability stable
     */
    interface DynamodbGlobalTableReplica {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html#region_name DynamodbGlobalTable#region_name}.
         *
         * @stability stable
         */
        readonly regionName: string;
    }
    /**
     * @stability stable
     */
    interface DynamodbGlobalTableTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html#create DynamodbGlobalTable#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html#delete DynamodbGlobalTable#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html#update DynamodbGlobalTable#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DynamodbGlobalTableTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html aws_dynamodb_global_table}.
     *
     * @stability stable
     */
    class DynamodbGlobalTable extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_global_table.html aws_dynamodb_global_table} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DynamodbGlobalTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _replica?;
        /**
         * @stability stable
         */
        get replica(): DynamodbGlobalTableReplica[];
        /**
         * @stability stable
         */
        set replica(value: DynamodbGlobalTableReplica[]);
        /**
         * @stability stable
         */
        get replicaInput(): DynamodbGlobalTableReplica[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DynamodbGlobalTableTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DynamodbGlobalTableTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DynamodbGlobalTableTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DynamodbKinesisStreamingDestinationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_kinesis_streaming_destination.html#stream_arn DynamodbKinesisStreamingDestination#stream_arn}.
         *
         * @stability stable
         */
        readonly streamArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_kinesis_streaming_destination.html#table_name DynamodbKinesisStreamingDestination#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_kinesis_streaming_destination.html aws_dynamodb_kinesis_streaming_destination}.
     *
     * @stability stable
     */
    class DynamodbKinesisStreamingDestination extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_kinesis_streaming_destination.html aws_dynamodb_kinesis_streaming_destination} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DynamodbKinesisStreamingDestinationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _streamArn?;
        /**
         * @stability stable
         */
        get streamArn(): string;
        /**
         * @stability stable
         */
        set streamArn(value: string);
        /**
         * @stability stable
         */
        get streamArnInput(): string | undefined;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DynamodbTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#billing_mode DynamodbTable#billing_mode}.
         *
         * @stability stable
         */
        readonly billingMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#hash_key DynamodbTable#hash_key}.
         *
         * @stability stable
         */
        readonly hashKey: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#name DynamodbTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#range_key DynamodbTable#range_key}.
         *
         * @stability stable
         */
        readonly rangeKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#read_capacity DynamodbTable#read_capacity}.
         *
         * @stability stable
         */
        readonly readCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#stream_enabled DynamodbTable#stream_enabled}.
         *
         * @stability stable
         */
        readonly streamEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#stream_view_type DynamodbTable#stream_view_type}.
         *
         * @stability stable
         */
        readonly streamViewType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#tags DynamodbTable#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#tags_all DynamodbTable#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#write_capacity DynamodbTable#write_capacity}.
         *
         * @stability stable
         */
        readonly writeCapacity?: number;
        /**
         * attribute block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#attribute DynamodbTable#attribute}
         *
         * @stability stable
         */
        readonly attribute: DynamodbTableAttribute[];
        /**
         * global_secondary_index block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#global_secondary_index DynamodbTable#global_secondary_index}
         *
         * @stability stable
         */
        readonly globalSecondaryIndex?: DynamodbTableGlobalSecondaryIndex[];
        /**
         * local_secondary_index block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#local_secondary_index DynamodbTable#local_secondary_index}
         *
         * @stability stable
         */
        readonly localSecondaryIndex?: DynamodbTableLocalSecondaryIndex[];
        /**
         * point_in_time_recovery block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#point_in_time_recovery DynamodbTable#point_in_time_recovery}
         *
         * @stability stable
         */
        readonly pointInTimeRecovery?: DynamodbTablePointInTimeRecovery;
        /**
         * replica block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#replica DynamodbTable#replica}
         *
         * @stability stable
         */
        readonly replica?: DynamodbTableReplica[];
        /**
         * server_side_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#server_side_encryption DynamodbTable#server_side_encryption}
         *
         * @stability stable
         */
        readonly serverSideEncryption?: DynamodbTableServerSideEncryption;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#timeouts DynamodbTable#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DynamodbTableTimeouts;
        /**
         * ttl block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#ttl DynamodbTable#ttl}
         *
         * @stability stable
         */
        readonly ttl?: DynamodbTableTtl;
    }
    /**
     * @stability stable
     */
    interface DynamodbTableAttribute {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#name DynamodbTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#type DynamodbTable#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    interface DynamodbTableGlobalSecondaryIndex {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#hash_key DynamodbTable#hash_key}.
         *
         * @stability stable
         */
        readonly hashKey: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#name DynamodbTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#non_key_attributes DynamodbTable#non_key_attributes}.
         *
         * @stability stable
         */
        readonly nonKeyAttributes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#projection_type DynamodbTable#projection_type}.
         *
         * @stability stable
         */
        readonly projectionType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#range_key DynamodbTable#range_key}.
         *
         * @stability stable
         */
        readonly rangeKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#read_capacity DynamodbTable#read_capacity}.
         *
         * @stability stable
         */
        readonly readCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#write_capacity DynamodbTable#write_capacity}.
         *
         * @stability stable
         */
        readonly writeCapacity?: number;
    }
    /**
     * @stability stable
     */
    interface DynamodbTableLocalSecondaryIndex {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#name DynamodbTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#non_key_attributes DynamodbTable#non_key_attributes}.
         *
         * @stability stable
         */
        readonly nonKeyAttributes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#projection_type DynamodbTable#projection_type}.
         *
         * @stability stable
         */
        readonly projectionType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#range_key DynamodbTable#range_key}.
         *
         * @stability stable
         */
        readonly rangeKey: string;
    }
    /**
     * @stability stable
     */
    interface DynamodbTablePointInTimeRecovery {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#enabled DynamodbTable#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DynamodbTablePointInTimeRecoveryOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface DynamodbTableReplica {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#kms_key_arn DynamodbTable#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#region_name DynamodbTable#region_name}.
         *
         * @stability stable
         */
        readonly regionName: string;
    }
    /**
     * @stability stable
     */
    interface DynamodbTableServerSideEncryption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#enabled DynamodbTable#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#kms_key_arn DynamodbTable#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
    }
    /**
     * @stability stable
     */
    class DynamodbTableServerSideEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DynamodbTableTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#create DynamodbTable#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#delete DynamodbTable#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#update DynamodbTable#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DynamodbTableTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DynamodbTableTtl {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#attribute_name DynamodbTable#attribute_name}.
         *
         * @stability stable
         */
        readonly attributeName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#enabled DynamodbTable#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html#kms_key_arn DynamodbTable#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
    }
    /**
     * @stability stable
     */
    class DynamodbTableTtlOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _attributeName?;
        /**
         * @stability stable
         */
        get attributeName(): string;
        /**
         * @stability stable
         */
        set attributeName(value: string);
        /**
         * @stability stable
         */
        get attributeNameInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html aws_dynamodb_table}.
     *
     * @stability stable
     */
    class DynamodbTable extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table.html aws_dynamodb_table} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DynamodbTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _billingMode?;
        /**
         * @stability stable
         */
        get billingMode(): string | undefined;
        /**
         * @stability stable
         */
        set billingMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetBillingMode(): void;
        /**
         * @stability stable
         */
        get billingModeInput(): string | undefined;
        private _hashKey?;
        /**
         * @stability stable
         */
        get hashKey(): string;
        /**
         * @stability stable
         */
        set hashKey(value: string);
        /**
         * @stability stable
         */
        get hashKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _rangeKey?;
        /**
         * @stability stable
         */
        get rangeKey(): string | undefined;
        /**
         * @stability stable
         */
        set rangeKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetRangeKey(): void;
        /**
         * @stability stable
         */
        get rangeKeyInput(): string | undefined;
        private _readCapacity?;
        /**
         * @stability stable
         */
        get readCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set readCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetReadCapacity(): void;
        /**
         * @stability stable
         */
        get readCapacityInput(): number | undefined;
        /**
         * @stability stable
         */
        get streamArn(): string;
        private _streamEnabled?;
        /**
         * @stability stable
         */
        get streamEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set streamEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetStreamEnabled(): void;
        /**
         * @stability stable
         */
        get streamEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get streamLabel(): string;
        private _streamViewType?;
        /**
         * @stability stable
         */
        get streamViewType(): string | undefined;
        /**
         * @stability stable
         */
        set streamViewType(value: string | undefined);
        /**
         * @stability stable
         */
        resetStreamViewType(): void;
        /**
         * @stability stable
         */
        get streamViewTypeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _writeCapacity?;
        /**
         * @stability stable
         */
        get writeCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set writeCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetWriteCapacity(): void;
        /**
         * @stability stable
         */
        get writeCapacityInput(): number | undefined;
        private _attribute?;
        /**
         * @stability stable
         */
        get attribute(): DynamodbTableAttribute[];
        /**
         * @stability stable
         */
        set attribute(value: DynamodbTableAttribute[]);
        /**
         * @stability stable
         */
        get attributeInput(): DynamodbTableAttribute[] | undefined;
        private _globalSecondaryIndex?;
        /**
         * @stability stable
         */
        get globalSecondaryIndex(): DynamodbTableGlobalSecondaryIndex[] | undefined;
        /**
         * @stability stable
         */
        set globalSecondaryIndex(value: DynamodbTableGlobalSecondaryIndex[] | undefined);
        /**
         * @stability stable
         */
        resetGlobalSecondaryIndex(): void;
        /**
         * @stability stable
         */
        get globalSecondaryIndexInput(): DynamodbTableGlobalSecondaryIndex[] | undefined;
        private _localSecondaryIndex?;
        /**
         * @stability stable
         */
        get localSecondaryIndex(): DynamodbTableLocalSecondaryIndex[] | undefined;
        /**
         * @stability stable
         */
        set localSecondaryIndex(value: DynamodbTableLocalSecondaryIndex[] | undefined);
        /**
         * @stability stable
         */
        resetLocalSecondaryIndex(): void;
        /**
         * @stability stable
         */
        get localSecondaryIndexInput(): DynamodbTableLocalSecondaryIndex[] | undefined;
        private _pointInTimeRecovery?;
        private __pointInTimeRecoveryOutput;
        /**
         * @stability stable
         */
        get pointInTimeRecovery(): DynamodbTablePointInTimeRecoveryOutputReference;
        /**
         * @stability stable
         */
        putPointInTimeRecovery(value: DynamodbTablePointInTimeRecovery | undefined): void;
        /**
         * @stability stable
         */
        resetPointInTimeRecovery(): void;
        /**
         * @stability stable
         */
        get pointInTimeRecoveryInput(): DynamodbTablePointInTimeRecovery | undefined;
        private _replica?;
        /**
         * @stability stable
         */
        get replica(): DynamodbTableReplica[] | undefined;
        /**
         * @stability stable
         */
        set replica(value: DynamodbTableReplica[] | undefined);
        /**
         * @stability stable
         */
        resetReplica(): void;
        /**
         * @stability stable
         */
        get replicaInput(): DynamodbTableReplica[] | undefined;
        private _serverSideEncryption?;
        private __serverSideEncryptionOutput;
        /**
         * @stability stable
         */
        get serverSideEncryption(): DynamodbTableServerSideEncryptionOutputReference;
        /**
         * @stability stable
         */
        putServerSideEncryption(value: DynamodbTableServerSideEncryption | undefined): void;
        /**
         * @stability stable
         */
        resetServerSideEncryption(): void;
        /**
         * @stability stable
         */
        get serverSideEncryptionInput(): DynamodbTableServerSideEncryption | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DynamodbTableTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DynamodbTableTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DynamodbTableTimeouts | undefined;
        private _ttl?;
        private __ttlOutput;
        /**
         * @stability stable
         */
        get ttl(): DynamodbTableTtlOutputReference;
        /**
         * @stability stable
         */
        putTtl(value: DynamodbTableTtl | undefined): void;
        /**
         * @stability stable
         */
        resetTtl(): void;
        /**
         * @stability stable
         */
        get ttlInput(): DynamodbTableTtl | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DynamodbTableItemConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table_item.html#hash_key DynamodbTableItem#hash_key}.
         *
         * @stability stable
         */
        readonly hashKey: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table_item.html#item DynamodbTableItem#item}.
         *
         * @stability stable
         */
        readonly item: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table_item.html#range_key DynamodbTableItem#range_key}.
         *
         * @stability stable
         */
        readonly rangeKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table_item.html#table_name DynamodbTableItem#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table_item.html aws_dynamodb_table_item}.
     *
     * @stability stable
     */
    class DynamodbTableItem extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_table_item.html aws_dynamodb_table_item} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DynamodbTableItemConfig);
        private _hashKey?;
        /**
         * @stability stable
         */
        get hashKey(): string;
        /**
         * @stability stable
         */
        set hashKey(value: string);
        /**
         * @stability stable
         */
        get hashKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _item?;
        /**
         * @stability stable
         */
        get item(): string;
        /**
         * @stability stable
         */
        set item(value: string);
        /**
         * @stability stable
         */
        get itemInput(): string | undefined;
        private _rangeKey?;
        /**
         * @stability stable
         */
        get rangeKey(): string | undefined;
        /**
         * @stability stable
         */
        set rangeKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetRangeKey(): void;
        /**
         * @stability stable
         */
        get rangeKeyInput(): string | undefined;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DynamodbTagConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_tag.html#key DynamodbTag#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_tag.html#resource_arn DynamodbTag#resource_arn}.
         *
         * @stability stable
         */
        readonly resourceArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_tag.html#value DynamodbTag#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_tag.html aws_dynamodb_tag}.
     *
     * @stability stable
     */
    class DynamodbTag extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/dynamodb_tag.html aws_dynamodb_tag} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DynamodbTagConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        set key(value: string);
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _resourceArn?;
        /**
         * @stability stable
         */
        get resourceArn(): string;
        /**
         * @stability stable
         */
        set resourceArn(value: string);
        /**
         * @stability stable
         */
        get resourceArnInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        set value(value: string);
        /**
         * @stability stable
         */
        get valueInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDynamodbTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table.html#name DataAwsDynamodbTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table.html#tags DataAwsDynamodbTable#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * server_side_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table.html#server_side_encryption DataAwsDynamodbTable#server_side_encryption}
         *
         * @stability stable
         */
        readonly serverSideEncryption?: DataAwsDynamodbTableServerSideEncryption;
    }
    /**
     * @stability stable
     */
    class DataAwsDynamodbTableAttribute extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsDynamodbTableGlobalSecondaryIndex extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get hashKey(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get nonKeyAttributes(): string[];
        /**
         * @stability stable
         */
        get projectionType(): string;
        /**
         * @stability stable
         */
        get rangeKey(): string;
        /**
         * @stability stable
         */
        get readCapacity(): number;
        /**
         * @stability stable
         */
        get writeCapacity(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsDynamodbTableLocalSecondaryIndex extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get nonKeyAttributes(): string[];
        /**
         * @stability stable
         */
        get projectionType(): string;
        /**
         * @stability stable
         */
        get rangeKey(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsDynamodbTablePointInTimeRecovery extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get enabled(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsDynamodbTableReplica extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get kmsKeyArn(): string;
        /**
         * @stability stable
         */
        get regionName(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsDynamodbTableTtl extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get attributeName(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
    }
    /**
     * @stability stable
     */
    interface DataAwsDynamodbTableServerSideEncryption {
    }
    /**
     * @stability stable
     */
    class DataAwsDynamodbTableServerSideEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table.html aws_dynamodb_table}.
     *
     * @stability stable
     */
    class DataAwsDynamodbTable extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/dynamodb_table.html aws_dynamodb_table} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDynamodbTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        attribute(index: string): DataAwsDynamodbTableAttribute;
        /**
         * @stability stable
         */
        get billingMode(): string;
        /**
         * @stability stable
         */
        globalSecondaryIndex(index: string): DataAwsDynamodbTableGlobalSecondaryIndex;
        /**
         * @stability stable
         */
        get hashKey(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        localSecondaryIndex(index: string): DataAwsDynamodbTableLocalSecondaryIndex;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        pointInTimeRecovery(index: string): DataAwsDynamodbTablePointInTimeRecovery;
        /**
         * @stability stable
         */
        get rangeKey(): string;
        /**
         * @stability stable
         */
        get readCapacity(): number;
        /**
         * @stability stable
         */
        replica(index: string): DataAwsDynamodbTableReplica;
        /**
         * @stability stable
         */
        get streamArn(): string;
        /**
         * @stability stable
         */
        get streamEnabled(): any;
        /**
         * @stability stable
         */
        get streamLabel(): string;
        /**
         * @stability stable
         */
        get streamViewType(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        ttl(index: string): DataAwsDynamodbTableTtl;
        /**
         * @stability stable
         */
        get writeCapacity(): number;
        private _serverSideEncryption?;
        private __serverSideEncryptionOutput;
        /**
         * @stability stable
         */
        get serverSideEncryption(): DataAwsDynamodbTableServerSideEncryptionOutputReference;
        /**
         * @stability stable
         */
        putServerSideEncryption(value: DataAwsDynamodbTableServerSideEncryption | undefined): void;
        /**
         * @stability stable
         */
        resetServerSideEncryption(): void;
        /**
         * @stability stable
         */
        get serverSideEncryptionInput(): DataAwsDynamodbTableServerSideEncryption | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
