import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS EC2 Container Registry
*/
export declare namespace ECR {
    /**
     * @stability stable
     */
    interface EcrLifecyclePolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_lifecycle_policy.html#policy EcrLifecyclePolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_lifecycle_policy.html#repository EcrLifecyclePolicy#repository}.
         *
         * @stability stable
         */
        readonly repository: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecr_lifecycle_policy.html aws_ecr_lifecycle_policy}.
     *
     * @stability stable
     */
    class EcrLifecyclePolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecr_lifecycle_policy.html aws_ecr_lifecycle_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcrLifecyclePolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        get registryId(): string;
        private _repository?;
        /**
         * @stability stable
         */
        get repository(): string;
        /**
         * @stability stable
         */
        set repository(value: string);
        /**
         * @stability stable
         */
        get repositoryInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcrRegistryPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_registry_policy.html#policy EcrRegistryPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecr_registry_policy.html aws_ecr_registry_policy}.
     *
     * @stability stable
     */
    class EcrRegistryPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecr_registry_policy.html aws_ecr_registry_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcrRegistryPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        get registryId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcrReplicationConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * replication_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration.html#replication_configuration EcrReplicationConfiguration#replication_configuration}
         *
         * @stability stable
         */
        readonly replicationConfiguration?: EcrReplicationConfigurationReplicationConfiguration;
    }
    /**
     * @stability stable
     */
    interface EcrReplicationConfigurationReplicationConfigurationRuleDestination {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration.html#region EcrReplicationConfiguration#region}.
         *
         * @stability stable
         */
        readonly region: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration.html#registry_id EcrReplicationConfiguration#registry_id}.
         *
         * @stability stable
         */
        readonly registryId: string;
    }
    /**
     * @stability stable
     */
    interface EcrReplicationConfigurationReplicationConfigurationRule {
        /**
         * destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration.html#destination EcrReplicationConfiguration#destination}
         *
         * @stability stable
         */
        readonly destination: EcrReplicationConfigurationReplicationConfigurationRuleDestination[];
    }
    /**
     * @stability stable
     */
    class EcrReplicationConfigurationReplicationConfigurationRuleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _destination?;
        /**
         * @stability stable
         */
        get destination(): EcrReplicationConfigurationReplicationConfigurationRuleDestination[];
        /**
         * @stability stable
         */
        set destination(value: EcrReplicationConfigurationReplicationConfigurationRuleDestination[]);
        /**
         * @stability stable
         */
        get destinationInput(): EcrReplicationConfigurationReplicationConfigurationRuleDestination[] | undefined;
    }
    /**
     * @stability stable
     */
    interface EcrReplicationConfigurationReplicationConfiguration {
        /**
         * rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration.html#rule EcrReplicationConfiguration#rule}
         *
         * @stability stable
         */
        readonly rule: EcrReplicationConfigurationReplicationConfigurationRule;
    }
    /**
     * @stability stable
     */
    class EcrReplicationConfigurationReplicationConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _rule?;
        private __ruleOutput;
        /**
         * @stability stable
         */
        get rule(): EcrReplicationConfigurationReplicationConfigurationRuleOutputReference;
        /**
         * @stability stable
         */
        putRule(value: EcrReplicationConfigurationReplicationConfigurationRule): void;
        /**
         * @stability stable
         */
        get ruleInput(): EcrReplicationConfigurationReplicationConfigurationRule | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration.html aws_ecr_replication_configuration}.
     *
     * @stability stable
     */
    class EcrReplicationConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecr_replication_configuration.html aws_ecr_replication_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: EcrReplicationConfigurationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get registryId(): string;
        private _replicationConfiguration?;
        private __replicationConfigurationOutput;
        /**
         * @stability stable
         */
        get replicationConfiguration(): EcrReplicationConfigurationReplicationConfigurationOutputReference;
        /**
         * @stability stable
         */
        putReplicationConfiguration(value: EcrReplicationConfigurationReplicationConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetReplicationConfiguration(): void;
        /**
         * @stability stable
         */
        get replicationConfigurationInput(): EcrReplicationConfigurationReplicationConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcrRepositoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#image_tag_mutability EcrRepository#image_tag_mutability}.
         *
         * @stability stable
         */
        readonly imageTagMutability?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#name EcrRepository#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#tags EcrRepository#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#tags_all EcrRepository#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * encryption_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#encryption_configuration EcrRepository#encryption_configuration}
         *
         * @stability stable
         */
        readonly encryptionConfiguration?: EcrRepositoryEncryptionConfiguration[];
        /**
         * image_scanning_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#image_scanning_configuration EcrRepository#image_scanning_configuration}
         *
         * @stability stable
         */
        readonly imageScanningConfiguration?: EcrRepositoryImageScanningConfiguration;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#timeouts EcrRepository#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: EcrRepositoryTimeouts;
    }
    /**
     * @stability stable
     */
    interface EcrRepositoryEncryptionConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#encryption_type EcrRepository#encryption_type}.
         *
         * @stability stable
         */
        readonly encryptionType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#kms_key EcrRepository#kms_key}.
         *
         * @stability stable
         */
        readonly kmsKey?: string;
    }
    /**
     * @stability stable
     */
    interface EcrRepositoryImageScanningConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#scan_on_push EcrRepository#scan_on_push}.
         *
         * @stability stable
         */
        readonly scanOnPush: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class EcrRepositoryImageScanningConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _scanOnPush?;
        /**
         * @stability stable
         */
        get scanOnPush(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set scanOnPush(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get scanOnPushInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface EcrRepositoryTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html#delete EcrRepository#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class EcrRepositoryTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html aws_ecr_repository}.
     *
     * @stability stable
     */
    class EcrRepository extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository.html aws_ecr_repository} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcrRepositoryConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _imageTagMutability?;
        /**
         * @stability stable
         */
        get imageTagMutability(): string | undefined;
        /**
         * @stability stable
         */
        set imageTagMutability(value: string | undefined);
        /**
         * @stability stable
         */
        resetImageTagMutability(): void;
        /**
         * @stability stable
         */
        get imageTagMutabilityInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get registryId(): string;
        /**
         * @stability stable
         */
        get repositoryUrl(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _encryptionConfiguration?;
        /**
         * @stability stable
         */
        get encryptionConfiguration(): EcrRepositoryEncryptionConfiguration[] | undefined;
        /**
         * @stability stable
         */
        set encryptionConfiguration(value: EcrRepositoryEncryptionConfiguration[] | undefined);
        /**
         * @stability stable
         */
        resetEncryptionConfiguration(): void;
        /**
         * @stability stable
         */
        get encryptionConfigurationInput(): EcrRepositoryEncryptionConfiguration[] | undefined;
        private _imageScanningConfiguration?;
        private __imageScanningConfigurationOutput;
        /**
         * @stability stable
         */
        get imageScanningConfiguration(): EcrRepositoryImageScanningConfigurationOutputReference;
        /**
         * @stability stable
         */
        putImageScanningConfiguration(value: EcrRepositoryImageScanningConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetImageScanningConfiguration(): void;
        /**
         * @stability stable
         */
        get imageScanningConfigurationInput(): EcrRepositoryImageScanningConfiguration | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): EcrRepositoryTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: EcrRepositoryTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): EcrRepositoryTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcrRepositoryPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository_policy.html#policy EcrRepositoryPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository_policy.html#repository EcrRepositoryPolicy#repository}.
         *
         * @stability stable
         */
        readonly repository: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository_policy.html aws_ecr_repository_policy}.
     *
     * @stability stable
     */
    class EcrRepositoryPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecr_repository_policy.html aws_ecr_repository_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcrRepositoryPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        get registryId(): string;
        private _repository?;
        /**
         * @stability stable
         */
        get repository(): string;
        /**
         * @stability stable
         */
        set repository(value: string);
        /**
         * @stability stable
         */
        get repositoryInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcrpublicRepositoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#force_destroy EcrpublicRepository#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#repository_name EcrpublicRepository#repository_name}.
         *
         * @stability stable
         */
        readonly repositoryName: string;
        /**
         * catalog_data block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#catalog_data EcrpublicRepository#catalog_data}
         *
         * @stability stable
         */
        readonly catalogData?: EcrpublicRepositoryCatalogData;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#timeouts EcrpublicRepository#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: EcrpublicRepositoryTimeouts;
    }
    /**
     * @stability stable
     */
    interface EcrpublicRepositoryCatalogData {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#about_text EcrpublicRepository#about_text}.
         *
         * @stability stable
         */
        readonly aboutText?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#architectures EcrpublicRepository#architectures}.
         *
         * @stability stable
         */
        readonly architectures?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#description EcrpublicRepository#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#logo_image_blob EcrpublicRepository#logo_image_blob}.
         *
         * @stability stable
         */
        readonly logoImageBlob?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#operating_systems EcrpublicRepository#operating_systems}.
         *
         * @stability stable
         */
        readonly operatingSystems?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#usage_text EcrpublicRepository#usage_text}.
         *
         * @stability stable
         */
        readonly usageText?: string;
    }
    /**
     * @stability stable
     */
    class EcrpublicRepositoryCatalogDataOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _aboutText?;
        /**
         * @stability stable
         */
        get aboutText(): string | undefined;
        /**
         * @stability stable
         */
        set aboutText(value: string | undefined);
        /**
         * @stability stable
         */
        resetAboutText(): void;
        /**
         * @stability stable
         */
        get aboutTextInput(): string | undefined;
        private _architectures?;
        /**
         * @stability stable
         */
        get architectures(): string[] | undefined;
        /**
         * @stability stable
         */
        set architectures(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetArchitectures(): void;
        /**
         * @stability stable
         */
        get architecturesInput(): string[] | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _logoImageBlob?;
        /**
         * @stability stable
         */
        get logoImageBlob(): string | undefined;
        /**
         * @stability stable
         */
        set logoImageBlob(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogoImageBlob(): void;
        /**
         * @stability stable
         */
        get logoImageBlobInput(): string | undefined;
        private _operatingSystems?;
        /**
         * @stability stable
         */
        get operatingSystems(): string[] | undefined;
        /**
         * @stability stable
         */
        set operatingSystems(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetOperatingSystems(): void;
        /**
         * @stability stable
         */
        get operatingSystemsInput(): string[] | undefined;
        private _usageText?;
        /**
         * @stability stable
         */
        get usageText(): string | undefined;
        /**
         * @stability stable
         */
        set usageText(value: string | undefined);
        /**
         * @stability stable
         */
        resetUsageText(): void;
        /**
         * @stability stable
         */
        get usageTextInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcrpublicRepositoryTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html#delete EcrpublicRepository#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class EcrpublicRepositoryTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html aws_ecrpublic_repository}.
     *
     * @stability stable
     */
    class EcrpublicRepository extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecrpublic_repository.html aws_ecrpublic_repository} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcrpublicRepositoryConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get registryId(): string;
        private _repositoryName?;
        /**
         * @stability stable
         */
        get repositoryName(): string;
        /**
         * @stability stable
         */
        set repositoryName(value: string);
        /**
         * @stability stable
         */
        get repositoryNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get repositoryUri(): string;
        private _catalogData?;
        private __catalogDataOutput;
        /**
         * @stability stable
         */
        get catalogData(): EcrpublicRepositoryCatalogDataOutputReference;
        /**
         * @stability stable
         */
        putCatalogData(value: EcrpublicRepositoryCatalogData | undefined): void;
        /**
         * @stability stable
         */
        resetCatalogData(): void;
        /**
         * @stability stable
         */
        get catalogDataInput(): EcrpublicRepositoryCatalogData | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): EcrpublicRepositoryTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: EcrpublicRepositoryTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): EcrpublicRepositoryTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEcrAuthorizationTokenConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_authorization_token.html#registry_id DataAwsEcrAuthorizationToken#registry_id}.
         *
         * @stability stable
         */
        readonly registryId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecr_authorization_token.html aws_ecr_authorization_token}.
     *
     * @stability stable
     */
    class DataAwsEcrAuthorizationToken extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecr_authorization_token.html aws_ecr_authorization_token} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsEcrAuthorizationTokenConfig);
        /**
         * @stability stable
         */
        get authorizationToken(): string;
        /**
         * @stability stable
         */
        get expiresAt(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get password(): string;
        /**
         * @stability stable
         */
        get proxyEndpoint(): string;
        private _registryId?;
        /**
         * @stability stable
         */
        get registryId(): string | undefined;
        /**
         * @stability stable
         */
        set registryId(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegistryId(): void;
        /**
         * @stability stable
         */
        get registryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get userName(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEcrImageConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_image.html#image_digest DataAwsEcrImage#image_digest}.
         *
         * @stability stable
         */
        readonly imageDigest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_image.html#image_tag DataAwsEcrImage#image_tag}.
         *
         * @stability stable
         */
        readonly imageTag?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_image.html#registry_id DataAwsEcrImage#registry_id}.
         *
         * @stability stable
         */
        readonly registryId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_image.html#repository_name DataAwsEcrImage#repository_name}.
         *
         * @stability stable
         */
        readonly repositoryName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecr_image.html aws_ecr_image}.
     *
     * @stability stable
     */
    class DataAwsEcrImage extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecr_image.html aws_ecr_image} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEcrImageConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _imageDigest?;
        /**
         * @stability stable
         */
        get imageDigest(): string | undefined;
        /**
         * @stability stable
         */
        set imageDigest(value: string | undefined);
        /**
         * @stability stable
         */
        resetImageDigest(): void;
        /**
         * @stability stable
         */
        get imageDigestInput(): string | undefined;
        /**
         * @stability stable
         */
        get imagePushedAt(): number;
        /**
         * @stability stable
         */
        get imageSizeInBytes(): number;
        private _imageTag?;
        /**
         * @stability stable
         */
        get imageTag(): string | undefined;
        /**
         * @stability stable
         */
        set imageTag(value: string | undefined);
        /**
         * @stability stable
         */
        resetImageTag(): void;
        /**
         * @stability stable
         */
        get imageTagInput(): string | undefined;
        /**
         * @stability stable
         */
        get imageTags(): string[];
        private _registryId?;
        /**
         * @stability stable
         */
        get registryId(): string | undefined;
        /**
         * @stability stable
         */
        set registryId(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegistryId(): void;
        /**
         * @stability stable
         */
        get registryIdInput(): string | undefined;
        private _repositoryName?;
        /**
         * @stability stable
         */
        get repositoryName(): string;
        /**
         * @stability stable
         */
        set repositoryName(value: string);
        /**
         * @stability stable
         */
        get repositoryNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEcrRepositoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository.html#name DataAwsEcrRepository#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository.html#registry_id DataAwsEcrRepository#registry_id}.
         *
         * @stability stable
         */
        readonly registryId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository.html#tags DataAwsEcrRepository#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsEcrRepositoryEncryptionConfiguration extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get encryptionType(): string;
        /**
         * @stability stable
         */
        get kmsKey(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsEcrRepositoryImageScanningConfiguration extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get scanOnPush(): any;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository.html aws_ecr_repository}.
     *
     * @stability stable
     */
    class DataAwsEcrRepository extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecr_repository.html aws_ecr_repository} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEcrRepositoryConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        encryptionConfiguration(index: string): DataAwsEcrRepositoryEncryptionConfiguration;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        imageScanningConfiguration(index: string): DataAwsEcrRepositoryImageScanningConfiguration;
        /**
         * @stability stable
         */
        get imageTagMutability(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _registryId?;
        /**
         * @stability stable
         */
        get registryId(): string | undefined;
        /**
         * @stability stable
         */
        set registryId(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegistryId(): void;
        /**
         * @stability stable
         */
        get registryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get repositoryUrl(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
