import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS EC2 Container Service
*/
export declare namespace ECS {
    /**
     * @stability stable
     */
    interface EcsCapacityProviderConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#name EcsCapacityProvider#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#tags EcsCapacityProvider#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#tags_all EcsCapacityProvider#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * auto_scaling_group_provider block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#auto_scaling_group_provider EcsCapacityProvider#auto_scaling_group_provider}
         *
         * @stability stable
         */
        readonly autoScalingGroupProvider: EcsCapacityProviderAutoScalingGroupProvider;
    }
    /**
     * @stability stable
     */
    interface EcsCapacityProviderAutoScalingGroupProviderManagedScaling {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#instance_warmup_period EcsCapacityProvider#instance_warmup_period}.
         *
         * @stability stable
         */
        readonly instanceWarmupPeriod?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#maximum_scaling_step_size EcsCapacityProvider#maximum_scaling_step_size}.
         *
         * @stability stable
         */
        readonly maximumScalingStepSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#minimum_scaling_step_size EcsCapacityProvider#minimum_scaling_step_size}.
         *
         * @stability stable
         */
        readonly minimumScalingStepSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#status EcsCapacityProvider#status}.
         *
         * @stability stable
         */
        readonly status?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#target_capacity EcsCapacityProvider#target_capacity}.
         *
         * @stability stable
         */
        readonly targetCapacity?: number;
    }
    /**
     * @stability stable
     */
    class EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceWarmupPeriod?;
        /**
         * @stability stable
         */
        get instanceWarmupPeriod(): number | undefined;
        /**
         * @stability stable
         */
        set instanceWarmupPeriod(value: number | undefined);
        /**
         * @stability stable
         */
        resetInstanceWarmupPeriod(): void;
        /**
         * @stability stable
         */
        get instanceWarmupPeriodInput(): number | undefined;
        private _maximumScalingStepSize?;
        /**
         * @stability stable
         */
        get maximumScalingStepSize(): number | undefined;
        /**
         * @stability stable
         */
        set maximumScalingStepSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaximumScalingStepSize(): void;
        /**
         * @stability stable
         */
        get maximumScalingStepSizeInput(): number | undefined;
        private _minimumScalingStepSize?;
        /**
         * @stability stable
         */
        get minimumScalingStepSize(): number | undefined;
        /**
         * @stability stable
         */
        set minimumScalingStepSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinimumScalingStepSize(): void;
        /**
         * @stability stable
         */
        get minimumScalingStepSizeInput(): number | undefined;
        private _status?;
        /**
         * @stability stable
         */
        get status(): string | undefined;
        /**
         * @stability stable
         */
        set status(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatus(): void;
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
        private _targetCapacity?;
        /**
         * @stability stable
         */
        get targetCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set targetCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetTargetCapacity(): void;
        /**
         * @stability stable
         */
        get targetCapacityInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsCapacityProviderAutoScalingGroupProvider {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#auto_scaling_group_arn EcsCapacityProvider#auto_scaling_group_arn}.
         *
         * @stability stable
         */
        readonly autoScalingGroupArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#managed_termination_protection EcsCapacityProvider#managed_termination_protection}.
         *
         * @stability stable
         */
        readonly managedTerminationProtection?: string;
        /**
         * managed_scaling block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html#managed_scaling EcsCapacityProvider#managed_scaling}
         *
         * @stability stable
         */
        readonly managedScaling?: EcsCapacityProviderAutoScalingGroupProviderManagedScaling;
    }
    /**
     * @stability stable
     */
    class EcsCapacityProviderAutoScalingGroupProviderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _autoScalingGroupArn?;
        /**
         * @stability stable
         */
        get autoScalingGroupArn(): string;
        /**
         * @stability stable
         */
        set autoScalingGroupArn(value: string);
        /**
         * @stability stable
         */
        get autoScalingGroupArnInput(): string | undefined;
        private _managedTerminationProtection?;
        /**
         * @stability stable
         */
        get managedTerminationProtection(): string | undefined;
        /**
         * @stability stable
         */
        set managedTerminationProtection(value: string | undefined);
        /**
         * @stability stable
         */
        resetManagedTerminationProtection(): void;
        /**
         * @stability stable
         */
        get managedTerminationProtectionInput(): string | undefined;
        private _managedScaling?;
        private __managedScalingOutput;
        /**
         * @stability stable
         */
        get managedScaling(): EcsCapacityProviderAutoScalingGroupProviderManagedScalingOutputReference;
        /**
         * @stability stable
         */
        putManagedScaling(value: EcsCapacityProviderAutoScalingGroupProviderManagedScaling | undefined): void;
        /**
         * @stability stable
         */
        resetManagedScaling(): void;
        /**
         * @stability stable
         */
        get managedScalingInput(): EcsCapacityProviderAutoScalingGroupProviderManagedScaling | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html aws_ecs_capacity_provider}.
     *
     * @stability stable
     */
    class EcsCapacityProvider extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_capacity_provider.html aws_ecs_capacity_provider} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcsCapacityProviderConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _autoScalingGroupProvider?;
        private __autoScalingGroupProviderOutput;
        /**
         * @stability stable
         */
        get autoScalingGroupProvider(): EcsCapacityProviderAutoScalingGroupProviderOutputReference;
        /**
         * @stability stable
         */
        putAutoScalingGroupProvider(value: EcsCapacityProviderAutoScalingGroupProvider): void;
        /**
         * @stability stable
         */
        get autoScalingGroupProviderInput(): EcsCapacityProviderAutoScalingGroupProvider | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcsClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#capacity_providers EcsCluster#capacity_providers}.
         *
         * @stability stable
         */
        readonly capacityProviders?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#name EcsCluster#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#tags EcsCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#tags_all EcsCluster#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#configuration EcsCluster#configuration}
         *
         * @stability stable
         */
        readonly configuration?: EcsClusterConfiguration;
        /**
         * default_capacity_provider_strategy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#default_capacity_provider_strategy EcsCluster#default_capacity_provider_strategy}
         *
         * @stability stable
         */
        readonly defaultCapacityProviderStrategy?: EcsClusterDefaultCapacityProviderStrategy[];
        /**
         * setting block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#setting EcsCluster#setting}
         *
         * @stability stable
         */
        readonly setting?: EcsClusterSetting[];
    }
    /**
     * @stability stable
     */
    interface EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#cloud_watch_encryption_enabled EcsCluster#cloud_watch_encryption_enabled}.
         *
         * @stability stable
         */
        readonly cloudWatchEncryptionEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#cloud_watch_log_group_name EcsCluster#cloud_watch_log_group_name}.
         *
         * @stability stable
         */
        readonly cloudWatchLogGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#s3_bucket_encryption_enabled EcsCluster#s3_bucket_encryption_enabled}.
         *
         * @stability stable
         */
        readonly s3BucketEncryptionEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#s3_bucket_name EcsCluster#s3_bucket_name}.
         *
         * @stability stable
         */
        readonly s3BucketName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#s3_key_prefix EcsCluster#s3_key_prefix}.
         *
         * @stability stable
         */
        readonly s3KeyPrefix?: string;
    }
    /**
     * @stability stable
     */
    class EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cloudWatchEncryptionEnabled?;
        /**
         * @stability stable
         */
        get cloudWatchEncryptionEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set cloudWatchEncryptionEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCloudWatchEncryptionEnabled(): void;
        /**
         * @stability stable
         */
        get cloudWatchEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _cloudWatchLogGroupName?;
        /**
         * @stability stable
         */
        get cloudWatchLogGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set cloudWatchLogGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetCloudWatchLogGroupName(): void;
        /**
         * @stability stable
         */
        get cloudWatchLogGroupNameInput(): string | undefined;
        private _s3BucketEncryptionEnabled?;
        /**
         * @stability stable
         */
        get s3BucketEncryptionEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set s3BucketEncryptionEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetS3BucketEncryptionEnabled(): void;
        /**
         * @stability stable
         */
        get s3BucketEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _s3BucketName?;
        /**
         * @stability stable
         */
        get s3BucketName(): string | undefined;
        /**
         * @stability stable
         */
        set s3BucketName(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3BucketName(): void;
        /**
         * @stability stable
         */
        get s3BucketNameInput(): string | undefined;
        private _s3KeyPrefix?;
        /**
         * @stability stable
         */
        get s3KeyPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set s3KeyPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3KeyPrefix(): void;
        /**
         * @stability stable
         */
        get s3KeyPrefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsClusterConfigurationExecuteCommandConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#kms_key_id EcsCluster#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#logging EcsCluster#logging}.
         *
         * @stability stable
         */
        readonly logging?: string;
        /**
         * log_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#log_configuration EcsCluster#log_configuration}
         *
         * @stability stable
         */
        readonly logConfiguration?: EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration;
    }
    /**
     * @stability stable
     */
    class EcsClusterConfigurationExecuteCommandConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _logging?;
        /**
         * @stability stable
         */
        get logging(): string | undefined;
        /**
         * @stability stable
         */
        set logging(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogging(): void;
        /**
         * @stability stable
         */
        get loggingInput(): string | undefined;
        private _logConfiguration?;
        private __logConfigurationOutput;
        /**
         * @stability stable
         */
        get logConfiguration(): EcsClusterConfigurationExecuteCommandConfigurationLogConfigurationOutputReference;
        /**
         * @stability stable
         */
        putLogConfiguration(value: EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetLogConfiguration(): void;
        /**
         * @stability stable
         */
        get logConfigurationInput(): EcsClusterConfigurationExecuteCommandConfigurationLogConfiguration | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsClusterConfiguration {
        /**
         * execute_command_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#execute_command_configuration EcsCluster#execute_command_configuration}
         *
         * @stability stable
         */
        readonly executeCommandConfiguration?: EcsClusterConfigurationExecuteCommandConfiguration;
    }
    /**
     * @stability stable
     */
    class EcsClusterConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _executeCommandConfiguration?;
        private __executeCommandConfigurationOutput;
        /**
         * @stability stable
         */
        get executeCommandConfiguration(): EcsClusterConfigurationExecuteCommandConfigurationOutputReference;
        /**
         * @stability stable
         */
        putExecuteCommandConfiguration(value: EcsClusterConfigurationExecuteCommandConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetExecuteCommandConfiguration(): void;
        /**
         * @stability stable
         */
        get executeCommandConfigurationInput(): EcsClusterConfigurationExecuteCommandConfiguration | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsClusterDefaultCapacityProviderStrategy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#base EcsCluster#base}.
         *
         * @stability stable
         */
        readonly base?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#capacity_provider EcsCluster#capacity_provider}.
         *
         * @stability stable
         */
        readonly capacityProvider: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#weight EcsCluster#weight}.
         *
         * @stability stable
         */
        readonly weight?: number;
    }
    /**
     * @stability stable
     */
    interface EcsClusterSetting {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#name EcsCluster#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html#value EcsCluster#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html aws_ecs_cluster}.
     *
     * @stability stable
     */
    class EcsCluster extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_cluster.html aws_ecs_cluster} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcsClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _capacityProviders?;
        /**
         * @stability stable
         */
        get capacityProviders(): string[] | undefined;
        /**
         * @stability stable
         */
        set capacityProviders(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCapacityProviders(): void;
        /**
         * @stability stable
         */
        get capacityProvidersInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _configuration?;
        private __configurationOutput;
        /**
         * @stability stable
         */
        get configuration(): EcsClusterConfigurationOutputReference;
        /**
         * @stability stable
         */
        putConfiguration(value: EcsClusterConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetConfiguration(): void;
        /**
         * @stability stable
         */
        get configurationInput(): EcsClusterConfiguration | undefined;
        private _defaultCapacityProviderStrategy?;
        /**
         * @stability stable
         */
        get defaultCapacityProviderStrategy(): EcsClusterDefaultCapacityProviderStrategy[] | undefined;
        /**
         * @stability stable
         */
        set defaultCapacityProviderStrategy(value: EcsClusterDefaultCapacityProviderStrategy[] | undefined);
        /**
         * @stability stable
         */
        resetDefaultCapacityProviderStrategy(): void;
        /**
         * @stability stable
         */
        get defaultCapacityProviderStrategyInput(): EcsClusterDefaultCapacityProviderStrategy[] | undefined;
        private _setting?;
        /**
         * @stability stable
         */
        get setting(): EcsClusterSetting[] | undefined;
        /**
         * @stability stable
         */
        set setting(value: EcsClusterSetting[] | undefined);
        /**
         * @stability stable
         */
        resetSetting(): void;
        /**
         * @stability stable
         */
        get settingInput(): EcsClusterSetting[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcsServiceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#cluster EcsService#cluster}.
         *
         * @stability stable
         */
        readonly cluster?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#deployment_maximum_percent EcsService#deployment_maximum_percent}.
         *
         * @stability stable
         */
        readonly deploymentMaximumPercent?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#deployment_minimum_healthy_percent EcsService#deployment_minimum_healthy_percent}.
         *
         * @stability stable
         */
        readonly deploymentMinimumHealthyPercent?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#desired_count EcsService#desired_count}.
         *
         * @stability stable
         */
        readonly desiredCount?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#enable_ecs_managed_tags EcsService#enable_ecs_managed_tags}.
         *
         * @stability stable
         */
        readonly enableEcsManagedTags?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#enable_execute_command EcsService#enable_execute_command}.
         *
         * @stability stable
         */
        readonly enableExecuteCommand?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#force_new_deployment EcsService#force_new_deployment}.
         *
         * @stability stable
         */
        readonly forceNewDeployment?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#health_check_grace_period_seconds EcsService#health_check_grace_period_seconds}.
         *
         * @stability stable
         */
        readonly healthCheckGracePeriodSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#iam_role EcsService#iam_role}.
         *
         * @stability stable
         */
        readonly iamRole?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#launch_type EcsService#launch_type}.
         *
         * @stability stable
         */
        readonly launchType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#name EcsService#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#platform_version EcsService#platform_version}.
         *
         * @stability stable
         */
        readonly platformVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#propagate_tags EcsService#propagate_tags}.
         *
         * @stability stable
         */
        readonly propagateTags?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#scheduling_strategy EcsService#scheduling_strategy}.
         *
         * @stability stable
         */
        readonly schedulingStrategy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#tags EcsService#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#tags_all EcsService#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#task_definition EcsService#task_definition}.
         *
         * @stability stable
         */
        readonly taskDefinition?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#wait_for_steady_state EcsService#wait_for_steady_state}.
         *
         * @stability stable
         */
        readonly waitForSteadyState?: boolean | cdktf.IResolvable;
        /**
         * capacity_provider_strategy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#capacity_provider_strategy EcsService#capacity_provider_strategy}
         *
         * @stability stable
         */
        readonly capacityProviderStrategy?: EcsServiceCapacityProviderStrategy[];
        /**
         * deployment_circuit_breaker block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#deployment_circuit_breaker EcsService#deployment_circuit_breaker}
         *
         * @stability stable
         */
        readonly deploymentCircuitBreaker?: EcsServiceDeploymentCircuitBreaker;
        /**
         * deployment_controller block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#deployment_controller EcsService#deployment_controller}
         *
         * @stability stable
         */
        readonly deploymentController?: EcsServiceDeploymentController;
        /**
         * load_balancer block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#load_balancer EcsService#load_balancer}
         *
         * @stability stable
         */
        readonly loadBalancer?: EcsServiceLoadBalancer[];
        /**
         * network_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#network_configuration EcsService#network_configuration}
         *
         * @stability stable
         */
        readonly networkConfiguration?: EcsServiceNetworkConfiguration;
        /**
         * ordered_placement_strategy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#ordered_placement_strategy EcsService#ordered_placement_strategy}
         *
         * @stability stable
         */
        readonly orderedPlacementStrategy?: EcsServiceOrderedPlacementStrategy[];
        /**
         * placement_constraints block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#placement_constraints EcsService#placement_constraints}
         *
         * @stability stable
         */
        readonly placementConstraints?: EcsServicePlacementConstraints[];
        /**
         * service_registries block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#service_registries EcsService#service_registries}
         *
         * @stability stable
         */
        readonly serviceRegistries?: EcsServiceServiceRegistries;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#timeouts EcsService#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: EcsServiceTimeouts;
    }
    /**
     * @stability stable
     */
    interface EcsServiceCapacityProviderStrategy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#base EcsService#base}.
         *
         * @stability stable
         */
        readonly base?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#capacity_provider EcsService#capacity_provider}.
         *
         * @stability stable
         */
        readonly capacityProvider: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#weight EcsService#weight}.
         *
         * @stability stable
         */
        readonly weight?: number;
    }
    /**
     * @stability stable
     */
    interface EcsServiceDeploymentCircuitBreaker {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#enable EcsService#enable}.
         *
         * @stability stable
         */
        readonly enable: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#rollback EcsService#rollback}.
         *
         * @stability stable
         */
        readonly rollback: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class EcsServiceDeploymentCircuitBreakerOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enable?;
        /**
         * @stability stable
         */
        get enable(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enable(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enableInput(): boolean | cdktf.IResolvable | undefined;
        private _rollback?;
        /**
         * @stability stable
         */
        get rollback(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set rollback(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get rollbackInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsServiceDeploymentController {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#type EcsService#type}.
         *
         * @stability stable
         */
        readonly type?: string;
    }
    /**
     * @stability stable
     */
    class EcsServiceDeploymentControllerOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsServiceLoadBalancer {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#container_name EcsService#container_name}.
         *
         * @stability stable
         */
        readonly containerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#container_port EcsService#container_port}.
         *
         * @stability stable
         */
        readonly containerPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#elb_name EcsService#elb_name}.
         *
         * @stability stable
         */
        readonly elbName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#target_group_arn EcsService#target_group_arn}.
         *
         * @stability stable
         */
        readonly targetGroupArn?: string;
    }
    /**
     * @stability stable
     */
    interface EcsServiceNetworkConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#assign_public_ip EcsService#assign_public_ip}.
         *
         * @stability stable
         */
        readonly assignPublicIp?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#security_groups EcsService#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#subnets EcsService#subnets}.
         *
         * @stability stable
         */
        readonly subnets: string[];
    }
    /**
     * @stability stable
     */
    class EcsServiceNetworkConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _assignPublicIp?;
        /**
         * @stability stable
         */
        get assignPublicIp(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set assignPublicIp(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAssignPublicIp(): void;
        /**
         * @stability stable
         */
        get assignPublicIpInput(): boolean | cdktf.IResolvable | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _subnets?;
        /**
         * @stability stable
         */
        get subnets(): string[];
        /**
         * @stability stable
         */
        set subnets(value: string[]);
        /**
         * @stability stable
         */
        get subnetsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsServiceOrderedPlacementStrategy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#field EcsService#field}.
         *
         * @stability stable
         */
        readonly field?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#type EcsService#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    interface EcsServicePlacementConstraints {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#expression EcsService#expression}.
         *
         * @stability stable
         */
        readonly expression?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#type EcsService#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    interface EcsServiceServiceRegistries {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#container_name EcsService#container_name}.
         *
         * @stability stable
         */
        readonly containerName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#container_port EcsService#container_port}.
         *
         * @stability stable
         */
        readonly containerPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#port EcsService#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#registry_arn EcsService#registry_arn}.
         *
         * @stability stable
         */
        readonly registryArn: string;
    }
    /**
     * @stability stable
     */
    class EcsServiceServiceRegistriesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _containerName?;
        /**
         * @stability stable
         */
        get containerName(): string | undefined;
        /**
         * @stability stable
         */
        set containerName(value: string | undefined);
        /**
         * @stability stable
         */
        resetContainerName(): void;
        /**
         * @stability stable
         */
        get containerNameInput(): string | undefined;
        private _containerPort?;
        /**
         * @stability stable
         */
        get containerPort(): number | undefined;
        /**
         * @stability stable
         */
        set containerPort(value: number | undefined);
        /**
         * @stability stable
         */
        resetContainerPort(): void;
        /**
         * @stability stable
         */
        get containerPortInput(): number | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _registryArn?;
        /**
         * @stability stable
         */
        get registryArn(): string;
        /**
         * @stability stable
         */
        set registryArn(value: string);
        /**
         * @stability stable
         */
        get registryArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsServiceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html#delete EcsService#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class EcsServiceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html aws_ecs_service}.
     *
     * @stability stable
     */
    class EcsService extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_service.html aws_ecs_service} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcsServiceConfig);
        private _cluster?;
        /**
         * @stability stable
         */
        get cluster(): string | undefined;
        /**
         * @stability stable
         */
        set cluster(value: string | undefined);
        /**
         * @stability stable
         */
        resetCluster(): void;
        /**
         * @stability stable
         */
        get clusterInput(): string | undefined;
        private _deploymentMaximumPercent?;
        /**
         * @stability stable
         */
        get deploymentMaximumPercent(): number | undefined;
        /**
         * @stability stable
         */
        set deploymentMaximumPercent(value: number | undefined);
        /**
         * @stability stable
         */
        resetDeploymentMaximumPercent(): void;
        /**
         * @stability stable
         */
        get deploymentMaximumPercentInput(): number | undefined;
        private _deploymentMinimumHealthyPercent?;
        /**
         * @stability stable
         */
        get deploymentMinimumHealthyPercent(): number | undefined;
        /**
         * @stability stable
         */
        set deploymentMinimumHealthyPercent(value: number | undefined);
        /**
         * @stability stable
         */
        resetDeploymentMinimumHealthyPercent(): void;
        /**
         * @stability stable
         */
        get deploymentMinimumHealthyPercentInput(): number | undefined;
        private _desiredCount?;
        /**
         * @stability stable
         */
        get desiredCount(): number | undefined;
        /**
         * @stability stable
         */
        set desiredCount(value: number | undefined);
        /**
         * @stability stable
         */
        resetDesiredCount(): void;
        /**
         * @stability stable
         */
        get desiredCountInput(): number | undefined;
        private _enableEcsManagedTags?;
        /**
         * @stability stable
         */
        get enableEcsManagedTags(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableEcsManagedTags(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableEcsManagedTags(): void;
        /**
         * @stability stable
         */
        get enableEcsManagedTagsInput(): boolean | cdktf.IResolvable | undefined;
        private _enableExecuteCommand?;
        /**
         * @stability stable
         */
        get enableExecuteCommand(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableExecuteCommand(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableExecuteCommand(): void;
        /**
         * @stability stable
         */
        get enableExecuteCommandInput(): boolean | cdktf.IResolvable | undefined;
        private _forceNewDeployment?;
        /**
         * @stability stable
         */
        get forceNewDeployment(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceNewDeployment(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceNewDeployment(): void;
        /**
         * @stability stable
         */
        get forceNewDeploymentInput(): boolean | cdktf.IResolvable | undefined;
        private _healthCheckGracePeriodSeconds?;
        /**
         * @stability stable
         */
        get healthCheckGracePeriodSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set healthCheckGracePeriodSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetHealthCheckGracePeriodSeconds(): void;
        /**
         * @stability stable
         */
        get healthCheckGracePeriodSecondsInput(): number | undefined;
        private _iamRole?;
        /**
         * @stability stable
         */
        get iamRole(): string | undefined;
        /**
         * @stability stable
         */
        set iamRole(value: string | undefined);
        /**
         * @stability stable
         */
        resetIamRole(): void;
        /**
         * @stability stable
         */
        get iamRoleInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _launchType?;
        /**
         * @stability stable
         */
        get launchType(): string | undefined;
        /**
         * @stability stable
         */
        set launchType(value: string | undefined);
        /**
         * @stability stable
         */
        resetLaunchType(): void;
        /**
         * @stability stable
         */
        get launchTypeInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _platformVersion?;
        /**
         * @stability stable
         */
        get platformVersion(): string | undefined;
        /**
         * @stability stable
         */
        set platformVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetPlatformVersion(): void;
        /**
         * @stability stable
         */
        get platformVersionInput(): string | undefined;
        private _propagateTags?;
        /**
         * @stability stable
         */
        get propagateTags(): string | undefined;
        /**
         * @stability stable
         */
        set propagateTags(value: string | undefined);
        /**
         * @stability stable
         */
        resetPropagateTags(): void;
        /**
         * @stability stable
         */
        get propagateTagsInput(): string | undefined;
        private _schedulingStrategy?;
        /**
         * @stability stable
         */
        get schedulingStrategy(): string | undefined;
        /**
         * @stability stable
         */
        set schedulingStrategy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchedulingStrategy(): void;
        /**
         * @stability stable
         */
        get schedulingStrategyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _taskDefinition?;
        /**
         * @stability stable
         */
        get taskDefinition(): string | undefined;
        /**
         * @stability stable
         */
        set taskDefinition(value: string | undefined);
        /**
         * @stability stable
         */
        resetTaskDefinition(): void;
        /**
         * @stability stable
         */
        get taskDefinitionInput(): string | undefined;
        private _waitForSteadyState?;
        /**
         * @stability stable
         */
        get waitForSteadyState(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set waitForSteadyState(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWaitForSteadyState(): void;
        /**
         * @stability stable
         */
        get waitForSteadyStateInput(): boolean | cdktf.IResolvable | undefined;
        private _capacityProviderStrategy?;
        /**
         * @stability stable
         */
        get capacityProviderStrategy(): EcsServiceCapacityProviderStrategy[] | undefined;
        /**
         * @stability stable
         */
        set capacityProviderStrategy(value: EcsServiceCapacityProviderStrategy[] | undefined);
        /**
         * @stability stable
         */
        resetCapacityProviderStrategy(): void;
        /**
         * @stability stable
         */
        get capacityProviderStrategyInput(): EcsServiceCapacityProviderStrategy[] | undefined;
        private _deploymentCircuitBreaker?;
        private __deploymentCircuitBreakerOutput;
        /**
         * @stability stable
         */
        get deploymentCircuitBreaker(): EcsServiceDeploymentCircuitBreakerOutputReference;
        /**
         * @stability stable
         */
        putDeploymentCircuitBreaker(value: EcsServiceDeploymentCircuitBreaker | undefined): void;
        /**
         * @stability stable
         */
        resetDeploymentCircuitBreaker(): void;
        /**
         * @stability stable
         */
        get deploymentCircuitBreakerInput(): EcsServiceDeploymentCircuitBreaker | undefined;
        private _deploymentController?;
        private __deploymentControllerOutput;
        /**
         * @stability stable
         */
        get deploymentController(): EcsServiceDeploymentControllerOutputReference;
        /**
         * @stability stable
         */
        putDeploymentController(value: EcsServiceDeploymentController | undefined): void;
        /**
         * @stability stable
         */
        resetDeploymentController(): void;
        /**
         * @stability stable
         */
        get deploymentControllerInput(): EcsServiceDeploymentController | undefined;
        private _loadBalancer?;
        /**
         * @stability stable
         */
        get loadBalancer(): EcsServiceLoadBalancer[] | undefined;
        /**
         * @stability stable
         */
        set loadBalancer(value: EcsServiceLoadBalancer[] | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancer(): void;
        /**
         * @stability stable
         */
        get loadBalancerInput(): EcsServiceLoadBalancer[] | undefined;
        private _networkConfiguration?;
        private __networkConfigurationOutput;
        /**
         * @stability stable
         */
        get networkConfiguration(): EcsServiceNetworkConfigurationOutputReference;
        /**
         * @stability stable
         */
        putNetworkConfiguration(value: EcsServiceNetworkConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetNetworkConfiguration(): void;
        /**
         * @stability stable
         */
        get networkConfigurationInput(): EcsServiceNetworkConfiguration | undefined;
        private _orderedPlacementStrategy?;
        /**
         * @stability stable
         */
        get orderedPlacementStrategy(): EcsServiceOrderedPlacementStrategy[] | undefined;
        /**
         * @stability stable
         */
        set orderedPlacementStrategy(value: EcsServiceOrderedPlacementStrategy[] | undefined);
        /**
         * @stability stable
         */
        resetOrderedPlacementStrategy(): void;
        /**
         * @stability stable
         */
        get orderedPlacementStrategyInput(): EcsServiceOrderedPlacementStrategy[] | undefined;
        private _placementConstraints?;
        /**
         * @stability stable
         */
        get placementConstraints(): EcsServicePlacementConstraints[] | undefined;
        /**
         * @stability stable
         */
        set placementConstraints(value: EcsServicePlacementConstraints[] | undefined);
        /**
         * @stability stable
         */
        resetPlacementConstraints(): void;
        /**
         * @stability stable
         */
        get placementConstraintsInput(): EcsServicePlacementConstraints[] | undefined;
        private _serviceRegistries?;
        private __serviceRegistriesOutput;
        /**
         * @stability stable
         */
        get serviceRegistries(): EcsServiceServiceRegistriesOutputReference;
        /**
         * @stability stable
         */
        putServiceRegistries(value: EcsServiceServiceRegistries | undefined): void;
        /**
         * @stability stable
         */
        resetServiceRegistries(): void;
        /**
         * @stability stable
         */
        get serviceRegistriesInput(): EcsServiceServiceRegistries | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): EcsServiceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: EcsServiceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): EcsServiceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcsTagConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_tag.html#key EcsTag#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_tag.html#resource_arn EcsTag#resource_arn}.
         *
         * @stability stable
         */
        readonly resourceArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_tag.html#value EcsTag#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_tag.html aws_ecs_tag}.
     *
     * @stability stable
     */
    class EcsTag extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_tag.html aws_ecs_tag} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcsTagConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        set key(value: string);
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _resourceArn?;
        /**
         * @stability stable
         */
        get resourceArn(): string;
        /**
         * @stability stable
         */
        set resourceArn(value: string);
        /**
         * @stability stable
         */
        get resourceArnInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        set value(value: string);
        /**
         * @stability stable
         */
        get valueInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#container_definitions EcsTaskDefinition#container_definitions}.
         *
         * @stability stable
         */
        readonly containerDefinitions: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#cpu EcsTaskDefinition#cpu}.
         *
         * @stability stable
         */
        readonly cpu?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#execution_role_arn EcsTaskDefinition#execution_role_arn}.
         *
         * @stability stable
         */
        readonly executionRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#family EcsTaskDefinition#family}.
         *
         * @stability stable
         */
        readonly family: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#ipc_mode EcsTaskDefinition#ipc_mode}.
         *
         * @stability stable
         */
        readonly ipcMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#memory EcsTaskDefinition#memory}.
         *
         * @stability stable
         */
        readonly memory?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#network_mode EcsTaskDefinition#network_mode}.
         *
         * @stability stable
         */
        readonly networkMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#pid_mode EcsTaskDefinition#pid_mode}.
         *
         * @stability stable
         */
        readonly pidMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#requires_compatibilities EcsTaskDefinition#requires_compatibilities}.
         *
         * @stability stable
         */
        readonly requiresCompatibilities?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#tags EcsTaskDefinition#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#tags_all EcsTaskDefinition#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#task_role_arn EcsTaskDefinition#task_role_arn}.
         *
         * @stability stable
         */
        readonly taskRoleArn?: string;
        /**
         * ephemeral_storage block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#ephemeral_storage EcsTaskDefinition#ephemeral_storage}
         *
         * @stability stable
         */
        readonly ephemeralStorage?: EcsTaskDefinitionEphemeralStorage;
        /**
         * inference_accelerator block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#inference_accelerator EcsTaskDefinition#inference_accelerator}
         *
         * @stability stable
         */
        readonly inferenceAccelerator?: EcsTaskDefinitionInferenceAccelerator[];
        /**
         * placement_constraints block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#placement_constraints EcsTaskDefinition#placement_constraints}
         *
         * @stability stable
         */
        readonly placementConstraints?: EcsTaskDefinitionPlacementConstraints[];
        /**
         * proxy_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#proxy_configuration EcsTaskDefinition#proxy_configuration}
         *
         * @stability stable
         */
        readonly proxyConfiguration?: EcsTaskDefinitionProxyConfiguration;
        /**
         * volume block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#volume EcsTaskDefinition#volume}
         *
         * @stability stable
         */
        readonly volume?: EcsTaskDefinitionVolume[];
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionEphemeralStorage {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#size_in_gib EcsTaskDefinition#size_in_gib}.
         *
         * @stability stable
         */
        readonly sizeInGib: number;
    }
    /**
     * @stability stable
     */
    class EcsTaskDefinitionEphemeralStorageOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _sizeInGib?;
        /**
         * @stability stable
         */
        get sizeInGib(): number;
        /**
         * @stability stable
         */
        set sizeInGib(value: number);
        /**
         * @stability stable
         */
        get sizeInGibInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionInferenceAccelerator {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#device_name EcsTaskDefinition#device_name}.
         *
         * @stability stable
         */
        readonly deviceName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#device_type EcsTaskDefinition#device_type}.
         *
         * @stability stable
         */
        readonly deviceType: string;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionPlacementConstraints {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#expression EcsTaskDefinition#expression}.
         *
         * @stability stable
         */
        readonly expression?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#type EcsTaskDefinition#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionProxyConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#container_name EcsTaskDefinition#container_name}.
         *
         * @stability stable
         */
        readonly containerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#properties EcsTaskDefinition#properties}.
         *
         * @stability stable
         */
        readonly properties?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#type EcsTaskDefinition#type}.
         *
         * @stability stable
         */
        readonly type?: string;
    }
    /**
     * @stability stable
     */
    class EcsTaskDefinitionProxyConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _containerName?;
        /**
         * @stability stable
         */
        get containerName(): string;
        /**
         * @stability stable
         */
        set containerName(value: string);
        /**
         * @stability stable
         */
        get containerNameInput(): string | undefined;
        private _properties?;
        /**
         * @stability stable
         */
        get properties(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set properties(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetProperties(): void;
        /**
         * @stability stable
         */
        get propertiesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionVolumeDockerVolumeConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#autoprovision EcsTaskDefinition#autoprovision}.
         *
         * @stability stable
         */
        readonly autoprovision?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#driver EcsTaskDefinition#driver}.
         *
         * @stability stable
         */
        readonly driver?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#driver_opts EcsTaskDefinition#driver_opts}.
         *
         * @stability stable
         */
        readonly driverOpts?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#labels EcsTaskDefinition#labels}.
         *
         * @stability stable
         */
        readonly labels?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#scope EcsTaskDefinition#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
    }
    /**
     * @stability stable
     */
    class EcsTaskDefinitionVolumeDockerVolumeConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _autoprovision?;
        /**
         * @stability stable
         */
        get autoprovision(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoprovision(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoprovision(): void;
        /**
         * @stability stable
         */
        get autoprovisionInput(): boolean | cdktf.IResolvable | undefined;
        private _driver?;
        /**
         * @stability stable
         */
        get driver(): string | undefined;
        /**
         * @stability stable
         */
        set driver(value: string | undefined);
        /**
         * @stability stable
         */
        resetDriver(): void;
        /**
         * @stability stable
         */
        get driverInput(): string | undefined;
        private _driverOpts?;
        /**
         * @stability stable
         */
        get driverOpts(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set driverOpts(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDriverOpts(): void;
        /**
         * @stability stable
         */
        get driverOptsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _labels?;
        /**
         * @stability stable
         */
        get labels(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set labels(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetLabels(): void;
        /**
         * @stability stable
         */
        get labelsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#access_point_id EcsTaskDefinition#access_point_id}.
         *
         * @stability stable
         */
        readonly accessPointId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#iam EcsTaskDefinition#iam}.
         *
         * @stability stable
         */
        readonly iam?: string;
    }
    /**
     * @stability stable
     */
    class EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _accessPointId?;
        /**
         * @stability stable
         */
        get accessPointId(): string | undefined;
        /**
         * @stability stable
         */
        set accessPointId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccessPointId(): void;
        /**
         * @stability stable
         */
        get accessPointIdInput(): string | undefined;
        private _iam?;
        /**
         * @stability stable
         */
        get iam(): string | undefined;
        /**
         * @stability stable
         */
        set iam(value: string | undefined);
        /**
         * @stability stable
         */
        resetIam(): void;
        /**
         * @stability stable
         */
        get iamInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionVolumeEfsVolumeConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#file_system_id EcsTaskDefinition#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#root_directory EcsTaskDefinition#root_directory}.
         *
         * @stability stable
         */
        readonly rootDirectory?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#transit_encryption EcsTaskDefinition#transit_encryption}.
         *
         * @stability stable
         */
        readonly transitEncryption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#transit_encryption_port EcsTaskDefinition#transit_encryption_port}.
         *
         * @stability stable
         */
        readonly transitEncryptionPort?: number;
        /**
         * authorization_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#authorization_config EcsTaskDefinition#authorization_config}
         *
         * @stability stable
         */
        readonly authorizationConfig?: EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig;
    }
    /**
     * @stability stable
     */
    class EcsTaskDefinitionVolumeEfsVolumeConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        private _rootDirectory?;
        /**
         * @stability stable
         */
        get rootDirectory(): string | undefined;
        /**
         * @stability stable
         */
        set rootDirectory(value: string | undefined);
        /**
         * @stability stable
         */
        resetRootDirectory(): void;
        /**
         * @stability stable
         */
        get rootDirectoryInput(): string | undefined;
        private _transitEncryption?;
        /**
         * @stability stable
         */
        get transitEncryption(): string | undefined;
        /**
         * @stability stable
         */
        set transitEncryption(value: string | undefined);
        /**
         * @stability stable
         */
        resetTransitEncryption(): void;
        /**
         * @stability stable
         */
        get transitEncryptionInput(): string | undefined;
        private _transitEncryptionPort?;
        /**
         * @stability stable
         */
        get transitEncryptionPort(): number | undefined;
        /**
         * @stability stable
         */
        set transitEncryptionPort(value: number | undefined);
        /**
         * @stability stable
         */
        resetTransitEncryptionPort(): void;
        /**
         * @stability stable
         */
        get transitEncryptionPortInput(): number | undefined;
        private _authorizationConfig?;
        private __authorizationConfigOutput;
        /**
         * @stability stable
         */
        get authorizationConfig(): EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfigOutputReference;
        /**
         * @stability stable
         */
        putAuthorizationConfig(value: EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig | undefined): void;
        /**
         * @stability stable
         */
        resetAuthorizationConfig(): void;
        /**
         * @stability stable
         */
        get authorizationConfigInput(): EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfigurationAuthorizationConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#credentials_parameter EcsTaskDefinition#credentials_parameter}.
         *
         * @stability stable
         */
        readonly credentialsParameter: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#domain EcsTaskDefinition#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
    }
    /**
     * @stability stable
     */
    class EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfigurationAuthorizationConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _credentialsParameter?;
        /**
         * @stability stable
         */
        get credentialsParameter(): string;
        /**
         * @stability stable
         */
        set credentialsParameter(value: string);
        /**
         * @stability stable
         */
        get credentialsParameterInput(): string | undefined;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#file_system_id EcsTaskDefinition#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#root_directory EcsTaskDefinition#root_directory}.
         *
         * @stability stable
         */
        readonly rootDirectory: string;
        /**
         * authorization_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#authorization_config EcsTaskDefinition#authorization_config}
         *
         * @stability stable
         */
        readonly authorizationConfig: EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfigurationAuthorizationConfig;
    }
    /**
     * @stability stable
     */
    class EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        private _rootDirectory?;
        /**
         * @stability stable
         */
        get rootDirectory(): string;
        /**
         * @stability stable
         */
        set rootDirectory(value: string);
        /**
         * @stability stable
         */
        get rootDirectoryInput(): string | undefined;
        private _authorizationConfig?;
        private __authorizationConfigOutput;
        /**
         * @stability stable
         */
        get authorizationConfig(): EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfigurationAuthorizationConfigOutputReference;
        /**
         * @stability stable
         */
        putAuthorizationConfig(value: EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfigurationAuthorizationConfig): void;
        /**
         * @stability stable
         */
        get authorizationConfigInput(): EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfigurationAuthorizationConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface EcsTaskDefinitionVolume {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#host_path EcsTaskDefinition#host_path}.
         *
         * @stability stable
         */
        readonly hostPath?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#name EcsTaskDefinition#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * docker_volume_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#docker_volume_configuration EcsTaskDefinition#docker_volume_configuration}
         *
         * @stability stable
         */
        readonly dockerVolumeConfiguration?: EcsTaskDefinitionVolumeDockerVolumeConfiguration;
        /**
         * efs_volume_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#efs_volume_configuration EcsTaskDefinition#efs_volume_configuration}
         *
         * @stability stable
         */
        readonly efsVolumeConfiguration?: EcsTaskDefinitionVolumeEfsVolumeConfiguration;
        /**
         * fsx_windows_file_server_volume_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html#fsx_windows_file_server_volume_configuration EcsTaskDefinition#fsx_windows_file_server_volume_configuration}
         *
         * @stability stable
         */
        readonly fsxWindowsFileServerVolumeConfiguration?: EcsTaskDefinitionVolumeFsxWindowsFileServerVolumeConfiguration;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html aws_ecs_task_definition}.
     *
     * @stability stable
     */
    class EcsTaskDefinition extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ecs_task_definition.html aws_ecs_task_definition} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EcsTaskDefinitionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _containerDefinitions?;
        /**
         * @stability stable
         */
        get containerDefinitions(): string;
        /**
         * @stability stable
         */
        set containerDefinitions(value: string);
        /**
         * @stability stable
         */
        get containerDefinitionsInput(): string | undefined;
        private _cpu?;
        /**
         * @stability stable
         */
        get cpu(): string | undefined;
        /**
         * @stability stable
         */
        set cpu(value: string | undefined);
        /**
         * @stability stable
         */
        resetCpu(): void;
        /**
         * @stability stable
         */
        get cpuInput(): string | undefined;
        private _executionRoleArn?;
        /**
         * @stability stable
         */
        get executionRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set executionRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetExecutionRoleArn(): void;
        /**
         * @stability stable
         */
        get executionRoleArnInput(): string | undefined;
        private _family?;
        /**
         * @stability stable
         */
        get family(): string;
        /**
         * @stability stable
         */
        set family(value: string);
        /**
         * @stability stable
         */
        get familyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipcMode?;
        /**
         * @stability stable
         */
        get ipcMode(): string | undefined;
        /**
         * @stability stable
         */
        set ipcMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpcMode(): void;
        /**
         * @stability stable
         */
        get ipcModeInput(): string | undefined;
        private _memory?;
        /**
         * @stability stable
         */
        get memory(): string | undefined;
        /**
         * @stability stable
         */
        set memory(value: string | undefined);
        /**
         * @stability stable
         */
        resetMemory(): void;
        /**
         * @stability stable
         */
        get memoryInput(): string | undefined;
        private _networkMode?;
        /**
         * @stability stable
         */
        get networkMode(): string | undefined;
        /**
         * @stability stable
         */
        set networkMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetNetworkMode(): void;
        /**
         * @stability stable
         */
        get networkModeInput(): string | undefined;
        private _pidMode?;
        /**
         * @stability stable
         */
        get pidMode(): string | undefined;
        /**
         * @stability stable
         */
        set pidMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetPidMode(): void;
        /**
         * @stability stable
         */
        get pidModeInput(): string | undefined;
        private _requiresCompatibilities?;
        /**
         * @stability stable
         */
        get requiresCompatibilities(): string[] | undefined;
        /**
         * @stability stable
         */
        set requiresCompatibilities(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetRequiresCompatibilities(): void;
        /**
         * @stability stable
         */
        get requiresCompatibilitiesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get revision(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _taskRoleArn?;
        /**
         * @stability stable
         */
        get taskRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set taskRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetTaskRoleArn(): void;
        /**
         * @stability stable
         */
        get taskRoleArnInput(): string | undefined;
        private _ephemeralStorage?;
        private __ephemeralStorageOutput;
        /**
         * @stability stable
         */
        get ephemeralStorage(): EcsTaskDefinitionEphemeralStorageOutputReference;
        /**
         * @stability stable
         */
        putEphemeralStorage(value: EcsTaskDefinitionEphemeralStorage | undefined): void;
        /**
         * @stability stable
         */
        resetEphemeralStorage(): void;
        /**
         * @stability stable
         */
        get ephemeralStorageInput(): EcsTaskDefinitionEphemeralStorage | undefined;
        private _inferenceAccelerator?;
        /**
         * @stability stable
         */
        get inferenceAccelerator(): EcsTaskDefinitionInferenceAccelerator[] | undefined;
        /**
         * @stability stable
         */
        set inferenceAccelerator(value: EcsTaskDefinitionInferenceAccelerator[] | undefined);
        /**
         * @stability stable
         */
        resetInferenceAccelerator(): void;
        /**
         * @stability stable
         */
        get inferenceAcceleratorInput(): EcsTaskDefinitionInferenceAccelerator[] | undefined;
        private _placementConstraints?;
        /**
         * @stability stable
         */
        get placementConstraints(): EcsTaskDefinitionPlacementConstraints[] | undefined;
        /**
         * @stability stable
         */
        set placementConstraints(value: EcsTaskDefinitionPlacementConstraints[] | undefined);
        /**
         * @stability stable
         */
        resetPlacementConstraints(): void;
        /**
         * @stability stable
         */
        get placementConstraintsInput(): EcsTaskDefinitionPlacementConstraints[] | undefined;
        private _proxyConfiguration?;
        private __proxyConfigurationOutput;
        /**
         * @stability stable
         */
        get proxyConfiguration(): EcsTaskDefinitionProxyConfigurationOutputReference;
        /**
         * @stability stable
         */
        putProxyConfiguration(value: EcsTaskDefinitionProxyConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetProxyConfiguration(): void;
        /**
         * @stability stable
         */
        get proxyConfigurationInput(): EcsTaskDefinitionProxyConfiguration | undefined;
        private _volume?;
        /**
         * @stability stable
         */
        get volume(): EcsTaskDefinitionVolume[] | undefined;
        /**
         * @stability stable
         */
        set volume(value: EcsTaskDefinitionVolume[] | undefined);
        /**
         * @stability stable
         */
        resetVolume(): void;
        /**
         * @stability stable
         */
        get volumeInput(): EcsTaskDefinitionVolume[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEcsClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecs_cluster.html#cluster_name DataAwsEcsCluster#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
    }
    /**
     * @stability stable
     */
    class DataAwsEcsClusterSetting extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get value(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecs_cluster.html aws_ecs_cluster}.
     *
     * @stability stable
     */
    class DataAwsEcsCluster extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecs_cluster.html aws_ecs_cluster} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEcsClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get pendingTasksCount(): number;
        /**
         * @stability stable
         */
        get registeredContainerInstancesCount(): number;
        /**
         * @stability stable
         */
        get runningTasksCount(): number;
        /**
         * @stability stable
         */
        setting(index: string): DataAwsEcsClusterSetting;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEcsContainerDefinitionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecs_container_definition.html#container_name DataAwsEcsContainerDefinition#container_name}.
         *
         * @stability stable
         */
        readonly containerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecs_container_definition.html#task_definition DataAwsEcsContainerDefinition#task_definition}.
         *
         * @stability stable
         */
        readonly taskDefinition: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecs_container_definition.html aws_ecs_container_definition}.
     *
     * @stability stable
     */
    class DataAwsEcsContainerDefinition extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecs_container_definition.html aws_ecs_container_definition} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEcsContainerDefinitionConfig);
        private _containerName?;
        /**
         * @stability stable
         */
        get containerName(): string;
        /**
         * @stability stable
         */
        set containerName(value: string);
        /**
         * @stability stable
         */
        get containerNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get cpu(): number;
        /**
         * @stability stable
         */
        get disableNetworking(): any;
        /**
         * @stability stable
         */
        dockerLabels(key: string): string;
        /**
         * @stability stable
         */
        environment(key: string): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get image(): string;
        /**
         * @stability stable
         */
        get imageDigest(): string;
        /**
         * @stability stable
         */
        get memory(): number;
        /**
         * @stability stable
         */
        get memoryReservation(): number;
        private _taskDefinition?;
        /**
         * @stability stable
         */
        get taskDefinition(): string;
        /**
         * @stability stable
         */
        set taskDefinition(value: string);
        /**
         * @stability stable
         */
        get taskDefinitionInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEcsServiceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecs_service.html#cluster_arn DataAwsEcsService#cluster_arn}.
         *
         * @stability stable
         */
        readonly clusterArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecs_service.html#service_name DataAwsEcsService#service_name}.
         *
         * @stability stable
         */
        readonly serviceName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecs_service.html aws_ecs_service}.
     *
     * @stability stable
     */
    class DataAwsEcsService extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecs_service.html aws_ecs_service} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEcsServiceConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterArn?;
        /**
         * @stability stable
         */
        get clusterArn(): string;
        /**
         * @stability stable
         */
        set clusterArn(value: string);
        /**
         * @stability stable
         */
        get clusterArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get desiredCount(): number;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get launchType(): string;
        /**
         * @stability stable
         */
        get schedulingStrategy(): string;
        private _serviceName?;
        /**
         * @stability stable
         */
        get serviceName(): string;
        /**
         * @stability stable
         */
        set serviceName(value: string);
        /**
         * @stability stable
         */
        get serviceNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get taskDefinition(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEcsTaskDefinitionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ecs_task_definition.html#task_definition DataAwsEcsTaskDefinition#task_definition}.
         *
         * @stability stable
         */
        readonly taskDefinition: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ecs_task_definition.html aws_ecs_task_definition}.
     *
     * @stability stable
     */
    class DataAwsEcsTaskDefinition extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ecs_task_definition.html aws_ecs_task_definition} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEcsTaskDefinitionConfig);
        /**
         * @stability stable
         */
        get family(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get networkMode(): string;
        /**
         * @stability stable
         */
        get revision(): number;
        /**
         * @stability stable
         */
        get status(): string;
        private _taskDefinition?;
        /**
         * @stability stable
         */
        get taskDefinition(): string;
        /**
         * @stability stable
         */
        set taskDefinition(value: string);
        /**
         * @stability stable
         */
        get taskDefinitionInput(): string | undefined;
        /**
         * @stability stable
         */
        get taskRoleArn(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
