import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS EFS
*/
export declare namespace EFS {
    /**
     * @stability stable
     */
    interface EfsAccessPointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#file_system_id EfsAccessPoint#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#tags EfsAccessPoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#tags_all EfsAccessPoint#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * posix_user block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#posix_user EfsAccessPoint#posix_user}
         *
         * @stability stable
         */
        readonly posixUser?: EfsAccessPointPosixUser;
        /**
         * root_directory block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#root_directory EfsAccessPoint#root_directory}
         *
         * @stability stable
         */
        readonly rootDirectory?: EfsAccessPointRootDirectory;
    }
    /**
     * @stability stable
     */
    interface EfsAccessPointPosixUser {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#gid EfsAccessPoint#gid}.
         *
         * @stability stable
         */
        readonly gid: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#secondary_gids EfsAccessPoint#secondary_gids}.
         *
         * @stability stable
         */
        readonly secondaryGids?: number[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#uid EfsAccessPoint#uid}.
         *
         * @stability stable
         */
        readonly uid: number;
    }
    /**
     * @stability stable
     */
    class EfsAccessPointPosixUserOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _gid?;
        /**
         * @stability stable
         */
        get gid(): number;
        /**
         * @stability stable
         */
        set gid(value: number);
        /**
         * @stability stable
         */
        get gidInput(): number | undefined;
        private _secondaryGids?;
        /**
         * @stability stable
         */
        get secondaryGids(): number[] | undefined;
        /**
         * @stability stable
         */
        set secondaryGids(value: number[] | undefined);
        /**
         * @stability stable
         */
        resetSecondaryGids(): void;
        /**
         * @stability stable
         */
        get secondaryGidsInput(): number[] | undefined;
        private _uid?;
        /**
         * @stability stable
         */
        get uid(): number;
        /**
         * @stability stable
         */
        set uid(value: number);
        /**
         * @stability stable
         */
        get uidInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface EfsAccessPointRootDirectoryCreationInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#owner_gid EfsAccessPoint#owner_gid}.
         *
         * @stability stable
         */
        readonly ownerGid: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#owner_uid EfsAccessPoint#owner_uid}.
         *
         * @stability stable
         */
        readonly ownerUid: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#permissions EfsAccessPoint#permissions}.
         *
         * @stability stable
         */
        readonly permissions: string;
    }
    /**
     * @stability stable
     */
    class EfsAccessPointRootDirectoryCreationInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _ownerGid?;
        /**
         * @stability stable
         */
        get ownerGid(): number;
        /**
         * @stability stable
         */
        set ownerGid(value: number);
        /**
         * @stability stable
         */
        get ownerGidInput(): number | undefined;
        private _ownerUid?;
        /**
         * @stability stable
         */
        get ownerUid(): number;
        /**
         * @stability stable
         */
        set ownerUid(value: number);
        /**
         * @stability stable
         */
        get ownerUidInput(): number | undefined;
        private _permissions?;
        /**
         * @stability stable
         */
        get permissions(): string;
        /**
         * @stability stable
         */
        set permissions(value: string);
        /**
         * @stability stable
         */
        get permissionsInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EfsAccessPointRootDirectory {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#path EfsAccessPoint#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * creation_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html#creation_info EfsAccessPoint#creation_info}
         *
         * @stability stable
         */
        readonly creationInfo?: EfsAccessPointRootDirectoryCreationInfo;
    }
    /**
     * @stability stable
     */
    class EfsAccessPointRootDirectoryOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _creationInfo?;
        private __creationInfoOutput;
        /**
         * @stability stable
         */
        get creationInfo(): EfsAccessPointRootDirectoryCreationInfoOutputReference;
        /**
         * @stability stable
         */
        putCreationInfo(value: EfsAccessPointRootDirectoryCreationInfo | undefined): void;
        /**
         * @stability stable
         */
        resetCreationInfo(): void;
        /**
         * @stability stable
         */
        get creationInfoInput(): EfsAccessPointRootDirectoryCreationInfo | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html aws_efs_access_point}.
     *
     * @stability stable
     */
    class EfsAccessPoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_access_point.html aws_efs_access_point} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EfsAccessPointConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get fileSystemArn(): string;
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _posixUser?;
        private __posixUserOutput;
        /**
         * @stability stable
         */
        get posixUser(): EfsAccessPointPosixUserOutputReference;
        /**
         * @stability stable
         */
        putPosixUser(value: EfsAccessPointPosixUser | undefined): void;
        /**
         * @stability stable
         */
        resetPosixUser(): void;
        /**
         * @stability stable
         */
        get posixUserInput(): EfsAccessPointPosixUser | undefined;
        private _rootDirectory?;
        private __rootDirectoryOutput;
        /**
         * @stability stable
         */
        get rootDirectory(): EfsAccessPointRootDirectoryOutputReference;
        /**
         * @stability stable
         */
        putRootDirectory(value: EfsAccessPointRootDirectory | undefined): void;
        /**
         * @stability stable
         */
        resetRootDirectory(): void;
        /**
         * @stability stable
         */
        get rootDirectoryInput(): EfsAccessPointRootDirectory | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EfsBackupPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_backup_policy.html#file_system_id EfsBackupPolicy#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
        /**
         * backup_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_backup_policy.html#backup_policy EfsBackupPolicy#backup_policy}
         *
         * @stability stable
         */
        readonly backupPolicy: EfsBackupPolicyBackupPolicy;
    }
    /**
     * @stability stable
     */
    interface EfsBackupPolicyBackupPolicy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_backup_policy.html#status EfsBackupPolicy#status}.
         *
         * @stability stable
         */
        readonly status: string;
    }
    /**
     * @stability stable
     */
    class EfsBackupPolicyBackupPolicyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _status?;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        set status(value: string);
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_backup_policy.html aws_efs_backup_policy}.
     *
     * @stability stable
     */
    class EfsBackupPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_backup_policy.html aws_efs_backup_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EfsBackupPolicyConfig);
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _backupPolicy?;
        private __backupPolicyOutput;
        /**
         * @stability stable
         */
        get backupPolicy(): EfsBackupPolicyBackupPolicyOutputReference;
        /**
         * @stability stable
         */
        putBackupPolicy(value: EfsBackupPolicyBackupPolicy): void;
        /**
         * @stability stable
         */
        get backupPolicyInput(): EfsBackupPolicyBackupPolicy | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EfsFileSystemConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#availability_zone_name EfsFileSystem#availability_zone_name}.
         *
         * @stability stable
         */
        readonly availabilityZoneName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#creation_token EfsFileSystem#creation_token}.
         *
         * @stability stable
         */
        readonly creationToken?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#encrypted EfsFileSystem#encrypted}.
         *
         * @stability stable
         */
        readonly encrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#kms_key_id EfsFileSystem#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#performance_mode EfsFileSystem#performance_mode}.
         *
         * @stability stable
         */
        readonly performanceMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#provisioned_throughput_in_mibps EfsFileSystem#provisioned_throughput_in_mibps}.
         *
         * @stability stable
         */
        readonly provisionedThroughputInMibps?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#tags EfsFileSystem#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#tags_all EfsFileSystem#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#throughput_mode EfsFileSystem#throughput_mode}.
         *
         * @stability stable
         */
        readonly throughputMode?: string;
        /**
         * lifecycle_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#lifecycle_policy EfsFileSystem#lifecycle_policy}
         *
         * @stability stable
         */
        readonly lifecyclePolicy?: EfsFileSystemLifecyclePolicy[];
    }
    /**
     * @stability stable
     */
    class EfsFileSystemSizeInBytes extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        get valueInIa(): number;
        /**
         * @stability stable
         */
        get valueInStandard(): number;
    }
    /**
     * @stability stable
     */
    interface EfsFileSystemLifecyclePolicy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#transition_to_ia EfsFileSystem#transition_to_ia}.
         *
         * @stability stable
         */
        readonly transitionToIa?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html#transition_to_primary_storage_class EfsFileSystem#transition_to_primary_storage_class}.
         *
         * @stability stable
         */
        readonly transitionToPrimaryStorageClass?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html aws_efs_file_system}.
     *
     * @stability stable
     */
    class EfsFileSystem extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system.html aws_efs_file_system} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: EfsFileSystemConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZoneId(): string;
        private _availabilityZoneName?;
        /**
         * @stability stable
         */
        get availabilityZoneName(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZoneName(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZoneName(): void;
        /**
         * @stability stable
         */
        get availabilityZoneNameInput(): string | undefined;
        private _creationToken?;
        /**
         * @stability stable
         */
        get creationToken(): string | undefined;
        /**
         * @stability stable
         */
        set creationToken(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreationToken(): void;
        /**
         * @stability stable
         */
        get creationTokenInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        private _encrypted?;
        /**
         * @stability stable
         */
        get encrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set encrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEncrypted(): void;
        /**
         * @stability stable
         */
        get encryptedInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get numberOfMountTargets(): number;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _performanceMode?;
        /**
         * @stability stable
         */
        get performanceMode(): string | undefined;
        /**
         * @stability stable
         */
        set performanceMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetPerformanceMode(): void;
        /**
         * @stability stable
         */
        get performanceModeInput(): string | undefined;
        private _provisionedThroughputInMibps?;
        /**
         * @stability stable
         */
        get provisionedThroughputInMibps(): number | undefined;
        /**
         * @stability stable
         */
        set provisionedThroughputInMibps(value: number | undefined);
        /**
         * @stability stable
         */
        resetProvisionedThroughputInMibps(): void;
        /**
         * @stability stable
         */
        get provisionedThroughputInMibpsInput(): number | undefined;
        /**
         * @stability stable
         */
        sizeInBytes(index: string): EfsFileSystemSizeInBytes;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _throughputMode?;
        /**
         * @stability stable
         */
        get throughputMode(): string | undefined;
        /**
         * @stability stable
         */
        set throughputMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetThroughputMode(): void;
        /**
         * @stability stable
         */
        get throughputModeInput(): string | undefined;
        private _lifecyclePolicy?;
        /**
         * @stability stable
         */
        get lifecyclePolicy(): EfsFileSystemLifecyclePolicy[] | undefined;
        /**
         * @stability stable
         */
        set lifecyclePolicy(value: EfsFileSystemLifecyclePolicy[] | undefined);
        /**
         * @stability stable
         */
        resetLifecyclePolicy(): void;
        /**
         * @stability stable
         */
        get lifecyclePolicyInput(): EfsFileSystemLifecyclePolicy[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EfsFileSystemPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system_policy.html#bypass_policy_lockout_safety_check EfsFileSystemPolicy#bypass_policy_lockout_safety_check}.
         *
         * @stability stable
         */
        readonly bypassPolicyLockoutSafetyCheck?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system_policy.html#file_system_id EfsFileSystemPolicy#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system_policy.html#policy EfsFileSystemPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system_policy.html aws_efs_file_system_policy}.
     *
     * @stability stable
     */
    class EfsFileSystemPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_file_system_policy.html aws_efs_file_system_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EfsFileSystemPolicyConfig);
        private _bypassPolicyLockoutSafetyCheck?;
        /**
         * @stability stable
         */
        get bypassPolicyLockoutSafetyCheck(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set bypassPolicyLockoutSafetyCheck(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBypassPolicyLockoutSafetyCheck(): void;
        /**
         * @stability stable
         */
        get bypassPolicyLockoutSafetyCheckInput(): boolean | cdktf.IResolvable | undefined;
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EfsMountTargetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_mount_target.html#file_system_id EfsMountTarget#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_mount_target.html#ip_address EfsMountTarget#ip_address}.
         *
         * @stability stable
         */
        readonly ipAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_mount_target.html#security_groups EfsMountTarget#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/efs_mount_target.html#subnet_id EfsMountTarget#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/efs_mount_target.html aws_efs_mount_target}.
     *
     * @stability stable
     */
    class EfsMountTarget extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/efs_mount_target.html aws_efs_mount_target} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EfsMountTargetConfig);
        /**
         * @stability stable
         */
        get availabilityZoneId(): string;
        /**
         * @stability stable
         */
        get availabilityZoneName(): string;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get fileSystemArn(): string;
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipAddress?;
        /**
         * @stability stable
         */
        get ipAddress(): string | undefined;
        /**
         * @stability stable
         */
        set ipAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpAddress(): void;
        /**
         * @stability stable
         */
        get ipAddressInput(): string | undefined;
        /**
         * @stability stable
         */
        get mountTargetDnsName(): string;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string;
        /**
         * @stability stable
         */
        set subnetId(value: string);
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEfsAccessPointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_access_point.html#access_point_id DataAwsEfsAccessPoint#access_point_id}.
         *
         * @stability stable
         */
        readonly accessPointId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_access_point.html#tags DataAwsEfsAccessPoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsEfsAccessPointPosixUser extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get gid(): number;
        /**
         * @stability stable
         */
        get secondaryGids(): any;
        /**
         * @stability stable
         */
        get uid(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsEfsAccessPointRootDirectoryCreationInfo extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get ownerGid(): number;
        /**
         * @stability stable
         */
        get ownerUid(): number;
        /**
         * @stability stable
         */
        get permissions(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsEfsAccessPointRootDirectory extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get creationInfo(): any;
        /**
         * @stability stable
         */
        get path(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/efs_access_point.html aws_efs_access_point}.
     *
     * @stability stable
     */
    class DataAwsEfsAccessPoint extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/efs_access_point.html aws_efs_access_point} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEfsAccessPointConfig);
        private _accessPointId?;
        /**
         * @stability stable
         */
        get accessPointId(): string;
        /**
         * @stability stable
         */
        set accessPointId(value: string);
        /**
         * @stability stable
         */
        get accessPointIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get fileSystemArn(): string;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        /**
         * @stability stable
         */
        posixUser(index: string): DataAwsEfsAccessPointPosixUser;
        /**
         * @stability stable
         */
        rootDirectory(index: string): DataAwsEfsAccessPointRootDirectory;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEfsAccessPointsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_access_points.html#file_system_id DataAwsEfsAccessPoints#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/efs_access_points.html aws_efs_access_points}.
     *
     * @stability stable
     */
    class DataAwsEfsAccessPoints extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/efs_access_points.html aws_efs_access_points} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEfsAccessPointsConfig);
        /**
         * @stability stable
         */
        get arns(): string[];
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEfsFileSystemConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system.html#creation_token DataAwsEfsFileSystem#creation_token}.
         *
         * @stability stable
         */
        readonly creationToken?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system.html#file_system_id DataAwsEfsFileSystem#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system.html#tags DataAwsEfsFileSystem#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsEfsFileSystemLifecyclePolicy extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get transitionToIa(): string;
        /**
         * @stability stable
         */
        get transitionToPrimaryStorageClass(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system.html aws_efs_file_system}.
     *
     * @stability stable
     */
    class DataAwsEfsFileSystem extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/efs_file_system.html aws_efs_file_system} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsEfsFileSystemConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZoneId(): string;
        /**
         * @stability stable
         */
        get availabilityZoneName(): string;
        private _creationToken?;
        /**
         * @stability stable
         */
        get creationToken(): string | undefined;
        /**
         * @stability stable
         */
        set creationToken(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreationToken(): void;
        /**
         * @stability stable
         */
        get creationTokenInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get encrypted(): any;
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string | undefined;
        /**
         * @stability stable
         */
        set fileSystemId(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileSystemId(): void;
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        lifecyclePolicy(index: string): DataAwsEfsFileSystemLifecyclePolicy;
        /**
         * @stability stable
         */
        get performanceMode(): string;
        /**
         * @stability stable
         */
        get provisionedThroughputInMibps(): number;
        /**
         * @stability stable
         */
        get sizeInBytes(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get throughputMode(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEfsMountTargetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_mount_target.html#access_point_id DataAwsEfsMountTarget#access_point_id}.
         *
         * @stability stable
         */
        readonly accessPointId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_mount_target.html#file_system_id DataAwsEfsMountTarget#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/efs_mount_target.html#mount_target_id DataAwsEfsMountTarget#mount_target_id}.
         *
         * @stability stable
         */
        readonly mountTargetId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/efs_mount_target.html aws_efs_mount_target}.
     *
     * @stability stable
     */
    class DataAwsEfsMountTarget extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/efs_mount_target.html aws_efs_mount_target} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsEfsMountTargetConfig);
        private _accessPointId?;
        /**
         * @stability stable
         */
        get accessPointId(): string | undefined;
        /**
         * @stability stable
         */
        set accessPointId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccessPointId(): void;
        /**
         * @stability stable
         */
        get accessPointIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get availabilityZoneId(): string;
        /**
         * @stability stable
         */
        get availabilityZoneName(): string;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get fileSystemArn(): string;
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string | undefined;
        /**
         * @stability stable
         */
        set fileSystemId(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileSystemId(): void;
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipAddress(): string;
        /**
         * @stability stable
         */
        get mountTargetDnsName(): string;
        private _mountTargetId?;
        /**
         * @stability stable
         */
        get mountTargetId(): string | undefined;
        /**
         * @stability stable
         */
        set mountTargetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetMountTargetId(): void;
        /**
         * @stability stable
         */
        get mountTargetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        /**
         * @stability stable
         */
        get securityGroups(): string[];
        /**
         * @stability stable
         */
        get subnetId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
