import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Elastic Kubernetes Service
*/
export declare namespace EKS {
    /**
     * @stability stable
     */
    interface EksAddonConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html#addon_name EksAddon#addon_name}.
         *
         * @stability stable
         */
        readonly addonName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html#addon_version EksAddon#addon_version}.
         *
         * @stability stable
         */
        readonly addonVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html#cluster_name EksAddon#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html#resolve_conflicts EksAddon#resolve_conflicts}.
         *
         * @stability stable
         */
        readonly resolveConflicts?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html#service_account_role_arn EksAddon#service_account_role_arn}.
         *
         * @stability stable
         */
        readonly serviceAccountRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html#tags EksAddon#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html#tags_all EksAddon#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html aws_eks_addon}.
     *
     * @stability stable
     */
    class EksAddon extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_addon.html aws_eks_addon} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EksAddonConfig);
        private _addonName?;
        /**
         * @stability stable
         */
        get addonName(): string;
        /**
         * @stability stable
         */
        set addonName(value: string);
        /**
         * @stability stable
         */
        get addonNameInput(): string | undefined;
        private _addonVersion?;
        /**
         * @stability stable
         */
        get addonVersion(): string | undefined;
        /**
         * @stability stable
         */
        set addonVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetAddonVersion(): void;
        /**
         * @stability stable
         */
        get addonVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get createdAt(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get modifiedAt(): string;
        private _resolveConflicts?;
        /**
         * @stability stable
         */
        get resolveConflicts(): string | undefined;
        /**
         * @stability stable
         */
        set resolveConflicts(value: string | undefined);
        /**
         * @stability stable
         */
        resetResolveConflicts(): void;
        /**
         * @stability stable
         */
        get resolveConflictsInput(): string | undefined;
        private _serviceAccountRoleArn?;
        /**
         * @stability stable
         */
        get serviceAccountRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set serviceAccountRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceAccountRoleArn(): void;
        /**
         * @stability stable
         */
        get serviceAccountRoleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EksClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#enabled_cluster_log_types EksCluster#enabled_cluster_log_types}.
         *
         * @stability stable
         */
        readonly enabledClusterLogTypes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#name EksCluster#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#role_arn EksCluster#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#tags EksCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#tags_all EksCluster#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#version EksCluster#version}.
         *
         * @stability stable
         */
        readonly version?: string;
        /**
         * encryption_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#encryption_config EksCluster#encryption_config}
         *
         * @stability stable
         */
        readonly encryptionConfig?: EksClusterEncryptionConfig;
        /**
         * kubernetes_network_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#kubernetes_network_config EksCluster#kubernetes_network_config}
         *
         * @stability stable
         */
        readonly kubernetesNetworkConfig?: EksClusterKubernetesNetworkConfig;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#timeouts EksCluster#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: EksClusterTimeouts;
        /**
         * vpc_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#vpc_config EksCluster#vpc_config}
         *
         * @stability stable
         */
        readonly vpcConfig: EksClusterVpcConfig;
    }
    /**
     * @stability stable
     */
    class EksClusterCertificateAuthority extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get data(): string;
    }
    /**
     * @stability stable
     */
    class EksClusterIdentityOidc extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get issuer(): string;
    }
    /**
     * @stability stable
     */
    class EksClusterIdentity extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get oidc(): any;
    }
    /**
     * @stability stable
     */
    interface EksClusterEncryptionConfigProvider {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#key_arn EksCluster#key_arn}.
         *
         * @stability stable
         */
        readonly keyArn: string;
    }
    /**
     * @stability stable
     */
    class EksClusterEncryptionConfigProviderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _keyArn?;
        /**
         * @stability stable
         */
        get keyArn(): string;
        /**
         * @stability stable
         */
        set keyArn(value: string);
        /**
         * @stability stable
         */
        get keyArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EksClusterEncryptionConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#resources EksCluster#resources}.
         *
         * @stability stable
         */
        readonly resources: string[];
        /**
         * provider block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#provider EksCluster#provider}
         *
         * @stability stable
         */
        readonly provider: EksClusterEncryptionConfigProvider;
    }
    /**
     * @stability stable
     */
    class EksClusterEncryptionConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _resources?;
        /**
         * @stability stable
         */
        get resources(): string[];
        /**
         * @stability stable
         */
        set resources(value: string[]);
        /**
         * @stability stable
         */
        get resourcesInput(): string[] | undefined;
        private _provider?;
        private __providerOutput;
        /**
         * @stability stable
         */
        get provider(): EksClusterEncryptionConfigProviderOutputReference;
        /**
         * @stability stable
         */
        putProvider(value: EksClusterEncryptionConfigProvider): void;
        /**
         * @stability stable
         */
        get providerInput(): EksClusterEncryptionConfigProvider | undefined;
    }
    /**
     * @stability stable
     */
    interface EksClusterKubernetesNetworkConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#service_ipv4_cidr EksCluster#service_ipv4_cidr}.
         *
         * @stability stable
         */
        readonly serviceIpv4Cidr?: string;
    }
    /**
     * @stability stable
     */
    class EksClusterKubernetesNetworkConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _serviceIpv4Cidr?;
        /**
         * @stability stable
         */
        get serviceIpv4Cidr(): string | undefined;
        /**
         * @stability stable
         */
        set serviceIpv4Cidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceIpv4Cidr(): void;
        /**
         * @stability stable
         */
        get serviceIpv4CidrInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EksClusterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#create EksCluster#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#delete EksCluster#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#update EksCluster#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class EksClusterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EksClusterVpcConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#endpoint_private_access EksCluster#endpoint_private_access}.
         *
         * @stability stable
         */
        readonly endpointPrivateAccess?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#endpoint_public_access EksCluster#endpoint_public_access}.
         *
         * @stability stable
         */
        readonly endpointPublicAccess?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#public_access_cidrs EksCluster#public_access_cidrs}.
         *
         * @stability stable
         */
        readonly publicAccessCidrs?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#security_group_ids EksCluster#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html#subnet_ids EksCluster#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
    }
    /**
     * @stability stable
     */
    class EksClusterVpcConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _endpointPrivateAccess?;
        /**
         * @stability stable
         */
        get endpointPrivateAccess(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set endpointPrivateAccess(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEndpointPrivateAccess(): void;
        /**
         * @stability stable
         */
        get endpointPrivateAccessInput(): boolean | cdktf.IResolvable | undefined;
        private _endpointPublicAccess?;
        /**
         * @stability stable
         */
        get endpointPublicAccess(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set endpointPublicAccess(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEndpointPublicAccess(): void;
        /**
         * @stability stable
         */
        get endpointPublicAccessInput(): boolean | cdktf.IResolvable | undefined;
        private _publicAccessCidrs?;
        /**
         * @stability stable
         */
        get publicAccessCidrs(): string[] | undefined;
        /**
         * @stability stable
         */
        set publicAccessCidrs(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPublicAccessCidrs(): void;
        /**
         * @stability stable
         */
        get publicAccessCidrsInput(): string[] | undefined;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html aws_eks_cluster}.
     *
     * @stability stable
     */
    class EksCluster extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_cluster.html aws_eks_cluster} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EksClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        certificateAuthority(index: string): EksClusterCertificateAuthority;
        /**
         * @stability stable
         */
        get createdAt(): string;
        private _enabledClusterLogTypes?;
        /**
         * @stability stable
         */
        get enabledClusterLogTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set enabledClusterLogTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEnabledClusterLogTypes(): void;
        /**
         * @stability stable
         */
        get enabledClusterLogTypesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        identity(index: string): EksClusterIdentity;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get platformVersion(): string;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
        private _encryptionConfig?;
        private __encryptionConfigOutput;
        /**
         * @stability stable
         */
        get encryptionConfig(): EksClusterEncryptionConfigOutputReference;
        /**
         * @stability stable
         */
        putEncryptionConfig(value: EksClusterEncryptionConfig | undefined): void;
        /**
         * @stability stable
         */
        resetEncryptionConfig(): void;
        /**
         * @stability stable
         */
        get encryptionConfigInput(): EksClusterEncryptionConfig | undefined;
        private _kubernetesNetworkConfig?;
        private __kubernetesNetworkConfigOutput;
        /**
         * @stability stable
         */
        get kubernetesNetworkConfig(): EksClusterKubernetesNetworkConfigOutputReference;
        /**
         * @stability stable
         */
        putKubernetesNetworkConfig(value: EksClusterKubernetesNetworkConfig | undefined): void;
        /**
         * @stability stable
         */
        resetKubernetesNetworkConfig(): void;
        /**
         * @stability stable
         */
        get kubernetesNetworkConfigInput(): EksClusterKubernetesNetworkConfig | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): EksClusterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: EksClusterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): EksClusterTimeouts | undefined;
        private _vpcConfig?;
        private __vpcConfigOutput;
        /**
         * @stability stable
         */
        get vpcConfig(): EksClusterVpcConfigOutputReference;
        /**
         * @stability stable
         */
        putVpcConfig(value: EksClusterVpcConfig): void;
        /**
         * @stability stable
         */
        get vpcConfigInput(): EksClusterVpcConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EksFargateProfileConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#cluster_name EksFargateProfile#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#fargate_profile_name EksFargateProfile#fargate_profile_name}.
         *
         * @stability stable
         */
        readonly fargateProfileName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#pod_execution_role_arn EksFargateProfile#pod_execution_role_arn}.
         *
         * @stability stable
         */
        readonly podExecutionRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#subnet_ids EksFargateProfile#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#tags EksFargateProfile#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#tags_all EksFargateProfile#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * selector block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#selector EksFargateProfile#selector}
         *
         * @stability stable
         */
        readonly selector: EksFargateProfileSelector[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#timeouts EksFargateProfile#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: EksFargateProfileTimeouts;
    }
    /**
     * @stability stable
     */
    interface EksFargateProfileSelector {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#labels EksFargateProfile#labels}.
         *
         * @stability stable
         */
        readonly labels?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#namespace EksFargateProfile#namespace}.
         *
         * @stability stable
         */
        readonly namespace: string;
    }
    /**
     * @stability stable
     */
    interface EksFargateProfileTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#create EksFargateProfile#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html#delete EksFargateProfile#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class EksFargateProfileTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html aws_eks_fargate_profile}.
     *
     * @stability stable
     */
    class EksFargateProfile extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_fargate_profile.html aws_eks_fargate_profile} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EksFargateProfileConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        private _fargateProfileName?;
        /**
         * @stability stable
         */
        get fargateProfileName(): string;
        /**
         * @stability stable
         */
        set fargateProfileName(value: string);
        /**
         * @stability stable
         */
        get fargateProfileNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _podExecutionRoleArn?;
        /**
         * @stability stable
         */
        get podExecutionRoleArn(): string;
        /**
         * @stability stable
         */
        set podExecutionRoleArn(value: string);
        /**
         * @stability stable
         */
        get podExecutionRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnetIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetIds(): void;
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _selector?;
        /**
         * @stability stable
         */
        get selector(): EksFargateProfileSelector[];
        /**
         * @stability stable
         */
        set selector(value: EksFargateProfileSelector[]);
        /**
         * @stability stable
         */
        get selectorInput(): EksFargateProfileSelector[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): EksFargateProfileTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: EksFargateProfileTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): EksFargateProfileTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EksIdentityProviderConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#cluster_name EksIdentityProviderConfig#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#tags EksIdentityProviderConfig#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#tags_all EksIdentityProviderConfig#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * oidc block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#oidc EksIdentityProviderConfig#oidc}
         *
         * @stability stable
         */
        readonly oidc: EksIdentityProviderConfigOidc;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#timeouts EksIdentityProviderConfig#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: EksIdentityProviderConfigTimeouts;
    }
    /**
     * @stability stable
     */
    interface EksIdentityProviderConfigOidc {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#client_id EksIdentityProviderConfig#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#groups_claim EksIdentityProviderConfig#groups_claim}.
         *
         * @stability stable
         */
        readonly groupsClaim?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#groups_prefix EksIdentityProviderConfig#groups_prefix}.
         *
         * @stability stable
         */
        readonly groupsPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#identity_provider_config_name EksIdentityProviderConfig#identity_provider_config_name}.
         *
         * @stability stable
         */
        readonly identityProviderConfigName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#issuer_url EksIdentityProviderConfig#issuer_url}.
         *
         * @stability stable
         */
        readonly issuerUrl: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#required_claims EksIdentityProviderConfig#required_claims}.
         *
         * @stability stable
         */
        readonly requiredClaims?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#username_claim EksIdentityProviderConfig#username_claim}.
         *
         * @stability stable
         */
        readonly usernameClaim?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#username_prefix EksIdentityProviderConfig#username_prefix}.
         *
         * @stability stable
         */
        readonly usernamePrefix?: string;
    }
    /**
     * @stability stable
     */
    class EksIdentityProviderConfigOidcOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _groupsClaim?;
        /**
         * @stability stable
         */
        get groupsClaim(): string | undefined;
        /**
         * @stability stable
         */
        set groupsClaim(value: string | undefined);
        /**
         * @stability stable
         */
        resetGroupsClaim(): void;
        /**
         * @stability stable
         */
        get groupsClaimInput(): string | undefined;
        private _groupsPrefix?;
        /**
         * @stability stable
         */
        get groupsPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set groupsPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetGroupsPrefix(): void;
        /**
         * @stability stable
         */
        get groupsPrefixInput(): string | undefined;
        private _identityProviderConfigName?;
        /**
         * @stability stable
         */
        get identityProviderConfigName(): string;
        /**
         * @stability stable
         */
        set identityProviderConfigName(value: string);
        /**
         * @stability stable
         */
        get identityProviderConfigNameInput(): string | undefined;
        private _issuerUrl?;
        /**
         * @stability stable
         */
        get issuerUrl(): string;
        /**
         * @stability stable
         */
        set issuerUrl(value: string);
        /**
         * @stability stable
         */
        get issuerUrlInput(): string | undefined;
        private _requiredClaims?;
        /**
         * @stability stable
         */
        get requiredClaims(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requiredClaims(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequiredClaims(): void;
        /**
         * @stability stable
         */
        get requiredClaimsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _usernameClaim?;
        /**
         * @stability stable
         */
        get usernameClaim(): string | undefined;
        /**
         * @stability stable
         */
        set usernameClaim(value: string | undefined);
        /**
         * @stability stable
         */
        resetUsernameClaim(): void;
        /**
         * @stability stable
         */
        get usernameClaimInput(): string | undefined;
        private _usernamePrefix?;
        /**
         * @stability stable
         */
        get usernamePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set usernamePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetUsernamePrefix(): void;
        /**
         * @stability stable
         */
        get usernamePrefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EksIdentityProviderConfigTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#create EksIdentityProviderConfig#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html#delete EksIdentityProviderConfig#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class EksIdentityProviderConfigTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html aws_eks_identity_provider_config}.
     *
     * @stability stable
     */
    class EksIdentityProviderConfig extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_identity_provider_config.html aws_eks_identity_provider_config} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EksIdentityProviderConfigConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _oidc?;
        private __oidcOutput;
        /**
         * @stability stable
         */
        get oidc(): EksIdentityProviderConfigOidcOutputReference;
        /**
         * @stability stable
         */
        putOidc(value: EksIdentityProviderConfigOidc): void;
        /**
         * @stability stable
         */
        get oidcInput(): EksIdentityProviderConfigOidc | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): EksIdentityProviderConfigTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: EksIdentityProviderConfigTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): EksIdentityProviderConfigTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EksNodeGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#ami_type EksNodeGroup#ami_type}.
         *
         * @stability stable
         */
        readonly amiType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#capacity_type EksNodeGroup#capacity_type}.
         *
         * @stability stable
         */
        readonly capacityType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#cluster_name EksNodeGroup#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#disk_size EksNodeGroup#disk_size}.
         *
         * @stability stable
         */
        readonly diskSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#force_update_version EksNodeGroup#force_update_version}.
         *
         * @stability stable
         */
        readonly forceUpdateVersion?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#instance_types EksNodeGroup#instance_types}.
         *
         * @stability stable
         */
        readonly instanceTypes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#labels EksNodeGroup#labels}.
         *
         * @stability stable
         */
        readonly labels?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#node_group_name EksNodeGroup#node_group_name}.
         *
         * @stability stable
         */
        readonly nodeGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#node_group_name_prefix EksNodeGroup#node_group_name_prefix}.
         *
         * @stability stable
         */
        readonly nodeGroupNamePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#node_role_arn EksNodeGroup#node_role_arn}.
         *
         * @stability stable
         */
        readonly nodeRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#release_version EksNodeGroup#release_version}.
         *
         * @stability stable
         */
        readonly releaseVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#subnet_ids EksNodeGroup#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#tags EksNodeGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#tags_all EksNodeGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#version EksNodeGroup#version}.
         *
         * @stability stable
         */
        readonly version?: string;
        /**
         * launch_template block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#launch_template EksNodeGroup#launch_template}
         *
         * @stability stable
         */
        readonly launchTemplate?: EksNodeGroupLaunchTemplate;
        /**
         * remote_access block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#remote_access EksNodeGroup#remote_access}
         *
         * @stability stable
         */
        readonly remoteAccess?: EksNodeGroupRemoteAccess;
        /**
         * scaling_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#scaling_config EksNodeGroup#scaling_config}
         *
         * @stability stable
         */
        readonly scalingConfig: EksNodeGroupScalingConfig;
        /**
         * taint block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#taint EksNodeGroup#taint}
         *
         * @stability stable
         */
        readonly taint?: EksNodeGroupTaint[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#timeouts EksNodeGroup#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: EksNodeGroupTimeouts;
        /**
         * update_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#update_config EksNodeGroup#update_config}
         *
         * @stability stable
         */
        readonly updateConfig?: EksNodeGroupUpdateConfig;
    }
    /**
     * @stability stable
     */
    class EksNodeGroupResourcesAutoscalingGroups extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get name(): string;
    }
    /**
     * @stability stable
     */
    class EksNodeGroupResources extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get autoscalingGroups(): any;
        /**
         * @stability stable
         */
        get remoteAccessSecurityGroupId(): string;
    }
    /**
     * @stability stable
     */
    interface EksNodeGroupLaunchTemplate {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#id EksNodeGroup#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#name EksNodeGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#version EksNodeGroup#version}.
         *
         * @stability stable
         */
        readonly version: string;
    }
    /**
     * @stability stable
     */
    class EksNodeGroupLaunchTemplateOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        set version(value: string);
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EksNodeGroupRemoteAccess {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#ec2_ssh_key EksNodeGroup#ec2_ssh_key}.
         *
         * @stability stable
         */
        readonly ec2SshKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#source_security_group_ids EksNodeGroup#source_security_group_ids}.
         *
         * @stability stable
         */
        readonly sourceSecurityGroupIds?: string[];
    }
    /**
     * @stability stable
     */
    class EksNodeGroupRemoteAccessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _ec2SshKey?;
        /**
         * @stability stable
         */
        get ec2SshKey(): string | undefined;
        /**
         * @stability stable
         */
        set ec2SshKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetEc2SshKey(): void;
        /**
         * @stability stable
         */
        get ec2SshKeyInput(): string | undefined;
        private _sourceSecurityGroupIds?;
        /**
         * @stability stable
         */
        get sourceSecurityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set sourceSecurityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSourceSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get sourceSecurityGroupIdsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface EksNodeGroupScalingConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#desired_size EksNodeGroup#desired_size}.
         *
         * @stability stable
         */
        readonly desiredSize: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#max_size EksNodeGroup#max_size}.
         *
         * @stability stable
         */
        readonly maxSize: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#min_size EksNodeGroup#min_size}.
         *
         * @stability stable
         */
        readonly minSize: number;
    }
    /**
     * @stability stable
     */
    class EksNodeGroupScalingConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _desiredSize?;
        /**
         * @stability stable
         */
        get desiredSize(): number;
        /**
         * @stability stable
         */
        set desiredSize(value: number);
        /**
         * @stability stable
         */
        get desiredSizeInput(): number | undefined;
        private _maxSize?;
        /**
         * @stability stable
         */
        get maxSize(): number;
        /**
         * @stability stable
         */
        set maxSize(value: number);
        /**
         * @stability stable
         */
        get maxSizeInput(): number | undefined;
        private _minSize?;
        /**
         * @stability stable
         */
        get minSize(): number;
        /**
         * @stability stable
         */
        set minSize(value: number);
        /**
         * @stability stable
         */
        get minSizeInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface EksNodeGroupTaint {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#effect EksNodeGroup#effect}.
         *
         * @stability stable
         */
        readonly effect: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#key EksNodeGroup#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#value EksNodeGroup#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * @stability stable
     */
    interface EksNodeGroupTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#create EksNodeGroup#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#delete EksNodeGroup#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#update EksNodeGroup#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class EksNodeGroupTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface EksNodeGroupUpdateConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#max_unavailable EksNodeGroup#max_unavailable}.
         *
         * @stability stable
         */
        readonly maxUnavailable?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html#max_unavailable_percentage EksNodeGroup#max_unavailable_percentage}.
         *
         * @stability stable
         */
        readonly maxUnavailablePercentage?: number;
    }
    /**
     * @stability stable
     */
    class EksNodeGroupUpdateConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _maxUnavailable?;
        /**
         * @stability stable
         */
        get maxUnavailable(): number | undefined;
        /**
         * @stability stable
         */
        set maxUnavailable(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxUnavailable(): void;
        /**
         * @stability stable
         */
        get maxUnavailableInput(): number | undefined;
        private _maxUnavailablePercentage?;
        /**
         * @stability stable
         */
        get maxUnavailablePercentage(): number | undefined;
        /**
         * @stability stable
         */
        set maxUnavailablePercentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxUnavailablePercentage(): void;
        /**
         * @stability stable
         */
        get maxUnavailablePercentageInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html aws_eks_node_group}.
     *
     * @stability stable
     */
    class EksNodeGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/eks_node_group.html aws_eks_node_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EksNodeGroupConfig);
        private _amiType?;
        /**
         * @stability stable
         */
        get amiType(): string | undefined;
        /**
         * @stability stable
         */
        set amiType(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmiType(): void;
        /**
         * @stability stable
         */
        get amiTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _capacityType?;
        /**
         * @stability stable
         */
        get capacityType(): string | undefined;
        /**
         * @stability stable
         */
        set capacityType(value: string | undefined);
        /**
         * @stability stable
         */
        resetCapacityType(): void;
        /**
         * @stability stable
         */
        get capacityTypeInput(): string | undefined;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        private _diskSize?;
        /**
         * @stability stable
         */
        get diskSize(): number | undefined;
        /**
         * @stability stable
         */
        set diskSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetDiskSize(): void;
        /**
         * @stability stable
         */
        get diskSizeInput(): number | undefined;
        private _forceUpdateVersion?;
        /**
         * @stability stable
         */
        get forceUpdateVersion(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceUpdateVersion(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceUpdateVersion(): void;
        /**
         * @stability stable
         */
        get forceUpdateVersionInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceTypes?;
        /**
         * @stability stable
         */
        get instanceTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set instanceTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetInstanceTypes(): void;
        /**
         * @stability stable
         */
        get instanceTypesInput(): string[] | undefined;
        private _labels?;
        /**
         * @stability stable
         */
        get labels(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set labels(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetLabels(): void;
        /**
         * @stability stable
         */
        get labelsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _nodeGroupName?;
        /**
         * @stability stable
         */
        get nodeGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set nodeGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetNodeGroupName(): void;
        /**
         * @stability stable
         */
        get nodeGroupNameInput(): string | undefined;
        private _nodeGroupNamePrefix?;
        /**
         * @stability stable
         */
        get nodeGroupNamePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set nodeGroupNamePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNodeGroupNamePrefix(): void;
        /**
         * @stability stable
         */
        get nodeGroupNamePrefixInput(): string | undefined;
        private _nodeRoleArn?;
        /**
         * @stability stable
         */
        get nodeRoleArn(): string;
        /**
         * @stability stable
         */
        set nodeRoleArn(value: string);
        /**
         * @stability stable
         */
        get nodeRoleArnInput(): string | undefined;
        private _releaseVersion?;
        /**
         * @stability stable
         */
        get releaseVersion(): string | undefined;
        /**
         * @stability stable
         */
        set releaseVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetReleaseVersion(): void;
        /**
         * @stability stable
         */
        get releaseVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        resources(index: string): EksNodeGroupResources;
        /**
         * @stability stable
         */
        get status(): string;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
        private _launchTemplate?;
        private __launchTemplateOutput;
        /**
         * @stability stable
         */
        get launchTemplate(): EksNodeGroupLaunchTemplateOutputReference;
        /**
         * @stability stable
         */
        putLaunchTemplate(value: EksNodeGroupLaunchTemplate | undefined): void;
        /**
         * @stability stable
         */
        resetLaunchTemplate(): void;
        /**
         * @stability stable
         */
        get launchTemplateInput(): EksNodeGroupLaunchTemplate | undefined;
        private _remoteAccess?;
        private __remoteAccessOutput;
        /**
         * @stability stable
         */
        get remoteAccess(): EksNodeGroupRemoteAccessOutputReference;
        /**
         * @stability stable
         */
        putRemoteAccess(value: EksNodeGroupRemoteAccess | undefined): void;
        /**
         * @stability stable
         */
        resetRemoteAccess(): void;
        /**
         * @stability stable
         */
        get remoteAccessInput(): EksNodeGroupRemoteAccess | undefined;
        private _scalingConfig?;
        private __scalingConfigOutput;
        /**
         * @stability stable
         */
        get scalingConfig(): EksNodeGroupScalingConfigOutputReference;
        /**
         * @stability stable
         */
        putScalingConfig(value: EksNodeGroupScalingConfig): void;
        /**
         * @stability stable
         */
        get scalingConfigInput(): EksNodeGroupScalingConfig | undefined;
        private _taint?;
        /**
         * @stability stable
         */
        get taint(): EksNodeGroupTaint[] | undefined;
        /**
         * @stability stable
         */
        set taint(value: EksNodeGroupTaint[] | undefined);
        /**
         * @stability stable
         */
        resetTaint(): void;
        /**
         * @stability stable
         */
        get taintInput(): EksNodeGroupTaint[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): EksNodeGroupTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: EksNodeGroupTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): EksNodeGroupTimeouts | undefined;
        private _updateConfig?;
        private __updateConfigOutput;
        /**
         * @stability stable
         */
        get updateConfig(): EksNodeGroupUpdateConfigOutputReference;
        /**
         * @stability stable
         */
        putUpdateConfig(value: EksNodeGroupUpdateConfig | undefined): void;
        /**
         * @stability stable
         */
        resetUpdateConfig(): void;
        /**
         * @stability stable
         */
        get updateConfigInput(): EksNodeGroupUpdateConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEksAddonConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_addon.html#addon_name DataAwsEksAddon#addon_name}.
         *
         * @stability stable
         */
        readonly addonName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_addon.html#cluster_name DataAwsEksAddon#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_addon.html#tags DataAwsEksAddon#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/eks_addon.html aws_eks_addon}.
     *
     * @stability stable
     */
    class DataAwsEksAddon extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_addon.html aws_eks_addon} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEksAddonConfig);
        private _addonName?;
        /**
         * @stability stable
         */
        get addonName(): string;
        /**
         * @stability stable
         */
        set addonName(value: string);
        /**
         * @stability stable
         */
        get addonNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get addonVersion(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get createdAt(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get modifiedAt(): string;
        /**
         * @stability stable
         */
        get serviceAccountRoleArn(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEksClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_cluster.html#name DataAwsEksCluster#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_cluster.html#tags DataAwsEksCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsEksClusterCertificateAuthority extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get data(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsEksClusterIdentityOidc extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get issuer(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsEksClusterIdentity extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get oidc(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsEksClusterKubernetesNetworkConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get serviceIpv4Cidr(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsEksClusterVpcConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get clusterSecurityGroupId(): string;
        /**
         * @stability stable
         */
        get endpointPrivateAccess(): any;
        /**
         * @stability stable
         */
        get endpointPublicAccess(): any;
        /**
         * @stability stable
         */
        get publicAccessCidrs(): string[];
        /**
         * @stability stable
         */
        get securityGroupIds(): string[];
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        get vpcId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/eks_cluster.html aws_eks_cluster}.
     *
     * @stability stable
     */
    class DataAwsEksCluster extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_cluster.html aws_eks_cluster} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEksClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        certificateAuthority(index: string): DataAwsEksClusterCertificateAuthority;
        /**
         * @stability stable
         */
        get createdAt(): string;
        /**
         * @stability stable
         */
        get enabledClusterLogTypes(): string[];
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        identity(index: string): DataAwsEksClusterIdentity;
        /**
         * @stability stable
         */
        kubernetesNetworkConfig(index: string): DataAwsEksClusterKubernetesNetworkConfig;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get platformVersion(): string;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        vpcConfig(index: string): DataAwsEksClusterVpcConfig;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEksClusterAuthConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_cluster_auth.html#name DataAwsEksClusterAuth#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/eks_cluster_auth.html aws_eks_cluster_auth}.
     *
     * @stability stable
     */
    class DataAwsEksClusterAuth extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_cluster_auth.html aws_eks_cluster_auth} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEksClusterAuthConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get token(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEksClustersConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/eks_clusters.html aws_eks_clusters}.
     *
     * @stability stable
     */
    class DataAwsEksClusters extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_clusters.html aws_eks_clusters} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsEksClustersConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get names(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEksNodeGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group.html#cluster_name DataAwsEksNodeGroup#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group.html#node_group_name DataAwsEksNodeGroup#node_group_name}.
         *
         * @stability stable
         */
        readonly nodeGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group.html#tags DataAwsEksNodeGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsEksNodeGroupRemoteAccess extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get ec2SshKey(): string;
        /**
         * @stability stable
         */
        get sourceSecurityGroupIds(): string[];
    }
    /**
     * @stability stable
     */
    class DataAwsEksNodeGroupResourcesAutoscalingGroups extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get name(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsEksNodeGroupResources extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get autoscalingGroups(): any;
        /**
         * @stability stable
         */
        get remoteAccessSecurityGroupId(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsEksNodeGroupScalingConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get desiredSize(): number;
        /**
         * @stability stable
         */
        get maxSize(): number;
        /**
         * @stability stable
         */
        get minSize(): number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group.html aws_eks_node_group}.
     *
     * @stability stable
     */
    class DataAwsEksNodeGroup extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_node_group.html aws_eks_node_group} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEksNodeGroupConfig);
        /**
         * @stability stable
         */
        get amiType(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get diskSize(): number;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get instanceTypes(): string[];
        /**
         * @stability stable
         */
        labels(key: string): string;
        private _nodeGroupName?;
        /**
         * @stability stable
         */
        get nodeGroupName(): string;
        /**
         * @stability stable
         */
        set nodeGroupName(value: string);
        /**
         * @stability stable
         */
        get nodeGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get nodeRoleArn(): string;
        /**
         * @stability stable
         */
        get releaseVersion(): string;
        /**
         * @stability stable
         */
        remoteAccess(index: string): DataAwsEksNodeGroupRemoteAccess;
        /**
         * @stability stable
         */
        resources(index: string): DataAwsEksNodeGroupResources;
        /**
         * @stability stable
         */
        scalingConfig(index: string): DataAwsEksNodeGroupScalingConfig;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsEksNodeGroupsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/eks_node_groups.html#cluster_name DataAwsEksNodeGroups#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/eks_node_groups.html aws_eks_node_groups}.
     *
     * @stability stable
     */
    class DataAwsEksNodeGroups extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/eks_node_groups.html aws_eks_node_groups} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsEksNodeGroupsConfig);
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get names(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
