import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS ElasticSearch Service
*/
export declare namespace ElasticSearch {
    /**
     * @stability stable
     */
    interface ElasticsearchDomainConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#access_policies ElasticsearchDomain#access_policies}.
         *
         * @stability stable
         */
        readonly accessPolicies?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#advanced_options ElasticsearchDomain#advanced_options}.
         *
         * @stability stable
         */
        readonly advancedOptions?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#domain_name ElasticsearchDomain#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#elasticsearch_version ElasticsearchDomain#elasticsearch_version}.
         *
         * @stability stable
         */
        readonly elasticsearchVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#tags ElasticsearchDomain#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#tags_all ElasticsearchDomain#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * advanced_security_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#advanced_security_options ElasticsearchDomain#advanced_security_options}
         *
         * @stability stable
         */
        readonly advancedSecurityOptions?: ElasticsearchDomainAdvancedSecurityOptions;
        /**
         * cluster_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#cluster_config ElasticsearchDomain#cluster_config}
         *
         * @stability stable
         */
        readonly clusterConfig?: ElasticsearchDomainClusterConfig;
        /**
         * cognito_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#cognito_options ElasticsearchDomain#cognito_options}
         *
         * @stability stable
         */
        readonly cognitoOptions?: ElasticsearchDomainCognitoOptions;
        /**
         * domain_endpoint_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#domain_endpoint_options ElasticsearchDomain#domain_endpoint_options}
         *
         * @stability stable
         */
        readonly domainEndpointOptions?: ElasticsearchDomainDomainEndpointOptions;
        /**
         * ebs_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#ebs_options ElasticsearchDomain#ebs_options}
         *
         * @stability stable
         */
        readonly ebsOptions?: ElasticsearchDomainEbsOptions;
        /**
         * encrypt_at_rest block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#encrypt_at_rest ElasticsearchDomain#encrypt_at_rest}
         *
         * @stability stable
         */
        readonly encryptAtRest?: ElasticsearchDomainEncryptAtRest;
        /**
         * log_publishing_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#log_publishing_options ElasticsearchDomain#log_publishing_options}
         *
         * @stability stable
         */
        readonly logPublishingOptions?: ElasticsearchDomainLogPublishingOptions[];
        /**
         * node_to_node_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#node_to_node_encryption ElasticsearchDomain#node_to_node_encryption}
         *
         * @stability stable
         */
        readonly nodeToNodeEncryption?: ElasticsearchDomainNodeToNodeEncryption;
        /**
         * snapshot_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#snapshot_options ElasticsearchDomain#snapshot_options}
         *
         * @stability stable
         */
        readonly snapshotOptions?: ElasticsearchDomainSnapshotOptions;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#timeouts ElasticsearchDomain#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: ElasticsearchDomainTimeouts;
        /**
         * vpc_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#vpc_options ElasticsearchDomain#vpc_options}
         *
         * @stability stable
         */
        readonly vpcOptions?: ElasticsearchDomainVpcOptions;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#master_user_arn ElasticsearchDomain#master_user_arn}.
         *
         * @stability stable
         */
        readonly masterUserArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#master_user_name ElasticsearchDomain#master_user_name}.
         *
         * @stability stable
         */
        readonly masterUserName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#master_user_password ElasticsearchDomain#master_user_password}.
         *
         * @stability stable
         */
        readonly masterUserPassword?: string;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _masterUserArn?;
        /**
         * @stability stable
         */
        get masterUserArn(): string | undefined;
        /**
         * @stability stable
         */
        set masterUserArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetMasterUserArn(): void;
        /**
         * @stability stable
         */
        get masterUserArnInput(): string | undefined;
        private _masterUserName?;
        /**
         * @stability stable
         */
        get masterUserName(): string | undefined;
        /**
         * @stability stable
         */
        set masterUserName(value: string | undefined);
        /**
         * @stability stable
         */
        resetMasterUserName(): void;
        /**
         * @stability stable
         */
        get masterUserNameInput(): string | undefined;
        private _masterUserPassword?;
        /**
         * @stability stable
         */
        get masterUserPassword(): string | undefined;
        /**
         * @stability stable
         */
        set masterUserPassword(value: string | undefined);
        /**
         * @stability stable
         */
        resetMasterUserPassword(): void;
        /**
         * @stability stable
         */
        get masterUserPasswordInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainAdvancedSecurityOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#enabled ElasticsearchDomain#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#internal_user_database_enabled ElasticsearchDomain#internal_user_database_enabled}.
         *
         * @stability stable
         */
        readonly internalUserDatabaseEnabled?: boolean | cdktf.IResolvable;
        /**
         * master_user_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#master_user_options ElasticsearchDomain#master_user_options}
         *
         * @stability stable
         */
        readonly masterUserOptions?: ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainAdvancedSecurityOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _internalUserDatabaseEnabled?;
        /**
         * @stability stable
         */
        get internalUserDatabaseEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set internalUserDatabaseEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInternalUserDatabaseEnabled(): void;
        /**
         * @stability stable
         */
        get internalUserDatabaseEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _masterUserOptions?;
        private __masterUserOptionsOutput;
        /**
         * @stability stable
         */
        get masterUserOptions(): ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptionsOutputReference;
        /**
         * @stability stable
         */
        putMasterUserOptions(value: ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions | undefined): void;
        /**
         * @stability stable
         */
        resetMasterUserOptions(): void;
        /**
         * @stability stable
         */
        get masterUserOptionsInput(): ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainClusterConfigZoneAwarenessConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#availability_zone_count ElasticsearchDomain#availability_zone_count}.
         *
         * @stability stable
         */
        readonly availabilityZoneCount?: number;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainClusterConfigZoneAwarenessConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _availabilityZoneCount?;
        /**
         * @stability stable
         */
        get availabilityZoneCount(): number | undefined;
        /**
         * @stability stable
         */
        set availabilityZoneCount(value: number | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZoneCount(): void;
        /**
         * @stability stable
         */
        get availabilityZoneCountInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainClusterConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#dedicated_master_count ElasticsearchDomain#dedicated_master_count}.
         *
         * @stability stable
         */
        readonly dedicatedMasterCount?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#dedicated_master_enabled ElasticsearchDomain#dedicated_master_enabled}.
         *
         * @stability stable
         */
        readonly dedicatedMasterEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#dedicated_master_type ElasticsearchDomain#dedicated_master_type}.
         *
         * @stability stable
         */
        readonly dedicatedMasterType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#instance_count ElasticsearchDomain#instance_count}.
         *
         * @stability stable
         */
        readonly instanceCount?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#instance_type ElasticsearchDomain#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#warm_count ElasticsearchDomain#warm_count}.
         *
         * @stability stable
         */
        readonly warmCount?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#warm_enabled ElasticsearchDomain#warm_enabled}.
         *
         * @stability stable
         */
        readonly warmEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#warm_type ElasticsearchDomain#warm_type}.
         *
         * @stability stable
         */
        readonly warmType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#zone_awareness_enabled ElasticsearchDomain#zone_awareness_enabled}.
         *
         * @stability stable
         */
        readonly zoneAwarenessEnabled?: boolean | cdktf.IResolvable;
        /**
         * zone_awareness_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#zone_awareness_config ElasticsearchDomain#zone_awareness_config}
         *
         * @stability stable
         */
        readonly zoneAwarenessConfig?: ElasticsearchDomainClusterConfigZoneAwarenessConfig;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainClusterConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _dedicatedMasterCount?;
        /**
         * @stability stable
         */
        get dedicatedMasterCount(): number | undefined;
        /**
         * @stability stable
         */
        set dedicatedMasterCount(value: number | undefined);
        /**
         * @stability stable
         */
        resetDedicatedMasterCount(): void;
        /**
         * @stability stable
         */
        get dedicatedMasterCountInput(): number | undefined;
        private _dedicatedMasterEnabled?;
        /**
         * @stability stable
         */
        get dedicatedMasterEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set dedicatedMasterEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDedicatedMasterEnabled(): void;
        /**
         * @stability stable
         */
        get dedicatedMasterEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _dedicatedMasterType?;
        /**
         * @stability stable
         */
        get dedicatedMasterType(): string | undefined;
        /**
         * @stability stable
         */
        set dedicatedMasterType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDedicatedMasterType(): void;
        /**
         * @stability stable
         */
        get dedicatedMasterTypeInput(): string | undefined;
        private _instanceCount?;
        /**
         * @stability stable
         */
        get instanceCount(): number | undefined;
        /**
         * @stability stable
         */
        set instanceCount(value: number | undefined);
        /**
         * @stability stable
         */
        resetInstanceCount(): void;
        /**
         * @stability stable
         */
        get instanceCountInput(): number | undefined;
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _warmCount?;
        /**
         * @stability stable
         */
        get warmCount(): number | undefined;
        /**
         * @stability stable
         */
        set warmCount(value: number | undefined);
        /**
         * @stability stable
         */
        resetWarmCount(): void;
        /**
         * @stability stable
         */
        get warmCountInput(): number | undefined;
        private _warmEnabled?;
        /**
         * @stability stable
         */
        get warmEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set warmEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWarmEnabled(): void;
        /**
         * @stability stable
         */
        get warmEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _warmType?;
        /**
         * @stability stable
         */
        get warmType(): string | undefined;
        /**
         * @stability stable
         */
        set warmType(value: string | undefined);
        /**
         * @stability stable
         */
        resetWarmType(): void;
        /**
         * @stability stable
         */
        get warmTypeInput(): string | undefined;
        private _zoneAwarenessEnabled?;
        /**
         * @stability stable
         */
        get zoneAwarenessEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set zoneAwarenessEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetZoneAwarenessEnabled(): void;
        /**
         * @stability stable
         */
        get zoneAwarenessEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _zoneAwarenessConfig?;
        private __zoneAwarenessConfigOutput;
        /**
         * @stability stable
         */
        get zoneAwarenessConfig(): ElasticsearchDomainClusterConfigZoneAwarenessConfigOutputReference;
        /**
         * @stability stable
         */
        putZoneAwarenessConfig(value: ElasticsearchDomainClusterConfigZoneAwarenessConfig | undefined): void;
        /**
         * @stability stable
         */
        resetZoneAwarenessConfig(): void;
        /**
         * @stability stable
         */
        get zoneAwarenessConfigInput(): ElasticsearchDomainClusterConfigZoneAwarenessConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainCognitoOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#enabled ElasticsearchDomain#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#identity_pool_id ElasticsearchDomain#identity_pool_id}.
         *
         * @stability stable
         */
        readonly identityPoolId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#role_arn ElasticsearchDomain#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#user_pool_id ElasticsearchDomain#user_pool_id}.
         *
         * @stability stable
         */
        readonly userPoolId: string;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainCognitoOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _identityPoolId?;
        /**
         * @stability stable
         */
        get identityPoolId(): string;
        /**
         * @stability stable
         */
        set identityPoolId(value: string);
        /**
         * @stability stable
         */
        get identityPoolIdInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _userPoolId?;
        /**
         * @stability stable
         */
        get userPoolId(): string;
        /**
         * @stability stable
         */
        set userPoolId(value: string);
        /**
         * @stability stable
         */
        get userPoolIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainDomainEndpointOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#custom_endpoint ElasticsearchDomain#custom_endpoint}.
         *
         * @stability stable
         */
        readonly customEndpoint?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#custom_endpoint_certificate_arn ElasticsearchDomain#custom_endpoint_certificate_arn}.
         *
         * @stability stable
         */
        readonly customEndpointCertificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#custom_endpoint_enabled ElasticsearchDomain#custom_endpoint_enabled}.
         *
         * @stability stable
         */
        readonly customEndpointEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#enforce_https ElasticsearchDomain#enforce_https}.
         *
         * @stability stable
         */
        readonly enforceHttps?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#tls_security_policy ElasticsearchDomain#tls_security_policy}.
         *
         * @stability stable
         */
        readonly tlsSecurityPolicy?: string;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainDomainEndpointOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _customEndpoint?;
        /**
         * @stability stable
         */
        get customEndpoint(): string | undefined;
        /**
         * @stability stable
         */
        set customEndpoint(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomEndpoint(): void;
        /**
         * @stability stable
         */
        get customEndpointInput(): string | undefined;
        private _customEndpointCertificateArn?;
        /**
         * @stability stable
         */
        get customEndpointCertificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set customEndpointCertificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomEndpointCertificateArn(): void;
        /**
         * @stability stable
         */
        get customEndpointCertificateArnInput(): string | undefined;
        private _customEndpointEnabled?;
        /**
         * @stability stable
         */
        get customEndpointEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set customEndpointEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCustomEndpointEnabled(): void;
        /**
         * @stability stable
         */
        get customEndpointEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _enforceHttps?;
        /**
         * @stability stable
         */
        get enforceHttps(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enforceHttps(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnforceHttps(): void;
        /**
         * @stability stable
         */
        get enforceHttpsInput(): boolean | cdktf.IResolvable | undefined;
        private _tlsSecurityPolicy?;
        /**
         * @stability stable
         */
        get tlsSecurityPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set tlsSecurityPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetTlsSecurityPolicy(): void;
        /**
         * @stability stable
         */
        get tlsSecurityPolicyInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainEbsOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#ebs_enabled ElasticsearchDomain#ebs_enabled}.
         *
         * @stability stable
         */
        readonly ebsEnabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#iops ElasticsearchDomain#iops}.
         *
         * @stability stable
         */
        readonly iops?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#volume_size ElasticsearchDomain#volume_size}.
         *
         * @stability stable
         */
        readonly volumeSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#volume_type ElasticsearchDomain#volume_type}.
         *
         * @stability stable
         */
        readonly volumeType?: string;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainEbsOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _ebsEnabled?;
        /**
         * @stability stable
         */
        get ebsEnabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set ebsEnabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get ebsEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _iops?;
        /**
         * @stability stable
         */
        get iops(): number | undefined;
        /**
         * @stability stable
         */
        set iops(value: number | undefined);
        /**
         * @stability stable
         */
        resetIops(): void;
        /**
         * @stability stable
         */
        get iopsInput(): number | undefined;
        private _volumeSize?;
        /**
         * @stability stable
         */
        get volumeSize(): number | undefined;
        /**
         * @stability stable
         */
        set volumeSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetVolumeSize(): void;
        /**
         * @stability stable
         */
        get volumeSizeInput(): number | undefined;
        private _volumeType?;
        /**
         * @stability stable
         */
        get volumeType(): string | undefined;
        /**
         * @stability stable
         */
        set volumeType(value: string | undefined);
        /**
         * @stability stable
         */
        resetVolumeType(): void;
        /**
         * @stability stable
         */
        get volumeTypeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainEncryptAtRest {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#enabled ElasticsearchDomain#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#kms_key_id ElasticsearchDomain#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainEncryptAtRestOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainLogPublishingOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#cloudwatch_log_group_arn ElasticsearchDomain#cloudwatch_log_group_arn}.
         *
         * @stability stable
         */
        readonly cloudwatchLogGroupArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#enabled ElasticsearchDomain#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#log_type ElasticsearchDomain#log_type}.
         *
         * @stability stable
         */
        readonly logType: string;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainNodeToNodeEncryption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#enabled ElasticsearchDomain#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainNodeToNodeEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainSnapshotOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#automated_snapshot_start_hour ElasticsearchDomain#automated_snapshot_start_hour}.
         *
         * @stability stable
         */
        readonly automatedSnapshotStartHour: number;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainSnapshotOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _automatedSnapshotStartHour?;
        /**
         * @stability stable
         */
        get automatedSnapshotStartHour(): number;
        /**
         * @stability stable
         */
        set automatedSnapshotStartHour(value: number);
        /**
         * @stability stable
         */
        get automatedSnapshotStartHourInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#update ElasticsearchDomain#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainVpcOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#security_group_ids ElasticsearchDomain#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html#subnet_ids ElasticsearchDomain#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds?: string[];
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainVpcOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnetIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetIds(): void;
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html aws_elasticsearch_domain}.
     *
     * @stability stable
     */
    class ElasticsearchDomain extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain.html aws_elasticsearch_domain} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ElasticsearchDomainConfig);
        private _accessPolicies?;
        /**
         * @stability stable
         */
        get accessPolicies(): string | undefined;
        /**
         * @stability stable
         */
        set accessPolicies(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccessPolicies(): void;
        /**
         * @stability stable
         */
        get accessPoliciesInput(): string | undefined;
        private _advancedOptions?;
        /**
         * @stability stable
         */
        get advancedOptions(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set advancedOptions(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAdvancedOptions(): void;
        /**
         * @stability stable
         */
        get advancedOptionsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get domainId(): string;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        private _elasticsearchVersion?;
        /**
         * @stability stable
         */
        get elasticsearchVersion(): string | undefined;
        /**
         * @stability stable
         */
        set elasticsearchVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetElasticsearchVersion(): void;
        /**
         * @stability stable
         */
        get elasticsearchVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kibanaEndpoint(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _advancedSecurityOptions?;
        private __advancedSecurityOptionsOutput;
        /**
         * @stability stable
         */
        get advancedSecurityOptions(): ElasticsearchDomainAdvancedSecurityOptionsOutputReference;
        /**
         * @stability stable
         */
        putAdvancedSecurityOptions(value: ElasticsearchDomainAdvancedSecurityOptions | undefined): void;
        /**
         * @stability stable
         */
        resetAdvancedSecurityOptions(): void;
        /**
         * @stability stable
         */
        get advancedSecurityOptionsInput(): ElasticsearchDomainAdvancedSecurityOptions | undefined;
        private _clusterConfig?;
        private __clusterConfigOutput;
        /**
         * @stability stable
         */
        get clusterConfig(): ElasticsearchDomainClusterConfigOutputReference;
        /**
         * @stability stable
         */
        putClusterConfig(value: ElasticsearchDomainClusterConfig | undefined): void;
        /**
         * @stability stable
         */
        resetClusterConfig(): void;
        /**
         * @stability stable
         */
        get clusterConfigInput(): ElasticsearchDomainClusterConfig | undefined;
        private _cognitoOptions?;
        private __cognitoOptionsOutput;
        /**
         * @stability stable
         */
        get cognitoOptions(): ElasticsearchDomainCognitoOptionsOutputReference;
        /**
         * @stability stable
         */
        putCognitoOptions(value: ElasticsearchDomainCognitoOptions | undefined): void;
        /**
         * @stability stable
         */
        resetCognitoOptions(): void;
        /**
         * @stability stable
         */
        get cognitoOptionsInput(): ElasticsearchDomainCognitoOptions | undefined;
        private _domainEndpointOptions?;
        private __domainEndpointOptionsOutput;
        /**
         * @stability stable
         */
        get domainEndpointOptions(): ElasticsearchDomainDomainEndpointOptionsOutputReference;
        /**
         * @stability stable
         */
        putDomainEndpointOptions(value: ElasticsearchDomainDomainEndpointOptions | undefined): void;
        /**
         * @stability stable
         */
        resetDomainEndpointOptions(): void;
        /**
         * @stability stable
         */
        get domainEndpointOptionsInput(): ElasticsearchDomainDomainEndpointOptions | undefined;
        private _ebsOptions?;
        private __ebsOptionsOutput;
        /**
         * @stability stable
         */
        get ebsOptions(): ElasticsearchDomainEbsOptionsOutputReference;
        /**
         * @stability stable
         */
        putEbsOptions(value: ElasticsearchDomainEbsOptions | undefined): void;
        /**
         * @stability stable
         */
        resetEbsOptions(): void;
        /**
         * @stability stable
         */
        get ebsOptionsInput(): ElasticsearchDomainEbsOptions | undefined;
        private _encryptAtRest?;
        private __encryptAtRestOutput;
        /**
         * @stability stable
         */
        get encryptAtRest(): ElasticsearchDomainEncryptAtRestOutputReference;
        /**
         * @stability stable
         */
        putEncryptAtRest(value: ElasticsearchDomainEncryptAtRest | undefined): void;
        /**
         * @stability stable
         */
        resetEncryptAtRest(): void;
        /**
         * @stability stable
         */
        get encryptAtRestInput(): ElasticsearchDomainEncryptAtRest | undefined;
        private _logPublishingOptions?;
        /**
         * @stability stable
         */
        get logPublishingOptions(): ElasticsearchDomainLogPublishingOptions[] | undefined;
        /**
         * @stability stable
         */
        set logPublishingOptions(value: ElasticsearchDomainLogPublishingOptions[] | undefined);
        /**
         * @stability stable
         */
        resetLogPublishingOptions(): void;
        /**
         * @stability stable
         */
        get logPublishingOptionsInput(): ElasticsearchDomainLogPublishingOptions[] | undefined;
        private _nodeToNodeEncryption?;
        private __nodeToNodeEncryptionOutput;
        /**
         * @stability stable
         */
        get nodeToNodeEncryption(): ElasticsearchDomainNodeToNodeEncryptionOutputReference;
        /**
         * @stability stable
         */
        putNodeToNodeEncryption(value: ElasticsearchDomainNodeToNodeEncryption | undefined): void;
        /**
         * @stability stable
         */
        resetNodeToNodeEncryption(): void;
        /**
         * @stability stable
         */
        get nodeToNodeEncryptionInput(): ElasticsearchDomainNodeToNodeEncryption | undefined;
        private _snapshotOptions?;
        private __snapshotOptionsOutput;
        /**
         * @stability stable
         */
        get snapshotOptions(): ElasticsearchDomainSnapshotOptionsOutputReference;
        /**
         * @stability stable
         */
        putSnapshotOptions(value: ElasticsearchDomainSnapshotOptions | undefined): void;
        /**
         * @stability stable
         */
        resetSnapshotOptions(): void;
        /**
         * @stability stable
         */
        get snapshotOptionsInput(): ElasticsearchDomainSnapshotOptions | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): ElasticsearchDomainTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: ElasticsearchDomainTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): ElasticsearchDomainTimeouts | undefined;
        private _vpcOptions?;
        private __vpcOptionsOutput;
        /**
         * @stability stable
         */
        get vpcOptions(): ElasticsearchDomainVpcOptionsOutputReference;
        /**
         * @stability stable
         */
        putVpcOptions(value: ElasticsearchDomainVpcOptions | undefined): void;
        /**
         * @stability stable
         */
        resetVpcOptions(): void;
        /**
         * @stability stable
         */
        get vpcOptionsInput(): ElasticsearchDomainVpcOptions | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_policy.html#access_policies ElasticsearchDomainPolicy#access_policies}.
         *
         * @stability stable
         */
        readonly accessPolicies: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_policy.html#domain_name ElasticsearchDomainPolicy#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_policy.html aws_elasticsearch_domain_policy}.
     *
     * @stability stable
     */
    class ElasticsearchDomainPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_policy.html aws_elasticsearch_domain_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ElasticsearchDomainPolicyConfig);
        private _accessPolicies?;
        /**
         * @stability stable
         */
        get accessPolicies(): string;
        /**
         * @stability stable
         */
        set accessPolicies(value: string);
        /**
         * @stability stable
         */
        get accessPoliciesInput(): string | undefined;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainSamlOptionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#domain_name ElasticsearchDomainSamlOptions#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * saml_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#saml_options ElasticsearchDomainSamlOptions#saml_options}
         *
         * @stability stable
         */
        readonly samlOptions?: ElasticsearchDomainSamlOptionsSamlOptions;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainSamlOptionsSamlOptionsIdp {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#entity_id ElasticsearchDomainSamlOptions#entity_id}.
         *
         * @stability stable
         */
        readonly entityId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#metadata_content ElasticsearchDomainSamlOptions#metadata_content}.
         *
         * @stability stable
         */
        readonly metadataContent: string;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainSamlOptionsSamlOptionsIdpOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _entityId?;
        /**
         * @stability stable
         */
        get entityId(): string;
        /**
         * @stability stable
         */
        set entityId(value: string);
        /**
         * @stability stable
         */
        get entityIdInput(): string | undefined;
        private _metadataContent?;
        /**
         * @stability stable
         */
        get metadataContent(): string;
        /**
         * @stability stable
         */
        set metadataContent(value: string);
        /**
         * @stability stable
         */
        get metadataContentInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElasticsearchDomainSamlOptionsSamlOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#enabled ElasticsearchDomainSamlOptions#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#master_backend_role ElasticsearchDomainSamlOptions#master_backend_role}.
         *
         * @stability stable
         */
        readonly masterBackendRole?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#master_user_name ElasticsearchDomainSamlOptions#master_user_name}.
         *
         * @stability stable
         */
        readonly masterUserName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#roles_key ElasticsearchDomainSamlOptions#roles_key}.
         *
         * @stability stable
         */
        readonly rolesKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#session_timeout_minutes ElasticsearchDomainSamlOptions#session_timeout_minutes}.
         *
         * @stability stable
         */
        readonly sessionTimeoutMinutes?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#subject_key ElasticsearchDomainSamlOptions#subject_key}.
         *
         * @stability stable
         */
        readonly subjectKey?: string;
        /**
         * idp block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html#idp ElasticsearchDomainSamlOptions#idp}
         *
         * @stability stable
         */
        readonly idp?: ElasticsearchDomainSamlOptionsSamlOptionsIdp;
    }
    /**
     * @stability stable
     */
    class ElasticsearchDomainSamlOptionsSamlOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _masterBackendRole?;
        /**
         * @stability stable
         */
        get masterBackendRole(): string | undefined;
        /**
         * @stability stable
         */
        set masterBackendRole(value: string | undefined);
        /**
         * @stability stable
         */
        resetMasterBackendRole(): void;
        /**
         * @stability stable
         */
        get masterBackendRoleInput(): string | undefined;
        private _masterUserName?;
        /**
         * @stability stable
         */
        get masterUserName(): string | undefined;
        /**
         * @stability stable
         */
        set masterUserName(value: string | undefined);
        /**
         * @stability stable
         */
        resetMasterUserName(): void;
        /**
         * @stability stable
         */
        get masterUserNameInput(): string | undefined;
        private _rolesKey?;
        /**
         * @stability stable
         */
        get rolesKey(): string | undefined;
        /**
         * @stability stable
         */
        set rolesKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetRolesKey(): void;
        /**
         * @stability stable
         */
        get rolesKeyInput(): string | undefined;
        private _sessionTimeoutMinutes?;
        /**
         * @stability stable
         */
        get sessionTimeoutMinutes(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeoutMinutes(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeoutMinutes(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutMinutesInput(): number | undefined;
        private _subjectKey?;
        /**
         * @stability stable
         */
        get subjectKey(): string | undefined;
        /**
         * @stability stable
         */
        set subjectKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubjectKey(): void;
        /**
         * @stability stable
         */
        get subjectKeyInput(): string | undefined;
        private _idp?;
        private __idpOutput;
        /**
         * @stability stable
         */
        get idp(): ElasticsearchDomainSamlOptionsSamlOptionsIdpOutputReference;
        /**
         * @stability stable
         */
        putIdp(value: ElasticsearchDomainSamlOptionsSamlOptionsIdp | undefined): void;
        /**
         * @stability stable
         */
        resetIdp(): void;
        /**
         * @stability stable
         */
        get idpInput(): ElasticsearchDomainSamlOptionsSamlOptionsIdp | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html aws_elasticsearch_domain_saml_options}.
     *
     * @stability stable
     */
    class ElasticsearchDomainSamlOptions extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elasticsearch_domain_saml_options.html aws_elasticsearch_domain_saml_options} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ElasticsearchDomainSamlOptionsConfig);
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _samlOptions?;
        private __samlOptionsOutput;
        /**
         * @stability stable
         */
        get samlOptions(): ElasticsearchDomainSamlOptionsSamlOptionsOutputReference;
        /**
         * @stability stable
         */
        putSamlOptions(value: ElasticsearchDomainSamlOptionsSamlOptions | undefined): void;
        /**
         * @stability stable
         */
        resetSamlOptions(): void;
        /**
         * @stability stable
         */
        get samlOptionsInput(): ElasticsearchDomainSamlOptionsSamlOptions | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsElasticsearchDomainConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/elasticsearch_domain.html#domain_name DataAwsElasticsearchDomain#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/elasticsearch_domain.html#tags DataAwsElasticsearchDomain#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainAdvancedSecurityOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get internalUserDatabaseEnabled(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainClusterConfigZoneAwarenessConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get availabilityZoneCount(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainClusterConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get dedicatedMasterCount(): number;
        /**
         * @stability stable
         */
        get dedicatedMasterEnabled(): any;
        /**
         * @stability stable
         */
        get dedicatedMasterType(): string;
        /**
         * @stability stable
         */
        get instanceCount(): number;
        /**
         * @stability stable
         */
        get instanceType(): string;
        /**
         * @stability stable
         */
        get warmCount(): number;
        /**
         * @stability stable
         */
        get warmEnabled(): any;
        /**
         * @stability stable
         */
        get warmType(): string;
        /**
         * @stability stable
         */
        get zoneAwarenessConfig(): any;
        /**
         * @stability stable
         */
        get zoneAwarenessEnabled(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainCognitoOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get identityPoolId(): string;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        get userPoolId(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainEbsOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get ebsEnabled(): any;
        /**
         * @stability stable
         */
        get iops(): number;
        /**
         * @stability stable
         */
        get volumeSize(): number;
        /**
         * @stability stable
         */
        get volumeType(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainEncryptionAtRest extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainLogPublishingOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get cloudwatchLogGroupArn(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get logType(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainNodeToNodeEncryption extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get enabled(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainSnapshotOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get automatedSnapshotStartHour(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsElasticsearchDomainVpcOptions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get securityGroupIds(): string[];
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        get vpcId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/elasticsearch_domain.html aws_elasticsearch_domain}.
     *
     * @stability stable
     */
    class DataAwsElasticsearchDomain extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/elasticsearch_domain.html aws_elasticsearch_domain} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsElasticsearchDomainConfig);
        /**
         * @stability stable
         */
        get accessPolicies(): string;
        /**
         * @stability stable
         */
        advancedOptions(key: string): string;
        /**
         * @stability stable
         */
        advancedSecurityOptions(index: string): DataAwsElasticsearchDomainAdvancedSecurityOptions;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        clusterConfig(index: string): DataAwsElasticsearchDomainClusterConfig;
        /**
         * @stability stable
         */
        cognitoOptions(index: string): DataAwsElasticsearchDomainCognitoOptions;
        /**
         * @stability stable
         */
        get created(): any;
        /**
         * @stability stable
         */
        get deleted(): any;
        /**
         * @stability stable
         */
        get domainId(): string;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        ebsOptions(index: string): DataAwsElasticsearchDomainEbsOptions;
        /**
         * @stability stable
         */
        get elasticsearchVersion(): string;
        /**
         * @stability stable
         */
        encryptionAtRest(index: string): DataAwsElasticsearchDomainEncryptionAtRest;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kibanaEndpoint(): string;
        /**
         * @stability stable
         */
        logPublishingOptions(index: string): DataAwsElasticsearchDomainLogPublishingOptions;
        /**
         * @stability stable
         */
        nodeToNodeEncryption(index: string): DataAwsElasticsearchDomainNodeToNodeEncryption;
        /**
         * @stability stable
         */
        get processing(): any;
        /**
         * @stability stable
         */
        snapshotOptions(index: string): DataAwsElasticsearchDomainSnapshotOptions;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        vpcOptions(index: string): DataAwsElasticsearchDomainVpcOptions;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
