import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Elastic Transcoder
*/
export declare namespace ElasticTranscoder {
    /**
     * @stability stable
     */
    interface ElastictranscoderPipelineConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#aws_kms_key_arn ElastictranscoderPipeline#aws_kms_key_arn}.
         *
         * @stability stable
         */
        readonly awsKmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#input_bucket ElastictranscoderPipeline#input_bucket}.
         *
         * @stability stable
         */
        readonly inputBucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#name ElastictranscoderPipeline#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#output_bucket ElastictranscoderPipeline#output_bucket}.
         *
         * @stability stable
         */
        readonly outputBucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#role ElastictranscoderPipeline#role}.
         *
         * @stability stable
         */
        readonly role: string;
        /**
         * content_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#content_config ElastictranscoderPipeline#content_config}
         *
         * @stability stable
         */
        readonly contentConfig?: ElastictranscoderPipelineContentConfig;
        /**
         * content_config_permissions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#content_config_permissions ElastictranscoderPipeline#content_config_permissions}
         *
         * @stability stable
         */
        readonly contentConfigPermissions?: ElastictranscoderPipelineContentConfigPermissions[];
        /**
         * notifications block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#notifications ElastictranscoderPipeline#notifications}
         *
         * @stability stable
         */
        readonly notifications?: ElastictranscoderPipelineNotifications;
        /**
         * thumbnail_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#thumbnail_config ElastictranscoderPipeline#thumbnail_config}
         *
         * @stability stable
         */
        readonly thumbnailConfig?: ElastictranscoderPipelineThumbnailConfig;
        /**
         * thumbnail_config_permissions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#thumbnail_config_permissions ElastictranscoderPipeline#thumbnail_config_permissions}
         *
         * @stability stable
         */
        readonly thumbnailConfigPermissions?: ElastictranscoderPipelineThumbnailConfigPermissions[];
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPipelineContentConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#bucket ElastictranscoderPipeline#bucket}.
         *
         * @stability stable
         */
        readonly bucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#storage_class ElastictranscoderPipeline#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass?: string;
    }
    /**
     * @stability stable
     */
    class ElastictranscoderPipelineContentConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string | undefined;
        /**
         * @stability stable
         */
        set bucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucket(): void;
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _storageClass?;
        /**
         * @stability stable
         */
        get storageClass(): string | undefined;
        /**
         * @stability stable
         */
        set storageClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageClass(): void;
        /**
         * @stability stable
         */
        get storageClassInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPipelineContentConfigPermissions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#access ElastictranscoderPipeline#access}.
         *
         * @stability stable
         */
        readonly access?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#grantee ElastictranscoderPipeline#grantee}.
         *
         * @stability stable
         */
        readonly grantee?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#grantee_type ElastictranscoderPipeline#grantee_type}.
         *
         * @stability stable
         */
        readonly granteeType?: string;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPipelineNotifications {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#completed ElastictranscoderPipeline#completed}.
         *
         * @stability stable
         */
        readonly completed?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#error ElastictranscoderPipeline#error}.
         *
         * @stability stable
         */
        readonly error?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#progressing ElastictranscoderPipeline#progressing}.
         *
         * @stability stable
         */
        readonly progressing?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#warning ElastictranscoderPipeline#warning}.
         *
         * @stability stable
         */
        readonly warning?: string;
    }
    /**
     * @stability stable
     */
    class ElastictranscoderPipelineNotificationsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _completed?;
        /**
         * @stability stable
         */
        get completed(): string | undefined;
        /**
         * @stability stable
         */
        set completed(value: string | undefined);
        /**
         * @stability stable
         */
        resetCompleted(): void;
        /**
         * @stability stable
         */
        get completedInput(): string | undefined;
        private _error?;
        /**
         * @stability stable
         */
        get error(): string | undefined;
        /**
         * @stability stable
         */
        set error(value: string | undefined);
        /**
         * @stability stable
         */
        resetError(): void;
        /**
         * @stability stable
         */
        get errorInput(): string | undefined;
        private _progressing?;
        /**
         * @stability stable
         */
        get progressing(): string | undefined;
        /**
         * @stability stable
         */
        set progressing(value: string | undefined);
        /**
         * @stability stable
         */
        resetProgressing(): void;
        /**
         * @stability stable
         */
        get progressingInput(): string | undefined;
        private _warning?;
        /**
         * @stability stable
         */
        get warning(): string | undefined;
        /**
         * @stability stable
         */
        set warning(value: string | undefined);
        /**
         * @stability stable
         */
        resetWarning(): void;
        /**
         * @stability stable
         */
        get warningInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPipelineThumbnailConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#bucket ElastictranscoderPipeline#bucket}.
         *
         * @stability stable
         */
        readonly bucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#storage_class ElastictranscoderPipeline#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass?: string;
    }
    /**
     * @stability stable
     */
    class ElastictranscoderPipelineThumbnailConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string | undefined;
        /**
         * @stability stable
         */
        set bucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucket(): void;
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _storageClass?;
        /**
         * @stability stable
         */
        get storageClass(): string | undefined;
        /**
         * @stability stable
         */
        set storageClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageClass(): void;
        /**
         * @stability stable
         */
        get storageClassInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPipelineThumbnailConfigPermissions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#access ElastictranscoderPipeline#access}.
         *
         * @stability stable
         */
        readonly access?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#grantee ElastictranscoderPipeline#grantee}.
         *
         * @stability stable
         */
        readonly grantee?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html#grantee_type ElastictranscoderPipeline#grantee_type}.
         *
         * @stability stable
         */
        readonly granteeType?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html aws_elastictranscoder_pipeline}.
     *
     * @stability stable
     */
    class ElastictranscoderPipeline extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_pipeline.html aws_elastictranscoder_pipeline} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ElastictranscoderPipelineConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _awsKmsKeyArn?;
        /**
         * @stability stable
         */
        get awsKmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set awsKmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetAwsKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get awsKmsKeyArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _inputBucket?;
        /**
         * @stability stable
         */
        get inputBucket(): string;
        /**
         * @stability stable
         */
        set inputBucket(value: string);
        /**
         * @stability stable
         */
        get inputBucketInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _outputBucket?;
        /**
         * @stability stable
         */
        get outputBucket(): string | undefined;
        /**
         * @stability stable
         */
        set outputBucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutputBucket(): void;
        /**
         * @stability stable
         */
        get outputBucketInput(): string | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        set role(value: string);
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        private _contentConfig?;
        private __contentConfigOutput;
        /**
         * @stability stable
         */
        get contentConfig(): ElastictranscoderPipelineContentConfigOutputReference;
        /**
         * @stability stable
         */
        putContentConfig(value: ElastictranscoderPipelineContentConfig | undefined): void;
        /**
         * @stability stable
         */
        resetContentConfig(): void;
        /**
         * @stability stable
         */
        get contentConfigInput(): ElastictranscoderPipelineContentConfig | undefined;
        private _contentConfigPermissions?;
        /**
         * @stability stable
         */
        get contentConfigPermissions(): ElastictranscoderPipelineContentConfigPermissions[] | undefined;
        /**
         * @stability stable
         */
        set contentConfigPermissions(value: ElastictranscoderPipelineContentConfigPermissions[] | undefined);
        /**
         * @stability stable
         */
        resetContentConfigPermissions(): void;
        /**
         * @stability stable
         */
        get contentConfigPermissionsInput(): ElastictranscoderPipelineContentConfigPermissions[] | undefined;
        private _notifications?;
        private __notificationsOutput;
        /**
         * @stability stable
         */
        get notifications(): ElastictranscoderPipelineNotificationsOutputReference;
        /**
         * @stability stable
         */
        putNotifications(value: ElastictranscoderPipelineNotifications | undefined): void;
        /**
         * @stability stable
         */
        resetNotifications(): void;
        /**
         * @stability stable
         */
        get notificationsInput(): ElastictranscoderPipelineNotifications | undefined;
        private _thumbnailConfig?;
        private __thumbnailConfigOutput;
        /**
         * @stability stable
         */
        get thumbnailConfig(): ElastictranscoderPipelineThumbnailConfigOutputReference;
        /**
         * @stability stable
         */
        putThumbnailConfig(value: ElastictranscoderPipelineThumbnailConfig | undefined): void;
        /**
         * @stability stable
         */
        resetThumbnailConfig(): void;
        /**
         * @stability stable
         */
        get thumbnailConfigInput(): ElastictranscoderPipelineThumbnailConfig | undefined;
        private _thumbnailConfigPermissions?;
        /**
         * @stability stable
         */
        get thumbnailConfigPermissions(): ElastictranscoderPipelineThumbnailConfigPermissions[] | undefined;
        /**
         * @stability stable
         */
        set thumbnailConfigPermissions(value: ElastictranscoderPipelineThumbnailConfigPermissions[] | undefined);
        /**
         * @stability stable
         */
        resetThumbnailConfigPermissions(): void;
        /**
         * @stability stable
         */
        get thumbnailConfigPermissionsInput(): ElastictranscoderPipelineThumbnailConfigPermissions[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPresetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#container ElastictranscoderPreset#container}.
         *
         * @stability stable
         */
        readonly container: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#description ElastictranscoderPreset#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#name ElastictranscoderPreset#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#type ElastictranscoderPreset#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#video_codec_options ElastictranscoderPreset#video_codec_options}.
         *
         * @stability stable
         */
        readonly videoCodecOptions?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * audio block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#audio ElastictranscoderPreset#audio}
         *
         * @stability stable
         */
        readonly audio?: ElastictranscoderPresetAudio;
        /**
         * audio_codec_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#audio_codec_options ElastictranscoderPreset#audio_codec_options}
         *
         * @stability stable
         */
        readonly audioCodecOptions?: ElastictranscoderPresetAudioCodecOptions;
        /**
         * thumbnails block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#thumbnails ElastictranscoderPreset#thumbnails}
         *
         * @stability stable
         */
        readonly thumbnails?: ElastictranscoderPresetThumbnails;
        /**
         * video block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#video ElastictranscoderPreset#video}
         *
         * @stability stable
         */
        readonly video?: ElastictranscoderPresetVideo;
        /**
         * video_watermarks block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#video_watermarks ElastictranscoderPreset#video_watermarks}
         *
         * @stability stable
         */
        readonly videoWatermarks?: ElastictranscoderPresetVideoWatermarks[];
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPresetAudio {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#audio_packing_mode ElastictranscoderPreset#audio_packing_mode}.
         *
         * @stability stable
         */
        readonly audioPackingMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#bit_rate ElastictranscoderPreset#bit_rate}.
         *
         * @stability stable
         */
        readonly bitRate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#channels ElastictranscoderPreset#channels}.
         *
         * @stability stable
         */
        readonly channels?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#codec ElastictranscoderPreset#codec}.
         *
         * @stability stable
         */
        readonly codec?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#sample_rate ElastictranscoderPreset#sample_rate}.
         *
         * @stability stable
         */
        readonly sampleRate?: string;
    }
    /**
     * @stability stable
     */
    class ElastictranscoderPresetAudioOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _audioPackingMode?;
        /**
         * @stability stable
         */
        get audioPackingMode(): string | undefined;
        /**
         * @stability stable
         */
        set audioPackingMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetAudioPackingMode(): void;
        /**
         * @stability stable
         */
        get audioPackingModeInput(): string | undefined;
        private _bitRate?;
        /**
         * @stability stable
         */
        get bitRate(): string | undefined;
        /**
         * @stability stable
         */
        set bitRate(value: string | undefined);
        /**
         * @stability stable
         */
        resetBitRate(): void;
        /**
         * @stability stable
         */
        get bitRateInput(): string | undefined;
        private _channels?;
        /**
         * @stability stable
         */
        get channels(): string | undefined;
        /**
         * @stability stable
         */
        set channels(value: string | undefined);
        /**
         * @stability stable
         */
        resetChannels(): void;
        /**
         * @stability stable
         */
        get channelsInput(): string | undefined;
        private _codec?;
        /**
         * @stability stable
         */
        get codec(): string | undefined;
        /**
         * @stability stable
         */
        set codec(value: string | undefined);
        /**
         * @stability stable
         */
        resetCodec(): void;
        /**
         * @stability stable
         */
        get codecInput(): string | undefined;
        private _sampleRate?;
        /**
         * @stability stable
         */
        get sampleRate(): string | undefined;
        /**
         * @stability stable
         */
        set sampleRate(value: string | undefined);
        /**
         * @stability stable
         */
        resetSampleRate(): void;
        /**
         * @stability stable
         */
        get sampleRateInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPresetAudioCodecOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#bit_depth ElastictranscoderPreset#bit_depth}.
         *
         * @stability stable
         */
        readonly bitDepth?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#bit_order ElastictranscoderPreset#bit_order}.
         *
         * @stability stable
         */
        readonly bitOrder?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#profile ElastictranscoderPreset#profile}.
         *
         * @stability stable
         */
        readonly profile?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#signed ElastictranscoderPreset#signed}.
         *
         * @stability stable
         */
        readonly signed?: string;
    }
    /**
     * @stability stable
     */
    class ElastictranscoderPresetAudioCodecOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bitDepth?;
        /**
         * @stability stable
         */
        get bitDepth(): string | undefined;
        /**
         * @stability stable
         */
        set bitDepth(value: string | undefined);
        /**
         * @stability stable
         */
        resetBitDepth(): void;
        /**
         * @stability stable
         */
        get bitDepthInput(): string | undefined;
        private _bitOrder?;
        /**
         * @stability stable
         */
        get bitOrder(): string | undefined;
        /**
         * @stability stable
         */
        set bitOrder(value: string | undefined);
        /**
         * @stability stable
         */
        resetBitOrder(): void;
        /**
         * @stability stable
         */
        get bitOrderInput(): string | undefined;
        private _profile?;
        /**
         * @stability stable
         */
        get profile(): string | undefined;
        /**
         * @stability stable
         */
        set profile(value: string | undefined);
        /**
         * @stability stable
         */
        resetProfile(): void;
        /**
         * @stability stable
         */
        get profileInput(): string | undefined;
        private _signed?;
        /**
         * @stability stable
         */
        get signed(): string | undefined;
        /**
         * @stability stable
         */
        set signed(value: string | undefined);
        /**
         * @stability stable
         */
        resetSigned(): void;
        /**
         * @stability stable
         */
        get signedInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPresetThumbnails {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#aspect_ratio ElastictranscoderPreset#aspect_ratio}.
         *
         * @stability stable
         */
        readonly aspectRatio?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#format ElastictranscoderPreset#format}.
         *
         * @stability stable
         */
        readonly format?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#interval ElastictranscoderPreset#interval}.
         *
         * @stability stable
         */
        readonly interval?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#max_height ElastictranscoderPreset#max_height}.
         *
         * @stability stable
         */
        readonly maxHeight?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#max_width ElastictranscoderPreset#max_width}.
         *
         * @stability stable
         */
        readonly maxWidth?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#padding_policy ElastictranscoderPreset#padding_policy}.
         *
         * @stability stable
         */
        readonly paddingPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#resolution ElastictranscoderPreset#resolution}.
         *
         * @stability stable
         */
        readonly resolution?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#sizing_policy ElastictranscoderPreset#sizing_policy}.
         *
         * @stability stable
         */
        readonly sizingPolicy?: string;
    }
    /**
     * @stability stable
     */
    class ElastictranscoderPresetThumbnailsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _aspectRatio?;
        /**
         * @stability stable
         */
        get aspectRatio(): string | undefined;
        /**
         * @stability stable
         */
        set aspectRatio(value: string | undefined);
        /**
         * @stability stable
         */
        resetAspectRatio(): void;
        /**
         * @stability stable
         */
        get aspectRatioInput(): string | undefined;
        private _format?;
        /**
         * @stability stable
         */
        get format(): string | undefined;
        /**
         * @stability stable
         */
        set format(value: string | undefined);
        /**
         * @stability stable
         */
        resetFormat(): void;
        /**
         * @stability stable
         */
        get formatInput(): string | undefined;
        private _interval?;
        /**
         * @stability stable
         */
        get interval(): string | undefined;
        /**
         * @stability stable
         */
        set interval(value: string | undefined);
        /**
         * @stability stable
         */
        resetInterval(): void;
        /**
         * @stability stable
         */
        get intervalInput(): string | undefined;
        private _maxHeight?;
        /**
         * @stability stable
         */
        get maxHeight(): string | undefined;
        /**
         * @stability stable
         */
        set maxHeight(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxHeight(): void;
        /**
         * @stability stable
         */
        get maxHeightInput(): string | undefined;
        private _maxWidth?;
        /**
         * @stability stable
         */
        get maxWidth(): string | undefined;
        /**
         * @stability stable
         */
        set maxWidth(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxWidth(): void;
        /**
         * @stability stable
         */
        get maxWidthInput(): string | undefined;
        private _paddingPolicy?;
        /**
         * @stability stable
         */
        get paddingPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set paddingPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPaddingPolicy(): void;
        /**
         * @stability stable
         */
        get paddingPolicyInput(): string | undefined;
        private _resolution?;
        /**
         * @stability stable
         */
        get resolution(): string | undefined;
        /**
         * @stability stable
         */
        set resolution(value: string | undefined);
        /**
         * @stability stable
         */
        resetResolution(): void;
        /**
         * @stability stable
         */
        get resolutionInput(): string | undefined;
        private _sizingPolicy?;
        /**
         * @stability stable
         */
        get sizingPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set sizingPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSizingPolicy(): void;
        /**
         * @stability stable
         */
        get sizingPolicyInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPresetVideo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#aspect_ratio ElastictranscoderPreset#aspect_ratio}.
         *
         * @stability stable
         */
        readonly aspectRatio?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#bit_rate ElastictranscoderPreset#bit_rate}.
         *
         * @stability stable
         */
        readonly bitRate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#codec ElastictranscoderPreset#codec}.
         *
         * @stability stable
         */
        readonly codec?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#display_aspect_ratio ElastictranscoderPreset#display_aspect_ratio}.
         *
         * @stability stable
         */
        readonly displayAspectRatio?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#fixed_gop ElastictranscoderPreset#fixed_gop}.
         *
         * @stability stable
         */
        readonly fixedGop?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#frame_rate ElastictranscoderPreset#frame_rate}.
         *
         * @stability stable
         */
        readonly frameRate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#keyframes_max_dist ElastictranscoderPreset#keyframes_max_dist}.
         *
         * @stability stable
         */
        readonly keyframesMaxDist?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#max_frame_rate ElastictranscoderPreset#max_frame_rate}.
         *
         * @stability stable
         */
        readonly maxFrameRate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#max_height ElastictranscoderPreset#max_height}.
         *
         * @stability stable
         */
        readonly maxHeight?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#max_width ElastictranscoderPreset#max_width}.
         *
         * @stability stable
         */
        readonly maxWidth?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#padding_policy ElastictranscoderPreset#padding_policy}.
         *
         * @stability stable
         */
        readonly paddingPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#resolution ElastictranscoderPreset#resolution}.
         *
         * @stability stable
         */
        readonly resolution?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#sizing_policy ElastictranscoderPreset#sizing_policy}.
         *
         * @stability stable
         */
        readonly sizingPolicy?: string;
    }
    /**
     * @stability stable
     */
    class ElastictranscoderPresetVideoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _aspectRatio?;
        /**
         * @stability stable
         */
        get aspectRatio(): string | undefined;
        /**
         * @stability stable
         */
        set aspectRatio(value: string | undefined);
        /**
         * @stability stable
         */
        resetAspectRatio(): void;
        /**
         * @stability stable
         */
        get aspectRatioInput(): string | undefined;
        private _bitRate?;
        /**
         * @stability stable
         */
        get bitRate(): string | undefined;
        /**
         * @stability stable
         */
        set bitRate(value: string | undefined);
        /**
         * @stability stable
         */
        resetBitRate(): void;
        /**
         * @stability stable
         */
        get bitRateInput(): string | undefined;
        private _codec?;
        /**
         * @stability stable
         */
        get codec(): string | undefined;
        /**
         * @stability stable
         */
        set codec(value: string | undefined);
        /**
         * @stability stable
         */
        resetCodec(): void;
        /**
         * @stability stable
         */
        get codecInput(): string | undefined;
        private _displayAspectRatio?;
        /**
         * @stability stable
         */
        get displayAspectRatio(): string | undefined;
        /**
         * @stability stable
         */
        set displayAspectRatio(value: string | undefined);
        /**
         * @stability stable
         */
        resetDisplayAspectRatio(): void;
        /**
         * @stability stable
         */
        get displayAspectRatioInput(): string | undefined;
        private _fixedGop?;
        /**
         * @stability stable
         */
        get fixedGop(): string | undefined;
        /**
         * @stability stable
         */
        set fixedGop(value: string | undefined);
        /**
         * @stability stable
         */
        resetFixedGop(): void;
        /**
         * @stability stable
         */
        get fixedGopInput(): string | undefined;
        private _frameRate?;
        /**
         * @stability stable
         */
        get frameRate(): string | undefined;
        /**
         * @stability stable
         */
        set frameRate(value: string | undefined);
        /**
         * @stability stable
         */
        resetFrameRate(): void;
        /**
         * @stability stable
         */
        get frameRateInput(): string | undefined;
        private _keyframesMaxDist?;
        /**
         * @stability stable
         */
        get keyframesMaxDist(): string | undefined;
        /**
         * @stability stable
         */
        set keyframesMaxDist(value: string | undefined);
        /**
         * @stability stable
         */
        resetKeyframesMaxDist(): void;
        /**
         * @stability stable
         */
        get keyframesMaxDistInput(): string | undefined;
        private _maxFrameRate?;
        /**
         * @stability stable
         */
        get maxFrameRate(): string | undefined;
        /**
         * @stability stable
         */
        set maxFrameRate(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxFrameRate(): void;
        /**
         * @stability stable
         */
        get maxFrameRateInput(): string | undefined;
        private _maxHeight?;
        /**
         * @stability stable
         */
        get maxHeight(): string | undefined;
        /**
         * @stability stable
         */
        set maxHeight(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxHeight(): void;
        /**
         * @stability stable
         */
        get maxHeightInput(): string | undefined;
        private _maxWidth?;
        /**
         * @stability stable
         */
        get maxWidth(): string | undefined;
        /**
         * @stability stable
         */
        set maxWidth(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxWidth(): void;
        /**
         * @stability stable
         */
        get maxWidthInput(): string | undefined;
        private _paddingPolicy?;
        /**
         * @stability stable
         */
        get paddingPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set paddingPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPaddingPolicy(): void;
        /**
         * @stability stable
         */
        get paddingPolicyInput(): string | undefined;
        private _resolution?;
        /**
         * @stability stable
         */
        get resolution(): string | undefined;
        /**
         * @stability stable
         */
        set resolution(value: string | undefined);
        /**
         * @stability stable
         */
        resetResolution(): void;
        /**
         * @stability stable
         */
        get resolutionInput(): string | undefined;
        private _sizingPolicy?;
        /**
         * @stability stable
         */
        get sizingPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set sizingPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSizingPolicy(): void;
        /**
         * @stability stable
         */
        get sizingPolicyInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface ElastictranscoderPresetVideoWatermarks {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#horizontal_align ElastictranscoderPreset#horizontal_align}.
         *
         * @stability stable
         */
        readonly horizontalAlign?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#horizontal_offset ElastictranscoderPreset#horizontal_offset}.
         *
         * @stability stable
         */
        readonly horizontalOffset?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#id ElastictranscoderPreset#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#max_height ElastictranscoderPreset#max_height}.
         *
         * @stability stable
         */
        readonly maxHeight?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#max_width ElastictranscoderPreset#max_width}.
         *
         * @stability stable
         */
        readonly maxWidth?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#opacity ElastictranscoderPreset#opacity}.
         *
         * @stability stable
         */
        readonly opacity?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#sizing_policy ElastictranscoderPreset#sizing_policy}.
         *
         * @stability stable
         */
        readonly sizingPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#target ElastictranscoderPreset#target}.
         *
         * @stability stable
         */
        readonly target?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#vertical_align ElastictranscoderPreset#vertical_align}.
         *
         * @stability stable
         */
        readonly verticalAlign?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html#vertical_offset ElastictranscoderPreset#vertical_offset}.
         *
         * @stability stable
         */
        readonly verticalOffset?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html aws_elastictranscoder_preset}.
     *
     * @stability stable
     */
    class ElastictranscoderPreset extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/elastictranscoder_preset.html aws_elastictranscoder_preset} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ElastictranscoderPresetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _container?;
        /**
         * @stability stable
         */
        get container(): string;
        /**
         * @stability stable
         */
        set container(value: string);
        /**
         * @stability stable
         */
        get containerInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _videoCodecOptions?;
        /**
         * @stability stable
         */
        get videoCodecOptions(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set videoCodecOptions(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetVideoCodecOptions(): void;
        /**
         * @stability stable
         */
        get videoCodecOptionsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _audio?;
        private __audioOutput;
        /**
         * @stability stable
         */
        get audio(): ElastictranscoderPresetAudioOutputReference;
        /**
         * @stability stable
         */
        putAudio(value: ElastictranscoderPresetAudio | undefined): void;
        /**
         * @stability stable
         */
        resetAudio(): void;
        /**
         * @stability stable
         */
        get audioInput(): ElastictranscoderPresetAudio | undefined;
        private _audioCodecOptions?;
        private __audioCodecOptionsOutput;
        /**
         * @stability stable
         */
        get audioCodecOptions(): ElastictranscoderPresetAudioCodecOptionsOutputReference;
        /**
         * @stability stable
         */
        putAudioCodecOptions(value: ElastictranscoderPresetAudioCodecOptions | undefined): void;
        /**
         * @stability stable
         */
        resetAudioCodecOptions(): void;
        /**
         * @stability stable
         */
        get audioCodecOptionsInput(): ElastictranscoderPresetAudioCodecOptions | undefined;
        private _thumbnails?;
        private __thumbnailsOutput;
        /**
         * @stability stable
         */
        get thumbnails(): ElastictranscoderPresetThumbnailsOutputReference;
        /**
         * @stability stable
         */
        putThumbnails(value: ElastictranscoderPresetThumbnails | undefined): void;
        /**
         * @stability stable
         */
        resetThumbnails(): void;
        /**
         * @stability stable
         */
        get thumbnailsInput(): ElastictranscoderPresetThumbnails | undefined;
        private _video?;
        private __videoOutput;
        /**
         * @stability stable
         */
        get video(): ElastictranscoderPresetVideoOutputReference;
        /**
         * @stability stable
         */
        putVideo(value: ElastictranscoderPresetVideo | undefined): void;
        /**
         * @stability stable
         */
        resetVideo(): void;
        /**
         * @stability stable
         */
        get videoInput(): ElastictranscoderPresetVideo | undefined;
        private _videoWatermarks?;
        /**
         * @stability stable
         */
        get videoWatermarks(): ElastictranscoderPresetVideoWatermarks[] | undefined;
        /**
         * @stability stable
         */
        set videoWatermarks(value: ElastictranscoderPresetVideoWatermarks[] | undefined);
        /**
         * @stability stable
         */
        resetVideoWatermarks(): void;
        /**
         * @stability stable
         */
        get videoWatermarksInput(): ElastictranscoderPresetVideoWatermarks[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
