import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Firewall Management Service
*/
export declare namespace FMS {
    /**
     * @stability stable
     */
    interface FmsAdminAccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_admin_account.html#account_id FmsAdminAccount#account_id}.
         *
         * @stability stable
         */
        readonly accountId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/fms_admin_account.html aws_fms_admin_account}.
     *
     * @stability stable
     */
    class FmsAdminAccount extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/fms_admin_account.html aws_fms_admin_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: FmsAdminAccountConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string | undefined;
        /**
         * @stability stable
         */
        set accountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccountId(): void;
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface FmsPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#delete_all_policy_resources FmsPolicy#delete_all_policy_resources}.
         *
         * @stability stable
         */
        readonly deleteAllPolicyResources?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#exclude_resource_tags FmsPolicy#exclude_resource_tags}.
         *
         * @stability stable
         */
        readonly excludeResourceTags: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#name FmsPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#remediation_enabled FmsPolicy#remediation_enabled}.
         *
         * @stability stable
         */
        readonly remediationEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#resource_tags FmsPolicy#resource_tags}.
         *
         * @stability stable
         */
        readonly resourceTags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#resource_type FmsPolicy#resource_type}.
         *
         * @stability stable
         */
        readonly resourceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#resource_type_list FmsPolicy#resource_type_list}.
         *
         * @stability stable
         */
        readonly resourceTypeList?: string[];
        /**
         * exclude_map block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#exclude_map FmsPolicy#exclude_map}
         *
         * @stability stable
         */
        readonly excludeMap?: FmsPolicyExcludeMap;
        /**
         * include_map block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#include_map FmsPolicy#include_map}
         *
         * @stability stable
         */
        readonly includeMap?: FmsPolicyIncludeMap;
        /**
         * security_service_policy_data block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#security_service_policy_data FmsPolicy#security_service_policy_data}
         *
         * @stability stable
         */
        readonly securityServicePolicyData: FmsPolicySecurityServicePolicyData;
    }
    /**
     * @stability stable
     */
    interface FmsPolicyExcludeMap {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#account FmsPolicy#account}.
         *
         * @stability stable
         */
        readonly account?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#orgunit FmsPolicy#orgunit}.
         *
         * @stability stable
         */
        readonly orgunit?: string[];
    }
    /**
     * @stability stable
     */
    class FmsPolicyExcludeMapOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _account?;
        /**
         * @stability stable
         */
        get account(): string[] | undefined;
        /**
         * @stability stable
         */
        set account(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAccount(): void;
        /**
         * @stability stable
         */
        get accountInput(): string[] | undefined;
        private _orgunit?;
        /**
         * @stability stable
         */
        get orgunit(): string[] | undefined;
        /**
         * @stability stable
         */
        set orgunit(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetOrgunit(): void;
        /**
         * @stability stable
         */
        get orgunitInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface FmsPolicyIncludeMap {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#account FmsPolicy#account}.
         *
         * @stability stable
         */
        readonly account?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#orgunit FmsPolicy#orgunit}.
         *
         * @stability stable
         */
        readonly orgunit?: string[];
    }
    /**
     * @stability stable
     */
    class FmsPolicyIncludeMapOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _account?;
        /**
         * @stability stable
         */
        get account(): string[] | undefined;
        /**
         * @stability stable
         */
        set account(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAccount(): void;
        /**
         * @stability stable
         */
        get accountInput(): string[] | undefined;
        private _orgunit?;
        /**
         * @stability stable
         */
        get orgunit(): string[] | undefined;
        /**
         * @stability stable
         */
        set orgunit(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetOrgunit(): void;
        /**
         * @stability stable
         */
        get orgunitInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface FmsPolicySecurityServicePolicyData {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#managed_service_data FmsPolicy#managed_service_data}.
         *
         * @stability stable
         */
        readonly managedServiceData?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html#type FmsPolicy#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    class FmsPolicySecurityServicePolicyDataOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _managedServiceData?;
        /**
         * @stability stable
         */
        get managedServiceData(): string | undefined;
        /**
         * @stability stable
         */
        set managedServiceData(value: string | undefined);
        /**
         * @stability stable
         */
        resetManagedServiceData(): void;
        /**
         * @stability stable
         */
        get managedServiceDataInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html aws_fms_policy}.
     *
     * @stability stable
     */
    class FmsPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/fms_policy.html aws_fms_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: FmsPolicyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _deleteAllPolicyResources?;
        /**
         * @stability stable
         */
        get deleteAllPolicyResources(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deleteAllPolicyResources(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeleteAllPolicyResources(): void;
        /**
         * @stability stable
         */
        get deleteAllPolicyResourcesInput(): boolean | cdktf.IResolvable | undefined;
        private _excludeResourceTags?;
        /**
         * @stability stable
         */
        get excludeResourceTags(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set excludeResourceTags(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get excludeResourceTagsInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get policyUpdateToken(): string;
        private _remediationEnabled?;
        /**
         * @stability stable
         */
        get remediationEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set remediationEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRemediationEnabled(): void;
        /**
         * @stability stable
         */
        get remediationEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _resourceTags?;
        /**
         * @stability stable
         */
        get resourceTags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set resourceTags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetResourceTags(): void;
        /**
         * @stability stable
         */
        get resourceTagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _resourceType?;
        /**
         * @stability stable
         */
        get resourceType(): string | undefined;
        /**
         * @stability stable
         */
        set resourceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetResourceType(): void;
        /**
         * @stability stable
         */
        get resourceTypeInput(): string | undefined;
        private _resourceTypeList?;
        /**
         * @stability stable
         */
        get resourceTypeList(): string[] | undefined;
        /**
         * @stability stable
         */
        set resourceTypeList(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetResourceTypeList(): void;
        /**
         * @stability stable
         */
        get resourceTypeListInput(): string[] | undefined;
        private _excludeMap?;
        private __excludeMapOutput;
        /**
         * @stability stable
         */
        get excludeMap(): FmsPolicyExcludeMapOutputReference;
        /**
         * @stability stable
         */
        putExcludeMap(value: FmsPolicyExcludeMap | undefined): void;
        /**
         * @stability stable
         */
        resetExcludeMap(): void;
        /**
         * @stability stable
         */
        get excludeMapInput(): FmsPolicyExcludeMap | undefined;
        private _includeMap?;
        private __includeMapOutput;
        /**
         * @stability stable
         */
        get includeMap(): FmsPolicyIncludeMapOutputReference;
        /**
         * @stability stable
         */
        putIncludeMap(value: FmsPolicyIncludeMap | undefined): void;
        /**
         * @stability stable
         */
        resetIncludeMap(): void;
        /**
         * @stability stable
         */
        get includeMapInput(): FmsPolicyIncludeMap | undefined;
        private _securityServicePolicyData?;
        private __securityServicePolicyDataOutput;
        /**
         * @stability stable
         */
        get securityServicePolicyData(): FmsPolicySecurityServicePolicyDataOutputReference;
        /**
         * @stability stable
         */
        putSecurityServicePolicyData(value: FmsPolicySecurityServicePolicyData): void;
        /**
         * @stability stable
         */
        get securityServicePolicyDataInput(): FmsPolicySecurityServicePolicyData | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
