import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS File System FSx
*/
export declare namespace FSx {
    /**
     * @stability stable
     */
    interface FsxBackupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html#file_system_id FsxBackup#file_system_id}.
         *
         * @stability stable
         */
        readonly fileSystemId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html#tags FsxBackup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html#tags_all FsxBackup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html#timeouts FsxBackup#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: FsxBackupTimeouts;
    }
    /**
     * @stability stable
     */
    interface FsxBackupTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html#create FsxBackup#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html#delete FsxBackup#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class FsxBackupTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html aws_fsx_backup}.
     *
     * @stability stable
     */
    class FsxBackup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_backup.html aws_fsx_backup} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: FsxBackupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _fileSystemId?;
        /**
         * @stability stable
         */
        get fileSystemId(): string;
        /**
         * @stability stable
         */
        set fileSystemId(value: string);
        /**
         * @stability stable
         */
        get fileSystemIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get type(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): FsxBackupTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: FsxBackupTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): FsxBackupTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface FsxLustreFileSystemConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#auto_import_policy FsxLustreFileSystem#auto_import_policy}.
         *
         * @stability stable
         */
        readonly autoImportPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#automatic_backup_retention_days FsxLustreFileSystem#automatic_backup_retention_days}.
         *
         * @stability stable
         */
        readonly automaticBackupRetentionDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#backup_id FsxLustreFileSystem#backup_id}.
         *
         * @stability stable
         */
        readonly backupId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#copy_tags_to_backups FsxLustreFileSystem#copy_tags_to_backups}.
         *
         * @stability stable
         */
        readonly copyTagsToBackups?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#daily_automatic_backup_start_time FsxLustreFileSystem#daily_automatic_backup_start_time}.
         *
         * @stability stable
         */
        readonly dailyAutomaticBackupStartTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#data_compression_type FsxLustreFileSystem#data_compression_type}.
         *
         * @stability stable
         */
        readonly dataCompressionType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#deployment_type FsxLustreFileSystem#deployment_type}.
         *
         * @stability stable
         */
        readonly deploymentType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#drive_cache_type FsxLustreFileSystem#drive_cache_type}.
         *
         * @stability stable
         */
        readonly driveCacheType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#export_path FsxLustreFileSystem#export_path}.
         *
         * @stability stable
         */
        readonly exportPath?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#import_path FsxLustreFileSystem#import_path}.
         *
         * @stability stable
         */
        readonly importPath?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#imported_file_chunk_size FsxLustreFileSystem#imported_file_chunk_size}.
         *
         * @stability stable
         */
        readonly importedFileChunkSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#kms_key_id FsxLustreFileSystem#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#per_unit_storage_throughput FsxLustreFileSystem#per_unit_storage_throughput}.
         *
         * @stability stable
         */
        readonly perUnitStorageThroughput?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#security_group_ids FsxLustreFileSystem#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#storage_capacity FsxLustreFileSystem#storage_capacity}.
         *
         * @stability stable
         */
        readonly storageCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#storage_type FsxLustreFileSystem#storage_type}.
         *
         * @stability stable
         */
        readonly storageType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#subnet_ids FsxLustreFileSystem#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#tags FsxLustreFileSystem#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#tags_all FsxLustreFileSystem#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#weekly_maintenance_start_time FsxLustreFileSystem#weekly_maintenance_start_time}.
         *
         * @stability stable
         */
        readonly weeklyMaintenanceStartTime?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#timeouts FsxLustreFileSystem#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: FsxLustreFileSystemTimeouts;
    }
    /**
     * @stability stable
     */
    interface FsxLustreFileSystemTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#create FsxLustreFileSystem#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#delete FsxLustreFileSystem#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html#update FsxLustreFileSystem#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class FsxLustreFileSystemTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html aws_fsx_lustre_file_system}.
     *
     * @stability stable
     */
    class FsxLustreFileSystem extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_lustre_file_system.html aws_fsx_lustre_file_system} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: FsxLustreFileSystemConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoImportPolicy?;
        /**
         * @stability stable
         */
        get autoImportPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set autoImportPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetAutoImportPolicy(): void;
        /**
         * @stability stable
         */
        get autoImportPolicyInput(): string | undefined;
        private _automaticBackupRetentionDays?;
        /**
         * @stability stable
         */
        get automaticBackupRetentionDays(): number | undefined;
        /**
         * @stability stable
         */
        set automaticBackupRetentionDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetAutomaticBackupRetentionDays(): void;
        /**
         * @stability stable
         */
        get automaticBackupRetentionDaysInput(): number | undefined;
        private _backupId?;
        /**
         * @stability stable
         */
        get backupId(): string | undefined;
        /**
         * @stability stable
         */
        set backupId(value: string | undefined);
        /**
         * @stability stable
         */
        resetBackupId(): void;
        /**
         * @stability stable
         */
        get backupIdInput(): string | undefined;
        private _copyTagsToBackups?;
        /**
         * @stability stable
         */
        get copyTagsToBackups(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set copyTagsToBackups(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCopyTagsToBackups(): void;
        /**
         * @stability stable
         */
        get copyTagsToBackupsInput(): boolean | cdktf.IResolvable | undefined;
        private _dailyAutomaticBackupStartTime?;
        /**
         * @stability stable
         */
        get dailyAutomaticBackupStartTime(): string | undefined;
        /**
         * @stability stable
         */
        set dailyAutomaticBackupStartTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetDailyAutomaticBackupStartTime(): void;
        /**
         * @stability stable
         */
        get dailyAutomaticBackupStartTimeInput(): string | undefined;
        private _dataCompressionType?;
        /**
         * @stability stable
         */
        get dataCompressionType(): string | undefined;
        /**
         * @stability stable
         */
        set dataCompressionType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDataCompressionType(): void;
        /**
         * @stability stable
         */
        get dataCompressionTypeInput(): string | undefined;
        private _deploymentType?;
        /**
         * @stability stable
         */
        get deploymentType(): string | undefined;
        /**
         * @stability stable
         */
        set deploymentType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeploymentType(): void;
        /**
         * @stability stable
         */
        get deploymentTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        private _driveCacheType?;
        /**
         * @stability stable
         */
        get driveCacheType(): string | undefined;
        /**
         * @stability stable
         */
        set driveCacheType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDriveCacheType(): void;
        /**
         * @stability stable
         */
        get driveCacheTypeInput(): string | undefined;
        private _exportPath?;
        /**
         * @stability stable
         */
        get exportPath(): string | undefined;
        /**
         * @stability stable
         */
        set exportPath(value: string | undefined);
        /**
         * @stability stable
         */
        resetExportPath(): void;
        /**
         * @stability stable
         */
        get exportPathInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _importPath?;
        /**
         * @stability stable
         */
        get importPath(): string | undefined;
        /**
         * @stability stable
         */
        set importPath(value: string | undefined);
        /**
         * @stability stable
         */
        resetImportPath(): void;
        /**
         * @stability stable
         */
        get importPathInput(): string | undefined;
        private _importedFileChunkSize?;
        /**
         * @stability stable
         */
        get importedFileChunkSize(): number | undefined;
        /**
         * @stability stable
         */
        set importedFileChunkSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetImportedFileChunkSize(): void;
        /**
         * @stability stable
         */
        get importedFileChunkSizeInput(): number | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get mountName(): string;
        /**
         * @stability stable
         */
        get networkInterfaceIds(): string[];
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _perUnitStorageThroughput?;
        /**
         * @stability stable
         */
        get perUnitStorageThroughput(): number | undefined;
        /**
         * @stability stable
         */
        set perUnitStorageThroughput(value: number | undefined);
        /**
         * @stability stable
         */
        resetPerUnitStorageThroughput(): void;
        /**
         * @stability stable
         */
        get perUnitStorageThroughputInput(): number | undefined;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _storageCapacity?;
        /**
         * @stability stable
         */
        get storageCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set storageCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetStorageCapacity(): void;
        /**
         * @stability stable
         */
        get storageCapacityInput(): number | undefined;
        private _storageType?;
        /**
         * @stability stable
         */
        get storageType(): string | undefined;
        /**
         * @stability stable
         */
        set storageType(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageType(): void;
        /**
         * @stability stable
         */
        get storageTypeInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _weeklyMaintenanceStartTime?;
        /**
         * @stability stable
         */
        get weeklyMaintenanceStartTime(): string | undefined;
        /**
         * @stability stable
         */
        set weeklyMaintenanceStartTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetWeeklyMaintenanceStartTime(): void;
        /**
         * @stability stable
         */
        get weeklyMaintenanceStartTimeInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): FsxLustreFileSystemTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: FsxLustreFileSystemTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): FsxLustreFileSystemTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface FsxOntapFileSystemConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#automatic_backup_retention_days FsxOntapFileSystem#automatic_backup_retention_days}.
         *
         * @stability stable
         */
        readonly automaticBackupRetentionDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#daily_automatic_backup_start_time FsxOntapFileSystem#daily_automatic_backup_start_time}.
         *
         * @stability stable
         */
        readonly dailyAutomaticBackupStartTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#deployment_type FsxOntapFileSystem#deployment_type}.
         *
         * @stability stable
         */
        readonly deploymentType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#endpoint_ip_address_range FsxOntapFileSystem#endpoint_ip_address_range}.
         *
         * @stability stable
         */
        readonly endpointIpAddressRange?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#fsx_admin_password FsxOntapFileSystem#fsx_admin_password}.
         *
         * @stability stable
         */
        readonly fsxAdminPassword?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#kms_key_id FsxOntapFileSystem#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#preferred_subnet_id FsxOntapFileSystem#preferred_subnet_id}.
         *
         * @stability stable
         */
        readonly preferredSubnetId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#route_table_ids FsxOntapFileSystem#route_table_ids}.
         *
         * @stability stable
         */
        readonly routeTableIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#security_group_ids FsxOntapFileSystem#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#storage_capacity FsxOntapFileSystem#storage_capacity}.
         *
         * @stability stable
         */
        readonly storageCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#storage_type FsxOntapFileSystem#storage_type}.
         *
         * @stability stable
         */
        readonly storageType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#subnet_ids FsxOntapFileSystem#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#tags FsxOntapFileSystem#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#tags_all FsxOntapFileSystem#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#throughput_capacity FsxOntapFileSystem#throughput_capacity}.
         *
         * @stability stable
         */
        readonly throughputCapacity: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#weekly_maintenance_start_time FsxOntapFileSystem#weekly_maintenance_start_time}.
         *
         * @stability stable
         */
        readonly weeklyMaintenanceStartTime?: string;
        /**
         * disk_iops_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#disk_iops_configuration FsxOntapFileSystem#disk_iops_configuration}
         *
         * @stability stable
         */
        readonly diskIopsConfiguration?: FsxOntapFileSystemDiskIopsConfiguration;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#timeouts FsxOntapFileSystem#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: FsxOntapFileSystemTimeouts;
    }
    /**
     * @stability stable
     */
    class FsxOntapFileSystemEndpointsIntercluster extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get ipAddresses(): string[];
    }
    /**
     * @stability stable
     */
    class FsxOntapFileSystemEndpointsManagement extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get ipAddresses(): string[];
    }
    /**
     * @stability stable
     */
    class FsxOntapFileSystemEndpoints extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get intercluster(): any;
        /**
         * @stability stable
         */
        get management(): any;
    }
    /**
     * @stability stable
     */
    interface FsxOntapFileSystemDiskIopsConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#iops FsxOntapFileSystem#iops}.
         *
         * @stability stable
         */
        readonly iops?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#mode FsxOntapFileSystem#mode}.
         *
         * @stability stable
         */
        readonly mode?: string;
    }
    /**
     * @stability stable
     */
    class FsxOntapFileSystemDiskIopsConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _iops?;
        /**
         * @stability stable
         */
        get iops(): number | undefined;
        /**
         * @stability stable
         */
        set iops(value: number | undefined);
        /**
         * @stability stable
         */
        resetIops(): void;
        /**
         * @stability stable
         */
        get iopsInput(): number | undefined;
        private _mode?;
        /**
         * @stability stable
         */
        get mode(): string | undefined;
        /**
         * @stability stable
         */
        set mode(value: string | undefined);
        /**
         * @stability stable
         */
        resetMode(): void;
        /**
         * @stability stable
         */
        get modeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface FsxOntapFileSystemTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#create FsxOntapFileSystem#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#delete FsxOntapFileSystem#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html#update FsxOntapFileSystem#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class FsxOntapFileSystemTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html aws_fsx_ontap_file_system}.
     *
     * @stability stable
     */
    class FsxOntapFileSystem extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_ontap_file_system.html aws_fsx_ontap_file_system} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: FsxOntapFileSystemConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _automaticBackupRetentionDays?;
        /**
         * @stability stable
         */
        get automaticBackupRetentionDays(): number | undefined;
        /**
         * @stability stable
         */
        set automaticBackupRetentionDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetAutomaticBackupRetentionDays(): void;
        /**
         * @stability stable
         */
        get automaticBackupRetentionDaysInput(): number | undefined;
        private _dailyAutomaticBackupStartTime?;
        /**
         * @stability stable
         */
        get dailyAutomaticBackupStartTime(): string | undefined;
        /**
         * @stability stable
         */
        set dailyAutomaticBackupStartTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetDailyAutomaticBackupStartTime(): void;
        /**
         * @stability stable
         */
        get dailyAutomaticBackupStartTimeInput(): string | undefined;
        private _deploymentType?;
        /**
         * @stability stable
         */
        get deploymentType(): string;
        /**
         * @stability stable
         */
        set deploymentType(value: string);
        /**
         * @stability stable
         */
        get deploymentTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        private _endpointIpAddressRange?;
        /**
         * @stability stable
         */
        get endpointIpAddressRange(): string | undefined;
        /**
         * @stability stable
         */
        set endpointIpAddressRange(value: string | undefined);
        /**
         * @stability stable
         */
        resetEndpointIpAddressRange(): void;
        /**
         * @stability stable
         */
        get endpointIpAddressRangeInput(): string | undefined;
        /**
         * @stability stable
         */
        endpoints(index: string): FsxOntapFileSystemEndpoints;
        private _fsxAdminPassword?;
        /**
         * @stability stable
         */
        get fsxAdminPassword(): string | undefined;
        /**
         * @stability stable
         */
        set fsxAdminPassword(value: string | undefined);
        /**
         * @stability stable
         */
        resetFsxAdminPassword(): void;
        /**
         * @stability stable
         */
        get fsxAdminPasswordInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get networkInterfaceIds(): string[];
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _preferredSubnetId?;
        /**
         * @stability stable
         */
        get preferredSubnetId(): string;
        /**
         * @stability stable
         */
        set preferredSubnetId(value: string);
        /**
         * @stability stable
         */
        get preferredSubnetIdInput(): string | undefined;
        private _routeTableIds?;
        /**
         * @stability stable
         */
        get routeTableIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set routeTableIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetRouteTableIds(): void;
        /**
         * @stability stable
         */
        get routeTableIdsInput(): string[] | undefined;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _storageCapacity?;
        /**
         * @stability stable
         */
        get storageCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set storageCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetStorageCapacity(): void;
        /**
         * @stability stable
         */
        get storageCapacityInput(): number | undefined;
        private _storageType?;
        /**
         * @stability stable
         */
        get storageType(): string | undefined;
        /**
         * @stability stable
         */
        set storageType(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageType(): void;
        /**
         * @stability stable
         */
        get storageTypeInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _throughputCapacity?;
        /**
         * @stability stable
         */
        get throughputCapacity(): number;
        /**
         * @stability stable
         */
        set throughputCapacity(value: number);
        /**
         * @stability stable
         */
        get throughputCapacityInput(): number | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _weeklyMaintenanceStartTime?;
        /**
         * @stability stable
         */
        get weeklyMaintenanceStartTime(): string | undefined;
        /**
         * @stability stable
         */
        set weeklyMaintenanceStartTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetWeeklyMaintenanceStartTime(): void;
        /**
         * @stability stable
         */
        get weeklyMaintenanceStartTimeInput(): string | undefined;
        private _diskIopsConfiguration?;
        private __diskIopsConfigurationOutput;
        /**
         * @stability stable
         */
        get diskIopsConfiguration(): FsxOntapFileSystemDiskIopsConfigurationOutputReference;
        /**
         * @stability stable
         */
        putDiskIopsConfiguration(value: FsxOntapFileSystemDiskIopsConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetDiskIopsConfiguration(): void;
        /**
         * @stability stable
         */
        get diskIopsConfigurationInput(): FsxOntapFileSystemDiskIopsConfiguration | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): FsxOntapFileSystemTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: FsxOntapFileSystemTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): FsxOntapFileSystemTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface FsxWindowsFileSystemConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#active_directory_id FsxWindowsFileSystem#active_directory_id}.
         *
         * @stability stable
         */
        readonly activeDirectoryId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#aliases FsxWindowsFileSystem#aliases}.
         *
         * @stability stable
         */
        readonly aliases?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#automatic_backup_retention_days FsxWindowsFileSystem#automatic_backup_retention_days}.
         *
         * @stability stable
         */
        readonly automaticBackupRetentionDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#backup_id FsxWindowsFileSystem#backup_id}.
         *
         * @stability stable
         */
        readonly backupId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#copy_tags_to_backups FsxWindowsFileSystem#copy_tags_to_backups}.
         *
         * @stability stable
         */
        readonly copyTagsToBackups?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#daily_automatic_backup_start_time FsxWindowsFileSystem#daily_automatic_backup_start_time}.
         *
         * @stability stable
         */
        readonly dailyAutomaticBackupStartTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#deployment_type FsxWindowsFileSystem#deployment_type}.
         *
         * @stability stable
         */
        readonly deploymentType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#kms_key_id FsxWindowsFileSystem#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#preferred_subnet_id FsxWindowsFileSystem#preferred_subnet_id}.
         *
         * @stability stable
         */
        readonly preferredSubnetId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#security_group_ids FsxWindowsFileSystem#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#skip_final_backup FsxWindowsFileSystem#skip_final_backup}.
         *
         * @stability stable
         */
        readonly skipFinalBackup?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#storage_capacity FsxWindowsFileSystem#storage_capacity}.
         *
         * @stability stable
         */
        readonly storageCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#storage_type FsxWindowsFileSystem#storage_type}.
         *
         * @stability stable
         */
        readonly storageType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#subnet_ids FsxWindowsFileSystem#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#tags FsxWindowsFileSystem#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#tags_all FsxWindowsFileSystem#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#throughput_capacity FsxWindowsFileSystem#throughput_capacity}.
         *
         * @stability stable
         */
        readonly throughputCapacity: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#weekly_maintenance_start_time FsxWindowsFileSystem#weekly_maintenance_start_time}.
         *
         * @stability stable
         */
        readonly weeklyMaintenanceStartTime?: string;
        /**
         * audit_log_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#audit_log_configuration FsxWindowsFileSystem#audit_log_configuration}
         *
         * @stability stable
         */
        readonly auditLogConfiguration?: FsxWindowsFileSystemAuditLogConfiguration;
        /**
         * self_managed_active_directory block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#self_managed_active_directory FsxWindowsFileSystem#self_managed_active_directory}
         *
         * @stability stable
         */
        readonly selfManagedActiveDirectory?: FsxWindowsFileSystemSelfManagedActiveDirectory;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#timeouts FsxWindowsFileSystem#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: FsxWindowsFileSystemTimeouts;
    }
    /**
     * @stability stable
     */
    interface FsxWindowsFileSystemAuditLogConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#audit_log_destination FsxWindowsFileSystem#audit_log_destination}.
         *
         * @stability stable
         */
        readonly auditLogDestination?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#file_access_audit_log_level FsxWindowsFileSystem#file_access_audit_log_level}.
         *
         * @stability stable
         */
        readonly fileAccessAuditLogLevel?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#file_share_access_audit_log_level FsxWindowsFileSystem#file_share_access_audit_log_level}.
         *
         * @stability stable
         */
        readonly fileShareAccessAuditLogLevel?: string;
    }
    /**
     * @stability stable
     */
    class FsxWindowsFileSystemAuditLogConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _auditLogDestination?;
        /**
         * @stability stable
         */
        get auditLogDestination(): string | undefined;
        /**
         * @stability stable
         */
        set auditLogDestination(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuditLogDestination(): void;
        /**
         * @stability stable
         */
        get auditLogDestinationInput(): string | undefined;
        private _fileAccessAuditLogLevel?;
        /**
         * @stability stable
         */
        get fileAccessAuditLogLevel(): string | undefined;
        /**
         * @stability stable
         */
        set fileAccessAuditLogLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileAccessAuditLogLevel(): void;
        /**
         * @stability stable
         */
        get fileAccessAuditLogLevelInput(): string | undefined;
        private _fileShareAccessAuditLogLevel?;
        /**
         * @stability stable
         */
        get fileShareAccessAuditLogLevel(): string | undefined;
        /**
         * @stability stable
         */
        set fileShareAccessAuditLogLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileShareAccessAuditLogLevel(): void;
        /**
         * @stability stable
         */
        get fileShareAccessAuditLogLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface FsxWindowsFileSystemSelfManagedActiveDirectory {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#dns_ips FsxWindowsFileSystem#dns_ips}.
         *
         * @stability stable
         */
        readonly dnsIps: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#domain_name FsxWindowsFileSystem#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#file_system_administrators_group FsxWindowsFileSystem#file_system_administrators_group}.
         *
         * @stability stable
         */
        readonly fileSystemAdministratorsGroup?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#organizational_unit_distinguished_name FsxWindowsFileSystem#organizational_unit_distinguished_name}.
         *
         * @stability stable
         */
        readonly organizationalUnitDistinguishedName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#password FsxWindowsFileSystem#password}.
         *
         * @stability stable
         */
        readonly password: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#username FsxWindowsFileSystem#username}.
         *
         * @stability stable
         */
        readonly username: string;
    }
    /**
     * @stability stable
     */
    class FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _dnsIps?;
        /**
         * @stability stable
         */
        get dnsIps(): string[];
        /**
         * @stability stable
         */
        set dnsIps(value: string[]);
        /**
         * @stability stable
         */
        get dnsIpsInput(): string[] | undefined;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        private _fileSystemAdministratorsGroup?;
        /**
         * @stability stable
         */
        get fileSystemAdministratorsGroup(): string | undefined;
        /**
         * @stability stable
         */
        set fileSystemAdministratorsGroup(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileSystemAdministratorsGroup(): void;
        /**
         * @stability stable
         */
        get fileSystemAdministratorsGroupInput(): string | undefined;
        private _organizationalUnitDistinguishedName?;
        /**
         * @stability stable
         */
        get organizationalUnitDistinguishedName(): string | undefined;
        /**
         * @stability stable
         */
        set organizationalUnitDistinguishedName(value: string | undefined);
        /**
         * @stability stable
         */
        resetOrganizationalUnitDistinguishedName(): void;
        /**
         * @stability stable
         */
        get organizationalUnitDistinguishedNameInput(): string | undefined;
        private _password?;
        /**
         * @stability stable
         */
        get password(): string;
        /**
         * @stability stable
         */
        set password(value: string);
        /**
         * @stability stable
         */
        get passwordInput(): string | undefined;
        private _username?;
        /**
         * @stability stable
         */
        get username(): string;
        /**
         * @stability stable
         */
        set username(value: string);
        /**
         * @stability stable
         */
        get usernameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface FsxWindowsFileSystemTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#create FsxWindowsFileSystem#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#delete FsxWindowsFileSystem#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html#update FsxWindowsFileSystem#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class FsxWindowsFileSystemTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html aws_fsx_windows_file_system}.
     *
     * @stability stable
     */
    class FsxWindowsFileSystem extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/fsx_windows_file_system.html aws_fsx_windows_file_system} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: FsxWindowsFileSystemConfig);
        private _activeDirectoryId?;
        /**
         * @stability stable
         */
        get activeDirectoryId(): string | undefined;
        /**
         * @stability stable
         */
        set activeDirectoryId(value: string | undefined);
        /**
         * @stability stable
         */
        resetActiveDirectoryId(): void;
        /**
         * @stability stable
         */
        get activeDirectoryIdInput(): string | undefined;
        private _aliases?;
        /**
         * @stability stable
         */
        get aliases(): string[] | undefined;
        /**
         * @stability stable
         */
        set aliases(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAliases(): void;
        /**
         * @stability stable
         */
        get aliasesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _automaticBackupRetentionDays?;
        /**
         * @stability stable
         */
        get automaticBackupRetentionDays(): number | undefined;
        /**
         * @stability stable
         */
        set automaticBackupRetentionDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetAutomaticBackupRetentionDays(): void;
        /**
         * @stability stable
         */
        get automaticBackupRetentionDaysInput(): number | undefined;
        private _backupId?;
        /**
         * @stability stable
         */
        get backupId(): string | undefined;
        /**
         * @stability stable
         */
        set backupId(value: string | undefined);
        /**
         * @stability stable
         */
        resetBackupId(): void;
        /**
         * @stability stable
         */
        get backupIdInput(): string | undefined;
        private _copyTagsToBackups?;
        /**
         * @stability stable
         */
        get copyTagsToBackups(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set copyTagsToBackups(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCopyTagsToBackups(): void;
        /**
         * @stability stable
         */
        get copyTagsToBackupsInput(): boolean | cdktf.IResolvable | undefined;
        private _dailyAutomaticBackupStartTime?;
        /**
         * @stability stable
         */
        get dailyAutomaticBackupStartTime(): string | undefined;
        /**
         * @stability stable
         */
        set dailyAutomaticBackupStartTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetDailyAutomaticBackupStartTime(): void;
        /**
         * @stability stable
         */
        get dailyAutomaticBackupStartTimeInput(): string | undefined;
        private _deploymentType?;
        /**
         * @stability stable
         */
        get deploymentType(): string | undefined;
        /**
         * @stability stable
         */
        set deploymentType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeploymentType(): void;
        /**
         * @stability stable
         */
        get deploymentTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get networkInterfaceIds(): string[];
        /**
         * @stability stable
         */
        get ownerId(): string;
        /**
         * @stability stable
         */
        get preferredFileServerIp(): string;
        private _preferredSubnetId?;
        /**
         * @stability stable
         */
        get preferredSubnetId(): string | undefined;
        /**
         * @stability stable
         */
        set preferredSubnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreferredSubnetId(): void;
        /**
         * @stability stable
         */
        get preferredSubnetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get remoteAdministrationEndpoint(): string;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _skipFinalBackup?;
        /**
         * @stability stable
         */
        get skipFinalBackup(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set skipFinalBackup(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSkipFinalBackup(): void;
        /**
         * @stability stable
         */
        get skipFinalBackupInput(): boolean | cdktf.IResolvable | undefined;
        private _storageCapacity?;
        /**
         * @stability stable
         */
        get storageCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set storageCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetStorageCapacity(): void;
        /**
         * @stability stable
         */
        get storageCapacityInput(): number | undefined;
        private _storageType?;
        /**
         * @stability stable
         */
        get storageType(): string | undefined;
        /**
         * @stability stable
         */
        set storageType(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageType(): void;
        /**
         * @stability stable
         */
        get storageTypeInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _throughputCapacity?;
        /**
         * @stability stable
         */
        get throughputCapacity(): number;
        /**
         * @stability stable
         */
        set throughputCapacity(value: number);
        /**
         * @stability stable
         */
        get throughputCapacityInput(): number | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _weeklyMaintenanceStartTime?;
        /**
         * @stability stable
         */
        get weeklyMaintenanceStartTime(): string | undefined;
        /**
         * @stability stable
         */
        set weeklyMaintenanceStartTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetWeeklyMaintenanceStartTime(): void;
        /**
         * @stability stable
         */
        get weeklyMaintenanceStartTimeInput(): string | undefined;
        private _auditLogConfiguration?;
        private __auditLogConfigurationOutput;
        /**
         * @stability stable
         */
        get auditLogConfiguration(): FsxWindowsFileSystemAuditLogConfigurationOutputReference;
        /**
         * @stability stable
         */
        putAuditLogConfiguration(value: FsxWindowsFileSystemAuditLogConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetAuditLogConfiguration(): void;
        /**
         * @stability stable
         */
        get auditLogConfigurationInput(): FsxWindowsFileSystemAuditLogConfiguration | undefined;
        private _selfManagedActiveDirectory?;
        private __selfManagedActiveDirectoryOutput;
        /**
         * @stability stable
         */
        get selfManagedActiveDirectory(): FsxWindowsFileSystemSelfManagedActiveDirectoryOutputReference;
        /**
         * @stability stable
         */
        putSelfManagedActiveDirectory(value: FsxWindowsFileSystemSelfManagedActiveDirectory | undefined): void;
        /**
         * @stability stable
         */
        resetSelfManagedActiveDirectory(): void;
        /**
         * @stability stable
         */
        get selfManagedActiveDirectoryInput(): FsxWindowsFileSystemSelfManagedActiveDirectory | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): FsxWindowsFileSystemTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: FsxWindowsFileSystemTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): FsxWindowsFileSystemTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
