import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Glacier
*/
export declare namespace Glacier {
    /**
     * @stability stable
     */
    interface GlacierVaultConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html#access_policy GlacierVault#access_policy}.
         *
         * @stability stable
         */
        readonly accessPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html#name GlacierVault#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html#tags GlacierVault#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html#tags_all GlacierVault#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * notification block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html#notification GlacierVault#notification}
         *
         * @stability stable
         */
        readonly notification?: GlacierVaultNotification;
    }
    /**
     * @stability stable
     */
    interface GlacierVaultNotification {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html#events GlacierVault#events}.
         *
         * @stability stable
         */
        readonly events: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html#sns_topic GlacierVault#sns_topic}.
         *
         * @stability stable
         */
        readonly snsTopic: string;
    }
    /**
     * @stability stable
     */
    class GlacierVaultNotificationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _events?;
        /**
         * @stability stable
         */
        get events(): string[];
        /**
         * @stability stable
         */
        set events(value: string[]);
        /**
         * @stability stable
         */
        get eventsInput(): string[] | undefined;
        private _snsTopic?;
        /**
         * @stability stable
         */
        get snsTopic(): string;
        /**
         * @stability stable
         */
        set snsTopic(value: string);
        /**
         * @stability stable
         */
        get snsTopicInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html aws_glacier_vault}.
     *
     * @stability stable
     */
    class GlacierVault extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault.html aws_glacier_vault} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlacierVaultConfig);
        private _accessPolicy?;
        /**
         * @stability stable
         */
        get accessPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set accessPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccessPolicy(): void;
        /**
         * @stability stable
         */
        get accessPolicyInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get location(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _notification?;
        private __notificationOutput;
        /**
         * @stability stable
         */
        get notification(): GlacierVaultNotificationOutputReference;
        /**
         * @stability stable
         */
        putNotification(value: GlacierVaultNotification | undefined): void;
        /**
         * @stability stable
         */
        resetNotification(): void;
        /**
         * @stability stable
         */
        get notificationInput(): GlacierVaultNotification | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlacierVaultLockConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault_lock.html#complete_lock GlacierVaultLock#complete_lock}.
         *
         * @stability stable
         */
        readonly completeLock: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault_lock.html#ignore_deletion_error GlacierVaultLock#ignore_deletion_error}.
         *
         * @stability stable
         */
        readonly ignoreDeletionError?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault_lock.html#policy GlacierVaultLock#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault_lock.html#vault_name GlacierVaultLock#vault_name}.
         *
         * @stability stable
         */
        readonly vaultName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault_lock.html aws_glacier_vault_lock}.
     *
     * @stability stable
     */
    class GlacierVaultLock extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glacier_vault_lock.html aws_glacier_vault_lock} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlacierVaultLockConfig);
        private _completeLock?;
        /**
         * @stability stable
         */
        get completeLock(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set completeLock(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get completeLockInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ignoreDeletionError?;
        /**
         * @stability stable
         */
        get ignoreDeletionError(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set ignoreDeletionError(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIgnoreDeletionError(): void;
        /**
         * @stability stable
         */
        get ignoreDeletionErrorInput(): boolean | cdktf.IResolvable | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _vaultName?;
        /**
         * @stability stable
         */
        get vaultName(): string;
        /**
         * @stability stable
         */
        set vaultName(value: string);
        /**
         * @stability stable
         */
        get vaultNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
