import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS GuardDuty
*/
export declare namespace GuardDuty {
    /**
     * @stability stable
     */
    interface GuarddutyDetectorConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html#enable GuarddutyDetector#enable}.
         *
         * @stability stable
         */
        readonly enable?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html#finding_publishing_frequency GuarddutyDetector#finding_publishing_frequency}.
         *
         * @stability stable
         */
        readonly findingPublishingFrequency?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html#tags GuarddutyDetector#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html#tags_all GuarddutyDetector#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * datasources block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html#datasources GuarddutyDetector#datasources}
         *
         * @stability stable
         */
        readonly datasources?: GuarddutyDetectorDatasources;
    }
    /**
     * @stability stable
     */
    interface GuarddutyDetectorDatasourcesS3Logs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html#enable GuarddutyDetector#enable}.
         *
         * @stability stable
         */
        readonly enable: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class GuarddutyDetectorDatasourcesS3LogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enable?;
        /**
         * @stability stable
         */
        get enable(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enable(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enableInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface GuarddutyDetectorDatasources {
        /**
         * s3_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html#s3_logs GuarddutyDetector#s3_logs}
         *
         * @stability stable
         */
        readonly s3Logs?: GuarddutyDetectorDatasourcesS3Logs;
    }
    /**
     * @stability stable
     */
    class GuarddutyDetectorDatasourcesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _s3Logs?;
        private __s3LogsOutput;
        /**
         * @stability stable
         */
        get s3Logs(): GuarddutyDetectorDatasourcesS3LogsOutputReference;
        /**
         * @stability stable
         */
        putS3Logs(value: GuarddutyDetectorDatasourcesS3Logs | undefined): void;
        /**
         * @stability stable
         */
        resetS3Logs(): void;
        /**
         * @stability stable
         */
        get s3LogsInput(): GuarddutyDetectorDatasourcesS3Logs | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html aws_guardduty_detector}.
     *
     * @stability stable
     */
    class GuarddutyDetector extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_detector.html aws_guardduty_detector} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: GuarddutyDetectorConfig);
        /**
         * @stability stable
         */
        get accountId(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        private _enable?;
        /**
         * @stability stable
         */
        get enable(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enable(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnable(): void;
        /**
         * @stability stable
         */
        get enableInput(): boolean | cdktf.IResolvable | undefined;
        private _findingPublishingFrequency?;
        /**
         * @stability stable
         */
        get findingPublishingFrequency(): string | undefined;
        /**
         * @stability stable
         */
        set findingPublishingFrequency(value: string | undefined);
        /**
         * @stability stable
         */
        resetFindingPublishingFrequency(): void;
        /**
         * @stability stable
         */
        get findingPublishingFrequencyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _datasources?;
        private __datasourcesOutput;
        /**
         * @stability stable
         */
        get datasources(): GuarddutyDetectorDatasourcesOutputReference;
        /**
         * @stability stable
         */
        putDatasources(value: GuarddutyDetectorDatasources | undefined): void;
        /**
         * @stability stable
         */
        resetDatasources(): void;
        /**
         * @stability stable
         */
        get datasourcesInput(): GuarddutyDetectorDatasources | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyFilterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#action GuarddutyFilter#action}.
         *
         * @stability stable
         */
        readonly action: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#description GuarddutyFilter#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#detector_id GuarddutyFilter#detector_id}.
         *
         * @stability stable
         */
        readonly detectorId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#name GuarddutyFilter#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#rank GuarddutyFilter#rank}.
         *
         * @stability stable
         */
        readonly rank: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#tags GuarddutyFilter#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#tags_all GuarddutyFilter#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * finding_criteria block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#finding_criteria GuarddutyFilter#finding_criteria}
         *
         * @stability stable
         */
        readonly findingCriteria: GuarddutyFilterFindingCriteria;
    }
    /**
     * @stability stable
     */
    interface GuarddutyFilterFindingCriteriaCriterion {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#equals GuarddutyFilter#equals}.
         *
         * @stability stable
         */
        readonly equalTo?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#field GuarddutyFilter#field}.
         *
         * @stability stable
         */
        readonly field: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#greater_than GuarddutyFilter#greater_than}.
         *
         * @stability stable
         */
        readonly greaterThan?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#greater_than_or_equal GuarddutyFilter#greater_than_or_equal}.
         *
         * @stability stable
         */
        readonly greaterThanOrEqual?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#less_than GuarddutyFilter#less_than}.
         *
         * @stability stable
         */
        readonly lessThan?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#less_than_or_equal GuarddutyFilter#less_than_or_equal}.
         *
         * @stability stable
         */
        readonly lessThanOrEqual?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#not_equals GuarddutyFilter#not_equals}.
         *
         * @stability stable
         */
        readonly notEquals?: string[];
    }
    /**
     * @stability stable
     */
    interface GuarddutyFilterFindingCriteria {
        /**
         * criterion block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html#criterion GuarddutyFilter#criterion}
         *
         * @stability stable
         */
        readonly criterion: GuarddutyFilterFindingCriteriaCriterion[];
    }
    /**
     * @stability stable
     */
    class GuarddutyFilterFindingCriteriaOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _criterion?;
        /**
         * @stability stable
         */
        get criterion(): GuarddutyFilterFindingCriteriaCriterion[];
        /**
         * @stability stable
         */
        set criterion(value: GuarddutyFilterFindingCriteriaCriterion[]);
        /**
         * @stability stable
         */
        get criterionInput(): GuarddutyFilterFindingCriteriaCriterion[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html aws_guardduty_filter}.
     *
     * @stability stable
     */
    class GuarddutyFilter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_filter.html aws_guardduty_filter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyFilterConfig);
        private _action?;
        /**
         * @stability stable
         */
        get action(): string;
        /**
         * @stability stable
         */
        set action(value: string);
        /**
         * @stability stable
         */
        get actionInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _detectorId?;
        /**
         * @stability stable
         */
        get detectorId(): string;
        /**
         * @stability stable
         */
        set detectorId(value: string);
        /**
         * @stability stable
         */
        get detectorIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _rank?;
        /**
         * @stability stable
         */
        get rank(): number;
        /**
         * @stability stable
         */
        set rank(value: number);
        /**
         * @stability stable
         */
        get rankInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _findingCriteria?;
        private __findingCriteriaOutput;
        /**
         * @stability stable
         */
        get findingCriteria(): GuarddutyFilterFindingCriteriaOutputReference;
        /**
         * @stability stable
         */
        putFindingCriteria(value: GuarddutyFilterFindingCriteria): void;
        /**
         * @stability stable
         */
        get findingCriteriaInput(): GuarddutyFilterFindingCriteria | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyInviteAccepterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_invite_accepter.html#detector_id GuarddutyInviteAccepter#detector_id}.
         *
         * @stability stable
         */
        readonly detectorId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_invite_accepter.html#master_account_id GuarddutyInviteAccepter#master_account_id}.
         *
         * @stability stable
         */
        readonly masterAccountId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_invite_accepter.html#timeouts GuarddutyInviteAccepter#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: GuarddutyInviteAccepterTimeouts;
    }
    /**
     * @stability stable
     */
    interface GuarddutyInviteAccepterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_invite_accepter.html#create GuarddutyInviteAccepter#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class GuarddutyInviteAccepterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_invite_accepter.html aws_guardduty_invite_accepter}.
     *
     * @stability stable
     */
    class GuarddutyInviteAccepter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_invite_accepter.html aws_guardduty_invite_accepter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyInviteAccepterConfig);
        private _detectorId?;
        /**
         * @stability stable
         */
        get detectorId(): string;
        /**
         * @stability stable
         */
        set detectorId(value: string);
        /**
         * @stability stable
         */
        get detectorIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _masterAccountId?;
        /**
         * @stability stable
         */
        get masterAccountId(): string;
        /**
         * @stability stable
         */
        set masterAccountId(value: string);
        /**
         * @stability stable
         */
        get masterAccountIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): GuarddutyInviteAccepterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: GuarddutyInviteAccepterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): GuarddutyInviteAccepterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyIpsetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html#activate GuarddutyIpset#activate}.
         *
         * @stability stable
         */
        readonly activate: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html#detector_id GuarddutyIpset#detector_id}.
         *
         * @stability stable
         */
        readonly detectorId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html#format GuarddutyIpset#format}.
         *
         * @stability stable
         */
        readonly format: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html#location GuarddutyIpset#location}.
         *
         * @stability stable
         */
        readonly location: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html#name GuarddutyIpset#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html#tags GuarddutyIpset#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html#tags_all GuarddutyIpset#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html aws_guardduty_ipset}.
     *
     * @stability stable
     */
    class GuarddutyIpset extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_ipset.html aws_guardduty_ipset} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyIpsetConfig);
        private _activate?;
        /**
         * @stability stable
         */
        get activate(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set activate(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get activateInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _detectorId?;
        /**
         * @stability stable
         */
        get detectorId(): string;
        /**
         * @stability stable
         */
        set detectorId(value: string);
        /**
         * @stability stable
         */
        get detectorIdInput(): string | undefined;
        private _format?;
        /**
         * @stability stable
         */
        get format(): string;
        /**
         * @stability stable
         */
        set format(value: string);
        /**
         * @stability stable
         */
        get formatInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _location?;
        /**
         * @stability stable
         */
        get location(): string;
        /**
         * @stability stable
         */
        set location(value: string);
        /**
         * @stability stable
         */
        get locationInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyMemberConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#account_id GuarddutyMember#account_id}.
         *
         * @stability stable
         */
        readonly accountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#detector_id GuarddutyMember#detector_id}.
         *
         * @stability stable
         */
        readonly detectorId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#disable_email_notification GuarddutyMember#disable_email_notification}.
         *
         * @stability stable
         */
        readonly disableEmailNotification?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#email GuarddutyMember#email}.
         *
         * @stability stable
         */
        readonly email: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#invitation_message GuarddutyMember#invitation_message}.
         *
         * @stability stable
         */
        readonly invitationMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#invite GuarddutyMember#invite}.
         *
         * @stability stable
         */
        readonly invite?: boolean | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#timeouts GuarddutyMember#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: GuarddutyMemberTimeouts;
    }
    /**
     * @stability stable
     */
    interface GuarddutyMemberTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#create GuarddutyMember#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html#update GuarddutyMember#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class GuarddutyMemberTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html aws_guardduty_member}.
     *
     * @stability stable
     */
    class GuarddutyMember extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_member.html aws_guardduty_member} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyMemberConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string;
        /**
         * @stability stable
         */
        set accountId(value: string);
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        private _detectorId?;
        /**
         * @stability stable
         */
        get detectorId(): string;
        /**
         * @stability stable
         */
        set detectorId(value: string);
        /**
         * @stability stable
         */
        get detectorIdInput(): string | undefined;
        private _disableEmailNotification?;
        /**
         * @stability stable
         */
        get disableEmailNotification(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set disableEmailNotification(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDisableEmailNotification(): void;
        /**
         * @stability stable
         */
        get disableEmailNotificationInput(): boolean | cdktf.IResolvable | undefined;
        private _email?;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        set email(value: string);
        /**
         * @stability stable
         */
        get emailInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _invitationMessage?;
        /**
         * @stability stable
         */
        get invitationMessage(): string | undefined;
        /**
         * @stability stable
         */
        set invitationMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetInvitationMessage(): void;
        /**
         * @stability stable
         */
        get invitationMessageInput(): string | undefined;
        private _invite?;
        /**
         * @stability stable
         */
        get invite(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set invite(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInvite(): void;
        /**
         * @stability stable
         */
        get inviteInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get relationshipStatus(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): GuarddutyMemberTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: GuarddutyMemberTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): GuarddutyMemberTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyOrganizationAdminAccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_admin_account.html#admin_account_id GuarddutyOrganizationAdminAccount#admin_account_id}.
         *
         * @stability stable
         */
        readonly adminAccountId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_admin_account.html aws_guardduty_organization_admin_account}.
     *
     * @stability stable
     */
    class GuarddutyOrganizationAdminAccount extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_admin_account.html aws_guardduty_organization_admin_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyOrganizationAdminAccountConfig);
        private _adminAccountId?;
        /**
         * @stability stable
         */
        get adminAccountId(): string;
        /**
         * @stability stable
         */
        set adminAccountId(value: string);
        /**
         * @stability stable
         */
        get adminAccountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyOrganizationConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration.html#auto_enable GuarddutyOrganizationConfiguration#auto_enable}.
         *
         * @stability stable
         */
        readonly autoEnable: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration.html#detector_id GuarddutyOrganizationConfiguration#detector_id}.
         *
         * @stability stable
         */
        readonly detectorId: string;
        /**
         * datasources block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration.html#datasources GuarddutyOrganizationConfiguration#datasources}
         *
         * @stability stable
         */
        readonly datasources?: GuarddutyOrganizationConfigurationDatasources;
    }
    /**
     * @stability stable
     */
    interface GuarddutyOrganizationConfigurationDatasourcesS3Logs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration.html#auto_enable GuarddutyOrganizationConfiguration#auto_enable}.
         *
         * @stability stable
         */
        readonly autoEnable: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _autoEnable?;
        /**
         * @stability stable
         */
        get autoEnable(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set autoEnable(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get autoEnableInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface GuarddutyOrganizationConfigurationDatasources {
        /**
         * s3_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration.html#s3_logs GuarddutyOrganizationConfiguration#s3_logs}
         *
         * @stability stable
         */
        readonly s3Logs?: GuarddutyOrganizationConfigurationDatasourcesS3Logs;
    }
    /**
     * @stability stable
     */
    class GuarddutyOrganizationConfigurationDatasourcesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _s3Logs?;
        private __s3LogsOutput;
        /**
         * @stability stable
         */
        get s3Logs(): GuarddutyOrganizationConfigurationDatasourcesS3LogsOutputReference;
        /**
         * @stability stable
         */
        putS3Logs(value: GuarddutyOrganizationConfigurationDatasourcesS3Logs | undefined): void;
        /**
         * @stability stable
         */
        resetS3Logs(): void;
        /**
         * @stability stable
         */
        get s3LogsInput(): GuarddutyOrganizationConfigurationDatasourcesS3Logs | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration.html aws_guardduty_organization_configuration}.
     *
     * @stability stable
     */
    class GuarddutyOrganizationConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_organization_configuration.html aws_guardduty_organization_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyOrganizationConfigurationConfig);
        private _autoEnable?;
        /**
         * @stability stable
         */
        get autoEnable(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set autoEnable(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get autoEnableInput(): boolean | cdktf.IResolvable | undefined;
        private _detectorId?;
        /**
         * @stability stable
         */
        get detectorId(): string;
        /**
         * @stability stable
         */
        set detectorId(value: string);
        /**
         * @stability stable
         */
        get detectorIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _datasources?;
        private __datasourcesOutput;
        /**
         * @stability stable
         */
        get datasources(): GuarddutyOrganizationConfigurationDatasourcesOutputReference;
        /**
         * @stability stable
         */
        putDatasources(value: GuarddutyOrganizationConfigurationDatasources | undefined): void;
        /**
         * @stability stable
         */
        resetDatasources(): void;
        /**
         * @stability stable
         */
        get datasourcesInput(): GuarddutyOrganizationConfigurationDatasources | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyPublishingDestinationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_publishing_destination.html#destination_arn GuarddutyPublishingDestination#destination_arn}.
         *
         * @stability stable
         */
        readonly destinationArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_publishing_destination.html#destination_type GuarddutyPublishingDestination#destination_type}.
         *
         * @stability stable
         */
        readonly destinationType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_publishing_destination.html#detector_id GuarddutyPublishingDestination#detector_id}.
         *
         * @stability stable
         */
        readonly detectorId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_publishing_destination.html#kms_key_arn GuarddutyPublishingDestination#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_publishing_destination.html aws_guardduty_publishing_destination}.
     *
     * @stability stable
     */
    class GuarddutyPublishingDestination extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_publishing_destination.html aws_guardduty_publishing_destination} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyPublishingDestinationConfig);
        private _destinationArn?;
        /**
         * @stability stable
         */
        get destinationArn(): string;
        /**
         * @stability stable
         */
        set destinationArn(value: string);
        /**
         * @stability stable
         */
        get destinationArnInput(): string | undefined;
        private _destinationType?;
        /**
         * @stability stable
         */
        get destinationType(): string | undefined;
        /**
         * @stability stable
         */
        set destinationType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDestinationType(): void;
        /**
         * @stability stable
         */
        get destinationTypeInput(): string | undefined;
        private _detectorId?;
        /**
         * @stability stable
         */
        get detectorId(): string;
        /**
         * @stability stable
         */
        set detectorId(value: string);
        /**
         * @stability stable
         */
        get detectorIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string);
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GuarddutyThreatintelsetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html#activate GuarddutyThreatintelset#activate}.
         *
         * @stability stable
         */
        readonly activate: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html#detector_id GuarddutyThreatintelset#detector_id}.
         *
         * @stability stable
         */
        readonly detectorId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html#format GuarddutyThreatintelset#format}.
         *
         * @stability stable
         */
        readonly format: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html#location GuarddutyThreatintelset#location}.
         *
         * @stability stable
         */
        readonly location: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html#name GuarddutyThreatintelset#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html#tags GuarddutyThreatintelset#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html#tags_all GuarddutyThreatintelset#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html aws_guardduty_threatintelset}.
     *
     * @stability stable
     */
    class GuarddutyThreatintelset extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/guardduty_threatintelset.html aws_guardduty_threatintelset} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GuarddutyThreatintelsetConfig);
        private _activate?;
        /**
         * @stability stable
         */
        get activate(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set activate(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get activateInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _detectorId?;
        /**
         * @stability stable
         */
        get detectorId(): string;
        /**
         * @stability stable
         */
        set detectorId(value: string);
        /**
         * @stability stable
         */
        get detectorIdInput(): string | undefined;
        private _format?;
        /**
         * @stability stable
         */
        get format(): string;
        /**
         * @stability stable
         */
        set format(value: string);
        /**
         * @stability stable
         */
        get formatInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _location?;
        /**
         * @stability stable
         */
        get location(): string;
        /**
         * @stability stable
         */
        set location(value: string);
        /**
         * @stability stable
         */
        get locationInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsGuarddutyDetectorConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/guardduty_detector.html aws_guardduty_detector}.
     *
     * @stability stable
     */
    class DataAwsGuarddutyDetector extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/guardduty_detector.html aws_guardduty_detector} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsGuarddutyDetectorConfig);
        /**
         * @stability stable
         */
        get findingPublishingFrequency(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get serviceRoleArn(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
