import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Identity and Access Management
*/
export declare namespace IAM {
    /**
     * @stability stable
     */
    interface IamAccessKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_access_key.html#pgp_key IamAccessKey#pgp_key}.
         *
         * @stability stable
         */
        readonly pgpKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_access_key.html#status IamAccessKey#status}.
         *
         * @stability stable
         */
        readonly status?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_access_key.html#user IamAccessKey#user}.
         *
         * @stability stable
         */
        readonly user: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_access_key.html aws_iam_access_key}.
     *
     * @stability stable
     */
    class IamAccessKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_access_key.html aws_iam_access_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamAccessKeyConfig);
        /**
         * @stability stable
         */
        get createDate(): string;
        /**
         * @stability stable
         */
        get encryptedSecret(): string;
        /**
         * @stability stable
         */
        get encryptedSesSmtpPasswordV4(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get keyFingerprint(): string;
        private _pgpKey?;
        /**
         * @stability stable
         */
        get pgpKey(): string | undefined;
        /**
         * @stability stable
         */
        set pgpKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetPgpKey(): void;
        /**
         * @stability stable
         */
        get pgpKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get secret(): string;
        /**
         * @stability stable
         */
        get sesSmtpPasswordV4(): string;
        private _status?;
        /**
         * @stability stable
         */
        get status(): string | undefined;
        /**
         * @stability stable
         */
        set status(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatus(): void;
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
        private _user?;
        /**
         * @stability stable
         */
        get user(): string;
        /**
         * @stability stable
         */
        set user(value: string);
        /**
         * @stability stable
         */
        get userInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamAccountAliasConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_alias.html#account_alias IamAccountAlias#account_alias}.
         *
         * @stability stable
         */
        readonly accountAlias: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_account_alias.html aws_iam_account_alias}.
     *
     * @stability stable
     */
    class IamAccountAlias extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_account_alias.html aws_iam_account_alias} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamAccountAliasConfig);
        private _accountAlias?;
        /**
         * @stability stable
         */
        get accountAlias(): string;
        /**
         * @stability stable
         */
        set accountAlias(value: string);
        /**
         * @stability stable
         */
        get accountAliasInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamAccountPasswordPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#allow_users_to_change_password IamAccountPasswordPolicy#allow_users_to_change_password}.
         *
         * @stability stable
         */
        readonly allowUsersToChangePassword?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#hard_expiry IamAccountPasswordPolicy#hard_expiry}.
         *
         * @stability stable
         */
        readonly hardExpiry?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#max_password_age IamAccountPasswordPolicy#max_password_age}.
         *
         * @stability stable
         */
        readonly maxPasswordAge?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#minimum_password_length IamAccountPasswordPolicy#minimum_password_length}.
         *
         * @stability stable
         */
        readonly minimumPasswordLength?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#password_reuse_prevention IamAccountPasswordPolicy#password_reuse_prevention}.
         *
         * @stability stable
         */
        readonly passwordReusePrevention?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#require_lowercase_characters IamAccountPasswordPolicy#require_lowercase_characters}.
         *
         * @stability stable
         */
        readonly requireLowercaseCharacters?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#require_numbers IamAccountPasswordPolicy#require_numbers}.
         *
         * @stability stable
         */
        readonly requireNumbers?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#require_symbols IamAccountPasswordPolicy#require_symbols}.
         *
         * @stability stable
         */
        readonly requireSymbols?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html#require_uppercase_characters IamAccountPasswordPolicy#require_uppercase_characters}.
         *
         * @stability stable
         */
        readonly requireUppercaseCharacters?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html aws_iam_account_password_policy}.
     *
     * @stability stable
     */
    class IamAccountPasswordPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_account_password_policy.html aws_iam_account_password_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: IamAccountPasswordPolicyConfig);
        private _allowUsersToChangePassword?;
        /**
         * @stability stable
         */
        get allowUsersToChangePassword(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowUsersToChangePassword(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowUsersToChangePassword(): void;
        /**
         * @stability stable
         */
        get allowUsersToChangePasswordInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get expirePasswords(): any;
        private _hardExpiry?;
        /**
         * @stability stable
         */
        get hardExpiry(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set hardExpiry(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetHardExpiry(): void;
        /**
         * @stability stable
         */
        get hardExpiryInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _maxPasswordAge?;
        /**
         * @stability stable
         */
        get maxPasswordAge(): number | undefined;
        /**
         * @stability stable
         */
        set maxPasswordAge(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxPasswordAge(): void;
        /**
         * @stability stable
         */
        get maxPasswordAgeInput(): number | undefined;
        private _minimumPasswordLength?;
        /**
         * @stability stable
         */
        get minimumPasswordLength(): number | undefined;
        /**
         * @stability stable
         */
        set minimumPasswordLength(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinimumPasswordLength(): void;
        /**
         * @stability stable
         */
        get minimumPasswordLengthInput(): number | undefined;
        private _passwordReusePrevention?;
        /**
         * @stability stable
         */
        get passwordReusePrevention(): number | undefined;
        /**
         * @stability stable
         */
        set passwordReusePrevention(value: number | undefined);
        /**
         * @stability stable
         */
        resetPasswordReusePrevention(): void;
        /**
         * @stability stable
         */
        get passwordReusePreventionInput(): number | undefined;
        private _requireLowercaseCharacters?;
        /**
         * @stability stable
         */
        get requireLowercaseCharacters(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireLowercaseCharacters(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireLowercaseCharacters(): void;
        /**
         * @stability stable
         */
        get requireLowercaseCharactersInput(): boolean | cdktf.IResolvable | undefined;
        private _requireNumbers?;
        /**
         * @stability stable
         */
        get requireNumbers(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireNumbers(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireNumbers(): void;
        /**
         * @stability stable
         */
        get requireNumbersInput(): boolean | cdktf.IResolvable | undefined;
        private _requireSymbols?;
        /**
         * @stability stable
         */
        get requireSymbols(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireSymbols(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireSymbols(): void;
        /**
         * @stability stable
         */
        get requireSymbolsInput(): boolean | cdktf.IResolvable | undefined;
        private _requireUppercaseCharacters?;
        /**
         * @stability stable
         */
        get requireUppercaseCharacters(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireUppercaseCharacters(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireUppercaseCharacters(): void;
        /**
         * @stability stable
         */
        get requireUppercaseCharactersInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group.html#name IamGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group.html#path IamGroup#path}.
         *
         * @stability stable
         */
        readonly path?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_group.html aws_iam_group}.
     *
     * @stability stable
     */
    class IamGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_group.html aws_iam_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        /**
         * @stability stable
         */
        get uniqueId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamGroupMembershipConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_membership.html#group IamGroupMembership#group}.
         *
         * @stability stable
         */
        readonly group: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_membership.html#name IamGroupMembership#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_membership.html#users IamGroupMembership#users}.
         *
         * @stability stable
         */
        readonly users: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_group_membership.html aws_iam_group_membership}.
     *
     * @stability stable
     */
    class IamGroupMembership extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_group_membership.html aws_iam_group_membership} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamGroupMembershipConfig);
        private _group?;
        /**
         * @stability stable
         */
        get group(): string;
        /**
         * @stability stable
         */
        set group(value: string);
        /**
         * @stability stable
         */
        get groupInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _users?;
        /**
         * @stability stable
         */
        get users(): string[];
        /**
         * @stability stable
         */
        set users(value: string[]);
        /**
         * @stability stable
         */
        get usersInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamGroupPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy.html#group IamGroupPolicy#group}.
         *
         * @stability stable
         */
        readonly group: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy.html#name IamGroupPolicy#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy.html#name_prefix IamGroupPolicy#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy.html#policy IamGroupPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy.html aws_iam_group_policy}.
     *
     * @stability stable
     */
    class IamGroupPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy.html aws_iam_group_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamGroupPolicyConfig);
        private _group?;
        /**
         * @stability stable
         */
        get group(): string;
        /**
         * @stability stable
         */
        set group(value: string);
        /**
         * @stability stable
         */
        get groupInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamGroupPolicyAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy_attachment.html#group IamGroupPolicyAttachment#group}.
         *
         * @stability stable
         */
        readonly group: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy_attachment.html#policy_arn IamGroupPolicyAttachment#policy_arn}.
         *
         * @stability stable
         */
        readonly policyArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy_attachment.html aws_iam_group_policy_attachment}.
     *
     * @stability stable
     */
    class IamGroupPolicyAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_group_policy_attachment.html aws_iam_group_policy_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamGroupPolicyAttachmentConfig);
        private _group?;
        /**
         * @stability stable
         */
        get group(): string;
        /**
         * @stability stable
         */
        set group(value: string);
        /**
         * @stability stable
         */
        get groupInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policyArn?;
        /**
         * @stability stable
         */
        get policyArn(): string;
        /**
         * @stability stable
         */
        set policyArn(value: string);
        /**
         * @stability stable
         */
        get policyArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamInstanceProfileConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html#name IamInstanceProfile#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html#name_prefix IamInstanceProfile#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html#path IamInstanceProfile#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html#role IamInstanceProfile#role}.
         *
         * @stability stable
         */
        readonly role?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html#tags IamInstanceProfile#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html#tags_all IamInstanceProfile#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html aws_iam_instance_profile}.
     *
     * @stability stable
     */
    class IamInstanceProfile extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_instance_profile.html aws_iam_instance_profile} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: IamInstanceProfileConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get createDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string | undefined;
        /**
         * @stability stable
         */
        set role(value: string | undefined);
        /**
         * @stability stable
         */
        resetRole(): void;
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get uniqueId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamOpenidConnectProviderConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_openid_connect_provider.html#client_id_list IamOpenidConnectProvider#client_id_list}.
         *
         * @stability stable
         */
        readonly clientIdList: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_openid_connect_provider.html#tags IamOpenidConnectProvider#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_openid_connect_provider.html#tags_all IamOpenidConnectProvider#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_openid_connect_provider.html#thumbprint_list IamOpenidConnectProvider#thumbprint_list}.
         *
         * @stability stable
         */
        readonly thumbprintList: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_openid_connect_provider.html#url IamOpenidConnectProvider#url}.
         *
         * @stability stable
         */
        readonly url: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_openid_connect_provider.html aws_iam_openid_connect_provider}.
     *
     * @stability stable
     */
    class IamOpenidConnectProvider extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_openid_connect_provider.html aws_iam_openid_connect_provider} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamOpenidConnectProviderConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _clientIdList?;
        /**
         * @stability stable
         */
        get clientIdList(): string[];
        /**
         * @stability stable
         */
        set clientIdList(value: string[]);
        /**
         * @stability stable
         */
        get clientIdListInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _thumbprintList?;
        /**
         * @stability stable
         */
        get thumbprintList(): string[];
        /**
         * @stability stable
         */
        set thumbprintList(value: string[]);
        /**
         * @stability stable
         */
        get thumbprintListInput(): string[] | undefined;
        private _url?;
        /**
         * @stability stable
         */
        get url(): string;
        /**
         * @stability stable
         */
        set url(value: string);
        /**
         * @stability stable
         */
        get urlInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html#description IamPolicy#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html#name IamPolicy#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html#name_prefix IamPolicy#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html#path IamPolicy#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html#policy IamPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html#tags IamPolicy#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html#tags_all IamPolicy#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html aws_iam_policy}.
     *
     * @stability stable
     */
    class IamPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_policy.html aws_iam_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamPolicyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        get policyId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamPolicyAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy_attachment.html#groups IamPolicyAttachment#groups}.
         *
         * @stability stable
         */
        readonly groups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy_attachment.html#name IamPolicyAttachment#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy_attachment.html#policy_arn IamPolicyAttachment#policy_arn}.
         *
         * @stability stable
         */
        readonly policyArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy_attachment.html#roles IamPolicyAttachment#roles}.
         *
         * @stability stable
         */
        readonly roles?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_policy_attachment.html#users IamPolicyAttachment#users}.
         *
         * @stability stable
         */
        readonly users?: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_policy_attachment.html aws_iam_policy_attachment}.
     *
     * @stability stable
     */
    class IamPolicyAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_policy_attachment.html aws_iam_policy_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamPolicyAttachmentConfig);
        private _groups?;
        /**
         * @stability stable
         */
        get groups(): string[] | undefined;
        /**
         * @stability stable
         */
        set groups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetGroups(): void;
        /**
         * @stability stable
         */
        get groupsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _policyArn?;
        /**
         * @stability stable
         */
        get policyArn(): string;
        /**
         * @stability stable
         */
        set policyArn(value: string);
        /**
         * @stability stable
         */
        get policyArnInput(): string | undefined;
        private _roles?;
        /**
         * @stability stable
         */
        get roles(): string[] | undefined;
        /**
         * @stability stable
         */
        set roles(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetRoles(): void;
        /**
         * @stability stable
         */
        get rolesInput(): string[] | undefined;
        private _users?;
        /**
         * @stability stable
         */
        get users(): string[] | undefined;
        /**
         * @stability stable
         */
        set users(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetUsers(): void;
        /**
         * @stability stable
         */
        get usersInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamRoleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#assume_role_policy IamRole#assume_role_policy}.
         *
         * @stability stable
         */
        readonly assumeRolePolicy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#description IamRole#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#force_detach_policies IamRole#force_detach_policies}.
         *
         * @stability stable
         */
        readonly forceDetachPolicies?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#managed_policy_arns IamRole#managed_policy_arns}.
         *
         * @stability stable
         */
        readonly managedPolicyArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#max_session_duration IamRole#max_session_duration}.
         *
         * @stability stable
         */
        readonly maxSessionDuration?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#name IamRole#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#name_prefix IamRole#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#path IamRole#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#permissions_boundary IamRole#permissions_boundary}.
         *
         * @stability stable
         */
        readonly permissionsBoundary?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#tags IamRole#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#tags_all IamRole#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * inline_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#inline_policy IamRole#inline_policy}
         *
         * @stability stable
         */
        readonly inlinePolicy?: IamRoleInlinePolicy[];
    }
    /**
     * @stability stable
     */
    interface IamRoleInlinePolicy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#name IamRole#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html#policy IamRole#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html aws_iam_role}.
     *
     * @stability stable
     */
    class IamRole extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_role.html aws_iam_role} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamRoleConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _assumeRolePolicy?;
        /**
         * @stability stable
         */
        get assumeRolePolicy(): string;
        /**
         * @stability stable
         */
        set assumeRolePolicy(value: string);
        /**
         * @stability stable
         */
        get assumeRolePolicyInput(): string | undefined;
        /**
         * @stability stable
         */
        get createDate(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _forceDetachPolicies?;
        /**
         * @stability stable
         */
        get forceDetachPolicies(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDetachPolicies(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDetachPolicies(): void;
        /**
         * @stability stable
         */
        get forceDetachPoliciesInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _managedPolicyArns?;
        /**
         * @stability stable
         */
        get managedPolicyArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set managedPolicyArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetManagedPolicyArns(): void;
        /**
         * @stability stable
         */
        get managedPolicyArnsInput(): string[] | undefined;
        private _maxSessionDuration?;
        /**
         * @stability stable
         */
        get maxSessionDuration(): number | undefined;
        /**
         * @stability stable
         */
        set maxSessionDuration(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxSessionDuration(): void;
        /**
         * @stability stable
         */
        get maxSessionDurationInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _permissionsBoundary?;
        /**
         * @stability stable
         */
        get permissionsBoundary(): string | undefined;
        /**
         * @stability stable
         */
        set permissionsBoundary(value: string | undefined);
        /**
         * @stability stable
         */
        resetPermissionsBoundary(): void;
        /**
         * @stability stable
         */
        get permissionsBoundaryInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get uniqueId(): string;
        private _inlinePolicy?;
        /**
         * @stability stable
         */
        get inlinePolicy(): IamRoleInlinePolicy[] | undefined;
        /**
         * @stability stable
         */
        set inlinePolicy(value: IamRoleInlinePolicy[] | undefined);
        /**
         * @stability stable
         */
        resetInlinePolicy(): void;
        /**
         * @stability stable
         */
        get inlinePolicyInput(): IamRoleInlinePolicy[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamRolePolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy.html#name IamRolePolicy#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy.html#name_prefix IamRolePolicy#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy.html#policy IamRolePolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy.html#role IamRolePolicy#role}.
         *
         * @stability stable
         */
        readonly role: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy.html aws_iam_role_policy}.
     *
     * @stability stable
     */
    class IamRolePolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy.html aws_iam_role_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamRolePolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        set role(value: string);
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamRolePolicyAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy_attachment.html#policy_arn IamRolePolicyAttachment#policy_arn}.
         *
         * @stability stable
         */
        readonly policyArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy_attachment.html#role IamRolePolicyAttachment#role}.
         *
         * @stability stable
         */
        readonly role: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy_attachment.html aws_iam_role_policy_attachment}.
     *
     * @stability stable
     */
    class IamRolePolicyAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_role_policy_attachment.html aws_iam_role_policy_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamRolePolicyAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policyArn?;
        /**
         * @stability stable
         */
        get policyArn(): string;
        /**
         * @stability stable
         */
        set policyArn(value: string);
        /**
         * @stability stable
         */
        get policyArnInput(): string | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        set role(value: string);
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamSamlProviderConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_saml_provider.html#name IamSamlProvider#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_saml_provider.html#saml_metadata_document IamSamlProvider#saml_metadata_document}.
         *
         * @stability stable
         */
        readonly samlMetadataDocument: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_saml_provider.html#tags IamSamlProvider#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_saml_provider.html#tags_all IamSamlProvider#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_saml_provider.html aws_iam_saml_provider}.
     *
     * @stability stable
     */
    class IamSamlProvider extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_saml_provider.html aws_iam_saml_provider} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamSamlProviderConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _samlMetadataDocument?;
        /**
         * @stability stable
         */
        get samlMetadataDocument(): string;
        /**
         * @stability stable
         */
        set samlMetadataDocument(value: string);
        /**
         * @stability stable
         */
        get samlMetadataDocumentInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get validUntil(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamServerCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#certificate_body IamServerCertificate#certificate_body}.
         *
         * @stability stable
         */
        readonly certificateBody: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#certificate_chain IamServerCertificate#certificate_chain}.
         *
         * @stability stable
         */
        readonly certificateChain?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#name IamServerCertificate#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#name_prefix IamServerCertificate#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#path IamServerCertificate#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#private_key IamServerCertificate#private_key}.
         *
         * @stability stable
         */
        readonly privateKey: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#tags IamServerCertificate#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html#tags_all IamServerCertificate#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html aws_iam_server_certificate}.
     *
     * @stability stable
     */
    class IamServerCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_server_certificate.html aws_iam_server_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamServerCertificateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _certificateBody?;
        /**
         * @stability stable
         */
        get certificateBody(): string;
        /**
         * @stability stable
         */
        set certificateBody(value: string);
        /**
         * @stability stable
         */
        get certificateBodyInput(): string | undefined;
        private _certificateChain?;
        /**
         * @stability stable
         */
        get certificateChain(): string | undefined;
        /**
         * @stability stable
         */
        set certificateChain(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateChain(): void;
        /**
         * @stability stable
         */
        get certificateChainInput(): string | undefined;
        /**
         * @stability stable
         */
        get expiration(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _privateKey?;
        /**
         * @stability stable
         */
        get privateKey(): string;
        /**
         * @stability stable
         */
        set privateKey(value: string);
        /**
         * @stability stable
         */
        get privateKeyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get uploadDate(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamServiceLinkedRoleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_service_linked_role.html#aws_service_name IamServiceLinkedRole#aws_service_name}.
         *
         * @stability stable
         */
        readonly awsServiceName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_service_linked_role.html#custom_suffix IamServiceLinkedRole#custom_suffix}.
         *
         * @stability stable
         */
        readonly customSuffix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_service_linked_role.html#description IamServiceLinkedRole#description}.
         *
         * @stability stable
         */
        readonly description?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_service_linked_role.html aws_iam_service_linked_role}.
     *
     * @stability stable
     */
    class IamServiceLinkedRole extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_service_linked_role.html aws_iam_service_linked_role} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamServiceLinkedRoleConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _awsServiceName?;
        /**
         * @stability stable
         */
        get awsServiceName(): string;
        /**
         * @stability stable
         */
        set awsServiceName(value: string);
        /**
         * @stability stable
         */
        get awsServiceNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get createDate(): string;
        private _customSuffix?;
        /**
         * @stability stable
         */
        get customSuffix(): string | undefined;
        /**
         * @stability stable
         */
        set customSuffix(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomSuffix(): void;
        /**
         * @stability stable
         */
        get customSuffixInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get uniqueId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamUserConfig extends cdktf.TerraformMetaArguments {
        /**
         * Delete user even if it has non-Terraform-managed IAM access keys, login profile or MFA devices.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html#force_destroy IamUser#force_destroy}
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html#name IamUser#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html#path IamUser#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html#permissions_boundary IamUser#permissions_boundary}.
         *
         * @stability stable
         */
        readonly permissionsBoundary?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html#tags IamUser#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html#tags_all IamUser#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html aws_iam_user}.
     *
     * @stability stable
     */
    class IamUser extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_user.html aws_iam_user} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamUserConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _permissionsBoundary?;
        /**
         * @stability stable
         */
        get permissionsBoundary(): string | undefined;
        /**
         * @stability stable
         */
        set permissionsBoundary(value: string | undefined);
        /**
         * @stability stable
         */
        resetPermissionsBoundary(): void;
        /**
         * @stability stable
         */
        get permissionsBoundaryInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get uniqueId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamUserGroupMembershipConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_group_membership.html#groups IamUserGroupMembership#groups}.
         *
         * @stability stable
         */
        readonly groups: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_group_membership.html#user IamUserGroupMembership#user}.
         *
         * @stability stable
         */
        readonly user: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_user_group_membership.html aws_iam_user_group_membership}.
     *
     * @stability stable
     */
    class IamUserGroupMembership extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_user_group_membership.html aws_iam_user_group_membership} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamUserGroupMembershipConfig);
        private _groups?;
        /**
         * @stability stable
         */
        get groups(): string[];
        /**
         * @stability stable
         */
        set groups(value: string[]);
        /**
         * @stability stable
         */
        get groupsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _user?;
        /**
         * @stability stable
         */
        get user(): string;
        /**
         * @stability stable
         */
        set user(value: string);
        /**
         * @stability stable
         */
        get userInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamUserLoginProfileConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_login_profile.html#password_length IamUserLoginProfile#password_length}.
         *
         * @stability stable
         */
        readonly passwordLength?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_login_profile.html#password_reset_required IamUserLoginProfile#password_reset_required}.
         *
         * @stability stable
         */
        readonly passwordResetRequired?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_login_profile.html#pgp_key IamUserLoginProfile#pgp_key}.
         *
         * @stability stable
         */
        readonly pgpKey: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_login_profile.html#user IamUserLoginProfile#user}.
         *
         * @stability stable
         */
        readonly user: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_user_login_profile.html aws_iam_user_login_profile}.
     *
     * @stability stable
     */
    class IamUserLoginProfile extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_user_login_profile.html aws_iam_user_login_profile} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamUserLoginProfileConfig);
        /**
         * @stability stable
         */
        get encryptedPassword(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get keyFingerprint(): string;
        private _passwordLength?;
        /**
         * @stability stable
         */
        get passwordLength(): number | undefined;
        /**
         * @stability stable
         */
        set passwordLength(value: number | undefined);
        /**
         * @stability stable
         */
        resetPasswordLength(): void;
        /**
         * @stability stable
         */
        get passwordLengthInput(): number | undefined;
        private _passwordResetRequired?;
        /**
         * @stability stable
         */
        get passwordResetRequired(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set passwordResetRequired(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPasswordResetRequired(): void;
        /**
         * @stability stable
         */
        get passwordResetRequiredInput(): boolean | cdktf.IResolvable | undefined;
        private _pgpKey?;
        /**
         * @stability stable
         */
        get pgpKey(): string;
        /**
         * @stability stable
         */
        set pgpKey(value: string);
        /**
         * @stability stable
         */
        get pgpKeyInput(): string | undefined;
        private _user?;
        /**
         * @stability stable
         */
        get user(): string;
        /**
         * @stability stable
         */
        set user(value: string);
        /**
         * @stability stable
         */
        get userInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamUserPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy.html#name IamUserPolicy#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy.html#name_prefix IamUserPolicy#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy.html#policy IamUserPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy.html#user IamUserPolicy#user}.
         *
         * @stability stable
         */
        readonly user: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy.html aws_iam_user_policy}.
     *
     * @stability stable
     */
    class IamUserPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy.html aws_iam_user_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamUserPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _user?;
        /**
         * @stability stable
         */
        get user(): string;
        /**
         * @stability stable
         */
        set user(value: string);
        /**
         * @stability stable
         */
        get userInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamUserPolicyAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy_attachment.html#policy_arn IamUserPolicyAttachment#policy_arn}.
         *
         * @stability stable
         */
        readonly policyArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy_attachment.html#user IamUserPolicyAttachment#user}.
         *
         * @stability stable
         */
        readonly user: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy_attachment.html aws_iam_user_policy_attachment}.
     *
     * @stability stable
     */
    class IamUserPolicyAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_user_policy_attachment.html aws_iam_user_policy_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamUserPolicyAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policyArn?;
        /**
         * @stability stable
         */
        get policyArn(): string;
        /**
         * @stability stable
         */
        set policyArn(value: string);
        /**
         * @stability stable
         */
        get policyArnInput(): string | undefined;
        private _user?;
        /**
         * @stability stable
         */
        get user(): string;
        /**
         * @stability stable
         */
        set user(value: string);
        /**
         * @stability stable
         */
        get userInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IamUserSshKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_ssh_key.html#encoding IamUserSshKey#encoding}.
         *
         * @stability stable
         */
        readonly encoding: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_ssh_key.html#public_key IamUserSshKey#public_key}.
         *
         * @stability stable
         */
        readonly publicKey: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_ssh_key.html#status IamUserSshKey#status}.
         *
         * @stability stable
         */
        readonly status?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iam_user_ssh_key.html#username IamUserSshKey#username}.
         *
         * @stability stable
         */
        readonly username: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iam_user_ssh_key.html aws_iam_user_ssh_key}.
     *
     * @stability stable
     */
    class IamUserSshKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iam_user_ssh_key.html aws_iam_user_ssh_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IamUserSshKeyConfig);
        private _encoding?;
        /**
         * @stability stable
         */
        get encoding(): string;
        /**
         * @stability stable
         */
        set encoding(value: string);
        /**
         * @stability stable
         */
        get encodingInput(): string | undefined;
        /**
         * @stability stable
         */
        get fingerprint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _publicKey?;
        /**
         * @stability stable
         */
        get publicKey(): string;
        /**
         * @stability stable
         */
        set publicKey(value: string);
        /**
         * @stability stable
         */
        get publicKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get sshPublicKeyId(): string;
        private _status?;
        /**
         * @stability stable
         */
        get status(): string | undefined;
        /**
         * @stability stable
         */
        set status(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatus(): void;
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
        private _username?;
        /**
         * @stability stable
         */
        get username(): string;
        /**
         * @stability stable
         */
        set username(value: string);
        /**
         * @stability stable
         */
        get usernameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamAccountAliasConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_account_alias.html aws_iam_account_alias}.
     *
     * @stability stable
     */
    class DataAwsIamAccountAlias extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_account_alias.html aws_iam_account_alias} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsIamAccountAliasConfig);
        /**
         * @stability stable
         */
        get accountAlias(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_group.html#group_name DataAwsIamGroup#group_name}.
         *
         * @stability stable
         */
        readonly groupName: string;
    }
    /**
     * @stability stable
     */
    class DataAwsIamGroupUsers extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get userId(): string;
        /**
         * @stability stable
         */
        get userName(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_group.html aws_iam_group}.
     *
     * @stability stable
     */
    class DataAwsIamGroup extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_group.html aws_iam_group} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsIamGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get groupId(): string;
        private _groupName?;
        /**
         * @stability stable
         */
        get groupName(): string;
        /**
         * @stability stable
         */
        set groupName(value: string);
        /**
         * @stability stable
         */
        get groupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        users(index: string): DataAwsIamGroupUsers;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamInstanceProfileConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_instance_profile.html#name DataAwsIamInstanceProfile#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_instance_profile.html aws_iam_instance_profile}.
     *
     * @stability stable
     */
    class DataAwsIamInstanceProfile extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_instance_profile.html aws_iam_instance_profile} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsIamInstanceProfileConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get createDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        get roleId(): string;
        /**
         * @stability stable
         */
        get roleName(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy.html#name DataAwsIamPolicy#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy.html#path_prefix DataAwsIamPolicy#path_prefix}.
         *
         * @stability stable
         */
        readonly pathPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy.html#tags DataAwsIamPolicy#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_policy.html aws_iam_policy}.
     *
     * @stability stable
     */
    class DataAwsIamPolicy extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_policy.html aws_iam_policy} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsIamPolicyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get path(): string;
        private _pathPrefix?;
        /**
         * @stability stable
         */
        get pathPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set pathPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPathPrefix(): void;
        /**
         * @stability stable
         */
        get pathPrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        get policyId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamPolicyDocumentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#override_json DataAwsIamPolicyDocument#override_json}.
         *
         * @stability stable
         */
        readonly overrideJson?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#override_policy_documents DataAwsIamPolicyDocument#override_policy_documents}.
         *
         * @stability stable
         */
        readonly overridePolicyDocuments?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#policy_id DataAwsIamPolicyDocument#policy_id}.
         *
         * @stability stable
         */
        readonly policyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#source_json DataAwsIamPolicyDocument#source_json}.
         *
         * @stability stable
         */
        readonly sourceJson?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#source_policy_documents DataAwsIamPolicyDocument#source_policy_documents}.
         *
         * @stability stable
         */
        readonly sourcePolicyDocuments?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#version DataAwsIamPolicyDocument#version}.
         *
         * @stability stable
         */
        readonly version?: string;
        /**
         * statement block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#statement DataAwsIamPolicyDocument#statement}
         *
         * @stability stable
         */
        readonly statement?: DataAwsIamPolicyDocumentStatement[];
    }
    /**
     * @stability stable
     */
    interface DataAwsIamPolicyDocumentStatementCondition {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#test DataAwsIamPolicyDocument#test}.
         *
         * @stability stable
         */
        readonly test: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#values DataAwsIamPolicyDocument#values}.
         *
         * @stability stable
         */
        readonly values: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#variable DataAwsIamPolicyDocument#variable}.
         *
         * @stability stable
         */
        readonly variable: string;
    }
    /**
     * @stability stable
     */
    interface DataAwsIamPolicyDocumentStatementNotPrincipals {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#identifiers DataAwsIamPolicyDocument#identifiers}.
         *
         * @stability stable
         */
        readonly identifiers: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#type DataAwsIamPolicyDocument#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    interface DataAwsIamPolicyDocumentStatementPrincipals {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#identifiers DataAwsIamPolicyDocument#identifiers}.
         *
         * @stability stable
         */
        readonly identifiers: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#type DataAwsIamPolicyDocument#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    interface DataAwsIamPolicyDocumentStatement {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#actions DataAwsIamPolicyDocument#actions}.
         *
         * @stability stable
         */
        readonly actions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#effect DataAwsIamPolicyDocument#effect}.
         *
         * @stability stable
         */
        readonly effect?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#not_actions DataAwsIamPolicyDocument#not_actions}.
         *
         * @stability stable
         */
        readonly notActions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#not_resources DataAwsIamPolicyDocument#not_resources}.
         *
         * @stability stable
         */
        readonly notResources?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#resources DataAwsIamPolicyDocument#resources}.
         *
         * @stability stable
         */
        readonly resources?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#sid DataAwsIamPolicyDocument#sid}.
         *
         * @stability stable
         */
        readonly sid?: string;
        /**
         * condition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#condition DataAwsIamPolicyDocument#condition}
         *
         * @stability stable
         */
        readonly condition?: DataAwsIamPolicyDocumentStatementCondition[];
        /**
         * not_principals block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#not_principals DataAwsIamPolicyDocument#not_principals}
         *
         * @stability stable
         */
        readonly notPrincipals?: DataAwsIamPolicyDocumentStatementNotPrincipals[];
        /**
         * principals block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html#principals DataAwsIamPolicyDocument#principals}
         *
         * @stability stable
         */
        readonly principals?: DataAwsIamPolicyDocumentStatementPrincipals[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html aws_iam_policy_document}.
     *
     * @stability stable
     */
    class DataAwsIamPolicyDocument extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_policy_document.html aws_iam_policy_document} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsIamPolicyDocumentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get json(): string;
        private _overrideJson?;
        /**
         * @stability stable
         */
        get overrideJson(): string | undefined;
        /**
         * @stability stable
         */
        set overrideJson(value: string | undefined);
        /**
         * @stability stable
         */
        resetOverrideJson(): void;
        /**
         * @stability stable
         */
        get overrideJsonInput(): string | undefined;
        private _overridePolicyDocuments?;
        /**
         * @stability stable
         */
        get overridePolicyDocuments(): string[] | undefined;
        /**
         * @stability stable
         */
        set overridePolicyDocuments(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetOverridePolicyDocuments(): void;
        /**
         * @stability stable
         */
        get overridePolicyDocumentsInput(): string[] | undefined;
        private _policyId?;
        /**
         * @stability stable
         */
        get policyId(): string | undefined;
        /**
         * @stability stable
         */
        set policyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicyId(): void;
        /**
         * @stability stable
         */
        get policyIdInput(): string | undefined;
        private _sourceJson?;
        /**
         * @stability stable
         */
        get sourceJson(): string | undefined;
        /**
         * @stability stable
         */
        set sourceJson(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceJson(): void;
        /**
         * @stability stable
         */
        get sourceJsonInput(): string | undefined;
        private _sourcePolicyDocuments?;
        /**
         * @stability stable
         */
        get sourcePolicyDocuments(): string[] | undefined;
        /**
         * @stability stable
         */
        set sourcePolicyDocuments(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSourcePolicyDocuments(): void;
        /**
         * @stability stable
         */
        get sourcePolicyDocumentsInput(): string[] | undefined;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
        private _statement?;
        /**
         * @stability stable
         */
        get statement(): DataAwsIamPolicyDocumentStatement[] | undefined;
        /**
         * @stability stable
         */
        set statement(value: DataAwsIamPolicyDocumentStatement[] | undefined);
        /**
         * @stability stable
         */
        resetStatement(): void;
        /**
         * @stability stable
         */
        get statementInput(): DataAwsIamPolicyDocumentStatement[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamRoleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_role.html#name DataAwsIamRole#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_role.html#tags DataAwsIamRole#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_role.html aws_iam_role}.
     *
     * @stability stable
     */
    class DataAwsIamRole extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_role.html aws_iam_role} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsIamRoleConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get assumeRolePolicy(): string;
        /**
         * @stability stable
         */
        get createDate(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get maxSessionDuration(): number;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get permissionsBoundary(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get uniqueId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamRolesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_roles.html#name_regex DataAwsIamRoles#name_regex}.
         *
         * @stability stable
         */
        readonly nameRegex?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_roles.html#path_prefix DataAwsIamRoles#path_prefix}.
         *
         * @stability stable
         */
        readonly pathPrefix?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_roles.html aws_iam_roles}.
     *
     * @stability stable
     */
    class DataAwsIamRoles extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_roles.html aws_iam_roles} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsIamRolesConfig);
        /**
         * @stability stable
         */
        get arns(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        private _nameRegex?;
        /**
         * @stability stable
         */
        get nameRegex(): string | undefined;
        /**
         * @stability stable
         */
        set nameRegex(value: string | undefined);
        /**
         * @stability stable
         */
        resetNameRegex(): void;
        /**
         * @stability stable
         */
        get nameRegexInput(): string | undefined;
        /**
         * @stability stable
         */
        get names(): string[];
        private _pathPrefix?;
        /**
         * @stability stable
         */
        get pathPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set pathPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPathPrefix(): void;
        /**
         * @stability stable
         */
        get pathPrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamServerCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_server_certificate.html#latest DataAwsIamServerCertificate#latest}.
         *
         * @stability stable
         */
        readonly latest?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_server_certificate.html#name DataAwsIamServerCertificate#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_server_certificate.html#name_prefix DataAwsIamServerCertificate#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_server_certificate.html#path_prefix DataAwsIamServerCertificate#path_prefix}.
         *
         * @stability stable
         */
        readonly pathPrefix?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_server_certificate.html aws_iam_server_certificate}.
     *
     * @stability stable
     */
    class DataAwsIamServerCertificate extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_server_certificate.html aws_iam_server_certificate} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsIamServerCertificateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificateBody(): string;
        /**
         * @stability stable
         */
        get certificateChain(): string;
        /**
         * @stability stable
         */
        get expirationDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _latest?;
        /**
         * @stability stable
         */
        get latest(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set latest(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetLatest(): void;
        /**
         * @stability stable
         */
        get latestInput(): boolean | cdktf.IResolvable | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        get path(): string;
        private _pathPrefix?;
        /**
         * @stability stable
         */
        get pathPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set pathPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPathPrefix(): void;
        /**
         * @stability stable
         */
        get pathPrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        get uploadDate(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamSessionContextConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_session_context.html#arn DataAwsIamSessionContext#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_session_context.html aws_iam_session_context}.
     *
     * @stability stable
     */
    class DataAwsIamSessionContext extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_session_context.html aws_iam_session_context} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsIamSessionContextConfig);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get issuerArn(): string;
        /**
         * @stability stable
         */
        get issuerId(): string;
        /**
         * @stability stable
         */
        get issuerName(): string;
        /**
         * @stability stable
         */
        get sessionName(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamUserConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_user.html#tags DataAwsIamUser#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_user.html#user_name DataAwsIamUser#user_name}.
         *
         * @stability stable
         */
        readonly userName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_user.html aws_iam_user}.
     *
     * @stability stable
     */
    class DataAwsIamUser extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_user.html aws_iam_user} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsIamUserConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get permissionsBoundary(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get userId(): string;
        private _userName?;
        /**
         * @stability stable
         */
        get userName(): string;
        /**
         * @stability stable
         */
        set userName(value: string);
        /**
         * @stability stable
         */
        get userNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIamUsersConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_users.html#name_regex DataAwsIamUsers#name_regex}.
         *
         * @stability stable
         */
        readonly nameRegex?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iam_users.html#path_prefix DataAwsIamUsers#path_prefix}.
         *
         * @stability stable
         */
        readonly pathPrefix?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iam_users.html aws_iam_users}.
     *
     * @stability stable
     */
    class DataAwsIamUsers extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iam_users.html aws_iam_users} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsIamUsersConfig);
        /**
         * @stability stable
         */
        get arns(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        private _nameRegex?;
        /**
         * @stability stable
         */
        get nameRegex(): string | undefined;
        /**
         * @stability stable
         */
        set nameRegex(value: string | undefined);
        /**
         * @stability stable
         */
        resetNameRegex(): void;
        /**
         * @stability stable
         */
        get nameRegexInput(): string | undefined;
        /**
         * @stability stable
         */
        get names(): string[];
        private _pathPrefix?;
        /**
         * @stability stable
         */
        get pathPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set pathPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPathPrefix(): void;
        /**
         * @stability stable
         */
        get pathPrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
