import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS IoT
*/
export declare namespace IoT {
    /**
     * @stability stable
     */
    interface IotAuthorizerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html#authorizer_function_arn IotAuthorizer#authorizer_function_arn}.
         *
         * @stability stable
         */
        readonly authorizerFunctionArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html#name IotAuthorizer#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html#signing_disabled IotAuthorizer#signing_disabled}.
         *
         * @stability stable
         */
        readonly signingDisabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html#status IotAuthorizer#status}.
         *
         * @stability stable
         */
        readonly status?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html#token_key_name IotAuthorizer#token_key_name}.
         *
         * @stability stable
         */
        readonly tokenKeyName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html#token_signing_public_keys IotAuthorizer#token_signing_public_keys}.
         *
         * @stability stable
         */
        readonly tokenSigningPublicKeys?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html aws_iot_authorizer}.
     *
     * @stability stable
     */
    class IotAuthorizer extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_authorizer.html aws_iot_authorizer} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotAuthorizerConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _authorizerFunctionArn?;
        /**
         * @stability stable
         */
        get authorizerFunctionArn(): string;
        /**
         * @stability stable
         */
        set authorizerFunctionArn(value: string);
        /**
         * @stability stable
         */
        get authorizerFunctionArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _signingDisabled?;
        /**
         * @stability stable
         */
        get signingDisabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set signingDisabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSigningDisabled(): void;
        /**
         * @stability stable
         */
        get signingDisabledInput(): boolean | cdktf.IResolvable | undefined;
        private _status?;
        /**
         * @stability stable
         */
        get status(): string | undefined;
        /**
         * @stability stable
         */
        set status(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatus(): void;
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
        private _tokenKeyName?;
        /**
         * @stability stable
         */
        get tokenKeyName(): string | undefined;
        /**
         * @stability stable
         */
        set tokenKeyName(value: string | undefined);
        /**
         * @stability stable
         */
        resetTokenKeyName(): void;
        /**
         * @stability stable
         */
        get tokenKeyNameInput(): string | undefined;
        private _tokenSigningPublicKeys?;
        /**
         * @stability stable
         */
        get tokenSigningPublicKeys(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tokenSigningPublicKeys(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTokenSigningPublicKeys(): void;
        /**
         * @stability stable
         */
        get tokenSigningPublicKeysInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_certificate.html#active IotCertificate#active}.
         *
         * @stability stable
         */
        readonly active: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_certificate.html#csr IotCertificate#csr}.
         *
         * @stability stable
         */
        readonly csr?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_certificate.html aws_iot_certificate}.
     *
     * @stability stable
     */
    class IotCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_certificate.html aws_iot_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotCertificateConfig);
        private _active?;
        /**
         * @stability stable
         */
        get active(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set active(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get activeInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificatePem(): string;
        private _csr?;
        /**
         * @stability stable
         */
        get csr(): string | undefined;
        /**
         * @stability stable
         */
        set csr(value: string | undefined);
        /**
         * @stability stable
         */
        resetCsr(): void;
        /**
         * @stability stable
         */
        get csrInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get privateKey(): string;
        /**
         * @stability stable
         */
        get publicKey(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_policy.html#name IotPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_policy.html#policy IotPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_policy.html aws_iot_policy}.
     *
     * @stability stable
     */
    class IotPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_policy.html aws_iot_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotPolicyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get defaultVersionId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotPolicyAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_policy_attachment.html#policy IotPolicyAttachment#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_policy_attachment.html#target IotPolicyAttachment#target}.
         *
         * @stability stable
         */
        readonly target: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_policy_attachment.html aws_iot_policy_attachment}.
     *
     * @stability stable
     */
    class IotPolicyAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_policy_attachment.html aws_iot_policy_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotPolicyAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _target?;
        /**
         * @stability stable
         */
        get target(): string;
        /**
         * @stability stable
         */
        set target(value: string);
        /**
         * @stability stable
         */
        get targetInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotRoleAliasConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_role_alias.html#alias IotRoleAlias#alias}.
         *
         * @stability stable
         */
        readonly alias: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_role_alias.html#credential_duration IotRoleAlias#credential_duration}.
         *
         * @stability stable
         */
        readonly credentialDuration?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_role_alias.html#role_arn IotRoleAlias#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_role_alias.html aws_iot_role_alias}.
     *
     * @stability stable
     */
    class IotRoleAlias extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_role_alias.html aws_iot_role_alias} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotRoleAliasConfig);
        private _alias?;
        /**
         * @stability stable
         */
        get alias(): string;
        /**
         * @stability stable
         */
        set alias(value: string);
        /**
         * @stability stable
         */
        get aliasInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _credentialDuration?;
        /**
         * @stability stable
         */
        get credentialDuration(): number | undefined;
        /**
         * @stability stable
         */
        set credentialDuration(value: number | undefined);
        /**
         * @stability stable
         */
        resetCredentialDuration(): void;
        /**
         * @stability stable
         */
        get credentialDurationInput(): number | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotThingConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing.html#attributes IotThing#attributes}.
         *
         * @stability stable
         */
        readonly attributes?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing.html#name IotThing#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing.html#thing_type_name IotThing#thing_type_name}.
         *
         * @stability stable
         */
        readonly thingTypeName?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_thing.html aws_iot_thing}.
     *
     * @stability stable
     */
    class IotThing extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_thing.html aws_iot_thing} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotThingConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _attributes?;
        /**
         * @stability stable
         */
        get attributes(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set attributes(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAttributes(): void;
        /**
         * @stability stable
         */
        get attributesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get defaultClientId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _thingTypeName?;
        /**
         * @stability stable
         */
        get thingTypeName(): string | undefined;
        /**
         * @stability stable
         */
        set thingTypeName(value: string | undefined);
        /**
         * @stability stable
         */
        resetThingTypeName(): void;
        /**
         * @stability stable
         */
        get thingTypeNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get version(): number;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotThingPrincipalAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_principal_attachment.html#principal IotThingPrincipalAttachment#principal}.
         *
         * @stability stable
         */
        readonly principal: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_principal_attachment.html#thing IotThingPrincipalAttachment#thing}.
         *
         * @stability stable
         */
        readonly thing: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_principal_attachment.html aws_iot_thing_principal_attachment}.
     *
     * @stability stable
     */
    class IotThingPrincipalAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_principal_attachment.html aws_iot_thing_principal_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotThingPrincipalAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _principal?;
        /**
         * @stability stable
         */
        get principal(): string;
        /**
         * @stability stable
         */
        set principal(value: string);
        /**
         * @stability stable
         */
        get principalInput(): string | undefined;
        private _thing?;
        /**
         * @stability stable
         */
        get thing(): string;
        /**
         * @stability stable
         */
        set thing(value: string);
        /**
         * @stability stable
         */
        get thingInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotThingTypeConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_type.html#deprecated IotThingType#deprecated}.
         *
         * @stability stable
         */
        readonly deprecated?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_type.html#name IotThingType#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * properties block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_type.html#properties IotThingType#properties}
         *
         * @stability stable
         */
        readonly properties?: IotThingTypeProperties;
    }
    /**
     * @stability stable
     */
    interface IotThingTypeProperties {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_type.html#description IotThingType#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_type.html#searchable_attributes IotThingType#searchable_attributes}.
         *
         * @stability stable
         */
        readonly searchableAttributes?: string[];
    }
    /**
     * @stability stable
     */
    class IotThingTypePropertiesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _searchableAttributes?;
        /**
         * @stability stable
         */
        get searchableAttributes(): string[] | undefined;
        /**
         * @stability stable
         */
        set searchableAttributes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSearchableAttributes(): void;
        /**
         * @stability stable
         */
        get searchableAttributesInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_type.html aws_iot_thing_type}.
     *
     * @stability stable
     */
    class IotThingType extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_thing_type.html aws_iot_thing_type} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotThingTypeConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _deprecated?;
        /**
         * @stability stable
         */
        get deprecated(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deprecated(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeprecated(): void;
        /**
         * @stability stable
         */
        get deprecatedInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _properties?;
        private __propertiesOutput;
        /**
         * @stability stable
         */
        get properties(): IotThingTypePropertiesOutputReference;
        /**
         * @stability stable
         */
        putProperties(value: IotThingTypeProperties | undefined): void;
        /**
         * @stability stable
         */
        resetProperties(): void;
        /**
         * @stability stable
         */
        get propertiesInput(): IotThingTypeProperties | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#description IotTopicRule#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#enabled IotTopicRule#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#name IotTopicRule#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#sql IotTopicRule#sql}.
         *
         * @stability stable
         */
        readonly sql: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#sql_version IotTopicRule#sql_version}.
         *
         * @stability stable
         */
        readonly sqlVersion: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#tags IotTopicRule#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#tags_all IotTopicRule#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * cloudwatch_alarm block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#cloudwatch_alarm IotTopicRule#cloudwatch_alarm}
         *
         * @stability stable
         */
        readonly cloudwatchAlarm?: IotTopicRuleCloudwatchAlarm[];
        /**
         * cloudwatch_metric block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#cloudwatch_metric IotTopicRule#cloudwatch_metric}
         *
         * @stability stable
         */
        readonly cloudwatchMetric?: IotTopicRuleCloudwatchMetric[];
        /**
         * dynamodb block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#dynamodb IotTopicRule#dynamodb}
         *
         * @stability stable
         */
        readonly dynamodb?: IotTopicRuleDynamodb[];
        /**
         * dynamodbv2 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#dynamodbv2 IotTopicRule#dynamodbv2}
         *
         * @stability stable
         */
        readonly dynamodbv2?: IotTopicRuleDynamodbv2[];
        /**
         * elasticsearch block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#elasticsearch IotTopicRule#elasticsearch}
         *
         * @stability stable
         */
        readonly elasticsearch?: IotTopicRuleElasticsearch[];
        /**
         * error_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#error_action IotTopicRule#error_action}
         *
         * @stability stable
         */
        readonly errorAction?: IotTopicRuleErrorAction;
        /**
         * firehose block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#firehose IotTopicRule#firehose}
         *
         * @stability stable
         */
        readonly firehose?: IotTopicRuleFirehose[];
        /**
         * iot_analytics block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#iot_analytics IotTopicRule#iot_analytics}
         *
         * @stability stable
         */
        readonly iotAnalytics?: IotTopicRuleIotAnalytics[];
        /**
         * iot_events block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#iot_events IotTopicRule#iot_events}
         *
         * @stability stable
         */
        readonly iotEvents?: IotTopicRuleIotEvents[];
        /**
         * kinesis block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#kinesis IotTopicRule#kinesis}
         *
         * @stability stable
         */
        readonly kinesis?: IotTopicRuleKinesis[];
        /**
         * lambda block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#lambda IotTopicRule#lambda}
         *
         * @stability stable
         */
        readonly lambda?: IotTopicRuleLambda[];
        /**
         * republish block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#republish IotTopicRule#republish}
         *
         * @stability stable
         */
        readonly republish?: IotTopicRuleRepublish[];
        /**
         * s3 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#s3 IotTopicRule#s3}
         *
         * @stability stable
         */
        readonly s3?: IotTopicRuleS3[];
        /**
         * sns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#sns IotTopicRule#sns}
         *
         * @stability stable
         */
        readonly sns?: IotTopicRuleSns[];
        /**
         * sqs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#sqs IotTopicRule#sqs}
         *
         * @stability stable
         */
        readonly sqs?: IotTopicRuleSqs[];
        /**
         * step_functions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#step_functions IotTopicRule#step_functions}
         *
         * @stability stable
         */
        readonly stepFunctions?: IotTopicRuleStepFunctions[];
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleCloudwatchAlarm {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#alarm_name IotTopicRule#alarm_name}.
         *
         * @stability stable
         */
        readonly alarmName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#state_reason IotTopicRule#state_reason}.
         *
         * @stability stable
         */
        readonly stateReason: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#state_value IotTopicRule#state_value}.
         *
         * @stability stable
         */
        readonly stateValue: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleCloudwatchMetric {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_name IotTopicRule#metric_name}.
         *
         * @stability stable
         */
        readonly metricName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_namespace IotTopicRule#metric_namespace}.
         *
         * @stability stable
         */
        readonly metricNamespace: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_timestamp IotTopicRule#metric_timestamp}.
         *
         * @stability stable
         */
        readonly metricTimestamp?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_unit IotTopicRule#metric_unit}.
         *
         * @stability stable
         */
        readonly metricUnit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_value IotTopicRule#metric_value}.
         *
         * @stability stable
         */
        readonly metricValue: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleDynamodb {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#hash_key_field IotTopicRule#hash_key_field}.
         *
         * @stability stable
         */
        readonly hashKeyField: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#hash_key_type IotTopicRule#hash_key_type}.
         *
         * @stability stable
         */
        readonly hashKeyType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#hash_key_value IotTopicRule#hash_key_value}.
         *
         * @stability stable
         */
        readonly hashKeyValue: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#operation IotTopicRule#operation}.
         *
         * @stability stable
         */
        readonly operation?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#payload_field IotTopicRule#payload_field}.
         *
         * @stability stable
         */
        readonly payloadField?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#range_key_field IotTopicRule#range_key_field}.
         *
         * @stability stable
         */
        readonly rangeKeyField?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#range_key_type IotTopicRule#range_key_type}.
         *
         * @stability stable
         */
        readonly rangeKeyType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#range_key_value IotTopicRule#range_key_value}.
         *
         * @stability stable
         */
        readonly rangeKeyValue?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#table_name IotTopicRule#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleDynamodbv2PutItem {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#table_name IotTopicRule#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleDynamodbv2PutItemOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleDynamodbv2 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * put_item block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#put_item IotTopicRule#put_item}
         *
         * @stability stable
         */
        readonly putItem?: IotTopicRuleDynamodbv2PutItem;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleElasticsearch {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#endpoint IotTopicRule#endpoint}.
         *
         * @stability stable
         */
        readonly endpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#id IotTopicRule#id}.
         *
         * @stability stable
         */
        readonly id: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#index IotTopicRule#index}.
         *
         * @stability stable
         */
        readonly index: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#type IotTopicRule#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionCloudwatchAlarm {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#alarm_name IotTopicRule#alarm_name}.
         *
         * @stability stable
         */
        readonly alarmName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#state_reason IotTopicRule#state_reason}.
         *
         * @stability stable
         */
        readonly stateReason: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#state_value IotTopicRule#state_value}.
         *
         * @stability stable
         */
        readonly stateValue: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionCloudwatchAlarmOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _alarmName?;
        /**
         * @stability stable
         */
        get alarmName(): string;
        /**
         * @stability stable
         */
        set alarmName(value: string);
        /**
         * @stability stable
         */
        get alarmNameInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _stateReason?;
        /**
         * @stability stable
         */
        get stateReason(): string;
        /**
         * @stability stable
         */
        set stateReason(value: string);
        /**
         * @stability stable
         */
        get stateReasonInput(): string | undefined;
        private _stateValue?;
        /**
         * @stability stable
         */
        get stateValue(): string;
        /**
         * @stability stable
         */
        set stateValue(value: string);
        /**
         * @stability stable
         */
        get stateValueInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionCloudwatchMetric {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_name IotTopicRule#metric_name}.
         *
         * @stability stable
         */
        readonly metricName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_namespace IotTopicRule#metric_namespace}.
         *
         * @stability stable
         */
        readonly metricNamespace: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_timestamp IotTopicRule#metric_timestamp}.
         *
         * @stability stable
         */
        readonly metricTimestamp?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_unit IotTopicRule#metric_unit}.
         *
         * @stability stable
         */
        readonly metricUnit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#metric_value IotTopicRule#metric_value}.
         *
         * @stability stable
         */
        readonly metricValue: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionCloudwatchMetricOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _metricName?;
        /**
         * @stability stable
         */
        get metricName(): string;
        /**
         * @stability stable
         */
        set metricName(value: string);
        /**
         * @stability stable
         */
        get metricNameInput(): string | undefined;
        private _metricNamespace?;
        /**
         * @stability stable
         */
        get metricNamespace(): string;
        /**
         * @stability stable
         */
        set metricNamespace(value: string);
        /**
         * @stability stable
         */
        get metricNamespaceInput(): string | undefined;
        private _metricTimestamp?;
        /**
         * @stability stable
         */
        get metricTimestamp(): string | undefined;
        /**
         * @stability stable
         */
        set metricTimestamp(value: string | undefined);
        /**
         * @stability stable
         */
        resetMetricTimestamp(): void;
        /**
         * @stability stable
         */
        get metricTimestampInput(): string | undefined;
        private _metricUnit?;
        /**
         * @stability stable
         */
        get metricUnit(): string;
        /**
         * @stability stable
         */
        set metricUnit(value: string);
        /**
         * @stability stable
         */
        get metricUnitInput(): string | undefined;
        private _metricValue?;
        /**
         * @stability stable
         */
        get metricValue(): string;
        /**
         * @stability stable
         */
        set metricValue(value: string);
        /**
         * @stability stable
         */
        get metricValueInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionDynamodb {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#hash_key_field IotTopicRule#hash_key_field}.
         *
         * @stability stable
         */
        readonly hashKeyField: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#hash_key_type IotTopicRule#hash_key_type}.
         *
         * @stability stable
         */
        readonly hashKeyType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#hash_key_value IotTopicRule#hash_key_value}.
         *
         * @stability stable
         */
        readonly hashKeyValue: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#operation IotTopicRule#operation}.
         *
         * @stability stable
         */
        readonly operation?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#payload_field IotTopicRule#payload_field}.
         *
         * @stability stable
         */
        readonly payloadField?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#range_key_field IotTopicRule#range_key_field}.
         *
         * @stability stable
         */
        readonly rangeKeyField?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#range_key_type IotTopicRule#range_key_type}.
         *
         * @stability stable
         */
        readonly rangeKeyType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#range_key_value IotTopicRule#range_key_value}.
         *
         * @stability stable
         */
        readonly rangeKeyValue?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#table_name IotTopicRule#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionDynamodbOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _hashKeyField?;
        /**
         * @stability stable
         */
        get hashKeyField(): string;
        /**
         * @stability stable
         */
        set hashKeyField(value: string);
        /**
         * @stability stable
         */
        get hashKeyFieldInput(): string | undefined;
        private _hashKeyType?;
        /**
         * @stability stable
         */
        get hashKeyType(): string | undefined;
        /**
         * @stability stable
         */
        set hashKeyType(value: string | undefined);
        /**
         * @stability stable
         */
        resetHashKeyType(): void;
        /**
         * @stability stable
         */
        get hashKeyTypeInput(): string | undefined;
        private _hashKeyValue?;
        /**
         * @stability stable
         */
        get hashKeyValue(): string;
        /**
         * @stability stable
         */
        set hashKeyValue(value: string);
        /**
         * @stability stable
         */
        get hashKeyValueInput(): string | undefined;
        private _operation?;
        /**
         * @stability stable
         */
        get operation(): string | undefined;
        /**
         * @stability stable
         */
        set operation(value: string | undefined);
        /**
         * @stability stable
         */
        resetOperation(): void;
        /**
         * @stability stable
         */
        get operationInput(): string | undefined;
        private _payloadField?;
        /**
         * @stability stable
         */
        get payloadField(): string | undefined;
        /**
         * @stability stable
         */
        set payloadField(value: string | undefined);
        /**
         * @stability stable
         */
        resetPayloadField(): void;
        /**
         * @stability stable
         */
        get payloadFieldInput(): string | undefined;
        private _rangeKeyField?;
        /**
         * @stability stable
         */
        get rangeKeyField(): string | undefined;
        /**
         * @stability stable
         */
        set rangeKeyField(value: string | undefined);
        /**
         * @stability stable
         */
        resetRangeKeyField(): void;
        /**
         * @stability stable
         */
        get rangeKeyFieldInput(): string | undefined;
        private _rangeKeyType?;
        /**
         * @stability stable
         */
        get rangeKeyType(): string | undefined;
        /**
         * @stability stable
         */
        set rangeKeyType(value: string | undefined);
        /**
         * @stability stable
         */
        resetRangeKeyType(): void;
        /**
         * @stability stable
         */
        get rangeKeyTypeInput(): string | undefined;
        private _rangeKeyValue?;
        /**
         * @stability stable
         */
        get rangeKeyValue(): string | undefined;
        /**
         * @stability stable
         */
        set rangeKeyValue(value: string | undefined);
        /**
         * @stability stable
         */
        resetRangeKeyValue(): void;
        /**
         * @stability stable
         */
        get rangeKeyValueInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionDynamodbv2PutItem {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#table_name IotTopicRule#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionDynamodbv2PutItemOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionDynamodbv2 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * put_item block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#put_item IotTopicRule#put_item}
         *
         * @stability stable
         */
        readonly putItem?: IotTopicRuleErrorActionDynamodbv2PutItem;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionDynamodbv2OutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _putItem?;
        private __putItemOutput;
        /**
         * @stability stable
         */
        get putItem(): IotTopicRuleErrorActionDynamodbv2PutItemOutputReference;
        /**
         * @stability stable
         */
        putPutItem(value: IotTopicRuleErrorActionDynamodbv2PutItem | undefined): void;
        /**
         * @stability stable
         */
        resetPutItem(): void;
        /**
         * @stability stable
         */
        get putItemInput(): IotTopicRuleErrorActionDynamodbv2PutItem | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionElasticsearch {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#endpoint IotTopicRule#endpoint}.
         *
         * @stability stable
         */
        readonly endpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#id IotTopicRule#id}.
         *
         * @stability stable
         */
        readonly id: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#index IotTopicRule#index}.
         *
         * @stability stable
         */
        readonly index: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#type IotTopicRule#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionElasticsearchOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _endpoint?;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        set endpoint(value: string);
        /**
         * @stability stable
         */
        get endpointInput(): string | undefined;
        private _id?;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        set id(value: string);
        /**
         * @stability stable
         */
        get idInput(): string | undefined;
        private _index?;
        /**
         * @stability stable
         */
        get index(): string;
        /**
         * @stability stable
         */
        set index(value: string);
        /**
         * @stability stable
         */
        get indexInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionFirehose {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#delivery_stream_name IotTopicRule#delivery_stream_name}.
         *
         * @stability stable
         */
        readonly deliveryStreamName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#separator IotTopicRule#separator}.
         *
         * @stability stable
         */
        readonly separator?: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionFirehoseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _deliveryStreamName?;
        /**
         * @stability stable
         */
        get deliveryStreamName(): string;
        /**
         * @stability stable
         */
        set deliveryStreamName(value: string);
        /**
         * @stability stable
         */
        get deliveryStreamNameInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _separator?;
        /**
         * @stability stable
         */
        get separator(): string | undefined;
        /**
         * @stability stable
         */
        set separator(value: string | undefined);
        /**
         * @stability stable
         */
        resetSeparator(): void;
        /**
         * @stability stable
         */
        get separatorInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionIotAnalytics {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#channel_name IotTopicRule#channel_name}.
         *
         * @stability stable
         */
        readonly channelName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionIotAnalyticsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _channelName?;
        /**
         * @stability stable
         */
        get channelName(): string;
        /**
         * @stability stable
         */
        set channelName(value: string);
        /**
         * @stability stable
         */
        get channelNameInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionIotEvents {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#input_name IotTopicRule#input_name}.
         *
         * @stability stable
         */
        readonly inputName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#message_id IotTopicRule#message_id}.
         *
         * @stability stable
         */
        readonly messageId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionIotEventsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _inputName?;
        /**
         * @stability stable
         */
        get inputName(): string;
        /**
         * @stability stable
         */
        set inputName(value: string);
        /**
         * @stability stable
         */
        get inputNameInput(): string | undefined;
        private _messageId?;
        /**
         * @stability stable
         */
        get messageId(): string | undefined;
        /**
         * @stability stable
         */
        set messageId(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageId(): void;
        /**
         * @stability stable
         */
        get messageIdInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionKinesis {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#partition_key IotTopicRule#partition_key}.
         *
         * @stability stable
         */
        readonly partitionKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#stream_name IotTopicRule#stream_name}.
         *
         * @stability stable
         */
        readonly streamName: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionKinesisOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _partitionKey?;
        /**
         * @stability stable
         */
        get partitionKey(): string | undefined;
        /**
         * @stability stable
         */
        set partitionKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetPartitionKey(): void;
        /**
         * @stability stable
         */
        get partitionKeyInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _streamName?;
        /**
         * @stability stable
         */
        get streamName(): string;
        /**
         * @stability stable
         */
        set streamName(value: string);
        /**
         * @stability stable
         */
        get streamNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionLambda {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#function_arn IotTopicRule#function_arn}.
         *
         * @stability stable
         */
        readonly functionArn: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionLambdaOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _functionArn?;
        /**
         * @stability stable
         */
        get functionArn(): string;
        /**
         * @stability stable
         */
        set functionArn(value: string);
        /**
         * @stability stable
         */
        get functionArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionRepublish {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#qos IotTopicRule#qos}.
         *
         * @stability stable
         */
        readonly qos?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#topic IotTopicRule#topic}.
         *
         * @stability stable
         */
        readonly topic: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionRepublishOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _qos?;
        /**
         * @stability stable
         */
        get qos(): number | undefined;
        /**
         * @stability stable
         */
        set qos(value: number | undefined);
        /**
         * @stability stable
         */
        resetQos(): void;
        /**
         * @stability stable
         */
        get qosInput(): number | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _topic?;
        /**
         * @stability stable
         */
        get topic(): string;
        /**
         * @stability stable
         */
        set topic(value: string);
        /**
         * @stability stable
         */
        get topicInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionS3 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#bucket_name IotTopicRule#bucket_name}.
         *
         * @stability stable
         */
        readonly bucketName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#key IotTopicRule#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionS3OutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketName?;
        /**
         * @stability stable
         */
        get bucketName(): string;
        /**
         * @stability stable
         */
        set bucketName(value: string);
        /**
         * @stability stable
         */
        get bucketNameInput(): string | undefined;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        set key(value: string);
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionSns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#message_format IotTopicRule#message_format}.
         *
         * @stability stable
         */
        readonly messageFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#target_arn IotTopicRule#target_arn}.
         *
         * @stability stable
         */
        readonly targetArn: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionSnsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _messageFormat?;
        /**
         * @stability stable
         */
        get messageFormat(): string | undefined;
        /**
         * @stability stable
         */
        set messageFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageFormat(): void;
        /**
         * @stability stable
         */
        get messageFormatInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _targetArn?;
        /**
         * @stability stable
         */
        get targetArn(): string;
        /**
         * @stability stable
         */
        set targetArn(value: string);
        /**
         * @stability stable
         */
        get targetArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionSqs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#queue_url IotTopicRule#queue_url}.
         *
         * @stability stable
         */
        readonly queueUrl: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#use_base64 IotTopicRule#use_base64}.
         *
         * @stability stable
         */
        readonly useBase64: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionSqsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _queueUrl?;
        /**
         * @stability stable
         */
        get queueUrl(): string;
        /**
         * @stability stable
         */
        set queueUrl(value: string);
        /**
         * @stability stable
         */
        get queueUrlInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _useBase64?;
        /**
         * @stability stable
         */
        get useBase64(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set useBase64(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get useBase64Input(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorActionStepFunctions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#execution_name_prefix IotTopicRule#execution_name_prefix}.
         *
         * @stability stable
         */
        readonly executionNamePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#state_machine_name IotTopicRule#state_machine_name}.
         *
         * @stability stable
         */
        readonly stateMachineName: string;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionStepFunctionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _executionNamePrefix?;
        /**
         * @stability stable
         */
        get executionNamePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set executionNamePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetExecutionNamePrefix(): void;
        /**
         * @stability stable
         */
        get executionNamePrefixInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _stateMachineName?;
        /**
         * @stability stable
         */
        get stateMachineName(): string;
        /**
         * @stability stable
         */
        set stateMachineName(value: string);
        /**
         * @stability stable
         */
        get stateMachineNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleErrorAction {
        /**
         * cloudwatch_alarm block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#cloudwatch_alarm IotTopicRule#cloudwatch_alarm}
         *
         * @stability stable
         */
        readonly cloudwatchAlarm?: IotTopicRuleErrorActionCloudwatchAlarm;
        /**
         * cloudwatch_metric block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#cloudwatch_metric IotTopicRule#cloudwatch_metric}
         *
         * @stability stable
         */
        readonly cloudwatchMetric?: IotTopicRuleErrorActionCloudwatchMetric;
        /**
         * dynamodb block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#dynamodb IotTopicRule#dynamodb}
         *
         * @stability stable
         */
        readonly dynamodb?: IotTopicRuleErrorActionDynamodb;
        /**
         * dynamodbv2 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#dynamodbv2 IotTopicRule#dynamodbv2}
         *
         * @stability stable
         */
        readonly dynamodbv2?: IotTopicRuleErrorActionDynamodbv2;
        /**
         * elasticsearch block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#elasticsearch IotTopicRule#elasticsearch}
         *
         * @stability stable
         */
        readonly elasticsearch?: IotTopicRuleErrorActionElasticsearch;
        /**
         * firehose block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#firehose IotTopicRule#firehose}
         *
         * @stability stable
         */
        readonly firehose?: IotTopicRuleErrorActionFirehose;
        /**
         * iot_analytics block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#iot_analytics IotTopicRule#iot_analytics}
         *
         * @stability stable
         */
        readonly iotAnalytics?: IotTopicRuleErrorActionIotAnalytics;
        /**
         * iot_events block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#iot_events IotTopicRule#iot_events}
         *
         * @stability stable
         */
        readonly iotEvents?: IotTopicRuleErrorActionIotEvents;
        /**
         * kinesis block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#kinesis IotTopicRule#kinesis}
         *
         * @stability stable
         */
        readonly kinesis?: IotTopicRuleErrorActionKinesis;
        /**
         * lambda block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#lambda IotTopicRule#lambda}
         *
         * @stability stable
         */
        readonly lambda?: IotTopicRuleErrorActionLambda;
        /**
         * republish block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#republish IotTopicRule#republish}
         *
         * @stability stable
         */
        readonly republish?: IotTopicRuleErrorActionRepublish;
        /**
         * s3 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#s3 IotTopicRule#s3}
         *
         * @stability stable
         */
        readonly s3?: IotTopicRuleErrorActionS3;
        /**
         * sns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#sns IotTopicRule#sns}
         *
         * @stability stable
         */
        readonly sns?: IotTopicRuleErrorActionSns;
        /**
         * sqs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#sqs IotTopicRule#sqs}
         *
         * @stability stable
         */
        readonly sqs?: IotTopicRuleErrorActionSqs;
        /**
         * step_functions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#step_functions IotTopicRule#step_functions}
         *
         * @stability stable
         */
        readonly stepFunctions?: IotTopicRuleErrorActionStepFunctions;
    }
    /**
     * @stability stable
     */
    class IotTopicRuleErrorActionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cloudwatchAlarm?;
        private __cloudwatchAlarmOutput;
        /**
         * @stability stable
         */
        get cloudwatchAlarm(): IotTopicRuleErrorActionCloudwatchAlarmOutputReference;
        /**
         * @stability stable
         */
        putCloudwatchAlarm(value: IotTopicRuleErrorActionCloudwatchAlarm | undefined): void;
        /**
         * @stability stable
         */
        resetCloudwatchAlarm(): void;
        /**
         * @stability stable
         */
        get cloudwatchAlarmInput(): IotTopicRuleErrorActionCloudwatchAlarm | undefined;
        private _cloudwatchMetric?;
        private __cloudwatchMetricOutput;
        /**
         * @stability stable
         */
        get cloudwatchMetric(): IotTopicRuleErrorActionCloudwatchMetricOutputReference;
        /**
         * @stability stable
         */
        putCloudwatchMetric(value: IotTopicRuleErrorActionCloudwatchMetric | undefined): void;
        /**
         * @stability stable
         */
        resetCloudwatchMetric(): void;
        /**
         * @stability stable
         */
        get cloudwatchMetricInput(): IotTopicRuleErrorActionCloudwatchMetric | undefined;
        private _dynamodb?;
        private __dynamodbOutput;
        /**
         * @stability stable
         */
        get dynamodb(): IotTopicRuleErrorActionDynamodbOutputReference;
        /**
         * @stability stable
         */
        putDynamodb(value: IotTopicRuleErrorActionDynamodb | undefined): void;
        /**
         * @stability stable
         */
        resetDynamodb(): void;
        /**
         * @stability stable
         */
        get dynamodbInput(): IotTopicRuleErrorActionDynamodb | undefined;
        private _dynamodbv2?;
        private __dynamodbv2Output;
        /**
         * @stability stable
         */
        get dynamodbv2(): IotTopicRuleErrorActionDynamodbv2OutputReference;
        /**
         * @stability stable
         */
        putDynamodbv2(value: IotTopicRuleErrorActionDynamodbv2 | undefined): void;
        /**
         * @stability stable
         */
        resetDynamodbv2(): void;
        /**
         * @stability stable
         */
        get dynamodbv2Input(): IotTopicRuleErrorActionDynamodbv2 | undefined;
        private _elasticsearch?;
        private __elasticsearchOutput;
        /**
         * @stability stable
         */
        get elasticsearch(): IotTopicRuleErrorActionElasticsearchOutputReference;
        /**
         * @stability stable
         */
        putElasticsearch(value: IotTopicRuleErrorActionElasticsearch | undefined): void;
        /**
         * @stability stable
         */
        resetElasticsearch(): void;
        /**
         * @stability stable
         */
        get elasticsearchInput(): IotTopicRuleErrorActionElasticsearch | undefined;
        private _firehose?;
        private __firehoseOutput;
        /**
         * @stability stable
         */
        get firehose(): IotTopicRuleErrorActionFirehoseOutputReference;
        /**
         * @stability stable
         */
        putFirehose(value: IotTopicRuleErrorActionFirehose | undefined): void;
        /**
         * @stability stable
         */
        resetFirehose(): void;
        /**
         * @stability stable
         */
        get firehoseInput(): IotTopicRuleErrorActionFirehose | undefined;
        private _iotAnalytics?;
        private __iotAnalyticsOutput;
        /**
         * @stability stable
         */
        get iotAnalytics(): IotTopicRuleErrorActionIotAnalyticsOutputReference;
        /**
         * @stability stable
         */
        putIotAnalytics(value: IotTopicRuleErrorActionIotAnalytics | undefined): void;
        /**
         * @stability stable
         */
        resetIotAnalytics(): void;
        /**
         * @stability stable
         */
        get iotAnalyticsInput(): IotTopicRuleErrorActionIotAnalytics | undefined;
        private _iotEvents?;
        private __iotEventsOutput;
        /**
         * @stability stable
         */
        get iotEvents(): IotTopicRuleErrorActionIotEventsOutputReference;
        /**
         * @stability stable
         */
        putIotEvents(value: IotTopicRuleErrorActionIotEvents | undefined): void;
        /**
         * @stability stable
         */
        resetIotEvents(): void;
        /**
         * @stability stable
         */
        get iotEventsInput(): IotTopicRuleErrorActionIotEvents | undefined;
        private _kinesis?;
        private __kinesisOutput;
        /**
         * @stability stable
         */
        get kinesis(): IotTopicRuleErrorActionKinesisOutputReference;
        /**
         * @stability stable
         */
        putKinesis(value: IotTopicRuleErrorActionKinesis | undefined): void;
        /**
         * @stability stable
         */
        resetKinesis(): void;
        /**
         * @stability stable
         */
        get kinesisInput(): IotTopicRuleErrorActionKinesis | undefined;
        private _lambda?;
        private __lambdaOutput;
        /**
         * @stability stable
         */
        get lambda(): IotTopicRuleErrorActionLambdaOutputReference;
        /**
         * @stability stable
         */
        putLambda(value: IotTopicRuleErrorActionLambda | undefined): void;
        /**
         * @stability stable
         */
        resetLambda(): void;
        /**
         * @stability stable
         */
        get lambdaInput(): IotTopicRuleErrorActionLambda | undefined;
        private _republish?;
        private __republishOutput;
        /**
         * @stability stable
         */
        get republish(): IotTopicRuleErrorActionRepublishOutputReference;
        /**
         * @stability stable
         */
        putRepublish(value: IotTopicRuleErrorActionRepublish | undefined): void;
        /**
         * @stability stable
         */
        resetRepublish(): void;
        /**
         * @stability stable
         */
        get republishInput(): IotTopicRuleErrorActionRepublish | undefined;
        private _s3?;
        private __s3Output;
        /**
         * @stability stable
         */
        get s3(): IotTopicRuleErrorActionS3OutputReference;
        /**
         * @stability stable
         */
        putS3(value: IotTopicRuleErrorActionS3 | undefined): void;
        /**
         * @stability stable
         */
        resetS3(): void;
        /**
         * @stability stable
         */
        get s3Input(): IotTopicRuleErrorActionS3 | undefined;
        private _sns?;
        private __snsOutput;
        /**
         * @stability stable
         */
        get sns(): IotTopicRuleErrorActionSnsOutputReference;
        /**
         * @stability stable
         */
        putSns(value: IotTopicRuleErrorActionSns | undefined): void;
        /**
         * @stability stable
         */
        resetSns(): void;
        /**
         * @stability stable
         */
        get snsInput(): IotTopicRuleErrorActionSns | undefined;
        private _sqs?;
        private __sqsOutput;
        /**
         * @stability stable
         */
        get sqs(): IotTopicRuleErrorActionSqsOutputReference;
        /**
         * @stability stable
         */
        putSqs(value: IotTopicRuleErrorActionSqs | undefined): void;
        /**
         * @stability stable
         */
        resetSqs(): void;
        /**
         * @stability stable
         */
        get sqsInput(): IotTopicRuleErrorActionSqs | undefined;
        private _stepFunctions?;
        private __stepFunctionsOutput;
        /**
         * @stability stable
         */
        get stepFunctions(): IotTopicRuleErrorActionStepFunctionsOutputReference;
        /**
         * @stability stable
         */
        putStepFunctions(value: IotTopicRuleErrorActionStepFunctions | undefined): void;
        /**
         * @stability stable
         */
        resetStepFunctions(): void;
        /**
         * @stability stable
         */
        get stepFunctionsInput(): IotTopicRuleErrorActionStepFunctions | undefined;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleFirehose {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#delivery_stream_name IotTopicRule#delivery_stream_name}.
         *
         * @stability stable
         */
        readonly deliveryStreamName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#separator IotTopicRule#separator}.
         *
         * @stability stable
         */
        readonly separator?: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleIotAnalytics {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#channel_name IotTopicRule#channel_name}.
         *
         * @stability stable
         */
        readonly channelName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleIotEvents {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#input_name IotTopicRule#input_name}.
         *
         * @stability stable
         */
        readonly inputName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#message_id IotTopicRule#message_id}.
         *
         * @stability stable
         */
        readonly messageId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleKinesis {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#partition_key IotTopicRule#partition_key}.
         *
         * @stability stable
         */
        readonly partitionKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#stream_name IotTopicRule#stream_name}.
         *
         * @stability stable
         */
        readonly streamName: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleLambda {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#function_arn IotTopicRule#function_arn}.
         *
         * @stability stable
         */
        readonly functionArn: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleRepublish {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#qos IotTopicRule#qos}.
         *
         * @stability stable
         */
        readonly qos?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#topic IotTopicRule#topic}.
         *
         * @stability stable
         */
        readonly topic: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleS3 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#bucket_name IotTopicRule#bucket_name}.
         *
         * @stability stable
         */
        readonly bucketName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#key IotTopicRule#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleSns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#message_format IotTopicRule#message_format}.
         *
         * @stability stable
         */
        readonly messageFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#target_arn IotTopicRule#target_arn}.
         *
         * @stability stable
         */
        readonly targetArn: string;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleSqs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#queue_url IotTopicRule#queue_url}.
         *
         * @stability stable
         */
        readonly queueUrl: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#use_base64 IotTopicRule#use_base64}.
         *
         * @stability stable
         */
        readonly useBase64: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    interface IotTopicRuleStepFunctions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#execution_name_prefix IotTopicRule#execution_name_prefix}.
         *
         * @stability stable
         */
        readonly executionNamePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#role_arn IotTopicRule#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html#state_machine_name IotTopicRule#state_machine_name}.
         *
         * @stability stable
         */
        readonly stateMachineName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html aws_iot_topic_rule}.
     *
     * @stability stable
     */
    class IotTopicRule extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/iot_topic_rule.html aws_iot_topic_rule} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: IotTopicRuleConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _sql?;
        /**
         * @stability stable
         */
        get sql(): string;
        /**
         * @stability stable
         */
        set sql(value: string);
        /**
         * @stability stable
         */
        get sqlInput(): string | undefined;
        private _sqlVersion?;
        /**
         * @stability stable
         */
        get sqlVersion(): string;
        /**
         * @stability stable
         */
        set sqlVersion(value: string);
        /**
         * @stability stable
         */
        get sqlVersionInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _cloudwatchAlarm?;
        /**
         * @stability stable
         */
        get cloudwatchAlarm(): IotTopicRuleCloudwatchAlarm[] | undefined;
        /**
         * @stability stable
         */
        set cloudwatchAlarm(value: IotTopicRuleCloudwatchAlarm[] | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchAlarm(): void;
        /**
         * @stability stable
         */
        get cloudwatchAlarmInput(): IotTopicRuleCloudwatchAlarm[] | undefined;
        private _cloudwatchMetric?;
        /**
         * @stability stable
         */
        get cloudwatchMetric(): IotTopicRuleCloudwatchMetric[] | undefined;
        /**
         * @stability stable
         */
        set cloudwatchMetric(value: IotTopicRuleCloudwatchMetric[] | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchMetric(): void;
        /**
         * @stability stable
         */
        get cloudwatchMetricInput(): IotTopicRuleCloudwatchMetric[] | undefined;
        private _dynamodb?;
        /**
         * @stability stable
         */
        get dynamodb(): IotTopicRuleDynamodb[] | undefined;
        /**
         * @stability stable
         */
        set dynamodb(value: IotTopicRuleDynamodb[] | undefined);
        /**
         * @stability stable
         */
        resetDynamodb(): void;
        /**
         * @stability stable
         */
        get dynamodbInput(): IotTopicRuleDynamodb[] | undefined;
        private _dynamodbv2?;
        /**
         * @stability stable
         */
        get dynamodbv2(): IotTopicRuleDynamodbv2[] | undefined;
        /**
         * @stability stable
         */
        set dynamodbv2(value: IotTopicRuleDynamodbv2[] | undefined);
        /**
         * @stability stable
         */
        resetDynamodbv2(): void;
        /**
         * @stability stable
         */
        get dynamodbv2Input(): IotTopicRuleDynamodbv2[] | undefined;
        private _elasticsearch?;
        /**
         * @stability stable
         */
        get elasticsearch(): IotTopicRuleElasticsearch[] | undefined;
        /**
         * @stability stable
         */
        set elasticsearch(value: IotTopicRuleElasticsearch[] | undefined);
        /**
         * @stability stable
         */
        resetElasticsearch(): void;
        /**
         * @stability stable
         */
        get elasticsearchInput(): IotTopicRuleElasticsearch[] | undefined;
        private _errorAction?;
        private __errorActionOutput;
        /**
         * @stability stable
         */
        get errorAction(): IotTopicRuleErrorActionOutputReference;
        /**
         * @stability stable
         */
        putErrorAction(value: IotTopicRuleErrorAction | undefined): void;
        /**
         * @stability stable
         */
        resetErrorAction(): void;
        /**
         * @stability stable
         */
        get errorActionInput(): IotTopicRuleErrorAction | undefined;
        private _firehose?;
        /**
         * @stability stable
         */
        get firehose(): IotTopicRuleFirehose[] | undefined;
        /**
         * @stability stable
         */
        set firehose(value: IotTopicRuleFirehose[] | undefined);
        /**
         * @stability stable
         */
        resetFirehose(): void;
        /**
         * @stability stable
         */
        get firehoseInput(): IotTopicRuleFirehose[] | undefined;
        private _iotAnalytics?;
        /**
         * @stability stable
         */
        get iotAnalytics(): IotTopicRuleIotAnalytics[] | undefined;
        /**
         * @stability stable
         */
        set iotAnalytics(value: IotTopicRuleIotAnalytics[] | undefined);
        /**
         * @stability stable
         */
        resetIotAnalytics(): void;
        /**
         * @stability stable
         */
        get iotAnalyticsInput(): IotTopicRuleIotAnalytics[] | undefined;
        private _iotEvents?;
        /**
         * @stability stable
         */
        get iotEvents(): IotTopicRuleIotEvents[] | undefined;
        /**
         * @stability stable
         */
        set iotEvents(value: IotTopicRuleIotEvents[] | undefined);
        /**
         * @stability stable
         */
        resetIotEvents(): void;
        /**
         * @stability stable
         */
        get iotEventsInput(): IotTopicRuleIotEvents[] | undefined;
        private _kinesis?;
        /**
         * @stability stable
         */
        get kinesis(): IotTopicRuleKinesis[] | undefined;
        /**
         * @stability stable
         */
        set kinesis(value: IotTopicRuleKinesis[] | undefined);
        /**
         * @stability stable
         */
        resetKinesis(): void;
        /**
         * @stability stable
         */
        get kinesisInput(): IotTopicRuleKinesis[] | undefined;
        private _lambda?;
        /**
         * @stability stable
         */
        get lambda(): IotTopicRuleLambda[] | undefined;
        /**
         * @stability stable
         */
        set lambda(value: IotTopicRuleLambda[] | undefined);
        /**
         * @stability stable
         */
        resetLambda(): void;
        /**
         * @stability stable
         */
        get lambdaInput(): IotTopicRuleLambda[] | undefined;
        private _republish?;
        /**
         * @stability stable
         */
        get republish(): IotTopicRuleRepublish[] | undefined;
        /**
         * @stability stable
         */
        set republish(value: IotTopicRuleRepublish[] | undefined);
        /**
         * @stability stable
         */
        resetRepublish(): void;
        /**
         * @stability stable
         */
        get republishInput(): IotTopicRuleRepublish[] | undefined;
        private _s3?;
        /**
         * @stability stable
         */
        get s3(): IotTopicRuleS3[] | undefined;
        /**
         * @stability stable
         */
        set s3(value: IotTopicRuleS3[] | undefined);
        /**
         * @stability stable
         */
        resetS3(): void;
        /**
         * @stability stable
         */
        get s3Input(): IotTopicRuleS3[] | undefined;
        private _sns?;
        /**
         * @stability stable
         */
        get sns(): IotTopicRuleSns[] | undefined;
        /**
         * @stability stable
         */
        set sns(value: IotTopicRuleSns[] | undefined);
        /**
         * @stability stable
         */
        resetSns(): void;
        /**
         * @stability stable
         */
        get snsInput(): IotTopicRuleSns[] | undefined;
        private _sqs?;
        /**
         * @stability stable
         */
        get sqs(): IotTopicRuleSqs[] | undefined;
        /**
         * @stability stable
         */
        set sqs(value: IotTopicRuleSqs[] | undefined);
        /**
         * @stability stable
         */
        resetSqs(): void;
        /**
         * @stability stable
         */
        get sqsInput(): IotTopicRuleSqs[] | undefined;
        private _stepFunctions?;
        /**
         * @stability stable
         */
        get stepFunctions(): IotTopicRuleStepFunctions[] | undefined;
        /**
         * @stability stable
         */
        set stepFunctions(value: IotTopicRuleStepFunctions[] | undefined);
        /**
         * @stability stable
         */
        resetStepFunctions(): void;
        /**
         * @stability stable
         */
        get stepFunctionsInput(): IotTopicRuleStepFunctions[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsIotEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/iot_endpoint.html#endpoint_type DataAwsIotEndpoint#endpoint_type}.
         *
         * @stability stable
         */
        readonly endpointType?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/iot_endpoint.html aws_iot_endpoint}.
     *
     * @stability stable
     */
    class DataAwsIotEndpoint extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/iot_endpoint.html aws_iot_endpoint} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsIotEndpointConfig);
        /**
         * @stability stable
         */
        get endpointAddress(): string;
        private _endpointType?;
        /**
         * @stability stable
         */
        get endpointType(): string | undefined;
        /**
         * @stability stable
         */
        set endpointType(value: string | undefined);
        /**
         * @stability stable
         */
        resetEndpointType(): void;
        /**
         * @stability stable
         */
        get endpointTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
