import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Key Management Service
*/
export declare namespace KMS {
    /**
     * @stability stable
     */
    interface KmsAliasConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_alias.html#name KmsAlias#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_alias.html#name_prefix KmsAlias#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_alias.html#target_key_id KmsAlias#target_key_id}.
         *
         * @stability stable
         */
        readonly targetKeyId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_alias.html aws_kms_alias}.
     *
     * @stability stable
     */
    class KmsAlias extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_alias.html aws_kms_alias} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: KmsAliasConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        get targetKeyArn(): string;
        private _targetKeyId?;
        /**
         * @stability stable
         */
        get targetKeyId(): string;
        /**
         * @stability stable
         */
        set targetKeyId(value: string);
        /**
         * @stability stable
         */
        get targetKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface KmsCiphertextConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_ciphertext.html#context KmsCiphertext#context}.
         *
         * @stability stable
         */
        readonly context?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_ciphertext.html#key_id KmsCiphertext#key_id}.
         *
         * @stability stable
         */
        readonly keyId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_ciphertext.html#plaintext KmsCiphertext#plaintext}.
         *
         * @stability stable
         */
        readonly plaintext: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_ciphertext.html aws_kms_ciphertext}.
     *
     * @stability stable
     */
    class KmsCiphertext extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_ciphertext.html aws_kms_ciphertext} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: KmsCiphertextConfig);
        /**
         * @stability stable
         */
        get ciphertextBlob(): string;
        private _context?;
        /**
         * @stability stable
         */
        get context(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set context(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetContext(): void;
        /**
         * @stability stable
         */
        get contextInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string;
        /**
         * @stability stable
         */
        set keyId(value: string);
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
        private _plaintext?;
        /**
         * @stability stable
         */
        get plaintext(): string;
        /**
         * @stability stable
         */
        set plaintext(value: string);
        /**
         * @stability stable
         */
        get plaintextInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface KmsExternalKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#bypass_policy_lockout_safety_check KmsExternalKey#bypass_policy_lockout_safety_check}.
         *
         * @stability stable
         */
        readonly bypassPolicyLockoutSafetyCheck?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#deletion_window_in_days KmsExternalKey#deletion_window_in_days}.
         *
         * @stability stable
         */
        readonly deletionWindowInDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#description KmsExternalKey#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#enabled KmsExternalKey#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#key_material_base64 KmsExternalKey#key_material_base64}.
         *
         * @stability stable
         */
        readonly keyMaterialBase64?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#policy KmsExternalKey#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#tags KmsExternalKey#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#tags_all KmsExternalKey#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html#valid_to KmsExternalKey#valid_to}.
         *
         * @stability stable
         */
        readonly validTo?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html aws_kms_external_key}.
     *
     * @stability stable
     */
    class KmsExternalKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_external_key.html aws_kms_external_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: KmsExternalKeyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _bypassPolicyLockoutSafetyCheck?;
        /**
         * @stability stable
         */
        get bypassPolicyLockoutSafetyCheck(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set bypassPolicyLockoutSafetyCheck(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBypassPolicyLockoutSafetyCheck(): void;
        /**
         * @stability stable
         */
        get bypassPolicyLockoutSafetyCheckInput(): boolean | cdktf.IResolvable | undefined;
        private _deletionWindowInDays?;
        /**
         * @stability stable
         */
        get deletionWindowInDays(): number | undefined;
        /**
         * @stability stable
         */
        set deletionWindowInDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetDeletionWindowInDays(): void;
        /**
         * @stability stable
         */
        get deletionWindowInDaysInput(): number | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get expirationModel(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyMaterialBase64?;
        /**
         * @stability stable
         */
        get keyMaterialBase64(): string | undefined;
        /**
         * @stability stable
         */
        set keyMaterialBase64(value: string | undefined);
        /**
         * @stability stable
         */
        resetKeyMaterialBase64(): void;
        /**
         * @stability stable
         */
        get keyMaterialBase64Input(): string | undefined;
        /**
         * @stability stable
         */
        get keyState(): string;
        /**
         * @stability stable
         */
        get keyUsage(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _validTo?;
        /**
         * @stability stable
         */
        get validTo(): string | undefined;
        /**
         * @stability stable
         */
        set validTo(value: string | undefined);
        /**
         * @stability stable
         */
        resetValidTo(): void;
        /**
         * @stability stable
         */
        get validToInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface KmsGrantConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#grant_creation_tokens KmsGrant#grant_creation_tokens}.
         *
         * @stability stable
         */
        readonly grantCreationTokens?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#grantee_principal KmsGrant#grantee_principal}.
         *
         * @stability stable
         */
        readonly granteePrincipal: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#key_id KmsGrant#key_id}.
         *
         * @stability stable
         */
        readonly keyId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#name KmsGrant#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#operations KmsGrant#operations}.
         *
         * @stability stable
         */
        readonly operations: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#retire_on_delete KmsGrant#retire_on_delete}.
         *
         * @stability stable
         */
        readonly retireOnDelete?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#retiring_principal KmsGrant#retiring_principal}.
         *
         * @stability stable
         */
        readonly retiringPrincipal?: string;
        /**
         * constraints block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#constraints KmsGrant#constraints}
         *
         * @stability stable
         */
        readonly constraints?: KmsGrantConstraints[];
    }
    /**
     * @stability stable
     */
    interface KmsGrantConstraints {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#encryption_context_equals KmsGrant#encryption_context_equals}.
         *
         * @stability stable
         */
        readonly encryptionContextEquals?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html#encryption_context_subset KmsGrant#encryption_context_subset}.
         *
         * @stability stable
         */
        readonly encryptionContextSubset?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html aws_kms_grant}.
     *
     * @stability stable
     */
    class KmsGrant extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_grant.html aws_kms_grant} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: KmsGrantConfig);
        private _grantCreationTokens?;
        /**
         * @stability stable
         */
        get grantCreationTokens(): string[] | undefined;
        /**
         * @stability stable
         */
        set grantCreationTokens(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetGrantCreationTokens(): void;
        /**
         * @stability stable
         */
        get grantCreationTokensInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get grantId(): string;
        /**
         * @stability stable
         */
        get grantToken(): string;
        private _granteePrincipal?;
        /**
         * @stability stable
         */
        get granteePrincipal(): string;
        /**
         * @stability stable
         */
        set granteePrincipal(value: string);
        /**
         * @stability stable
         */
        get granteePrincipalInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string;
        /**
         * @stability stable
         */
        set keyId(value: string);
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _operations?;
        /**
         * @stability stable
         */
        get operations(): string[];
        /**
         * @stability stable
         */
        set operations(value: string[]);
        /**
         * @stability stable
         */
        get operationsInput(): string[] | undefined;
        private _retireOnDelete?;
        /**
         * @stability stable
         */
        get retireOnDelete(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set retireOnDelete(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRetireOnDelete(): void;
        /**
         * @stability stable
         */
        get retireOnDeleteInput(): boolean | cdktf.IResolvable | undefined;
        private _retiringPrincipal?;
        /**
         * @stability stable
         */
        get retiringPrincipal(): string | undefined;
        /**
         * @stability stable
         */
        set retiringPrincipal(value: string | undefined);
        /**
         * @stability stable
         */
        resetRetiringPrincipal(): void;
        /**
         * @stability stable
         */
        get retiringPrincipalInput(): string | undefined;
        private _constraints?;
        /**
         * @stability stable
         */
        get constraints(): KmsGrantConstraints[] | undefined;
        /**
         * @stability stable
         */
        set constraints(value: KmsGrantConstraints[] | undefined);
        /**
         * @stability stable
         */
        resetConstraints(): void;
        /**
         * @stability stable
         */
        get constraintsInput(): KmsGrantConstraints[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface KmsKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#bypass_policy_lockout_safety_check KmsKey#bypass_policy_lockout_safety_check}.
         *
         * @stability stable
         */
        readonly bypassPolicyLockoutSafetyCheck?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#customer_master_key_spec KmsKey#customer_master_key_spec}.
         *
         * @stability stable
         */
        readonly customerMasterKeySpec?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#deletion_window_in_days KmsKey#deletion_window_in_days}.
         *
         * @stability stable
         */
        readonly deletionWindowInDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#description KmsKey#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#enable_key_rotation KmsKey#enable_key_rotation}.
         *
         * @stability stable
         */
        readonly enableKeyRotation?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#is_enabled KmsKey#is_enabled}.
         *
         * @stability stable
         */
        readonly isEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#key_usage KmsKey#key_usage}.
         *
         * @stability stable
         */
        readonly keyUsage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#policy KmsKey#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#tags KmsKey#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html#tags_all KmsKey#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html aws_kms_key}.
     *
     * @stability stable
     */
    class KmsKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/kms_key.html aws_kms_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: KmsKeyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _bypassPolicyLockoutSafetyCheck?;
        /**
         * @stability stable
         */
        get bypassPolicyLockoutSafetyCheck(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set bypassPolicyLockoutSafetyCheck(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBypassPolicyLockoutSafetyCheck(): void;
        /**
         * @stability stable
         */
        get bypassPolicyLockoutSafetyCheckInput(): boolean | cdktf.IResolvable | undefined;
        private _customerMasterKeySpec?;
        /**
         * @stability stable
         */
        get customerMasterKeySpec(): string | undefined;
        /**
         * @stability stable
         */
        set customerMasterKeySpec(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerMasterKeySpec(): void;
        /**
         * @stability stable
         */
        get customerMasterKeySpecInput(): string | undefined;
        private _deletionWindowInDays?;
        /**
         * @stability stable
         */
        get deletionWindowInDays(): number | undefined;
        /**
         * @stability stable
         */
        set deletionWindowInDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetDeletionWindowInDays(): void;
        /**
         * @stability stable
         */
        get deletionWindowInDaysInput(): number | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _enableKeyRotation?;
        /**
         * @stability stable
         */
        get enableKeyRotation(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableKeyRotation(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableKeyRotation(): void;
        /**
         * @stability stable
         */
        get enableKeyRotationInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _isEnabled?;
        /**
         * @stability stable
         */
        get isEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set isEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIsEnabled(): void;
        /**
         * @stability stable
         */
        get isEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get keyId(): string;
        private _keyUsage?;
        /**
         * @stability stable
         */
        get keyUsage(): string | undefined;
        /**
         * @stability stable
         */
        set keyUsage(value: string | undefined);
        /**
         * @stability stable
         */
        resetKeyUsage(): void;
        /**
         * @stability stable
         */
        get keyUsageInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsAliasConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_alias.html#name DataAwsKmsAlias#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/kms_alias.html aws_kms_alias}.
     *
     * @stability stable
     */
    class DataAwsKmsAlias extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/kms_alias.html aws_kms_alias} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsKmsAliasConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get targetKeyArn(): string;
        /**
         * @stability stable
         */
        get targetKeyId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsCiphertextConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_ciphertext.html#context DataAwsKmsCiphertext#context}.
         *
         * @stability stable
         */
        readonly context?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_ciphertext.html#key_id DataAwsKmsCiphertext#key_id}.
         *
         * @stability stable
         */
        readonly keyId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_ciphertext.html#plaintext DataAwsKmsCiphertext#plaintext}.
         *
         * @stability stable
         */
        readonly plaintext: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/kms_ciphertext.html aws_kms_ciphertext}.
     *
     * @stability stable
     */
    class DataAwsKmsCiphertext extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/kms_ciphertext.html aws_kms_ciphertext} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsKmsCiphertextConfig);
        /**
         * @stability stable
         */
        get ciphertextBlob(): string;
        private _context?;
        /**
         * @stability stable
         */
        get context(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set context(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetContext(): void;
        /**
         * @stability stable
         */
        get contextInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string;
        /**
         * @stability stable
         */
        set keyId(value: string);
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
        private _plaintext?;
        /**
         * @stability stable
         */
        get plaintext(): string;
        /**
         * @stability stable
         */
        set plaintext(value: string);
        /**
         * @stability stable
         */
        get plaintextInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_key.html#grant_tokens DataAwsKmsKey#grant_tokens}.
         *
         * @stability stable
         */
        readonly grantTokens?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_key.html#key_id DataAwsKmsKey#key_id}.
         *
         * @stability stable
         */
        readonly keyId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/kms_key.html aws_kms_key}.
     *
     * @stability stable
     */
    class DataAwsKmsKey extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/kms_key.html aws_kms_key} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsKmsKeyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsAccountId(): string;
        /**
         * @stability stable
         */
        get creationDate(): string;
        /**
         * @stability stable
         */
        get customerMasterKeySpec(): string;
        /**
         * @stability stable
         */
        get deletionDate(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get expirationModel(): string;
        private _grantTokens?;
        /**
         * @stability stable
         */
        get grantTokens(): string[] | undefined;
        /**
         * @stability stable
         */
        set grantTokens(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetGrantTokens(): void;
        /**
         * @stability stable
         */
        get grantTokensInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string;
        /**
         * @stability stable
         */
        set keyId(value: string);
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get keyManager(): string;
        /**
         * @stability stable
         */
        get keyState(): string;
        /**
         * @stability stable
         */
        get keyUsage(): string;
        /**
         * @stability stable
         */
        get origin(): string;
        /**
         * @stability stable
         */
        get validTo(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsPublicKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_public_key.html#grant_tokens DataAwsKmsPublicKey#grant_tokens}.
         *
         * @stability stable
         */
        readonly grantTokens?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_public_key.html#key_id DataAwsKmsPublicKey#key_id}.
         *
         * @stability stable
         */
        readonly keyId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/kms_public_key.html aws_kms_public_key}.
     *
     * @stability stable
     */
    class DataAwsKmsPublicKey extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/kms_public_key.html aws_kms_public_key} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsKmsPublicKeyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get customerMasterKeySpec(): string;
        /**
         * @stability stable
         */
        get encryptionAlgorithms(): string[];
        private _grantTokens?;
        /**
         * @stability stable
         */
        get grantTokens(): string[] | undefined;
        /**
         * @stability stable
         */
        set grantTokens(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetGrantTokens(): void;
        /**
         * @stability stable
         */
        get grantTokensInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string;
        /**
         * @stability stable
         */
        set keyId(value: string);
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get keyUsage(): string;
        /**
         * @stability stable
         */
        get publicKey(): string;
        /**
         * @stability stable
         */
        get signingAlgorithms(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsSecretConfig extends cdktf.TerraformMetaArguments {
        /**
         * secret block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secret.html#secret DataAwsKmsSecret#secret}
         *
         * @stability stable
         */
        readonly secret: DataAwsKmsSecretSecret[];
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsSecretSecret {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secret.html#context DataAwsKmsSecret#context}.
         *
         * @stability stable
         */
        readonly context?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secret.html#grant_tokens DataAwsKmsSecret#grant_tokens}.
         *
         * @stability stable
         */
        readonly grantTokens?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secret.html#name DataAwsKmsSecret#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secret.html#payload DataAwsKmsSecret#payload}.
         *
         * @stability stable
         */
        readonly payload: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/kms_secret.html aws_kms_secret}.
     *
     * @stability stable
     */
    class DataAwsKmsSecret extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/kms_secret.html aws_kms_secret} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsKmsSecretConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _secret?;
        /**
         * @stability stable
         */
        get secret(): DataAwsKmsSecretSecret[];
        /**
         * @stability stable
         */
        set secret(value: DataAwsKmsSecretSecret[]);
        /**
         * @stability stable
         */
        get secretInput(): DataAwsKmsSecretSecret[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsSecretsConfig extends cdktf.TerraformMetaArguments {
        /**
         * secret block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secrets.html#secret DataAwsKmsSecrets#secret}
         *
         * @stability stable
         */
        readonly secret: DataAwsKmsSecretsSecret[];
    }
    /**
     * @stability stable
     */
    interface DataAwsKmsSecretsSecret {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secrets.html#context DataAwsKmsSecrets#context}.
         *
         * @stability stable
         */
        readonly context?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secrets.html#grant_tokens DataAwsKmsSecrets#grant_tokens}.
         *
         * @stability stable
         */
        readonly grantTokens?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secrets.html#name DataAwsKmsSecrets#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/kms_secrets.html#payload DataAwsKmsSecrets#payload}.
         *
         * @stability stable
         */
        readonly payload: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/kms_secrets.html aws_kms_secrets}.
     *
     * @stability stable
     */
    class DataAwsKmsSecrets extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/kms_secrets.html aws_kms_secrets} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsKmsSecretsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        plaintext(key: string): string;
        private _secret?;
        /**
         * @stability stable
         */
        get secret(): DataAwsKmsSecretsSecret[];
        /**
         * @stability stable
         */
        set secret(value: DataAwsKmsSecretsSecret[]);
        /**
         * @stability stable
         */
        get secretInput(): DataAwsKmsSecretsSecret[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
