import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Lake Formation
*/
export declare namespace LakeFormation {
    /**
     * @stability stable
     */
    interface LakeformationDataLakeSettingsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#admins LakeformationDataLakeSettings#admins}.
         *
         * @stability stable
         */
        readonly admins?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#catalog_id LakeformationDataLakeSettings#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#trusted_resource_owners LakeformationDataLakeSettings#trusted_resource_owners}.
         *
         * @stability stable
         */
        readonly trustedResourceOwners?: string[];
        /**
         * create_database_default_permissions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#create_database_default_permissions LakeformationDataLakeSettings#create_database_default_permissions}
         *
         * @stability stable
         */
        readonly createDatabaseDefaultPermissions?: LakeformationDataLakeSettingsCreateDatabaseDefaultPermissions[];
        /**
         * create_table_default_permissions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#create_table_default_permissions LakeformationDataLakeSettings#create_table_default_permissions}
         *
         * @stability stable
         */
        readonly createTableDefaultPermissions?: LakeformationDataLakeSettingsCreateTableDefaultPermissions[];
    }
    /**
     * @stability stable
     */
    interface LakeformationDataLakeSettingsCreateDatabaseDefaultPermissions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#permissions LakeformationDataLakeSettings#permissions}.
         *
         * @stability stable
         */
        readonly permissions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#principal LakeformationDataLakeSettings#principal}.
         *
         * @stability stable
         */
        readonly principal?: string;
    }
    /**
     * @stability stable
     */
    interface LakeformationDataLakeSettingsCreateTableDefaultPermissions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#permissions LakeformationDataLakeSettings#permissions}.
         *
         * @stability stable
         */
        readonly permissions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html#principal LakeformationDataLakeSettings#principal}.
         *
         * @stability stable
         */
        readonly principal?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html aws_lakeformation_data_lake_settings}.
     *
     * @stability stable
     */
    class LakeformationDataLakeSettings extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_data_lake_settings.html aws_lakeformation_data_lake_settings} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: LakeformationDataLakeSettingsConfig);
        private _admins?;
        /**
         * @stability stable
         */
        get admins(): string[] | undefined;
        /**
         * @stability stable
         */
        set admins(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAdmins(): void;
        /**
         * @stability stable
         */
        get adminsInput(): string[] | undefined;
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _trustedResourceOwners?;
        /**
         * @stability stable
         */
        get trustedResourceOwners(): string[] | undefined;
        /**
         * @stability stable
         */
        set trustedResourceOwners(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTrustedResourceOwners(): void;
        /**
         * @stability stable
         */
        get trustedResourceOwnersInput(): string[] | undefined;
        private _createDatabaseDefaultPermissions?;
        /**
         * @stability stable
         */
        get createDatabaseDefaultPermissions(): LakeformationDataLakeSettingsCreateDatabaseDefaultPermissions[] | undefined;
        /**
         * @stability stable
         */
        set createDatabaseDefaultPermissions(value: LakeformationDataLakeSettingsCreateDatabaseDefaultPermissions[] | undefined);
        /**
         * @stability stable
         */
        resetCreateDatabaseDefaultPermissions(): void;
        /**
         * @stability stable
         */
        get createDatabaseDefaultPermissionsInput(): LakeformationDataLakeSettingsCreateDatabaseDefaultPermissions[] | undefined;
        private _createTableDefaultPermissions?;
        /**
         * @stability stable
         */
        get createTableDefaultPermissions(): LakeformationDataLakeSettingsCreateTableDefaultPermissions[] | undefined;
        /**
         * @stability stable
         */
        set createTableDefaultPermissions(value: LakeformationDataLakeSettingsCreateTableDefaultPermissions[] | undefined);
        /**
         * @stability stable
         */
        resetCreateTableDefaultPermissions(): void;
        /**
         * @stability stable
         */
        get createTableDefaultPermissionsInput(): LakeformationDataLakeSettingsCreateTableDefaultPermissions[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LakeformationPermissionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#catalog_id LakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#catalog_resource LakeformationPermissions#catalog_resource}.
         *
         * @stability stable
         */
        readonly catalogResource?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#permissions LakeformationPermissions#permissions}.
         *
         * @stability stable
         */
        readonly permissions: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#permissions_with_grant_option LakeformationPermissions#permissions_with_grant_option}.
         *
         * @stability stable
         */
        readonly permissionsWithGrantOption?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#principal LakeformationPermissions#principal}.
         *
         * @stability stable
         */
        readonly principal: string;
        /**
         * data_location block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#data_location LakeformationPermissions#data_location}
         *
         * @stability stable
         */
        readonly dataLocation?: LakeformationPermissionsDataLocation;
        /**
         * database block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#database LakeformationPermissions#database}
         *
         * @stability stable
         */
        readonly database?: LakeformationPermissionsDatabase;
        /**
         * table block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#table LakeformationPermissions#table}
         *
         * @stability stable
         */
        readonly table?: LakeformationPermissionsTable;
        /**
         * table_with_columns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#table_with_columns LakeformationPermissions#table_with_columns}
         *
         * @stability stable
         */
        readonly tableWithColumns?: LakeformationPermissionsTableWithColumns;
    }
    /**
     * @stability stable
     */
    interface LakeformationPermissionsDataLocation {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#arn LakeformationPermissions#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#catalog_id LakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
    }
    /**
     * @stability stable
     */
    class LakeformationPermissionsDataLocationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LakeformationPermissionsDatabase {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#catalog_id LakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#name LakeformationPermissions#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    class LakeformationPermissionsDatabaseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LakeformationPermissionsTable {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#catalog_id LakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#database_name LakeformationPermissions#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#name LakeformationPermissions#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#wildcard LakeformationPermissions#wildcard}.
         *
         * @stability stable
         */
        readonly wildcard?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class LakeformationPermissionsTableOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _wildcard?;
        /**
         * @stability stable
         */
        get wildcard(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set wildcard(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWildcard(): void;
        /**
         * @stability stable
         */
        get wildcardInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface LakeformationPermissionsTableWithColumns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#catalog_id LakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#column_names LakeformationPermissions#column_names}.
         *
         * @stability stable
         */
        readonly columnNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#database_name LakeformationPermissions#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#excluded_column_names LakeformationPermissions#excluded_column_names}.
         *
         * @stability stable
         */
        readonly excludedColumnNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#name LakeformationPermissions#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html#wildcard LakeformationPermissions#wildcard}.
         *
         * @stability stable
         */
        readonly wildcard?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class LakeformationPermissionsTableWithColumnsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _columnNames?;
        /**
         * @stability stable
         */
        get columnNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set columnNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetColumnNames(): void;
        /**
         * @stability stable
         */
        get columnNamesInput(): string[] | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _excludedColumnNames?;
        /**
         * @stability stable
         */
        get excludedColumnNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set excludedColumnNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetExcludedColumnNames(): void;
        /**
         * @stability stable
         */
        get excludedColumnNamesInput(): string[] | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _wildcard?;
        /**
         * @stability stable
         */
        get wildcard(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set wildcard(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWildcard(): void;
        /**
         * @stability stable
         */
        get wildcardInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html aws_lakeformation_permissions}.
     *
     * @stability stable
     */
    class LakeformationPermissions extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_permissions.html aws_lakeformation_permissions} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LakeformationPermissionsConfig);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _catalogResource?;
        /**
         * @stability stable
         */
        get catalogResource(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set catalogResource(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCatalogResource(): void;
        /**
         * @stability stable
         */
        get catalogResourceInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _permissions?;
        /**
         * @stability stable
         */
        get permissions(): string[];
        /**
         * @stability stable
         */
        set permissions(value: string[]);
        /**
         * @stability stable
         */
        get permissionsInput(): string[] | undefined;
        private _permissionsWithGrantOption?;
        /**
         * @stability stable
         */
        get permissionsWithGrantOption(): string[] | undefined;
        /**
         * @stability stable
         */
        set permissionsWithGrantOption(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPermissionsWithGrantOption(): void;
        /**
         * @stability stable
         */
        get permissionsWithGrantOptionInput(): string[] | undefined;
        private _principal?;
        /**
         * @stability stable
         */
        get principal(): string;
        /**
         * @stability stable
         */
        set principal(value: string);
        /**
         * @stability stable
         */
        get principalInput(): string | undefined;
        private _dataLocation?;
        private __dataLocationOutput;
        /**
         * @stability stable
         */
        get dataLocation(): LakeformationPermissionsDataLocationOutputReference;
        /**
         * @stability stable
         */
        putDataLocation(value: LakeformationPermissionsDataLocation | undefined): void;
        /**
         * @stability stable
         */
        resetDataLocation(): void;
        /**
         * @stability stable
         */
        get dataLocationInput(): LakeformationPermissionsDataLocation | undefined;
        private _database?;
        private __databaseOutput;
        /**
         * @stability stable
         */
        get database(): LakeformationPermissionsDatabaseOutputReference;
        /**
         * @stability stable
         */
        putDatabase(value: LakeformationPermissionsDatabase | undefined): void;
        /**
         * @stability stable
         */
        resetDatabase(): void;
        /**
         * @stability stable
         */
        get databaseInput(): LakeformationPermissionsDatabase | undefined;
        private _table?;
        private __tableOutput;
        /**
         * @stability stable
         */
        get table(): LakeformationPermissionsTableOutputReference;
        /**
         * @stability stable
         */
        putTable(value: LakeformationPermissionsTable | undefined): void;
        /**
         * @stability stable
         */
        resetTable(): void;
        /**
         * @stability stable
         */
        get tableInput(): LakeformationPermissionsTable | undefined;
        private _tableWithColumns?;
        private __tableWithColumnsOutput;
        /**
         * @stability stable
         */
        get tableWithColumns(): LakeformationPermissionsTableWithColumnsOutputReference;
        /**
         * @stability stable
         */
        putTableWithColumns(value: LakeformationPermissionsTableWithColumns | undefined): void;
        /**
         * @stability stable
         */
        resetTableWithColumns(): void;
        /**
         * @stability stable
         */
        get tableWithColumnsInput(): LakeformationPermissionsTableWithColumns | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LakeformationResourceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_resource.html#arn LakeformationResource#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_resource.html#role_arn LakeformationResource#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_resource.html aws_lakeformation_resource}.
     *
     * @stability stable
     */
    class LakeformationResource extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lakeformation_resource.html aws_lakeformation_resource} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LakeformationResourceConfig);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastModified(): string;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string | undefined;
        /**
         * @stability stable
         */
        set roleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetRoleArn(): void;
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLakeformationDataLakeSettingsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_data_lake_settings.html#catalog_id DataAwsLakeformationDataLakeSettings#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsLakeformationDataLakeSettingsCreateDatabaseDefaultPermissions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get permissions(): string[];
        /**
         * @stability stable
         */
        get principal(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLakeformationDataLakeSettingsCreateTableDefaultPermissions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get permissions(): string[];
        /**
         * @stability stable
         */
        get principal(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_data_lake_settings.html aws_lakeformation_data_lake_settings}.
     *
     * @stability stable
     */
    class DataAwsLakeformationDataLakeSettings extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_data_lake_settings.html aws_lakeformation_data_lake_settings} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsLakeformationDataLakeSettingsConfig);
        /**
         * @stability stable
         */
        get admins(): string[];
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        /**
         * @stability stable
         */
        createDatabaseDefaultPermissions(index: string): DataAwsLakeformationDataLakeSettingsCreateDatabaseDefaultPermissions;
        /**
         * @stability stable
         */
        createTableDefaultPermissions(index: string): DataAwsLakeformationDataLakeSettingsCreateTableDefaultPermissions;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get trustedResourceOwners(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLakeformationPermissionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#catalog_id DataAwsLakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#catalog_resource DataAwsLakeformationPermissions#catalog_resource}.
         *
         * @stability stable
         */
        readonly catalogResource?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#principal DataAwsLakeformationPermissions#principal}.
         *
         * @stability stable
         */
        readonly principal: string;
        /**
         * data_location block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#data_location DataAwsLakeformationPermissions#data_location}
         *
         * @stability stable
         */
        readonly dataLocation?: DataAwsLakeformationPermissionsDataLocation;
        /**
         * database block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#database DataAwsLakeformationPermissions#database}
         *
         * @stability stable
         */
        readonly database?: DataAwsLakeformationPermissionsDatabase;
        /**
         * table block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#table DataAwsLakeformationPermissions#table}
         *
         * @stability stable
         */
        readonly table?: DataAwsLakeformationPermissionsTable;
        /**
         * table_with_columns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#table_with_columns DataAwsLakeformationPermissions#table_with_columns}
         *
         * @stability stable
         */
        readonly tableWithColumns?: DataAwsLakeformationPermissionsTableWithColumns;
    }
    /**
     * @stability stable
     */
    interface DataAwsLakeformationPermissionsDataLocation {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#arn DataAwsLakeformationPermissions#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#catalog_id DataAwsLakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsLakeformationPermissionsDataLocationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DataAwsLakeformationPermissionsDatabase {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#catalog_id DataAwsLakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#name DataAwsLakeformationPermissions#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    class DataAwsLakeformationPermissionsDatabaseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DataAwsLakeformationPermissionsTable {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#catalog_id DataAwsLakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#database_name DataAwsLakeformationPermissions#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#name DataAwsLakeformationPermissions#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#wildcard DataAwsLakeformationPermissions#wildcard}.
         *
         * @stability stable
         */
        readonly wildcard?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsLakeformationPermissionsTableOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _wildcard?;
        /**
         * @stability stable
         */
        get wildcard(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set wildcard(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWildcard(): void;
        /**
         * @stability stable
         */
        get wildcardInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface DataAwsLakeformationPermissionsTableWithColumns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#catalog_id DataAwsLakeformationPermissions#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#column_names DataAwsLakeformationPermissions#column_names}.
         *
         * @stability stable
         */
        readonly columnNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#database_name DataAwsLakeformationPermissions#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#excluded_column_names DataAwsLakeformationPermissions#excluded_column_names}.
         *
         * @stability stable
         */
        readonly excludedColumnNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#name DataAwsLakeformationPermissions#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html#wildcard DataAwsLakeformationPermissions#wildcard}.
         *
         * @stability stable
         */
        readonly wildcard?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsLakeformationPermissionsTableWithColumnsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _columnNames?;
        /**
         * @stability stable
         */
        get columnNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set columnNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetColumnNames(): void;
        /**
         * @stability stable
         */
        get columnNamesInput(): string[] | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _excludedColumnNames?;
        /**
         * @stability stable
         */
        get excludedColumnNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set excludedColumnNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetExcludedColumnNames(): void;
        /**
         * @stability stable
         */
        get excludedColumnNamesInput(): string[] | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _wildcard?;
        /**
         * @stability stable
         */
        get wildcard(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set wildcard(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWildcard(): void;
        /**
         * @stability stable
         */
        get wildcardInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html aws_lakeformation_permissions}.
     *
     * @stability stable
     */
    class DataAwsLakeformationPermissions extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_permissions.html aws_lakeformation_permissions} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLakeformationPermissionsConfig);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _catalogResource?;
        /**
         * @stability stable
         */
        get catalogResource(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set catalogResource(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCatalogResource(): void;
        /**
         * @stability stable
         */
        get catalogResourceInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get permissions(): string[];
        /**
         * @stability stable
         */
        get permissionsWithGrantOption(): string[];
        private _principal?;
        /**
         * @stability stable
         */
        get principal(): string;
        /**
         * @stability stable
         */
        set principal(value: string);
        /**
         * @stability stable
         */
        get principalInput(): string | undefined;
        private _dataLocation?;
        private __dataLocationOutput;
        /**
         * @stability stable
         */
        get dataLocation(): DataAwsLakeformationPermissionsDataLocationOutputReference;
        /**
         * @stability stable
         */
        putDataLocation(value: DataAwsLakeformationPermissionsDataLocation | undefined): void;
        /**
         * @stability stable
         */
        resetDataLocation(): void;
        /**
         * @stability stable
         */
        get dataLocationInput(): DataAwsLakeformationPermissionsDataLocation | undefined;
        private _database?;
        private __databaseOutput;
        /**
         * @stability stable
         */
        get database(): DataAwsLakeformationPermissionsDatabaseOutputReference;
        /**
         * @stability stable
         */
        putDatabase(value: DataAwsLakeformationPermissionsDatabase | undefined): void;
        /**
         * @stability stable
         */
        resetDatabase(): void;
        /**
         * @stability stable
         */
        get databaseInput(): DataAwsLakeformationPermissionsDatabase | undefined;
        private _table?;
        private __tableOutput;
        /**
         * @stability stable
         */
        get table(): DataAwsLakeformationPermissionsTableOutputReference;
        /**
         * @stability stable
         */
        putTable(value: DataAwsLakeformationPermissionsTable | undefined): void;
        /**
         * @stability stable
         */
        resetTable(): void;
        /**
         * @stability stable
         */
        get tableInput(): DataAwsLakeformationPermissionsTable | undefined;
        private _tableWithColumns?;
        private __tableWithColumnsOutput;
        /**
         * @stability stable
         */
        get tableWithColumns(): DataAwsLakeformationPermissionsTableWithColumnsOutputReference;
        /**
         * @stability stable
         */
        putTableWithColumns(value: DataAwsLakeformationPermissionsTableWithColumns | undefined): void;
        /**
         * @stability stable
         */
        resetTableWithColumns(): void;
        /**
         * @stability stable
         */
        get tableWithColumnsInput(): DataAwsLakeformationPermissionsTableWithColumns | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLakeformationResourceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_resource.html#arn DataAwsLakeformationResource#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_resource.html aws_lakeformation_resource}.
     *
     * @stability stable
     */
    class DataAwsLakeformationResource extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lakeformation_resource.html aws_lakeformation_resource} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLakeformationResourceConfig);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastModified(): string;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
