import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Lambda
*/
export declare namespace LambdaFunction {
    /**
     * @stability stable
     */
    interface LambdaAliasConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html#description LambdaAlias#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html#function_name LambdaAlias#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html#function_version LambdaAlias#function_version}.
         *
         * @stability stable
         */
        readonly functionVersion: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html#name LambdaAlias#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * routing_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html#routing_config LambdaAlias#routing_config}
         *
         * @stability stable
         */
        readonly routingConfig?: LambdaAliasRoutingConfig;
    }
    /**
     * @stability stable
     */
    interface LambdaAliasRoutingConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html#additional_version_weights LambdaAlias#additional_version_weights}.
         *
         * @stability stable
         */
        readonly additionalVersionWeights?: {
            [key: string]: number;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class LambdaAliasRoutingConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _additionalVersionWeights?;
        /**
         * @stability stable
         */
        get additionalVersionWeights(): {
            [key: string]: number;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set additionalVersionWeights(value: {
            [key: string]: number;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAdditionalVersionWeights(): void;
        /**
         * @stability stable
         */
        get additionalVersionWeightsInput(): cdktf.IResolvable | {
            [key: string]: number;
        } | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html aws_lambda_alias}.
     *
     * @stability stable
     */
    class LambdaAlias extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_alias.html aws_lambda_alias} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaAliasConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        private _functionVersion?;
        /**
         * @stability stable
         */
        get functionVersion(): string;
        /**
         * @stability stable
         */
        set functionVersion(value: string);
        /**
         * @stability stable
         */
        get functionVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get invokeArn(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _routingConfig?;
        private __routingConfigOutput;
        /**
         * @stability stable
         */
        get routingConfig(): LambdaAliasRoutingConfigOutputReference;
        /**
         * @stability stable
         */
        putRoutingConfig(value: LambdaAliasRoutingConfig | undefined): void;
        /**
         * @stability stable
         */
        resetRoutingConfig(): void;
        /**
         * @stability stable
         */
        get routingConfigInput(): LambdaAliasRoutingConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LambdaCodeSigningConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#description LambdaCodeSigningConfig#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * allowed_publishers block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#allowed_publishers LambdaCodeSigningConfig#allowed_publishers}
         *
         * @stability stable
         */
        readonly allowedPublishers: LambdaCodeSigningConfigAllowedPublishers;
        /**
         * policies block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#policies LambdaCodeSigningConfig#policies}
         *
         * @stability stable
         */
        readonly policies?: LambdaCodeSigningConfigPolicies;
    }
    /**
     * @stability stable
     */
    interface LambdaCodeSigningConfigAllowedPublishers {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#signing_profile_version_arns LambdaCodeSigningConfig#signing_profile_version_arns}.
         *
         * @stability stable
         */
        readonly signingProfileVersionArns: string[];
    }
    /**
     * @stability stable
     */
    class LambdaCodeSigningConfigAllowedPublishersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _signingProfileVersionArns?;
        /**
         * @stability stable
         */
        get signingProfileVersionArns(): string[];
        /**
         * @stability stable
         */
        set signingProfileVersionArns(value: string[]);
        /**
         * @stability stable
         */
        get signingProfileVersionArnsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaCodeSigningConfigPolicies {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html#untrusted_artifact_on_deployment LambdaCodeSigningConfig#untrusted_artifact_on_deployment}.
         *
         * @stability stable
         */
        readonly untrustedArtifactOnDeployment: string;
    }
    /**
     * @stability stable
     */
    class LambdaCodeSigningConfigPoliciesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _untrustedArtifactOnDeployment?;
        /**
         * @stability stable
         */
        get untrustedArtifactOnDeployment(): string;
        /**
         * @stability stable
         */
        set untrustedArtifactOnDeployment(value: string);
        /**
         * @stability stable
         */
        get untrustedArtifactOnDeploymentInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html aws_lambda_code_signing_config}.
     *
     * @stability stable
     */
    class LambdaCodeSigningConfig extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_code_signing_config.html aws_lambda_code_signing_config} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaCodeSigningConfigConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get configId(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastModified(): string;
        private _allowedPublishers?;
        private __allowedPublishersOutput;
        /**
         * @stability stable
         */
        get allowedPublishers(): LambdaCodeSigningConfigAllowedPublishersOutputReference;
        /**
         * @stability stable
         */
        putAllowedPublishers(value: LambdaCodeSigningConfigAllowedPublishers): void;
        /**
         * @stability stable
         */
        get allowedPublishersInput(): LambdaCodeSigningConfigAllowedPublishers | undefined;
        private _policies?;
        private __policiesOutput;
        /**
         * @stability stable
         */
        get policies(): LambdaCodeSigningConfigPoliciesOutputReference;
        /**
         * @stability stable
         */
        putPolicies(value: LambdaCodeSigningConfigPolicies | undefined): void;
        /**
         * @stability stable
         */
        resetPolicies(): void;
        /**
         * @stability stable
         */
        get policiesInput(): LambdaCodeSigningConfigPolicies | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LambdaEventSourceMappingConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#batch_size LambdaEventSourceMapping#batch_size}.
         *
         * @stability stable
         */
        readonly batchSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#bisect_batch_on_function_error LambdaEventSourceMapping#bisect_batch_on_function_error}.
         *
         * @stability stable
         */
        readonly bisectBatchOnFunctionError?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#enabled LambdaEventSourceMapping#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#event_source_arn LambdaEventSourceMapping#event_source_arn}.
         *
         * @stability stable
         */
        readonly eventSourceArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#function_name LambdaEventSourceMapping#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#function_response_types LambdaEventSourceMapping#function_response_types}.
         *
         * @stability stable
         */
        readonly functionResponseTypes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#maximum_batching_window_in_seconds LambdaEventSourceMapping#maximum_batching_window_in_seconds}.
         *
         * @stability stable
         */
        readonly maximumBatchingWindowInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#maximum_record_age_in_seconds LambdaEventSourceMapping#maximum_record_age_in_seconds}.
         *
         * @stability stable
         */
        readonly maximumRecordAgeInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#maximum_retry_attempts LambdaEventSourceMapping#maximum_retry_attempts}.
         *
         * @stability stable
         */
        readonly maximumRetryAttempts?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#parallelization_factor LambdaEventSourceMapping#parallelization_factor}.
         *
         * @stability stable
         */
        readonly parallelizationFactor?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#queues LambdaEventSourceMapping#queues}.
         *
         * @stability stable
         */
        readonly queues?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#starting_position LambdaEventSourceMapping#starting_position}.
         *
         * @stability stable
         */
        readonly startingPosition?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#starting_position_timestamp LambdaEventSourceMapping#starting_position_timestamp}.
         *
         * @stability stable
         */
        readonly startingPositionTimestamp?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#topics LambdaEventSourceMapping#topics}.
         *
         * @stability stable
         */
        readonly topics?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#tumbling_window_in_seconds LambdaEventSourceMapping#tumbling_window_in_seconds}.
         *
         * @stability stable
         */
        readonly tumblingWindowInSeconds?: number;
        /**
         * destination_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#destination_config LambdaEventSourceMapping#destination_config}
         *
         * @stability stable
         */
        readonly destinationConfig?: LambdaEventSourceMappingDestinationConfig;
        /**
         * self_managed_event_source block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#self_managed_event_source LambdaEventSourceMapping#self_managed_event_source}
         *
         * @stability stable
         */
        readonly selfManagedEventSource?: LambdaEventSourceMappingSelfManagedEventSource;
        /**
         * source_access_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#source_access_configuration LambdaEventSourceMapping#source_access_configuration}
         *
         * @stability stable
         */
        readonly sourceAccessConfiguration?: LambdaEventSourceMappingSourceAccessConfiguration[];
    }
    /**
     * @stability stable
     */
    interface LambdaEventSourceMappingDestinationConfigOnFailure {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#destination_arn LambdaEventSourceMapping#destination_arn}.
         *
         * @stability stable
         */
        readonly destinationArn: string;
    }
    /**
     * @stability stable
     */
    class LambdaEventSourceMappingDestinationConfigOnFailureOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _destinationArn?;
        /**
         * @stability stable
         */
        get destinationArn(): string;
        /**
         * @stability stable
         */
        set destinationArn(value: string);
        /**
         * @stability stable
         */
        get destinationArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaEventSourceMappingDestinationConfig {
        /**
         * on_failure block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#on_failure LambdaEventSourceMapping#on_failure}
         *
         * @stability stable
         */
        readonly onFailure?: LambdaEventSourceMappingDestinationConfigOnFailure;
    }
    /**
     * @stability stable
     */
    class LambdaEventSourceMappingDestinationConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _onFailure?;
        private __onFailureOutput;
        /**
         * @stability stable
         */
        get onFailure(): LambdaEventSourceMappingDestinationConfigOnFailureOutputReference;
        /**
         * @stability stable
         */
        putOnFailure(value: LambdaEventSourceMappingDestinationConfigOnFailure | undefined): void;
        /**
         * @stability stable
         */
        resetOnFailure(): void;
        /**
         * @stability stable
         */
        get onFailureInput(): LambdaEventSourceMappingDestinationConfigOnFailure | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaEventSourceMappingSelfManagedEventSource {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#endpoints LambdaEventSourceMapping#endpoints}.
         *
         * @stability stable
         */
        readonly endpoints: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class LambdaEventSourceMappingSelfManagedEventSourceOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _endpoints?;
        /**
         * @stability stable
         */
        get endpoints(): {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set endpoints(value: {
            [key: string]: string;
        } | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get endpointsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaEventSourceMappingSourceAccessConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#type LambdaEventSourceMapping#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html#uri LambdaEventSourceMapping#uri}.
         *
         * @stability stable
         */
        readonly uri: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html aws_lambda_event_source_mapping}.
     *
     * @stability stable
     */
    class LambdaEventSourceMapping extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_event_source_mapping.html aws_lambda_event_source_mapping} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaEventSourceMappingConfig);
        private _batchSize?;
        /**
         * @stability stable
         */
        get batchSize(): number | undefined;
        /**
         * @stability stable
         */
        set batchSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetBatchSize(): void;
        /**
         * @stability stable
         */
        get batchSizeInput(): number | undefined;
        private _bisectBatchOnFunctionError?;
        /**
         * @stability stable
         */
        get bisectBatchOnFunctionError(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set bisectBatchOnFunctionError(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBisectBatchOnFunctionError(): void;
        /**
         * @stability stable
         */
        get bisectBatchOnFunctionErrorInput(): boolean | cdktf.IResolvable | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _eventSourceArn?;
        /**
         * @stability stable
         */
        get eventSourceArn(): string | undefined;
        /**
         * @stability stable
         */
        set eventSourceArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetEventSourceArn(): void;
        /**
         * @stability stable
         */
        get eventSourceArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get functionArn(): string;
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        private _functionResponseTypes?;
        /**
         * @stability stable
         */
        get functionResponseTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set functionResponseTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetFunctionResponseTypes(): void;
        /**
         * @stability stable
         */
        get functionResponseTypesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastModified(): string;
        /**
         * @stability stable
         */
        get lastProcessingResult(): string;
        private _maximumBatchingWindowInSeconds?;
        /**
         * @stability stable
         */
        get maximumBatchingWindowInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set maximumBatchingWindowInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaximumBatchingWindowInSeconds(): void;
        /**
         * @stability stable
         */
        get maximumBatchingWindowInSecondsInput(): number | undefined;
        private _maximumRecordAgeInSeconds?;
        /**
         * @stability stable
         */
        get maximumRecordAgeInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set maximumRecordAgeInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaximumRecordAgeInSeconds(): void;
        /**
         * @stability stable
         */
        get maximumRecordAgeInSecondsInput(): number | undefined;
        private _maximumRetryAttempts?;
        /**
         * @stability stable
         */
        get maximumRetryAttempts(): number | undefined;
        /**
         * @stability stable
         */
        set maximumRetryAttempts(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaximumRetryAttempts(): void;
        /**
         * @stability stable
         */
        get maximumRetryAttemptsInput(): number | undefined;
        private _parallelizationFactor?;
        /**
         * @stability stable
         */
        get parallelizationFactor(): number | undefined;
        /**
         * @stability stable
         */
        set parallelizationFactor(value: number | undefined);
        /**
         * @stability stable
         */
        resetParallelizationFactor(): void;
        /**
         * @stability stable
         */
        get parallelizationFactorInput(): number | undefined;
        private _queues?;
        /**
         * @stability stable
         */
        get queues(): string[] | undefined;
        /**
         * @stability stable
         */
        set queues(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetQueues(): void;
        /**
         * @stability stable
         */
        get queuesInput(): string[] | undefined;
        private _startingPosition?;
        /**
         * @stability stable
         */
        get startingPosition(): string | undefined;
        /**
         * @stability stable
         */
        set startingPosition(value: string | undefined);
        /**
         * @stability stable
         */
        resetStartingPosition(): void;
        /**
         * @stability stable
         */
        get startingPositionInput(): string | undefined;
        private _startingPositionTimestamp?;
        /**
         * @stability stable
         */
        get startingPositionTimestamp(): string | undefined;
        /**
         * @stability stable
         */
        set startingPositionTimestamp(value: string | undefined);
        /**
         * @stability stable
         */
        resetStartingPositionTimestamp(): void;
        /**
         * @stability stable
         */
        get startingPositionTimestampInput(): string | undefined;
        /**
         * @stability stable
         */
        get state(): string;
        /**
         * @stability stable
         */
        get stateTransitionReason(): string;
        private _topics?;
        /**
         * @stability stable
         */
        get topics(): string[] | undefined;
        /**
         * @stability stable
         */
        set topics(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTopics(): void;
        /**
         * @stability stable
         */
        get topicsInput(): string[] | undefined;
        private _tumblingWindowInSeconds?;
        /**
         * @stability stable
         */
        get tumblingWindowInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tumblingWindowInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTumblingWindowInSeconds(): void;
        /**
         * @stability stable
         */
        get tumblingWindowInSecondsInput(): number | undefined;
        /**
         * @stability stable
         */
        get uuid(): string;
        private _destinationConfig?;
        private __destinationConfigOutput;
        /**
         * @stability stable
         */
        get destinationConfig(): LambdaEventSourceMappingDestinationConfigOutputReference;
        /**
         * @stability stable
         */
        putDestinationConfig(value: LambdaEventSourceMappingDestinationConfig | undefined): void;
        /**
         * @stability stable
         */
        resetDestinationConfig(): void;
        /**
         * @stability stable
         */
        get destinationConfigInput(): LambdaEventSourceMappingDestinationConfig | undefined;
        private _selfManagedEventSource?;
        private __selfManagedEventSourceOutput;
        /**
         * @stability stable
         */
        get selfManagedEventSource(): LambdaEventSourceMappingSelfManagedEventSourceOutputReference;
        /**
         * @stability stable
         */
        putSelfManagedEventSource(value: LambdaEventSourceMappingSelfManagedEventSource | undefined): void;
        /**
         * @stability stable
         */
        resetSelfManagedEventSource(): void;
        /**
         * @stability stable
         */
        get selfManagedEventSourceInput(): LambdaEventSourceMappingSelfManagedEventSource | undefined;
        private _sourceAccessConfiguration?;
        /**
         * @stability stable
         */
        get sourceAccessConfiguration(): LambdaEventSourceMappingSourceAccessConfiguration[] | undefined;
        /**
         * @stability stable
         */
        set sourceAccessConfiguration(value: LambdaEventSourceMappingSourceAccessConfiguration[] | undefined);
        /**
         * @stability stable
         */
        resetSourceAccessConfiguration(): void;
        /**
         * @stability stable
         */
        get sourceAccessConfigurationInput(): LambdaEventSourceMappingSourceAccessConfiguration[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#architectures LambdaFunction#architectures}.
         *
         * @stability stable
         */
        readonly architectures?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#code_signing_config_arn LambdaFunction#code_signing_config_arn}.
         *
         * @stability stable
         */
        readonly codeSigningConfigArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#description LambdaFunction#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#filename LambdaFunction#filename}.
         *
         * @stability stable
         */
        readonly filename?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#function_name LambdaFunction#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#handler LambdaFunction#handler}.
         *
         * @stability stable
         */
        readonly handler?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#image_uri LambdaFunction#image_uri}.
         *
         * @stability stable
         */
        readonly imageUri?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#kms_key_arn LambdaFunction#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#layers LambdaFunction#layers}.
         *
         * @stability stable
         */
        readonly layers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#memory_size LambdaFunction#memory_size}.
         *
         * @stability stable
         */
        readonly memorySize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#package_type LambdaFunction#package_type}.
         *
         * @stability stable
         */
        readonly packageType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#publish LambdaFunction#publish}.
         *
         * @stability stable
         */
        readonly publish?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#reserved_concurrent_executions LambdaFunction#reserved_concurrent_executions}.
         *
         * @stability stable
         */
        readonly reservedConcurrentExecutions?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#role LambdaFunction#role}.
         *
         * @stability stable
         */
        readonly role: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#runtime LambdaFunction#runtime}.
         *
         * @stability stable
         */
        readonly runtime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#s3_bucket LambdaFunction#s3_bucket}.
         *
         * @stability stable
         */
        readonly s3Bucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#s3_key LambdaFunction#s3_key}.
         *
         * @stability stable
         */
        readonly s3Key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#s3_object_version LambdaFunction#s3_object_version}.
         *
         * @stability stable
         */
        readonly s3ObjectVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#source_code_hash LambdaFunction#source_code_hash}.
         *
         * @stability stable
         */
        readonly sourceCodeHash?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#tags LambdaFunction#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#tags_all LambdaFunction#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#timeout LambdaFunction#timeout}.
         *
         * @stability stable
         */
        readonly timeout?: number;
        /**
         * dead_letter_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#dead_letter_config LambdaFunction#dead_letter_config}
         *
         * @stability stable
         */
        readonly deadLetterConfig?: LambdaFunctionDeadLetterConfig;
        /**
         * environment block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#environment LambdaFunction#environment}
         *
         * @stability stable
         */
        readonly environment?: LambdaFunctionEnvironment;
        /**
         * file_system_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#file_system_config LambdaFunction#file_system_config}
         *
         * @stability stable
         */
        readonly fileSystemConfig?: LambdaFunctionFileSystemConfig;
        /**
         * image_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#image_config LambdaFunction#image_config}
         *
         * @stability stable
         */
        readonly imageConfig?: LambdaFunctionImageConfig;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#timeouts LambdaFunction#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: LambdaFunctionTimeouts;
        /**
         * tracing_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#tracing_config LambdaFunction#tracing_config}
         *
         * @stability stable
         */
        readonly tracingConfig?: LambdaFunctionTracingConfig;
        /**
         * vpc_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#vpc_config LambdaFunction#vpc_config}
         *
         * @stability stable
         */
        readonly vpcConfig?: LambdaFunctionVpcConfig;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionDeadLetterConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#target_arn LambdaFunction#target_arn}.
         *
         * @stability stable
         */
        readonly targetArn: string;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionDeadLetterConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _targetArn?;
        /**
         * @stability stable
         */
        get targetArn(): string;
        /**
         * @stability stable
         */
        set targetArn(value: string);
        /**
         * @stability stable
         */
        get targetArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionEnvironment {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#variables LambdaFunction#variables}.
         *
         * @stability stable
         */
        readonly variables?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionEnvironmentOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _variables?;
        /**
         * @stability stable
         */
        get variables(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set variables(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetVariables(): void;
        /**
         * @stability stable
         */
        get variablesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionFileSystemConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#arn LambdaFunction#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#local_mount_path LambdaFunction#local_mount_path}.
         *
         * @stability stable
         */
        readonly localMountPath: string;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionFileSystemConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        private _localMountPath?;
        /**
         * @stability stable
         */
        get localMountPath(): string;
        /**
         * @stability stable
         */
        set localMountPath(value: string);
        /**
         * @stability stable
         */
        get localMountPathInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionImageConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#command LambdaFunction#command}.
         *
         * @stability stable
         */
        readonly command?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#entry_point LambdaFunction#entry_point}.
         *
         * @stability stable
         */
        readonly entryPoint?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#working_directory LambdaFunction#working_directory}.
         *
         * @stability stable
         */
        readonly workingDirectory?: string;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionImageConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _command?;
        /**
         * @stability stable
         */
        get command(): string[] | undefined;
        /**
         * @stability stable
         */
        set command(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCommand(): void;
        /**
         * @stability stable
         */
        get commandInput(): string[] | undefined;
        private _entryPoint?;
        /**
         * @stability stable
         */
        get entryPoint(): string[] | undefined;
        /**
         * @stability stable
         */
        set entryPoint(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEntryPoint(): void;
        /**
         * @stability stable
         */
        get entryPointInput(): string[] | undefined;
        private _workingDirectory?;
        /**
         * @stability stable
         */
        get workingDirectory(): string | undefined;
        /**
         * @stability stable
         */
        set workingDirectory(value: string | undefined);
        /**
         * @stability stable
         */
        resetWorkingDirectory(): void;
        /**
         * @stability stable
         */
        get workingDirectoryInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#create LambdaFunction#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionTracingConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#mode LambdaFunction#mode}.
         *
         * @stability stable
         */
        readonly mode: string;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionTracingConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _mode?;
        /**
         * @stability stable
         */
        get mode(): string;
        /**
         * @stability stable
         */
        set mode(value: string);
        /**
         * @stability stable
         */
        get modeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionVpcConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#security_group_ids LambdaFunction#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html#subnet_ids LambdaFunction#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
    }
    /**
     * @stability stable
     */
    class LambdaFunctionVpcConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[];
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[]);
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html aws_lambda_function}.
     *
     * @stability stable
     */
    class LambdaFunction extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_function.html aws_lambda_function} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaFunctionConfig);
        private _architectures?;
        /**
         * @stability stable
         */
        get architectures(): string[] | undefined;
        /**
         * @stability stable
         */
        set architectures(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetArchitectures(): void;
        /**
         * @stability stable
         */
        get architecturesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _codeSigningConfigArn?;
        /**
         * @stability stable
         */
        get codeSigningConfigArn(): string | undefined;
        /**
         * @stability stable
         */
        set codeSigningConfigArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCodeSigningConfigArn(): void;
        /**
         * @stability stable
         */
        get codeSigningConfigArnInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _filename?;
        /**
         * @stability stable
         */
        get filename(): string | undefined;
        /**
         * @stability stable
         */
        set filename(value: string | undefined);
        /**
         * @stability stable
         */
        resetFilename(): void;
        /**
         * @stability stable
         */
        get filenameInput(): string | undefined;
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        private _handler?;
        /**
         * @stability stable
         */
        get handler(): string | undefined;
        /**
         * @stability stable
         */
        set handler(value: string | undefined);
        /**
         * @stability stable
         */
        resetHandler(): void;
        /**
         * @stability stable
         */
        get handlerInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _imageUri?;
        /**
         * @stability stable
         */
        get imageUri(): string | undefined;
        /**
         * @stability stable
         */
        set imageUri(value: string | undefined);
        /**
         * @stability stable
         */
        resetImageUri(): void;
        /**
         * @stability stable
         */
        get imageUriInput(): string | undefined;
        /**
         * @stability stable
         */
        get invokeArn(): string;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get lastModified(): string;
        private _layers?;
        /**
         * @stability stable
         */
        get layers(): string[] | undefined;
        /**
         * @stability stable
         */
        set layers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetLayers(): void;
        /**
         * @stability stable
         */
        get layersInput(): string[] | undefined;
        private _memorySize?;
        /**
         * @stability stable
         */
        get memorySize(): number | undefined;
        /**
         * @stability stable
         */
        set memorySize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMemorySize(): void;
        /**
         * @stability stable
         */
        get memorySizeInput(): number | undefined;
        private _packageType?;
        /**
         * @stability stable
         */
        get packageType(): string | undefined;
        /**
         * @stability stable
         */
        set packageType(value: string | undefined);
        /**
         * @stability stable
         */
        resetPackageType(): void;
        /**
         * @stability stable
         */
        get packageTypeInput(): string | undefined;
        private _publish?;
        /**
         * @stability stable
         */
        get publish(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set publish(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPublish(): void;
        /**
         * @stability stable
         */
        get publishInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get qualifiedArn(): string;
        private _reservedConcurrentExecutions?;
        /**
         * @stability stable
         */
        get reservedConcurrentExecutions(): number | undefined;
        /**
         * @stability stable
         */
        set reservedConcurrentExecutions(value: number | undefined);
        /**
         * @stability stable
         */
        resetReservedConcurrentExecutions(): void;
        /**
         * @stability stable
         */
        get reservedConcurrentExecutionsInput(): number | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        set role(value: string);
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        private _runtime?;
        /**
         * @stability stable
         */
        get runtime(): string | undefined;
        /**
         * @stability stable
         */
        set runtime(value: string | undefined);
        /**
         * @stability stable
         */
        resetRuntime(): void;
        /**
         * @stability stable
         */
        get runtimeInput(): string | undefined;
        private _s3Bucket?;
        /**
         * @stability stable
         */
        get s3Bucket(): string | undefined;
        /**
         * @stability stable
         */
        set s3Bucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3Bucket(): void;
        /**
         * @stability stable
         */
        get s3BucketInput(): string | undefined;
        private _s3Key?;
        /**
         * @stability stable
         */
        get s3Key(): string | undefined;
        /**
         * @stability stable
         */
        set s3Key(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3Key(): void;
        /**
         * @stability stable
         */
        get s3KeyInput(): string | undefined;
        private _s3ObjectVersion?;
        /**
         * @stability stable
         */
        get s3ObjectVersion(): string | undefined;
        /**
         * @stability stable
         */
        set s3ObjectVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3ObjectVersion(): void;
        /**
         * @stability stable
         */
        get s3ObjectVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get signingJobArn(): string;
        /**
         * @stability stable
         */
        get signingProfileVersionArn(): string;
        private _sourceCodeHash?;
        /**
         * @stability stable
         */
        get sourceCodeHash(): string | undefined;
        /**
         * @stability stable
         */
        set sourceCodeHash(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceCodeHash(): void;
        /**
         * @stability stable
         */
        get sourceCodeHashInput(): string | undefined;
        /**
         * @stability stable
         */
        get sourceCodeSize(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _timeout?;
        /**
         * @stability stable
         */
        get timeout(): number | undefined;
        /**
         * @stability stable
         */
        set timeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeout(): void;
        /**
         * @stability stable
         */
        get timeoutInput(): number | undefined;
        /**
         * @stability stable
         */
        get version(): string;
        private _deadLetterConfig?;
        private __deadLetterConfigOutput;
        /**
         * @stability stable
         */
        get deadLetterConfig(): LambdaFunctionDeadLetterConfigOutputReference;
        /**
         * @stability stable
         */
        putDeadLetterConfig(value: LambdaFunctionDeadLetterConfig | undefined): void;
        /**
         * @stability stable
         */
        resetDeadLetterConfig(): void;
        /**
         * @stability stable
         */
        get deadLetterConfigInput(): LambdaFunctionDeadLetterConfig | undefined;
        private _environment?;
        private __environmentOutput;
        /**
         * @stability stable
         */
        get environment(): LambdaFunctionEnvironmentOutputReference;
        /**
         * @stability stable
         */
        putEnvironment(value: LambdaFunctionEnvironment | undefined): void;
        /**
         * @stability stable
         */
        resetEnvironment(): void;
        /**
         * @stability stable
         */
        get environmentInput(): LambdaFunctionEnvironment | undefined;
        private _fileSystemConfig?;
        private __fileSystemConfigOutput;
        /**
         * @stability stable
         */
        get fileSystemConfig(): LambdaFunctionFileSystemConfigOutputReference;
        /**
         * @stability stable
         */
        putFileSystemConfig(value: LambdaFunctionFileSystemConfig | undefined): void;
        /**
         * @stability stable
         */
        resetFileSystemConfig(): void;
        /**
         * @stability stable
         */
        get fileSystemConfigInput(): LambdaFunctionFileSystemConfig | undefined;
        private _imageConfig?;
        private __imageConfigOutput;
        /**
         * @stability stable
         */
        get imageConfig(): LambdaFunctionImageConfigOutputReference;
        /**
         * @stability stable
         */
        putImageConfig(value: LambdaFunctionImageConfig | undefined): void;
        /**
         * @stability stable
         */
        resetImageConfig(): void;
        /**
         * @stability stable
         */
        get imageConfigInput(): LambdaFunctionImageConfig | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): LambdaFunctionTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: LambdaFunctionTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): LambdaFunctionTimeouts | undefined;
        private _tracingConfig?;
        private __tracingConfigOutput;
        /**
         * @stability stable
         */
        get tracingConfig(): LambdaFunctionTracingConfigOutputReference;
        /**
         * @stability stable
         */
        putTracingConfig(value: LambdaFunctionTracingConfig | undefined): void;
        /**
         * @stability stable
         */
        resetTracingConfig(): void;
        /**
         * @stability stable
         */
        get tracingConfigInput(): LambdaFunctionTracingConfig | undefined;
        private _vpcConfig?;
        private __vpcConfigOutput;
        /**
         * @stability stable
         */
        get vpcConfig(): LambdaFunctionVpcConfigOutputReference;
        /**
         * @stability stable
         */
        putVpcConfig(value: LambdaFunctionVpcConfig | undefined): void;
        /**
         * @stability stable
         */
        resetVpcConfig(): void;
        /**
         * @stability stable
         */
        get vpcConfigInput(): LambdaFunctionVpcConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionEventInvokeConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#function_name LambdaFunctionEventInvokeConfig#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#maximum_event_age_in_seconds LambdaFunctionEventInvokeConfig#maximum_event_age_in_seconds}.
         *
         * @stability stable
         */
        readonly maximumEventAgeInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#maximum_retry_attempts LambdaFunctionEventInvokeConfig#maximum_retry_attempts}.
         *
         * @stability stable
         */
        readonly maximumRetryAttempts?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#qualifier LambdaFunctionEventInvokeConfig#qualifier}.
         *
         * @stability stable
         */
        readonly qualifier?: string;
        /**
         * destination_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#destination_config LambdaFunctionEventInvokeConfig#destination_config}
         *
         * @stability stable
         */
        readonly destinationConfig?: LambdaFunctionEventInvokeConfigDestinationConfig;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionEventInvokeConfigDestinationConfigOnFailure {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#destination LambdaFunctionEventInvokeConfig#destination}.
         *
         * @stability stable
         */
        readonly destination: string;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _destination?;
        /**
         * @stability stable
         */
        get destination(): string;
        /**
         * @stability stable
         */
        set destination(value: string);
        /**
         * @stability stable
         */
        get destinationInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#destination LambdaFunctionEventInvokeConfig#destination}.
         *
         * @stability stable
         */
        readonly destination: string;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _destination?;
        /**
         * @stability stable
         */
        get destination(): string;
        /**
         * @stability stable
         */
        set destination(value: string);
        /**
         * @stability stable
         */
        get destinationInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LambdaFunctionEventInvokeConfigDestinationConfig {
        /**
         * on_failure block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#on_failure LambdaFunctionEventInvokeConfig#on_failure}
         *
         * @stability stable
         */
        readonly onFailure?: LambdaFunctionEventInvokeConfigDestinationConfigOnFailure;
        /**
         * on_success block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html#on_success LambdaFunctionEventInvokeConfig#on_success}
         *
         * @stability stable
         */
        readonly onSuccess?: LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess;
    }
    /**
     * @stability stable
     */
    class LambdaFunctionEventInvokeConfigDestinationConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _onFailure?;
        private __onFailureOutput;
        /**
         * @stability stable
         */
        get onFailure(): LambdaFunctionEventInvokeConfigDestinationConfigOnFailureOutputReference;
        /**
         * @stability stable
         */
        putOnFailure(value: LambdaFunctionEventInvokeConfigDestinationConfigOnFailure | undefined): void;
        /**
         * @stability stable
         */
        resetOnFailure(): void;
        /**
         * @stability stable
         */
        get onFailureInput(): LambdaFunctionEventInvokeConfigDestinationConfigOnFailure | undefined;
        private _onSuccess?;
        private __onSuccessOutput;
        /**
         * @stability stable
         */
        get onSuccess(): LambdaFunctionEventInvokeConfigDestinationConfigOnSuccessOutputReference;
        /**
         * @stability stable
         */
        putOnSuccess(value: LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess | undefined): void;
        /**
         * @stability stable
         */
        resetOnSuccess(): void;
        /**
         * @stability stable
         */
        get onSuccessInput(): LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html aws_lambda_function_event_invoke_config}.
     *
     * @stability stable
     */
    class LambdaFunctionEventInvokeConfig extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_function_event_invoke_config.html aws_lambda_function_event_invoke_config} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaFunctionEventInvokeConfigConfig);
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _maximumEventAgeInSeconds?;
        /**
         * @stability stable
         */
        get maximumEventAgeInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set maximumEventAgeInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaximumEventAgeInSeconds(): void;
        /**
         * @stability stable
         */
        get maximumEventAgeInSecondsInput(): number | undefined;
        private _maximumRetryAttempts?;
        /**
         * @stability stable
         */
        get maximumRetryAttempts(): number | undefined;
        /**
         * @stability stable
         */
        set maximumRetryAttempts(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaximumRetryAttempts(): void;
        /**
         * @stability stable
         */
        get maximumRetryAttemptsInput(): number | undefined;
        private _qualifier?;
        /**
         * @stability stable
         */
        get qualifier(): string | undefined;
        /**
         * @stability stable
         */
        set qualifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetQualifier(): void;
        /**
         * @stability stable
         */
        get qualifierInput(): string | undefined;
        private _destinationConfig?;
        private __destinationConfigOutput;
        /**
         * @stability stable
         */
        get destinationConfig(): LambdaFunctionEventInvokeConfigDestinationConfigOutputReference;
        /**
         * @stability stable
         */
        putDestinationConfig(value: LambdaFunctionEventInvokeConfigDestinationConfig | undefined): void;
        /**
         * @stability stable
         */
        resetDestinationConfig(): void;
        /**
         * @stability stable
         */
        get destinationConfigInput(): LambdaFunctionEventInvokeConfigDestinationConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LambdaLayerVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#compatible_architectures LambdaLayerVersion#compatible_architectures}.
         *
         * @stability stable
         */
        readonly compatibleArchitectures?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#compatible_runtimes LambdaLayerVersion#compatible_runtimes}.
         *
         * @stability stable
         */
        readonly compatibleRuntimes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#description LambdaLayerVersion#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#filename LambdaLayerVersion#filename}.
         *
         * @stability stable
         */
        readonly filename?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#layer_name LambdaLayerVersion#layer_name}.
         *
         * @stability stable
         */
        readonly layerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#license_info LambdaLayerVersion#license_info}.
         *
         * @stability stable
         */
        readonly licenseInfo?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#s3_bucket LambdaLayerVersion#s3_bucket}.
         *
         * @stability stable
         */
        readonly s3Bucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#s3_key LambdaLayerVersion#s3_key}.
         *
         * @stability stable
         */
        readonly s3Key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#s3_object_version LambdaLayerVersion#s3_object_version}.
         *
         * @stability stable
         */
        readonly s3ObjectVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html#source_code_hash LambdaLayerVersion#source_code_hash}.
         *
         * @stability stable
         */
        readonly sourceCodeHash?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html aws_lambda_layer_version}.
     *
     * @stability stable
     */
    class LambdaLayerVersion extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_layer_version.html aws_lambda_layer_version} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaLayerVersionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _compatibleArchitectures?;
        /**
         * @stability stable
         */
        get compatibleArchitectures(): string[] | undefined;
        /**
         * @stability stable
         */
        set compatibleArchitectures(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCompatibleArchitectures(): void;
        /**
         * @stability stable
         */
        get compatibleArchitecturesInput(): string[] | undefined;
        private _compatibleRuntimes?;
        /**
         * @stability stable
         */
        get compatibleRuntimes(): string[] | undefined;
        /**
         * @stability stable
         */
        set compatibleRuntimes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCompatibleRuntimes(): void;
        /**
         * @stability stable
         */
        get compatibleRuntimesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get createdDate(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _filename?;
        /**
         * @stability stable
         */
        get filename(): string | undefined;
        /**
         * @stability stable
         */
        set filename(value: string | undefined);
        /**
         * @stability stable
         */
        resetFilename(): void;
        /**
         * @stability stable
         */
        get filenameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get layerArn(): string;
        private _layerName?;
        /**
         * @stability stable
         */
        get layerName(): string;
        /**
         * @stability stable
         */
        set layerName(value: string);
        /**
         * @stability stable
         */
        get layerNameInput(): string | undefined;
        private _licenseInfo?;
        /**
         * @stability stable
         */
        get licenseInfo(): string | undefined;
        /**
         * @stability stable
         */
        set licenseInfo(value: string | undefined);
        /**
         * @stability stable
         */
        resetLicenseInfo(): void;
        /**
         * @stability stable
         */
        get licenseInfoInput(): string | undefined;
        private _s3Bucket?;
        /**
         * @stability stable
         */
        get s3Bucket(): string | undefined;
        /**
         * @stability stable
         */
        set s3Bucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3Bucket(): void;
        /**
         * @stability stable
         */
        get s3BucketInput(): string | undefined;
        private _s3Key?;
        /**
         * @stability stable
         */
        get s3Key(): string | undefined;
        /**
         * @stability stable
         */
        set s3Key(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3Key(): void;
        /**
         * @stability stable
         */
        get s3KeyInput(): string | undefined;
        private _s3ObjectVersion?;
        /**
         * @stability stable
         */
        get s3ObjectVersion(): string | undefined;
        /**
         * @stability stable
         */
        set s3ObjectVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3ObjectVersion(): void;
        /**
         * @stability stable
         */
        get s3ObjectVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get signingJobArn(): string;
        /**
         * @stability stable
         */
        get signingProfileVersionArn(): string;
        private _sourceCodeHash?;
        /**
         * @stability stable
         */
        get sourceCodeHash(): string | undefined;
        /**
         * @stability stable
         */
        set sourceCodeHash(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceCodeHash(): void;
        /**
         * @stability stable
         */
        get sourceCodeHashInput(): string | undefined;
        /**
         * @stability stable
         */
        get sourceCodeSize(): number;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LambdaPermissionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#action LambdaPermission#action}.
         *
         * @stability stable
         */
        readonly action: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#event_source_token LambdaPermission#event_source_token}.
         *
         * @stability stable
         */
        readonly eventSourceToken?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#function_name LambdaPermission#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#principal LambdaPermission#principal}.
         *
         * @stability stable
         */
        readonly principal: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#qualifier LambdaPermission#qualifier}.
         *
         * @stability stable
         */
        readonly qualifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#source_account LambdaPermission#source_account}.
         *
         * @stability stable
         */
        readonly sourceAccount?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#source_arn LambdaPermission#source_arn}.
         *
         * @stability stable
         */
        readonly sourceArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#statement_id LambdaPermission#statement_id}.
         *
         * @stability stable
         */
        readonly statementId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html#statement_id_prefix LambdaPermission#statement_id_prefix}.
         *
         * @stability stable
         */
        readonly statementIdPrefix?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html aws_lambda_permission}.
     *
     * @stability stable
     */
    class LambdaPermission extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_permission.html aws_lambda_permission} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaPermissionConfig);
        private _action?;
        /**
         * @stability stable
         */
        get action(): string;
        /**
         * @stability stable
         */
        set action(value: string);
        /**
         * @stability stable
         */
        get actionInput(): string | undefined;
        private _eventSourceToken?;
        /**
         * @stability stable
         */
        get eventSourceToken(): string | undefined;
        /**
         * @stability stable
         */
        set eventSourceToken(value: string | undefined);
        /**
         * @stability stable
         */
        resetEventSourceToken(): void;
        /**
         * @stability stable
         */
        get eventSourceTokenInput(): string | undefined;
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _principal?;
        /**
         * @stability stable
         */
        get principal(): string;
        /**
         * @stability stable
         */
        set principal(value: string);
        /**
         * @stability stable
         */
        get principalInput(): string | undefined;
        private _qualifier?;
        /**
         * @stability stable
         */
        get qualifier(): string | undefined;
        /**
         * @stability stable
         */
        set qualifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetQualifier(): void;
        /**
         * @stability stable
         */
        get qualifierInput(): string | undefined;
        private _sourceAccount?;
        /**
         * @stability stable
         */
        get sourceAccount(): string | undefined;
        /**
         * @stability stable
         */
        set sourceAccount(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceAccount(): void;
        /**
         * @stability stable
         */
        get sourceAccountInput(): string | undefined;
        private _sourceArn?;
        /**
         * @stability stable
         */
        get sourceArn(): string | undefined;
        /**
         * @stability stable
         */
        set sourceArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceArn(): void;
        /**
         * @stability stable
         */
        get sourceArnInput(): string | undefined;
        private _statementId?;
        /**
         * @stability stable
         */
        get statementId(): string | undefined;
        /**
         * @stability stable
         */
        set statementId(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatementId(): void;
        /**
         * @stability stable
         */
        get statementIdInput(): string | undefined;
        private _statementIdPrefix?;
        /**
         * @stability stable
         */
        get statementIdPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set statementIdPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatementIdPrefix(): void;
        /**
         * @stability stable
         */
        get statementIdPrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LambdaProvisionedConcurrencyConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html#function_name LambdaProvisionedConcurrencyConfig#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html#provisioned_concurrent_executions LambdaProvisionedConcurrencyConfig#provisioned_concurrent_executions}.
         *
         * @stability stable
         */
        readonly provisionedConcurrentExecutions: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html#qualifier LambdaProvisionedConcurrencyConfig#qualifier}.
         *
         * @stability stable
         */
        readonly qualifier: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html#timeouts LambdaProvisionedConcurrencyConfig#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: LambdaProvisionedConcurrencyConfigTimeouts;
    }
    /**
     * @stability stable
     */
    interface LambdaProvisionedConcurrencyConfigTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html#create LambdaProvisionedConcurrencyConfig#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html#update LambdaProvisionedConcurrencyConfig#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class LambdaProvisionedConcurrencyConfigTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html aws_lambda_provisioned_concurrency_config}.
     *
     * @stability stable
     */
    class LambdaProvisionedConcurrencyConfig extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lambda_provisioned_concurrency_config.html aws_lambda_provisioned_concurrency_config} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LambdaProvisionedConcurrencyConfigConfig);
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _provisionedConcurrentExecutions?;
        /**
         * @stability stable
         */
        get provisionedConcurrentExecutions(): number;
        /**
         * @stability stable
         */
        set provisionedConcurrentExecutions(value: number);
        /**
         * @stability stable
         */
        get provisionedConcurrentExecutionsInput(): number | undefined;
        private _qualifier?;
        /**
         * @stability stable
         */
        get qualifier(): string;
        /**
         * @stability stable
         */
        set qualifier(value: string);
        /**
         * @stability stable
         */
        get qualifierInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): LambdaProvisionedConcurrencyConfigTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: LambdaProvisionedConcurrencyConfigTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): LambdaProvisionedConcurrencyConfigTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLambdaAliasConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_alias.html#function_name DataAwsLambdaAlias#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_alias.html#name DataAwsLambdaAlias#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lambda_alias.html aws_lambda_alias}.
     *
     * @stability stable
     */
    class DataAwsLambdaAlias extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lambda_alias.html aws_lambda_alias} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLambdaAliasConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get description(): string;
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get functionVersion(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get invokeArn(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLambdaCodeSigningConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config.html#arn DataAwsLambdaCodeSigningConfig#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
    }
    /**
     * @stability stable
     */
    class DataAwsLambdaCodeSigningConfigAllowedPublishers extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get signingProfileVersionArns(): string[];
    }
    /**
     * @stability stable
     */
    class DataAwsLambdaCodeSigningConfigPolicies extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get untrustedArtifactOnDeployment(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config.html aws_lambda_code_signing_config}.
     *
     * @stability stable
     */
    class DataAwsLambdaCodeSigningConfig extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lambda_code_signing_config.html aws_lambda_code_signing_config} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLambdaCodeSigningConfigConfig);
        /**
         * @stability stable
         */
        allowedPublishers(index: string): DataAwsLambdaCodeSigningConfigAllowedPublishers;
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        /**
         * @stability stable
         */
        get configId(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastModified(): string;
        /**
         * @stability stable
         */
        policies(index: string): DataAwsLambdaCodeSigningConfigPolicies;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLambdaFunctionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_function.html#function_name DataAwsLambdaFunction#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_function.html#qualifier DataAwsLambdaFunction#qualifier}.
         *
         * @stability stable
         */
        readonly qualifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_function.html#tags DataAwsLambdaFunction#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsLambdaFunctionDeadLetterConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get targetArn(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLambdaFunctionEnvironment extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get variables(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsLambdaFunctionFileSystemConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get localMountPath(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLambdaFunctionTracingConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get mode(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLambdaFunctionVpcConfig extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get securityGroupIds(): string[];
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        get vpcId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lambda_function.html aws_lambda_function}.
     *
     * @stability stable
     */
    class DataAwsLambdaFunction extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lambda_function.html aws_lambda_function} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLambdaFunctionConfig);
        /**
         * @stability stable
         */
        get architectures(): string[];
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get codeSigningConfigArn(): string;
        /**
         * @stability stable
         */
        deadLetterConfig(index: string): DataAwsLambdaFunctionDeadLetterConfig;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        environment(index: string): DataAwsLambdaFunctionEnvironment;
        /**
         * @stability stable
         */
        fileSystemConfig(index: string): DataAwsLambdaFunctionFileSystemConfig;
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get handler(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get invokeArn(): string;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string;
        /**
         * @stability stable
         */
        get lastModified(): string;
        /**
         * @stability stable
         */
        get layers(): string[];
        /**
         * @stability stable
         */
        get memorySize(): number;
        /**
         * @stability stable
         */
        get qualifiedArn(): string;
        private _qualifier?;
        /**
         * @stability stable
         */
        get qualifier(): string | undefined;
        /**
         * @stability stable
         */
        set qualifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetQualifier(): void;
        /**
         * @stability stable
         */
        get qualifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get reservedConcurrentExecutions(): number;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        get runtime(): string;
        /**
         * @stability stable
         */
        get signingJobArn(): string;
        /**
         * @stability stable
         */
        get signingProfileVersionArn(): string;
        /**
         * @stability stable
         */
        get sourceCodeHash(): string;
        /**
         * @stability stable
         */
        get sourceCodeSize(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get timeout(): number;
        /**
         * @stability stable
         */
        tracingConfig(index: string): DataAwsLambdaFunctionTracingConfig;
        /**
         * @stability stable
         */
        get version(): string;
        /**
         * @stability stable
         */
        vpcConfig(index: string): DataAwsLambdaFunctionVpcConfig;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLambdaInvocationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_invocation.html#function_name DataAwsLambdaInvocation#function_name}.
         *
         * @stability stable
         */
        readonly functionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_invocation.html#input DataAwsLambdaInvocation#input}.
         *
         * @stability stable
         */
        readonly input: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_invocation.html#qualifier DataAwsLambdaInvocation#qualifier}.
         *
         * @stability stable
         */
        readonly qualifier?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lambda_invocation.html aws_lambda_invocation}.
     *
     * @stability stable
     */
    class DataAwsLambdaInvocation extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lambda_invocation.html aws_lambda_invocation} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLambdaInvocationConfig);
        private _functionName?;
        /**
         * @stability stable
         */
        get functionName(): string;
        /**
         * @stability stable
         */
        set functionName(value: string);
        /**
         * @stability stable
         */
        get functionNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _input?;
        /**
         * @stability stable
         */
        get input(): string;
        /**
         * @stability stable
         */
        set input(value: string);
        /**
         * @stability stable
         */
        get inputInput(): string | undefined;
        private _qualifier?;
        /**
         * @stability stable
         */
        get qualifier(): string | undefined;
        /**
         * @stability stable
         */
        set qualifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetQualifier(): void;
        /**
         * @stability stable
         */
        get qualifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get result(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLambdaLayerVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_layer_version.html#compatible_architecture DataAwsLambdaLayerVersion#compatible_architecture}.
         *
         * @stability stable
         */
        readonly compatibleArchitecture?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_layer_version.html#compatible_runtime DataAwsLambdaLayerVersion#compatible_runtime}.
         *
         * @stability stable
         */
        readonly compatibleRuntime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_layer_version.html#layer_name DataAwsLambdaLayerVersion#layer_name}.
         *
         * @stability stable
         */
        readonly layerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lambda_layer_version.html#version DataAwsLambdaLayerVersion#version}.
         *
         * @stability stable
         */
        readonly version?: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lambda_layer_version.html aws_lambda_layer_version}.
     *
     * @stability stable
     */
    class DataAwsLambdaLayerVersion extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lambda_layer_version.html aws_lambda_layer_version} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsLambdaLayerVersionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _compatibleArchitecture?;
        /**
         * @stability stable
         */
        get compatibleArchitecture(): string | undefined;
        /**
         * @stability stable
         */
        set compatibleArchitecture(value: string | undefined);
        /**
         * @stability stable
         */
        resetCompatibleArchitecture(): void;
        /**
         * @stability stable
         */
        get compatibleArchitectureInput(): string | undefined;
        /**
         * @stability stable
         */
        get compatibleArchitectures(): string[];
        private _compatibleRuntime?;
        /**
         * @stability stable
         */
        get compatibleRuntime(): string | undefined;
        /**
         * @stability stable
         */
        set compatibleRuntime(value: string | undefined);
        /**
         * @stability stable
         */
        resetCompatibleRuntime(): void;
        /**
         * @stability stable
         */
        get compatibleRuntimeInput(): string | undefined;
        /**
         * @stability stable
         */
        get compatibleRuntimes(): string[];
        /**
         * @stability stable
         */
        get createdDate(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get layerArn(): string;
        private _layerName?;
        /**
         * @stability stable
         */
        get layerName(): string;
        /**
         * @stability stable
         */
        set layerName(value: string);
        /**
         * @stability stable
         */
        get layerNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get licenseInfo(): string;
        /**
         * @stability stable
         */
        get signingJobArn(): string;
        /**
         * @stability stable
         */
        get signingProfileVersionArn(): string;
        /**
         * @stability stable
         */
        get sourceCodeHash(): string;
        /**
         * @stability stable
         */
        get sourceCodeSize(): number;
        private _version?;
        /**
         * @stability stable
         */
        get version(): number | undefined;
        /**
         * @stability stable
         */
        set version(value: number | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): number | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
