import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Lightsail
*/
export declare namespace Lightsail {
    /**
     * @stability stable
     */
    interface LightsailDomainConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_domain.html#domain_name LightsailDomain#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_domain.html aws_lightsail_domain}.
     *
     * @stability stable
     */
    class LightsailDomain extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_domain.html aws_lightsail_domain} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LightsailDomainConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LightsailInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#availability_zone LightsailInstance#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#blueprint_id LightsailInstance#blueprint_id}.
         *
         * @stability stable
         */
        readonly blueprintId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#bundle_id LightsailInstance#bundle_id}.
         *
         * @stability stable
         */
        readonly bundleId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#key_pair_name LightsailInstance#key_pair_name}.
         *
         * @stability stable
         */
        readonly keyPairName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#name LightsailInstance#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#tags LightsailInstance#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#tags_all LightsailInstance#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html#user_data LightsailInstance#user_data}.
         *
         * @stability stable
         */
        readonly userData?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html aws_lightsail_instance}.
     *
     * @stability stable
     */
    class LightsailInstance extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance.html aws_lightsail_instance} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LightsailInstanceConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        /**
         * @stability stable
         */
        set availabilityZone(value: string);
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _blueprintId?;
        /**
         * @stability stable
         */
        get blueprintId(): string;
        /**
         * @stability stable
         */
        set blueprintId(value: string);
        /**
         * @stability stable
         */
        get blueprintIdInput(): string | undefined;
        private _bundleId?;
        /**
         * @stability stable
         */
        get bundleId(): string;
        /**
         * @stability stable
         */
        set bundleId(value: string);
        /**
         * @stability stable
         */
        get bundleIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get cpuCount(): number;
        /**
         * @stability stable
         */
        get createdAt(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipv6Address(): string;
        /**
         * @stability stable
         */
        get ipv6Addresses(): string[];
        /**
         * @stability stable
         */
        get isStaticIp(): any;
        private _keyPairName?;
        /**
         * @stability stable
         */
        get keyPairName(): string | undefined;
        /**
         * @stability stable
         */
        set keyPairName(value: string | undefined);
        /**
         * @stability stable
         */
        resetKeyPairName(): void;
        /**
         * @stability stable
         */
        get keyPairNameInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get privateIpAddress(): string;
        /**
         * @stability stable
         */
        get publicIpAddress(): string;
        /**
         * @stability stable
         */
        get ramSize(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _userData?;
        /**
         * @stability stable
         */
        get userData(): string | undefined;
        /**
         * @stability stable
         */
        set userData(value: string | undefined);
        /**
         * @stability stable
         */
        resetUserData(): void;
        /**
         * @stability stable
         */
        get userDataInput(): string | undefined;
        /**
         * @stability stable
         */
        get username(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LightsailInstancePublicPortsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html#instance_name LightsailInstancePublicPorts#instance_name}.
         *
         * @stability stable
         */
        readonly instanceName: string;
        /**
         * port_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html#port_info LightsailInstancePublicPorts#port_info}
         *
         * @stability stable
         */
        readonly portInfo: LightsailInstancePublicPortsPortInfo[];
    }
    /**
     * @stability stable
     */
    interface LightsailInstancePublicPortsPortInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html#cidrs LightsailInstancePublicPorts#cidrs}.
         *
         * @stability stable
         */
        readonly cidrs?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html#from_port LightsailInstancePublicPorts#from_port}.
         *
         * @stability stable
         */
        readonly fromPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html#protocol LightsailInstancePublicPorts#protocol}.
         *
         * @stability stable
         */
        readonly protocol: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html#to_port LightsailInstancePublicPorts#to_port}.
         *
         * @stability stable
         */
        readonly toPort: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html aws_lightsail_instance_public_ports}.
     *
     * @stability stable
     */
    class LightsailInstancePublicPorts extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_instance_public_ports.html aws_lightsail_instance_public_ports} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LightsailInstancePublicPortsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceName?;
        /**
         * @stability stable
         */
        get instanceName(): string;
        /**
         * @stability stable
         */
        set instanceName(value: string);
        /**
         * @stability stable
         */
        get instanceNameInput(): string | undefined;
        private _portInfo?;
        /**
         * @stability stable
         */
        get portInfo(): LightsailInstancePublicPortsPortInfo[];
        /**
         * @stability stable
         */
        set portInfo(value: LightsailInstancePublicPortsPortInfo[]);
        /**
         * @stability stable
         */
        get portInfoInput(): LightsailInstancePublicPortsPortInfo[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LightsailKeyPairConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_key_pair.html#name LightsailKeyPair#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_key_pair.html#name_prefix LightsailKeyPair#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_key_pair.html#pgp_key LightsailKeyPair#pgp_key}.
         *
         * @stability stable
         */
        readonly pgpKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_key_pair.html#public_key LightsailKeyPair#public_key}.
         *
         * @stability stable
         */
        readonly publicKey?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_key_pair.html aws_lightsail_key_pair}.
     *
     * @stability stable
     */
    class LightsailKeyPair extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_key_pair.html aws_lightsail_key_pair} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: LightsailKeyPairConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get encryptedFingerprint(): string;
        /**
         * @stability stable
         */
        get encryptedPrivateKey(): string;
        /**
         * @stability stable
         */
        get fingerprint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _pgpKey?;
        /**
         * @stability stable
         */
        get pgpKey(): string | undefined;
        /**
         * @stability stable
         */
        set pgpKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetPgpKey(): void;
        /**
         * @stability stable
         */
        get pgpKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get privateKey(): string;
        private _publicKey?;
        /**
         * @stability stable
         */
        get publicKey(): string | undefined;
        /**
         * @stability stable
         */
        set publicKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetPublicKey(): void;
        /**
         * @stability stable
         */
        get publicKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LightsailStaticIpConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_static_ip.html#name LightsailStaticIp#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_static_ip.html aws_lightsail_static_ip}.
     *
     * @stability stable
     */
    class LightsailStaticIp extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_static_ip.html aws_lightsail_static_ip} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LightsailStaticIpConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipAddress(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get supportCode(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LightsailStaticIpAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_static_ip_attachment.html#instance_name LightsailStaticIpAttachment#instance_name}.
         *
         * @stability stable
         */
        readonly instanceName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lightsail_static_ip_attachment.html#static_ip_name LightsailStaticIpAttachment#static_ip_name}.
         *
         * @stability stable
         */
        readonly staticIpName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lightsail_static_ip_attachment.html aws_lightsail_static_ip_attachment}.
     *
     * @stability stable
     */
    class LightsailStaticIpAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lightsail_static_ip_attachment.html aws_lightsail_static_ip_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LightsailStaticIpAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceName?;
        /**
         * @stability stable
         */
        get instanceName(): string;
        /**
         * @stability stable
         */
        set instanceName(value: string);
        /**
         * @stability stable
         */
        get instanceNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get ipAddress(): string;
        private _staticIpName?;
        /**
         * @stability stable
         */
        get staticIpName(): string;
        /**
         * @stability stable
         */
        set staticIpName(value: string);
        /**
         * @stability stable
         */
        get staticIpNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
