import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Managed Streaming for Kafka
*/
export declare namespace MSK {
    /**
     * @stability stable
     */
    interface MskClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#cluster_name MskCluster#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#enhanced_monitoring MskCluster#enhanced_monitoring}.
         *
         * @stability stable
         */
        readonly enhancedMonitoring?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#kafka_version MskCluster#kafka_version}.
         *
         * @stability stable
         */
        readonly kafkaVersion: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#number_of_broker_nodes MskCluster#number_of_broker_nodes}.
         *
         * @stability stable
         */
        readonly numberOfBrokerNodes: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#tags MskCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#tags_all MskCluster#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * broker_node_group_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#broker_node_group_info MskCluster#broker_node_group_info}
         *
         * @stability stable
         */
        readonly brokerNodeGroupInfo: MskClusterBrokerNodeGroupInfo;
        /**
         * client_authentication block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#client_authentication MskCluster#client_authentication}
         *
         * @stability stable
         */
        readonly clientAuthentication?: MskClusterClientAuthentication;
        /**
         * configuration_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#configuration_info MskCluster#configuration_info}
         *
         * @stability stable
         */
        readonly configurationInfo?: MskClusterConfigurationInfo;
        /**
         * encryption_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#encryption_info MskCluster#encryption_info}
         *
         * @stability stable
         */
        readonly encryptionInfo?: MskClusterEncryptionInfo;
        /**
         * logging_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#logging_info MskCluster#logging_info}
         *
         * @stability stable
         */
        readonly loggingInfo?: MskClusterLoggingInfo;
        /**
         * open_monitoring block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#open_monitoring MskCluster#open_monitoring}
         *
         * @stability stable
         */
        readonly openMonitoring?: MskClusterOpenMonitoring;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#timeouts MskCluster#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: MskClusterTimeouts;
    }
    /**
     * @stability stable
     */
    interface MskClusterBrokerNodeGroupInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#az_distribution MskCluster#az_distribution}.
         *
         * @stability stable
         */
        readonly azDistribution?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#client_subnets MskCluster#client_subnets}.
         *
         * @stability stable
         */
        readonly clientSubnets: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#ebs_volume_size MskCluster#ebs_volume_size}.
         *
         * @stability stable
         */
        readonly ebsVolumeSize: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#instance_type MskCluster#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#security_groups MskCluster#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups: string[];
    }
    /**
     * @stability stable
     */
    class MskClusterBrokerNodeGroupInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _azDistribution?;
        /**
         * @stability stable
         */
        get azDistribution(): string | undefined;
        /**
         * @stability stable
         */
        set azDistribution(value: string | undefined);
        /**
         * @stability stable
         */
        resetAzDistribution(): void;
        /**
         * @stability stable
         */
        get azDistributionInput(): string | undefined;
        private _clientSubnets?;
        /**
         * @stability stable
         */
        get clientSubnets(): string[];
        /**
         * @stability stable
         */
        set clientSubnets(value: string[]);
        /**
         * @stability stable
         */
        get clientSubnetsInput(): string[] | undefined;
        private _ebsVolumeSize?;
        /**
         * @stability stable
         */
        get ebsVolumeSize(): number;
        /**
         * @stability stable
         */
        set ebsVolumeSize(value: number);
        /**
         * @stability stable
         */
        get ebsVolumeSizeInput(): number | undefined;
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string;
        /**
         * @stability stable
         */
        set instanceType(value: string);
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[];
        /**
         * @stability stable
         */
        set securityGroups(value: string[]);
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterClientAuthenticationSasl {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#iam MskCluster#iam}.
         *
         * @stability stable
         */
        readonly iam?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#scram MskCluster#scram}.
         *
         * @stability stable
         */
        readonly scram?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class MskClusterClientAuthenticationSaslOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _iam?;
        /**
         * @stability stable
         */
        get iam(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set iam(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIam(): void;
        /**
         * @stability stable
         */
        get iamInput(): boolean | cdktf.IResolvable | undefined;
        private _scram?;
        /**
         * @stability stable
         */
        get scram(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set scram(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetScram(): void;
        /**
         * @stability stable
         */
        get scramInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterClientAuthenticationTls {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#certificate_authority_arns MskCluster#certificate_authority_arns}.
         *
         * @stability stable
         */
        readonly certificateAuthorityArns?: string[];
    }
    /**
     * @stability stable
     */
    class MskClusterClientAuthenticationTlsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _certificateAuthorityArns?;
        /**
         * @stability stable
         */
        get certificateAuthorityArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set certificateAuthorityArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCertificateAuthorityArns(): void;
        /**
         * @stability stable
         */
        get certificateAuthorityArnsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterClientAuthentication {
        /**
         * sasl block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#sasl MskCluster#sasl}
         *
         * @stability stable
         */
        readonly sasl?: MskClusterClientAuthenticationSasl;
        /**
         * tls block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#tls MskCluster#tls}
         *
         * @stability stable
         */
        readonly tls?: MskClusterClientAuthenticationTls;
    }
    /**
     * @stability stable
     */
    class MskClusterClientAuthenticationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _sasl?;
        private __saslOutput;
        /**
         * @stability stable
         */
        get sasl(): MskClusterClientAuthenticationSaslOutputReference;
        /**
         * @stability stable
         */
        putSasl(value: MskClusterClientAuthenticationSasl | undefined): void;
        /**
         * @stability stable
         */
        resetSasl(): void;
        /**
         * @stability stable
         */
        get saslInput(): MskClusterClientAuthenticationSasl | undefined;
        private _tls?;
        private __tlsOutput;
        /**
         * @stability stable
         */
        get tls(): MskClusterClientAuthenticationTlsOutputReference;
        /**
         * @stability stable
         */
        putTls(value: MskClusterClientAuthenticationTls | undefined): void;
        /**
         * @stability stable
         */
        resetTls(): void;
        /**
         * @stability stable
         */
        get tlsInput(): MskClusterClientAuthenticationTls | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterConfigurationInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#arn MskCluster#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#revision MskCluster#revision}.
         *
         * @stability stable
         */
        readonly revision: number;
    }
    /**
     * @stability stable
     */
    class MskClusterConfigurationInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _arn?;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        set arn(value: string);
        /**
         * @stability stable
         */
        get arnInput(): string | undefined;
        private _revision?;
        /**
         * @stability stable
         */
        get revision(): number;
        /**
         * @stability stable
         */
        set revision(value: number);
        /**
         * @stability stable
         */
        get revisionInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterEncryptionInfoEncryptionInTransit {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#client_broker MskCluster#client_broker}.
         *
         * @stability stable
         */
        readonly clientBroker?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#in_cluster MskCluster#in_cluster}.
         *
         * @stability stable
         */
        readonly inCluster?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class MskClusterEncryptionInfoEncryptionInTransitOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _clientBroker?;
        /**
         * @stability stable
         */
        get clientBroker(): string | undefined;
        /**
         * @stability stable
         */
        set clientBroker(value: string | undefined);
        /**
         * @stability stable
         */
        resetClientBroker(): void;
        /**
         * @stability stable
         */
        get clientBrokerInput(): string | undefined;
        private _inCluster?;
        /**
         * @stability stable
         */
        get inCluster(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set inCluster(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInCluster(): void;
        /**
         * @stability stable
         */
        get inClusterInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterEncryptionInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#encryption_at_rest_kms_key_arn MskCluster#encryption_at_rest_kms_key_arn}.
         *
         * @stability stable
         */
        readonly encryptionAtRestKmsKeyArn?: string;
        /**
         * encryption_in_transit block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#encryption_in_transit MskCluster#encryption_in_transit}
         *
         * @stability stable
         */
        readonly encryptionInTransit?: MskClusterEncryptionInfoEncryptionInTransit;
    }
    /**
     * @stability stable
     */
    class MskClusterEncryptionInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _encryptionAtRestKmsKeyArn?;
        /**
         * @stability stable
         */
        get encryptionAtRestKmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set encryptionAtRestKmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetEncryptionAtRestKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get encryptionAtRestKmsKeyArnInput(): string | undefined;
        private _encryptionInTransit?;
        private __encryptionInTransitOutput;
        /**
         * @stability stable
         */
        get encryptionInTransit(): MskClusterEncryptionInfoEncryptionInTransitOutputReference;
        /**
         * @stability stable
         */
        putEncryptionInTransit(value: MskClusterEncryptionInfoEncryptionInTransit | undefined): void;
        /**
         * @stability stable
         */
        resetEncryptionInTransit(): void;
        /**
         * @stability stable
         */
        get encryptionInTransitInput(): MskClusterEncryptionInfoEncryptionInTransit | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterLoggingInfoBrokerLogsCloudwatchLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#enabled MskCluster#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#log_group MskCluster#log_group}.
         *
         * @stability stable
         */
        readonly logGroup?: string;
    }
    /**
     * @stability stable
     */
    class MskClusterLoggingInfoBrokerLogsCloudwatchLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _logGroup?;
        /**
         * @stability stable
         */
        get logGroup(): string | undefined;
        /**
         * @stability stable
         */
        set logGroup(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogGroup(): void;
        /**
         * @stability stable
         */
        get logGroupInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterLoggingInfoBrokerLogsFirehose {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#delivery_stream MskCluster#delivery_stream}.
         *
         * @stability stable
         */
        readonly deliveryStream?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#enabled MskCluster#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class MskClusterLoggingInfoBrokerLogsFirehoseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _deliveryStream?;
        /**
         * @stability stable
         */
        get deliveryStream(): string | undefined;
        /**
         * @stability stable
         */
        set deliveryStream(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeliveryStream(): void;
        /**
         * @stability stable
         */
        get deliveryStreamInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterLoggingInfoBrokerLogsS3 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#bucket MskCluster#bucket}.
         *
         * @stability stable
         */
        readonly bucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#enabled MskCluster#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#prefix MskCluster#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
    }
    /**
     * @stability stable
     */
    class MskClusterLoggingInfoBrokerLogsS3OutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string | undefined;
        /**
         * @stability stable
         */
        set bucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucket(): void;
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterLoggingInfoBrokerLogs {
        /**
         * cloudwatch_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#cloudwatch_logs MskCluster#cloudwatch_logs}
         *
         * @stability stable
         */
        readonly cloudwatchLogs?: MskClusterLoggingInfoBrokerLogsCloudwatchLogs;
        /**
         * firehose block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#firehose MskCluster#firehose}
         *
         * @stability stable
         */
        readonly firehose?: MskClusterLoggingInfoBrokerLogsFirehose;
        /**
         * s3 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#s3 MskCluster#s3}
         *
         * @stability stable
         */
        readonly s3?: MskClusterLoggingInfoBrokerLogsS3;
    }
    /**
     * @stability stable
     */
    class MskClusterLoggingInfoBrokerLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cloudwatchLogs?;
        private __cloudwatchLogsOutput;
        /**
         * @stability stable
         */
        get cloudwatchLogs(): MskClusterLoggingInfoBrokerLogsCloudwatchLogsOutputReference;
        /**
         * @stability stable
         */
        putCloudwatchLogs(value: MskClusterLoggingInfoBrokerLogsCloudwatchLogs | undefined): void;
        /**
         * @stability stable
         */
        resetCloudwatchLogs(): void;
        /**
         * @stability stable
         */
        get cloudwatchLogsInput(): MskClusterLoggingInfoBrokerLogsCloudwatchLogs | undefined;
        private _firehose?;
        private __firehoseOutput;
        /**
         * @stability stable
         */
        get firehose(): MskClusterLoggingInfoBrokerLogsFirehoseOutputReference;
        /**
         * @stability stable
         */
        putFirehose(value: MskClusterLoggingInfoBrokerLogsFirehose | undefined): void;
        /**
         * @stability stable
         */
        resetFirehose(): void;
        /**
         * @stability stable
         */
        get firehoseInput(): MskClusterLoggingInfoBrokerLogsFirehose | undefined;
        private _s3?;
        private __s3Output;
        /**
         * @stability stable
         */
        get s3(): MskClusterLoggingInfoBrokerLogsS3OutputReference;
        /**
         * @stability stable
         */
        putS3(value: MskClusterLoggingInfoBrokerLogsS3 | undefined): void;
        /**
         * @stability stable
         */
        resetS3(): void;
        /**
         * @stability stable
         */
        get s3Input(): MskClusterLoggingInfoBrokerLogsS3 | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterLoggingInfo {
        /**
         * broker_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#broker_logs MskCluster#broker_logs}
         *
         * @stability stable
         */
        readonly brokerLogs: MskClusterLoggingInfoBrokerLogs;
    }
    /**
     * @stability stable
     */
    class MskClusterLoggingInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _brokerLogs?;
        private __brokerLogsOutput;
        /**
         * @stability stable
         */
        get brokerLogs(): MskClusterLoggingInfoBrokerLogsOutputReference;
        /**
         * @stability stable
         */
        putBrokerLogs(value: MskClusterLoggingInfoBrokerLogs): void;
        /**
         * @stability stable
         */
        get brokerLogsInput(): MskClusterLoggingInfoBrokerLogs | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterOpenMonitoringPrometheusJmxExporter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#enabled_in_broker MskCluster#enabled_in_broker}.
         *
         * @stability stable
         */
        readonly enabledInBroker: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class MskClusterOpenMonitoringPrometheusJmxExporterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabledInBroker?;
        /**
         * @stability stable
         */
        get enabledInBroker(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabledInBroker(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInBrokerInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterOpenMonitoringPrometheusNodeExporter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#enabled_in_broker MskCluster#enabled_in_broker}.
         *
         * @stability stable
         */
        readonly enabledInBroker: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class MskClusterOpenMonitoringPrometheusNodeExporterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabledInBroker?;
        /**
         * @stability stable
         */
        get enabledInBroker(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabledInBroker(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInBrokerInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterOpenMonitoringPrometheus {
        /**
         * jmx_exporter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#jmx_exporter MskCluster#jmx_exporter}
         *
         * @stability stable
         */
        readonly jmxExporter?: MskClusterOpenMonitoringPrometheusJmxExporter;
        /**
         * node_exporter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#node_exporter MskCluster#node_exporter}
         *
         * @stability stable
         */
        readonly nodeExporter?: MskClusterOpenMonitoringPrometheusNodeExporter;
    }
    /**
     * @stability stable
     */
    class MskClusterOpenMonitoringPrometheusOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _jmxExporter?;
        private __jmxExporterOutput;
        /**
         * @stability stable
         */
        get jmxExporter(): MskClusterOpenMonitoringPrometheusJmxExporterOutputReference;
        /**
         * @stability stable
         */
        putJmxExporter(value: MskClusterOpenMonitoringPrometheusJmxExporter | undefined): void;
        /**
         * @stability stable
         */
        resetJmxExporter(): void;
        /**
         * @stability stable
         */
        get jmxExporterInput(): MskClusterOpenMonitoringPrometheusJmxExporter | undefined;
        private _nodeExporter?;
        private __nodeExporterOutput;
        /**
         * @stability stable
         */
        get nodeExporter(): MskClusterOpenMonitoringPrometheusNodeExporterOutputReference;
        /**
         * @stability stable
         */
        putNodeExporter(value: MskClusterOpenMonitoringPrometheusNodeExporter | undefined): void;
        /**
         * @stability stable
         */
        resetNodeExporter(): void;
        /**
         * @stability stable
         */
        get nodeExporterInput(): MskClusterOpenMonitoringPrometheusNodeExporter | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterOpenMonitoring {
        /**
         * prometheus block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#prometheus MskCluster#prometheus}
         *
         * @stability stable
         */
        readonly prometheus: MskClusterOpenMonitoringPrometheus;
    }
    /**
     * @stability stable
     */
    class MskClusterOpenMonitoringOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _prometheus?;
        private __prometheusOutput;
        /**
         * @stability stable
         */
        get prometheus(): MskClusterOpenMonitoringPrometheusOutputReference;
        /**
         * @stability stable
         */
        putPrometheus(value: MskClusterOpenMonitoringPrometheus): void;
        /**
         * @stability stable
         */
        get prometheusInput(): MskClusterOpenMonitoringPrometheus | undefined;
    }
    /**
     * @stability stable
     */
    interface MskClusterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#create MskCluster#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#delete MskCluster#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html#update MskCluster#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class MskClusterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html aws_msk_cluster}.
     *
     * @stability stable
     */
    class MskCluster extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/msk_cluster.html aws_msk_cluster} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: MskClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokers(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokersSaslIam(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokersSaslScram(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokersTls(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get currentVersion(): string;
        private _enhancedMonitoring?;
        /**
         * @stability stable
         */
        get enhancedMonitoring(): string | undefined;
        /**
         * @stability stable
         */
        set enhancedMonitoring(value: string | undefined);
        /**
         * @stability stable
         */
        resetEnhancedMonitoring(): void;
        /**
         * @stability stable
         */
        get enhancedMonitoringInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kafkaVersion?;
        /**
         * @stability stable
         */
        get kafkaVersion(): string;
        /**
         * @stability stable
         */
        set kafkaVersion(value: string);
        /**
         * @stability stable
         */
        get kafkaVersionInput(): string | undefined;
        private _numberOfBrokerNodes?;
        /**
         * @stability stable
         */
        get numberOfBrokerNodes(): number;
        /**
         * @stability stable
         */
        set numberOfBrokerNodes(value: number);
        /**
         * @stability stable
         */
        get numberOfBrokerNodesInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get zookeeperConnectString(): string;
        /**
         * @stability stable
         */
        get zookeeperConnectStringTls(): string;
        private _brokerNodeGroupInfo?;
        private __brokerNodeGroupInfoOutput;
        /**
         * @stability stable
         */
        get brokerNodeGroupInfo(): MskClusterBrokerNodeGroupInfoOutputReference;
        /**
         * @stability stable
         */
        putBrokerNodeGroupInfo(value: MskClusterBrokerNodeGroupInfo): void;
        /**
         * @stability stable
         */
        get brokerNodeGroupInfoInput(): MskClusterBrokerNodeGroupInfo | undefined;
        private _clientAuthentication?;
        private __clientAuthenticationOutput;
        /**
         * @stability stable
         */
        get clientAuthentication(): MskClusterClientAuthenticationOutputReference;
        /**
         * @stability stable
         */
        putClientAuthentication(value: MskClusterClientAuthentication | undefined): void;
        /**
         * @stability stable
         */
        resetClientAuthentication(): void;
        /**
         * @stability stable
         */
        get clientAuthenticationInput(): MskClusterClientAuthentication | undefined;
        private _configurationInfo?;
        private __configurationInfoOutput;
        /**
         * @stability stable
         */
        get configurationInfo(): MskClusterConfigurationInfoOutputReference;
        /**
         * @stability stable
         */
        putConfigurationInfo(value: MskClusterConfigurationInfo | undefined): void;
        /**
         * @stability stable
         */
        resetConfigurationInfo(): void;
        /**
         * @stability stable
         */
        get configurationInfoInput(): MskClusterConfigurationInfo | undefined;
        private _encryptionInfo?;
        private __encryptionInfoOutput;
        /**
         * @stability stable
         */
        get encryptionInfo(): MskClusterEncryptionInfoOutputReference;
        /**
         * @stability stable
         */
        putEncryptionInfo(value: MskClusterEncryptionInfo | undefined): void;
        /**
         * @stability stable
         */
        resetEncryptionInfo(): void;
        /**
         * @stability stable
         */
        get encryptionInfoInput(): MskClusterEncryptionInfo | undefined;
        private _loggingInfo?;
        private __loggingInfoOutput;
        /**
         * @stability stable
         */
        get loggingInfo(): MskClusterLoggingInfoOutputReference;
        /**
         * @stability stable
         */
        putLoggingInfo(value: MskClusterLoggingInfo | undefined): void;
        /**
         * @stability stable
         */
        resetLoggingInfo(): void;
        /**
         * @stability stable
         */
        get loggingInfoInput(): MskClusterLoggingInfo | undefined;
        private _openMonitoring?;
        private __openMonitoringOutput;
        /**
         * @stability stable
         */
        get openMonitoring(): MskClusterOpenMonitoringOutputReference;
        /**
         * @stability stable
         */
        putOpenMonitoring(value: MskClusterOpenMonitoring | undefined): void;
        /**
         * @stability stable
         */
        resetOpenMonitoring(): void;
        /**
         * @stability stable
         */
        get openMonitoringInput(): MskClusterOpenMonitoring | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): MskClusterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: MskClusterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): MskClusterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface MskConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_configuration.html#description MskConfiguration#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_configuration.html#kafka_versions MskConfiguration#kafka_versions}.
         *
         * @stability stable
         */
        readonly kafkaVersions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_configuration.html#name MskConfiguration#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_configuration.html#server_properties MskConfiguration#server_properties}.
         *
         * @stability stable
         */
        readonly serverProperties: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/msk_configuration.html aws_msk_configuration}.
     *
     * @stability stable
     */
    class MskConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/msk_configuration.html aws_msk_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: MskConfigurationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kafkaVersions?;
        /**
         * @stability stable
         */
        get kafkaVersions(): string[] | undefined;
        /**
         * @stability stable
         */
        set kafkaVersions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetKafkaVersions(): void;
        /**
         * @stability stable
         */
        get kafkaVersionsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get latestRevision(): number;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _serverProperties?;
        /**
         * @stability stable
         */
        get serverProperties(): string;
        /**
         * @stability stable
         */
        set serverProperties(value: string);
        /**
         * @stability stable
         */
        get serverPropertiesInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface MskScramSecretAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_scram_secret_association.html#cluster_arn MskScramSecretAssociation#cluster_arn}.
         *
         * @stability stable
         */
        readonly clusterArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/msk_scram_secret_association.html#secret_arn_list MskScramSecretAssociation#secret_arn_list}.
         *
         * @stability stable
         */
        readonly secretArnList: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/msk_scram_secret_association.html aws_msk_scram_secret_association}.
     *
     * @stability stable
     */
    class MskScramSecretAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/msk_scram_secret_association.html aws_msk_scram_secret_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: MskScramSecretAssociationConfig);
        private _clusterArn?;
        /**
         * @stability stable
         */
        get clusterArn(): string;
        /**
         * @stability stable
         */
        set clusterArn(value: string);
        /**
         * @stability stable
         */
        get clusterArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _secretArnList?;
        /**
         * @stability stable
         */
        get secretArnList(): string[];
        /**
         * @stability stable
         */
        set secretArnList(value: string[]);
        /**
         * @stability stable
         */
        get secretArnListInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsMskBrokerNodesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/msk_broker_nodes.html#cluster_arn DataAwsMskBrokerNodes#cluster_arn}.
         *
         * @stability stable
         */
        readonly clusterArn: string;
    }
    /**
     * @stability stable
     */
    class DataAwsMskBrokerNodesNodeInfoList extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get attachedEniId(): string;
        /**
         * @stability stable
         */
        get brokerId(): number;
        /**
         * @stability stable
         */
        get clientSubnet(): string;
        /**
         * @stability stable
         */
        get clientVpcIpAddress(): string;
        /**
         * @stability stable
         */
        get endpoints(): string[];
        /**
         * @stability stable
         */
        get nodeArn(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/msk_broker_nodes.html aws_msk_broker_nodes}.
     *
     * @stability stable
     */
    class DataAwsMskBrokerNodes extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/msk_broker_nodes.html aws_msk_broker_nodes} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsMskBrokerNodesConfig);
        private _clusterArn?;
        /**
         * @stability stable
         */
        get clusterArn(): string;
        /**
         * @stability stable
         */
        set clusterArn(value: string);
        /**
         * @stability stable
         */
        get clusterArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        nodeInfoList(index: string): DataAwsMskBrokerNodesNodeInfoList;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsMskClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/msk_cluster.html#cluster_name DataAwsMskCluster#cluster_name}.
         *
         * @stability stable
         */
        readonly clusterName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/msk_cluster.html#tags DataAwsMskCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/msk_cluster.html aws_msk_cluster}.
     *
     * @stability stable
     */
    class DataAwsMskCluster extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/msk_cluster.html aws_msk_cluster} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsMskClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokers(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokersSaslIam(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokersSaslScram(): string;
        /**
         * @stability stable
         */
        get bootstrapBrokersTls(): string;
        private _clusterName?;
        /**
         * @stability stable
         */
        get clusterName(): string;
        /**
         * @stability stable
         */
        set clusterName(value: string);
        /**
         * @stability stable
         */
        get clusterNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kafkaVersion(): string;
        /**
         * @stability stable
         */
        get numberOfBrokerNodes(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get zookeeperConnectString(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsMskConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/msk_configuration.html#name DataAwsMskConfiguration#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/msk_configuration.html aws_msk_configuration}.
     *
     * @stability stable
     */
    class DataAwsMskConfiguration extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/msk_configuration.html aws_msk_configuration} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsMskConfigurationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kafkaVersions(): string[];
        /**
         * @stability stable
         */
        get latestRevision(): number;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get serverProperties(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsMskKafkaVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/msk_kafka_version.html#preferred_versions DataAwsMskKafkaVersion#preferred_versions}.
         *
         * @stability stable
         */
        readonly preferredVersions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/msk_kafka_version.html#version DataAwsMskKafkaVersion#version}.
         *
         * @stability stable
         */
        readonly version?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/msk_kafka_version.html aws_msk_kafka_version}.
     *
     * @stability stable
     */
    class DataAwsMskKafkaVersion extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/msk_kafka_version.html aws_msk_kafka_version} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsMskKafkaVersionConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _preferredVersions?;
        /**
         * @stability stable
         */
        get preferredVersions(): string[] | undefined;
        /**
         * @stability stable
         */
        set preferredVersions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPreferredVersions(): void;
        /**
         * @stability stable
         */
        get preferredVersionsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
