import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Managed Workloads for Apache Airflow
*/
export declare namespace MWAA {
    /**
     * @stability stable
     */
    interface MwaaEnvironmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#airflow_configuration_options MwaaEnvironment#airflow_configuration_options}.
         *
         * @stability stable
         */
        readonly airflowConfigurationOptions?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#airflow_version MwaaEnvironment#airflow_version}.
         *
         * @stability stable
         */
        readonly airflowVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#dag_s3_path MwaaEnvironment#dag_s3_path}.
         *
         * @stability stable
         */
        readonly dagS3Path: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#environment_class MwaaEnvironment#environment_class}.
         *
         * @stability stable
         */
        readonly environmentClass?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#execution_role_arn MwaaEnvironment#execution_role_arn}.
         *
         * @stability stable
         */
        readonly executionRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#kms_key MwaaEnvironment#kms_key}.
         *
         * @stability stable
         */
        readonly kmsKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#max_workers MwaaEnvironment#max_workers}.
         *
         * @stability stable
         */
        readonly maxWorkers?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#min_workers MwaaEnvironment#min_workers}.
         *
         * @stability stable
         */
        readonly minWorkers?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#name MwaaEnvironment#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#plugins_s3_object_version MwaaEnvironment#plugins_s3_object_version}.
         *
         * @stability stable
         */
        readonly pluginsS3ObjectVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#plugins_s3_path MwaaEnvironment#plugins_s3_path}.
         *
         * @stability stable
         */
        readonly pluginsS3Path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#requirements_s3_object_version MwaaEnvironment#requirements_s3_object_version}.
         *
         * @stability stable
         */
        readonly requirementsS3ObjectVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#requirements_s3_path MwaaEnvironment#requirements_s3_path}.
         *
         * @stability stable
         */
        readonly requirementsS3Path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#source_bucket_arn MwaaEnvironment#source_bucket_arn}.
         *
         * @stability stable
         */
        readonly sourceBucketArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#tags MwaaEnvironment#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#tags_all MwaaEnvironment#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#webserver_access_mode MwaaEnvironment#webserver_access_mode}.
         *
         * @stability stable
         */
        readonly webserverAccessMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#weekly_maintenance_window_start MwaaEnvironment#weekly_maintenance_window_start}.
         *
         * @stability stable
         */
        readonly weeklyMaintenanceWindowStart?: string;
        /**
         * logging_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#logging_configuration MwaaEnvironment#logging_configuration}
         *
         * @stability stable
         */
        readonly loggingConfiguration?: MwaaEnvironmentLoggingConfiguration;
        /**
         * network_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#network_configuration MwaaEnvironment#network_configuration}
         *
         * @stability stable
         */
        readonly networkConfiguration: MwaaEnvironmentNetworkConfiguration;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLastUpdatedError extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get errorCode(): string;
        /**
         * @stability stable
         */
        get errorMessage(): string;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLastUpdated extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get createdAt(): string;
        /**
         * @stability stable
         */
        get error(): any;
        /**
         * @stability stable
         */
        get status(): string;
    }
    /**
     * @stability stable
     */
    interface MwaaEnvironmentLoggingConfigurationDagProcessingLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#enabled MwaaEnvironment#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#log_level MwaaEnvironment#log_level}.
         *
         * @stability stable
         */
        readonly logLevel?: string;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLoggingConfigurationDagProcessingLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _logLevel?;
        /**
         * @stability stable
         */
        get logLevel(): string | undefined;
        /**
         * @stability stable
         */
        set logLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogLevel(): void;
        /**
         * @stability stable
         */
        get logLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface MwaaEnvironmentLoggingConfigurationSchedulerLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#enabled MwaaEnvironment#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#log_level MwaaEnvironment#log_level}.
         *
         * @stability stable
         */
        readonly logLevel?: string;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLoggingConfigurationSchedulerLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _logLevel?;
        /**
         * @stability stable
         */
        get logLevel(): string | undefined;
        /**
         * @stability stable
         */
        set logLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogLevel(): void;
        /**
         * @stability stable
         */
        get logLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface MwaaEnvironmentLoggingConfigurationTaskLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#enabled MwaaEnvironment#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#log_level MwaaEnvironment#log_level}.
         *
         * @stability stable
         */
        readonly logLevel?: string;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLoggingConfigurationTaskLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _logLevel?;
        /**
         * @stability stable
         */
        get logLevel(): string | undefined;
        /**
         * @stability stable
         */
        set logLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogLevel(): void;
        /**
         * @stability stable
         */
        get logLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface MwaaEnvironmentLoggingConfigurationWebserverLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#enabled MwaaEnvironment#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#log_level MwaaEnvironment#log_level}.
         *
         * @stability stable
         */
        readonly logLevel?: string;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLoggingConfigurationWebserverLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _logLevel?;
        /**
         * @stability stable
         */
        get logLevel(): string | undefined;
        /**
         * @stability stable
         */
        set logLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogLevel(): void;
        /**
         * @stability stable
         */
        get logLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface MwaaEnvironmentLoggingConfigurationWorkerLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#enabled MwaaEnvironment#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#log_level MwaaEnvironment#log_level}.
         *
         * @stability stable
         */
        readonly logLevel?: string;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLoggingConfigurationWorkerLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _logLevel?;
        /**
         * @stability stable
         */
        get logLevel(): string | undefined;
        /**
         * @stability stable
         */
        set logLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogLevel(): void;
        /**
         * @stability stable
         */
        get logLevelInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface MwaaEnvironmentLoggingConfiguration {
        /**
         * dag_processing_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#dag_processing_logs MwaaEnvironment#dag_processing_logs}
         *
         * @stability stable
         */
        readonly dagProcessingLogs?: MwaaEnvironmentLoggingConfigurationDagProcessingLogs;
        /**
         * scheduler_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#scheduler_logs MwaaEnvironment#scheduler_logs}
         *
         * @stability stable
         */
        readonly schedulerLogs?: MwaaEnvironmentLoggingConfigurationSchedulerLogs;
        /**
         * task_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#task_logs MwaaEnvironment#task_logs}
         *
         * @stability stable
         */
        readonly taskLogs?: MwaaEnvironmentLoggingConfigurationTaskLogs;
        /**
         * webserver_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#webserver_logs MwaaEnvironment#webserver_logs}
         *
         * @stability stable
         */
        readonly webserverLogs?: MwaaEnvironmentLoggingConfigurationWebserverLogs;
        /**
         * worker_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#worker_logs MwaaEnvironment#worker_logs}
         *
         * @stability stable
         */
        readonly workerLogs?: MwaaEnvironmentLoggingConfigurationWorkerLogs;
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentLoggingConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _dagProcessingLogs?;
        private __dagProcessingLogsOutput;
        /**
         * @stability stable
         */
        get dagProcessingLogs(): MwaaEnvironmentLoggingConfigurationDagProcessingLogsOutputReference;
        /**
         * @stability stable
         */
        putDagProcessingLogs(value: MwaaEnvironmentLoggingConfigurationDagProcessingLogs | undefined): void;
        /**
         * @stability stable
         */
        resetDagProcessingLogs(): void;
        /**
         * @stability stable
         */
        get dagProcessingLogsInput(): MwaaEnvironmentLoggingConfigurationDagProcessingLogs | undefined;
        private _schedulerLogs?;
        private __schedulerLogsOutput;
        /**
         * @stability stable
         */
        get schedulerLogs(): MwaaEnvironmentLoggingConfigurationSchedulerLogsOutputReference;
        /**
         * @stability stable
         */
        putSchedulerLogs(value: MwaaEnvironmentLoggingConfigurationSchedulerLogs | undefined): void;
        /**
         * @stability stable
         */
        resetSchedulerLogs(): void;
        /**
         * @stability stable
         */
        get schedulerLogsInput(): MwaaEnvironmentLoggingConfigurationSchedulerLogs | undefined;
        private _taskLogs?;
        private __taskLogsOutput;
        /**
         * @stability stable
         */
        get taskLogs(): MwaaEnvironmentLoggingConfigurationTaskLogsOutputReference;
        /**
         * @stability stable
         */
        putTaskLogs(value: MwaaEnvironmentLoggingConfigurationTaskLogs | undefined): void;
        /**
         * @stability stable
         */
        resetTaskLogs(): void;
        /**
         * @stability stable
         */
        get taskLogsInput(): MwaaEnvironmentLoggingConfigurationTaskLogs | undefined;
        private _webserverLogs?;
        private __webserverLogsOutput;
        /**
         * @stability stable
         */
        get webserverLogs(): MwaaEnvironmentLoggingConfigurationWebserverLogsOutputReference;
        /**
         * @stability stable
         */
        putWebserverLogs(value: MwaaEnvironmentLoggingConfigurationWebserverLogs | undefined): void;
        /**
         * @stability stable
         */
        resetWebserverLogs(): void;
        /**
         * @stability stable
         */
        get webserverLogsInput(): MwaaEnvironmentLoggingConfigurationWebserverLogs | undefined;
        private _workerLogs?;
        private __workerLogsOutput;
        /**
         * @stability stable
         */
        get workerLogs(): MwaaEnvironmentLoggingConfigurationWorkerLogsOutputReference;
        /**
         * @stability stable
         */
        putWorkerLogs(value: MwaaEnvironmentLoggingConfigurationWorkerLogs | undefined): void;
        /**
         * @stability stable
         */
        resetWorkerLogs(): void;
        /**
         * @stability stable
         */
        get workerLogsInput(): MwaaEnvironmentLoggingConfigurationWorkerLogs | undefined;
    }
    /**
     * @stability stable
     */
    interface MwaaEnvironmentNetworkConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#security_group_ids MwaaEnvironment#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html#subnet_ids MwaaEnvironment#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
    }
    /**
     * @stability stable
     */
    class MwaaEnvironmentNetworkConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[];
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[]);
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html aws_mwaa_environment}.
     *
     * @stability stable
     */
    class MwaaEnvironment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/mwaa_environment.html aws_mwaa_environment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: MwaaEnvironmentConfig);
        private _airflowConfigurationOptions?;
        /**
         * @stability stable
         */
        get airflowConfigurationOptions(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set airflowConfigurationOptions(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAirflowConfigurationOptions(): void;
        /**
         * @stability stable
         */
        get airflowConfigurationOptionsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _airflowVersion?;
        /**
         * @stability stable
         */
        get airflowVersion(): string | undefined;
        /**
         * @stability stable
         */
        set airflowVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetAirflowVersion(): void;
        /**
         * @stability stable
         */
        get airflowVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get createdAt(): string;
        private _dagS3Path?;
        /**
         * @stability stable
         */
        get dagS3Path(): string;
        /**
         * @stability stable
         */
        set dagS3Path(value: string);
        /**
         * @stability stable
         */
        get dagS3PathInput(): string | undefined;
        private _environmentClass?;
        /**
         * @stability stable
         */
        get environmentClass(): string | undefined;
        /**
         * @stability stable
         */
        set environmentClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetEnvironmentClass(): void;
        /**
         * @stability stable
         */
        get environmentClassInput(): string | undefined;
        private _executionRoleArn?;
        /**
         * @stability stable
         */
        get executionRoleArn(): string;
        /**
         * @stability stable
         */
        set executionRoleArn(value: string);
        /**
         * @stability stable
         */
        get executionRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKey?;
        /**
         * @stability stable
         */
        get kmsKey(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKey(): void;
        /**
         * @stability stable
         */
        get kmsKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        lastUpdated(index: string): MwaaEnvironmentLastUpdated;
        private _maxWorkers?;
        /**
         * @stability stable
         */
        get maxWorkers(): number | undefined;
        /**
         * @stability stable
         */
        set maxWorkers(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxWorkers(): void;
        /**
         * @stability stable
         */
        get maxWorkersInput(): number | undefined;
        private _minWorkers?;
        /**
         * @stability stable
         */
        get minWorkers(): number | undefined;
        /**
         * @stability stable
         */
        set minWorkers(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinWorkers(): void;
        /**
         * @stability stable
         */
        get minWorkersInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _pluginsS3ObjectVersion?;
        /**
         * @stability stable
         */
        get pluginsS3ObjectVersion(): string | undefined;
        /**
         * @stability stable
         */
        set pluginsS3ObjectVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetPluginsS3ObjectVersion(): void;
        /**
         * @stability stable
         */
        get pluginsS3ObjectVersionInput(): string | undefined;
        private _pluginsS3Path?;
        /**
         * @stability stable
         */
        get pluginsS3Path(): string | undefined;
        /**
         * @stability stable
         */
        set pluginsS3Path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPluginsS3Path(): void;
        /**
         * @stability stable
         */
        get pluginsS3PathInput(): string | undefined;
        private _requirementsS3ObjectVersion?;
        /**
         * @stability stable
         */
        get requirementsS3ObjectVersion(): string | undefined;
        /**
         * @stability stable
         */
        set requirementsS3ObjectVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetRequirementsS3ObjectVersion(): void;
        /**
         * @stability stable
         */
        get requirementsS3ObjectVersionInput(): string | undefined;
        private _requirementsS3Path?;
        /**
         * @stability stable
         */
        get requirementsS3Path(): string | undefined;
        /**
         * @stability stable
         */
        set requirementsS3Path(value: string | undefined);
        /**
         * @stability stable
         */
        resetRequirementsS3Path(): void;
        /**
         * @stability stable
         */
        get requirementsS3PathInput(): string | undefined;
        /**
         * @stability stable
         */
        get serviceRoleArn(): string;
        private _sourceBucketArn?;
        /**
         * @stability stable
         */
        get sourceBucketArn(): string;
        /**
         * @stability stable
         */
        set sourceBucketArn(value: string);
        /**
         * @stability stable
         */
        get sourceBucketArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _webserverAccessMode?;
        /**
         * @stability stable
         */
        get webserverAccessMode(): string | undefined;
        /**
         * @stability stable
         */
        set webserverAccessMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetWebserverAccessMode(): void;
        /**
         * @stability stable
         */
        get webserverAccessModeInput(): string | undefined;
        /**
         * @stability stable
         */
        get webserverUrl(): string;
        private _weeklyMaintenanceWindowStart?;
        /**
         * @stability stable
         */
        get weeklyMaintenanceWindowStart(): string | undefined;
        /**
         * @stability stable
         */
        set weeklyMaintenanceWindowStart(value: string | undefined);
        /**
         * @stability stable
         */
        resetWeeklyMaintenanceWindowStart(): void;
        /**
         * @stability stable
         */
        get weeklyMaintenanceWindowStartInput(): string | undefined;
        private _loggingConfiguration?;
        private __loggingConfigurationOutput;
        /**
         * @stability stable
         */
        get loggingConfiguration(): MwaaEnvironmentLoggingConfigurationOutputReference;
        /**
         * @stability stable
         */
        putLoggingConfiguration(value: MwaaEnvironmentLoggingConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetLoggingConfiguration(): void;
        /**
         * @stability stable
         */
        get loggingConfigurationInput(): MwaaEnvironmentLoggingConfiguration | undefined;
        private _networkConfiguration?;
        private __networkConfigurationOutput;
        /**
         * @stability stable
         */
        get networkConfiguration(): MwaaEnvironmentNetworkConfigurationOutputReference;
        /**
         * @stability stable
         */
        putNetworkConfiguration(value: MwaaEnvironmentNetworkConfiguration): void;
        /**
         * @stability stable
         */
        get networkConfigurationInput(): MwaaEnvironmentNetworkConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
