import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Macie 2
*/
export declare namespace Macie2 {
    /**
     * @stability stable
     */
    interface Macie2AccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_account.html#finding_publishing_frequency Macie2Account#finding_publishing_frequency}.
         *
         * @stability stable
         */
        readonly findingPublishingFrequency?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_account.html#status Macie2Account#status}.
         *
         * @stability stable
         */
        readonly status?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/macie2_account.html aws_macie2_account}.
     *
     * @stability stable
     */
    class Macie2Account extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/macie2_account.html aws_macie2_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: Macie2AccountConfig);
        /**
         * @stability stable
         */
        get createdAt(): string;
        private _findingPublishingFrequency?;
        /**
         * @stability stable
         */
        get findingPublishingFrequency(): string | undefined;
        /**
         * @stability stable
         */
        set findingPublishingFrequency(value: string | undefined);
        /**
         * @stability stable
         */
        resetFindingPublishingFrequency(): void;
        /**
         * @stability stable
         */
        get findingPublishingFrequencyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get serviceRole(): string;
        private _status?;
        /**
         * @stability stable
         */
        get status(): string | undefined;
        /**
         * @stability stable
         */
        set status(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatus(): void;
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
        /**
         * @stability stable
         */
        get updatedAt(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#custom_data_identifier_ids Macie2ClassificationJob#custom_data_identifier_ids}.
         *
         * @stability stable
         */
        readonly customDataIdentifierIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#description Macie2ClassificationJob#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#initial_run Macie2ClassificationJob#initial_run}.
         *
         * @stability stable
         */
        readonly initialRun?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#job_status Macie2ClassificationJob#job_status}.
         *
         * @stability stable
         */
        readonly jobStatus?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#job_type Macie2ClassificationJob#job_type}.
         *
         * @stability stable
         */
        readonly jobType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#name Macie2ClassificationJob#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#name_prefix Macie2ClassificationJob#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#sampling_percentage Macie2ClassificationJob#sampling_percentage}.
         *
         * @stability stable
         */
        readonly samplingPercentage?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#tags Macie2ClassificationJob#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#tags_all Macie2ClassificationJob#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * s3_job_definition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#s3_job_definition Macie2ClassificationJob#s3_job_definition}
         *
         * @stability stable
         */
        readonly s3JobDefinition: Macie2ClassificationJobS3JobDefinition;
        /**
         * schedule_frequency block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#schedule_frequency Macie2ClassificationJob#schedule_frequency}
         *
         * @stability stable
         */
        readonly scheduleFrequency?: Macie2ClassificationJobScheduleFrequency;
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobUserPausedDetails extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get jobExpiresAt(): string;
        /**
         * @stability stable
         */
        get jobImminentExpirationHealthEventArn(): string;
        /**
         * @stability stable
         */
        get jobPausedAt(): string;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionBucketDefinitions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#account_id Macie2ClassificationJob#account_id}.
         *
         * @stability stable
         */
        readonly accountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#buckets Macie2ClassificationJob#buckets}.
         *
         * @stability stable
         */
        readonly buckets: string[];
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingExcludesAndSimpleScopeTerm {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#comparator Macie2ClassificationJob#comparator}.
         *
         * @stability stable
         */
        readonly comparator?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#key Macie2ClassificationJob#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#values Macie2ClassificationJob#values}.
         *
         * @stability stable
         */
        readonly values?: string[];
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionScopingExcludesAndSimpleScopeTermOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _comparator?;
        /**
         * @stability stable
         */
        get comparator(): string | undefined;
        /**
         * @stability stable
         */
        set comparator(value: string | undefined);
        /**
         * @stability stable
         */
        resetComparator(): void;
        /**
         * @stability stable
         */
        get comparatorInput(): string | undefined;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string | undefined;
        /**
         * @stability stable
         */
        set key(value: string | undefined);
        /**
         * @stability stable
         */
        resetKey(): void;
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[] | undefined;
        /**
         * @stability stable
         */
        set values(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetValues(): void;
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTermTagValues {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#key Macie2ClassificationJob#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#value Macie2ClassificationJob#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTerm {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#comparator Macie2ClassificationJob#comparator}.
         *
         * @stability stable
         */
        readonly comparator?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#key Macie2ClassificationJob#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#target Macie2ClassificationJob#target}.
         *
         * @stability stable
         */
        readonly target?: string;
        /**
         * tag_values block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#tag_values Macie2ClassificationJob#tag_values}
         *
         * @stability stable
         */
        readonly tagValues?: Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTermTagValues[];
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTermOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _comparator?;
        /**
         * @stability stable
         */
        get comparator(): string | undefined;
        /**
         * @stability stable
         */
        set comparator(value: string | undefined);
        /**
         * @stability stable
         */
        resetComparator(): void;
        /**
         * @stability stable
         */
        get comparatorInput(): string | undefined;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string | undefined;
        /**
         * @stability stable
         */
        set key(value: string | undefined);
        /**
         * @stability stable
         */
        resetKey(): void;
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _target?;
        /**
         * @stability stable
         */
        get target(): string | undefined;
        /**
         * @stability stable
         */
        set target(value: string | undefined);
        /**
         * @stability stable
         */
        resetTarget(): void;
        /**
         * @stability stable
         */
        get targetInput(): string | undefined;
        private _tagValues?;
        /**
         * @stability stable
         */
        get tagValues(): Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTermTagValues[] | undefined;
        /**
         * @stability stable
         */
        set tagValues(value: Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTermTagValues[] | undefined);
        /**
         * @stability stable
         */
        resetTagValues(): void;
        /**
         * @stability stable
         */
        get tagValuesInput(): Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTermTagValues[] | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingExcludesAnd {
        /**
         * simple_scope_term block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#simple_scope_term Macie2ClassificationJob#simple_scope_term}
         *
         * @stability stable
         */
        readonly simpleScopeTerm?: Macie2ClassificationJobS3JobDefinitionScopingExcludesAndSimpleScopeTerm;
        /**
         * tag_scope_term block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#tag_scope_term Macie2ClassificationJob#tag_scope_term}
         *
         * @stability stable
         */
        readonly tagScopeTerm?: Macie2ClassificationJobS3JobDefinitionScopingExcludesAndTagScopeTerm;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingExcludes {
        /**
         * and block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#and Macie2ClassificationJob#and}
         *
         * @stability stable
         */
        readonly and?: Macie2ClassificationJobS3JobDefinitionScopingExcludesAnd[];
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionScopingExcludesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _and?;
        /**
         * @stability stable
         */
        get and(): Macie2ClassificationJobS3JobDefinitionScopingExcludesAnd[] | undefined;
        /**
         * @stability stable
         */
        set and(value: Macie2ClassificationJobS3JobDefinitionScopingExcludesAnd[] | undefined);
        /**
         * @stability stable
         */
        resetAnd(): void;
        /**
         * @stability stable
         */
        get andInput(): Macie2ClassificationJobS3JobDefinitionScopingExcludesAnd[] | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingIncludesAndSimpleScopeTerm {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#comparator Macie2ClassificationJob#comparator}.
         *
         * @stability stable
         */
        readonly comparator?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#key Macie2ClassificationJob#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#values Macie2ClassificationJob#values}.
         *
         * @stability stable
         */
        readonly values?: string[];
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionScopingIncludesAndSimpleScopeTermOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _comparator?;
        /**
         * @stability stable
         */
        get comparator(): string | undefined;
        /**
         * @stability stable
         */
        set comparator(value: string | undefined);
        /**
         * @stability stable
         */
        resetComparator(): void;
        /**
         * @stability stable
         */
        get comparatorInput(): string | undefined;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string | undefined;
        /**
         * @stability stable
         */
        set key(value: string | undefined);
        /**
         * @stability stable
         */
        resetKey(): void;
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[] | undefined;
        /**
         * @stability stable
         */
        set values(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetValues(): void;
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValues {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#key Macie2ClassificationJob#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#value Macie2ClassificationJob#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTerm {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#comparator Macie2ClassificationJob#comparator}.
         *
         * @stability stable
         */
        readonly comparator?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#key Macie2ClassificationJob#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#target Macie2ClassificationJob#target}.
         *
         * @stability stable
         */
        readonly target?: string;
        /**
         * tag_values block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#tag_values Macie2ClassificationJob#tag_values}
         *
         * @stability stable
         */
        readonly tagValues?: Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValues[];
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _comparator?;
        /**
         * @stability stable
         */
        get comparator(): string | undefined;
        /**
         * @stability stable
         */
        set comparator(value: string | undefined);
        /**
         * @stability stable
         */
        resetComparator(): void;
        /**
         * @stability stable
         */
        get comparatorInput(): string | undefined;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string | undefined;
        /**
         * @stability stable
         */
        set key(value: string | undefined);
        /**
         * @stability stable
         */
        resetKey(): void;
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _target?;
        /**
         * @stability stable
         */
        get target(): string | undefined;
        /**
         * @stability stable
         */
        set target(value: string | undefined);
        /**
         * @stability stable
         */
        resetTarget(): void;
        /**
         * @stability stable
         */
        get targetInput(): string | undefined;
        private _tagValues?;
        /**
         * @stability stable
         */
        get tagValues(): Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValues[] | undefined;
        /**
         * @stability stable
         */
        set tagValues(value: Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValues[] | undefined);
        /**
         * @stability stable
         */
        resetTagValues(): void;
        /**
         * @stability stable
         */
        get tagValuesInput(): Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTermTagValues[] | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingIncludesAnd {
        /**
         * simple_scope_term block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#simple_scope_term Macie2ClassificationJob#simple_scope_term}
         *
         * @stability stable
         */
        readonly simpleScopeTerm?: Macie2ClassificationJobS3JobDefinitionScopingIncludesAndSimpleScopeTerm;
        /**
         * tag_scope_term block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#tag_scope_term Macie2ClassificationJob#tag_scope_term}
         *
         * @stability stable
         */
        readonly tagScopeTerm?: Macie2ClassificationJobS3JobDefinitionScopingIncludesAndTagScopeTerm;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScopingIncludes {
        /**
         * and block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#and Macie2ClassificationJob#and}
         *
         * @stability stable
         */
        readonly and?: Macie2ClassificationJobS3JobDefinitionScopingIncludesAnd[];
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionScopingIncludesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _and?;
        /**
         * @stability stable
         */
        get and(): Macie2ClassificationJobS3JobDefinitionScopingIncludesAnd[] | undefined;
        /**
         * @stability stable
         */
        set and(value: Macie2ClassificationJobS3JobDefinitionScopingIncludesAnd[] | undefined);
        /**
         * @stability stable
         */
        resetAnd(): void;
        /**
         * @stability stable
         */
        get andInput(): Macie2ClassificationJobS3JobDefinitionScopingIncludesAnd[] | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinitionScoping {
        /**
         * excludes block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#excludes Macie2ClassificationJob#excludes}
         *
         * @stability stable
         */
        readonly excludes?: Macie2ClassificationJobS3JobDefinitionScopingExcludes;
        /**
         * includes block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#includes Macie2ClassificationJob#includes}
         *
         * @stability stable
         */
        readonly includes?: Macie2ClassificationJobS3JobDefinitionScopingIncludes;
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionScopingOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _excludes?;
        private __excludesOutput;
        /**
         * @stability stable
         */
        get excludes(): Macie2ClassificationJobS3JobDefinitionScopingExcludesOutputReference;
        /**
         * @stability stable
         */
        putExcludes(value: Macie2ClassificationJobS3JobDefinitionScopingExcludes | undefined): void;
        /**
         * @stability stable
         */
        resetExcludes(): void;
        /**
         * @stability stable
         */
        get excludesInput(): Macie2ClassificationJobS3JobDefinitionScopingExcludes | undefined;
        private _includes?;
        private __includesOutput;
        /**
         * @stability stable
         */
        get includes(): Macie2ClassificationJobS3JobDefinitionScopingIncludesOutputReference;
        /**
         * @stability stable
         */
        putIncludes(value: Macie2ClassificationJobS3JobDefinitionScopingIncludes | undefined): void;
        /**
         * @stability stable
         */
        resetIncludes(): void;
        /**
         * @stability stable
         */
        get includesInput(): Macie2ClassificationJobS3JobDefinitionScopingIncludes | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobS3JobDefinition {
        /**
         * bucket_definitions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#bucket_definitions Macie2ClassificationJob#bucket_definitions}
         *
         * @stability stable
         */
        readonly bucketDefinitions?: Macie2ClassificationJobS3JobDefinitionBucketDefinitions[];
        /**
         * scoping block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#scoping Macie2ClassificationJob#scoping}
         *
         * @stability stable
         */
        readonly scoping?: Macie2ClassificationJobS3JobDefinitionScoping;
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobS3JobDefinitionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketDefinitions?;
        /**
         * @stability stable
         */
        get bucketDefinitions(): Macie2ClassificationJobS3JobDefinitionBucketDefinitions[] | undefined;
        /**
         * @stability stable
         */
        set bucketDefinitions(value: Macie2ClassificationJobS3JobDefinitionBucketDefinitions[] | undefined);
        /**
         * @stability stable
         */
        resetBucketDefinitions(): void;
        /**
         * @stability stable
         */
        get bucketDefinitionsInput(): Macie2ClassificationJobS3JobDefinitionBucketDefinitions[] | undefined;
        private _scoping?;
        private __scopingOutput;
        /**
         * @stability stable
         */
        get scoping(): Macie2ClassificationJobS3JobDefinitionScopingOutputReference;
        /**
         * @stability stable
         */
        putScoping(value: Macie2ClassificationJobS3JobDefinitionScoping | undefined): void;
        /**
         * @stability stable
         */
        resetScoping(): void;
        /**
         * @stability stable
         */
        get scopingInput(): Macie2ClassificationJobS3JobDefinitionScoping | undefined;
    }
    /**
     * @stability stable
     */
    interface Macie2ClassificationJobScheduleFrequency {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#daily_schedule Macie2ClassificationJob#daily_schedule}.
         *
         * @stability stable
         */
        readonly dailySchedule?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#monthly_schedule Macie2ClassificationJob#monthly_schedule}.
         *
         * @stability stable
         */
        readonly monthlySchedule?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html#weekly_schedule Macie2ClassificationJob#weekly_schedule}.
         *
         * @stability stable
         */
        readonly weeklySchedule?: string;
    }
    /**
     * @stability stable
     */
    class Macie2ClassificationJobScheduleFrequencyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _dailySchedule?;
        /**
         * @stability stable
         */
        get dailySchedule(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set dailySchedule(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDailySchedule(): void;
        /**
         * @stability stable
         */
        get dailyScheduleInput(): boolean | cdktf.IResolvable | undefined;
        private _monthlySchedule?;
        /**
         * @stability stable
         */
        get monthlySchedule(): number | undefined;
        /**
         * @stability stable
         */
        set monthlySchedule(value: number | undefined);
        /**
         * @stability stable
         */
        resetMonthlySchedule(): void;
        /**
         * @stability stable
         */
        get monthlyScheduleInput(): number | undefined;
        private _weeklySchedule?;
        /**
         * @stability stable
         */
        get weeklySchedule(): string | undefined;
        /**
         * @stability stable
         */
        set weeklySchedule(value: string | undefined);
        /**
         * @stability stable
         */
        resetWeeklySchedule(): void;
        /**
         * @stability stable
         */
        get weeklyScheduleInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html aws_macie2_classification_job}.
     *
     * @stability stable
     */
    class Macie2ClassificationJob extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/macie2_classification_job.html aws_macie2_classification_job} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: Macie2ClassificationJobConfig);
        /**
         * @stability stable
         */
        get createdAt(): string;
        private _customDataIdentifierIds?;
        /**
         * @stability stable
         */
        get customDataIdentifierIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set customDataIdentifierIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCustomDataIdentifierIds(): void;
        /**
         * @stability stable
         */
        get customDataIdentifierIdsInput(): string[] | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _initialRun?;
        /**
         * @stability stable
         */
        get initialRun(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set initialRun(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInitialRun(): void;
        /**
         * @stability stable
         */
        get initialRunInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get jobArn(): string;
        /**
         * @stability stable
         */
        get jobId(): string;
        private _jobStatus?;
        /**
         * @stability stable
         */
        get jobStatus(): string | undefined;
        /**
         * @stability stable
         */
        set jobStatus(value: string | undefined);
        /**
         * @stability stable
         */
        resetJobStatus(): void;
        /**
         * @stability stable
         */
        get jobStatusInput(): string | undefined;
        private _jobType?;
        /**
         * @stability stable
         */
        get jobType(): string;
        /**
         * @stability stable
         */
        set jobType(value: string);
        /**
         * @stability stable
         */
        get jobTypeInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _samplingPercentage?;
        /**
         * @stability stable
         */
        get samplingPercentage(): number | undefined;
        /**
         * @stability stable
         */
        set samplingPercentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetSamplingPercentage(): void;
        /**
         * @stability stable
         */
        get samplingPercentageInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        userPausedDetails(index: string): Macie2ClassificationJobUserPausedDetails;
        private _s3JobDefinition?;
        private __s3JobDefinitionOutput;
        /**
         * @stability stable
         */
        get s3JobDefinition(): Macie2ClassificationJobS3JobDefinitionOutputReference;
        /**
         * @stability stable
         */
        putS3JobDefinition(value: Macie2ClassificationJobS3JobDefinition): void;
        /**
         * @stability stable
         */
        get s3JobDefinitionInput(): Macie2ClassificationJobS3JobDefinition | undefined;
        private _scheduleFrequency?;
        private __scheduleFrequencyOutput;
        /**
         * @stability stable
         */
        get scheduleFrequency(): Macie2ClassificationJobScheduleFrequencyOutputReference;
        /**
         * @stability stable
         */
        putScheduleFrequency(value: Macie2ClassificationJobScheduleFrequency | undefined): void;
        /**
         * @stability stable
         */
        resetScheduleFrequency(): void;
        /**
         * @stability stable
         */
        get scheduleFrequencyInput(): Macie2ClassificationJobScheduleFrequency | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface Macie2CustomDataIdentifierConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#description Macie2CustomDataIdentifier#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#ignore_words Macie2CustomDataIdentifier#ignore_words}.
         *
         * @stability stable
         */
        readonly ignoreWords?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#keywords Macie2CustomDataIdentifier#keywords}.
         *
         * @stability stable
         */
        readonly keywords?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#maximum_match_distance Macie2CustomDataIdentifier#maximum_match_distance}.
         *
         * @stability stable
         */
        readonly maximumMatchDistance?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#name Macie2CustomDataIdentifier#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#name_prefix Macie2CustomDataIdentifier#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#regex Macie2CustomDataIdentifier#regex}.
         *
         * @stability stable
         */
        readonly regex?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#tags Macie2CustomDataIdentifier#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html#tags_all Macie2CustomDataIdentifier#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html aws_macie2_custom_data_identifier}.
     *
     * @stability stable
     */
    class Macie2CustomDataIdentifier extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/macie2_custom_data_identifier.html aws_macie2_custom_data_identifier} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: Macie2CustomDataIdentifierConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get createdAt(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ignoreWords?;
        /**
         * @stability stable
         */
        get ignoreWords(): string[] | undefined;
        /**
         * @stability stable
         */
        set ignoreWords(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetIgnoreWords(): void;
        /**
         * @stability stable
         */
        get ignoreWordsInput(): string[] | undefined;
        private _keywords?;
        /**
         * @stability stable
         */
        get keywords(): string[] | undefined;
        /**
         * @stability stable
         */
        set keywords(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetKeywords(): void;
        /**
         * @stability stable
         */
        get keywordsInput(): string[] | undefined;
        private _maximumMatchDistance?;
        /**
         * @stability stable
         */
        get maximumMatchDistance(): number | undefined;
        /**
         * @stability stable
         */
        set maximumMatchDistance(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaximumMatchDistance(): void;
        /**
         * @stability stable
         */
        get maximumMatchDistanceInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _regex?;
        /**
         * @stability stable
         */
        get regex(): string | undefined;
        /**
         * @stability stable
         */
        set regex(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegex(): void;
        /**
         * @stability stable
         */
        get regexInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface Macie2FindingsFilterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#action Macie2FindingsFilter#action}.
         *
         * @stability stable
         */
        readonly action: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#description Macie2FindingsFilter#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#name Macie2FindingsFilter#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#name_prefix Macie2FindingsFilter#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#position Macie2FindingsFilter#position}.
         *
         * @stability stable
         */
        readonly position?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#tags Macie2FindingsFilter#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#tags_all Macie2FindingsFilter#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * finding_criteria block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#finding_criteria Macie2FindingsFilter#finding_criteria}
         *
         * @stability stable
         */
        readonly findingCriteria: Macie2FindingsFilterFindingCriteria;
    }
    /**
     * @stability stable
     */
    interface Macie2FindingsFilterFindingCriteriaCriterion {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#eq Macie2FindingsFilter#eq}.
         *
         * @stability stable
         */
        readonly eq?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#eq_exact_match Macie2FindingsFilter#eq_exact_match}.
         *
         * @stability stable
         */
        readonly eqExactMatch?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#field Macie2FindingsFilter#field}.
         *
         * @stability stable
         */
        readonly field: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#gt Macie2FindingsFilter#gt}.
         *
         * @stability stable
         */
        readonly gt?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#gte Macie2FindingsFilter#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#lt Macie2FindingsFilter#lt}.
         *
         * @stability stable
         */
        readonly lt?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#lte Macie2FindingsFilter#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#neq Macie2FindingsFilter#neq}.
         *
         * @stability stable
         */
        readonly neq?: string[];
    }
    /**
     * @stability stable
     */
    interface Macie2FindingsFilterFindingCriteria {
        /**
         * criterion block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html#criterion Macie2FindingsFilter#criterion}
         *
         * @stability stable
         */
        readonly criterion?: Macie2FindingsFilterFindingCriteriaCriterion[];
    }
    /**
     * @stability stable
     */
    class Macie2FindingsFilterFindingCriteriaOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _criterion?;
        /**
         * @stability stable
         */
        get criterion(): Macie2FindingsFilterFindingCriteriaCriterion[] | undefined;
        /**
         * @stability stable
         */
        set criterion(value: Macie2FindingsFilterFindingCriteriaCriterion[] | undefined);
        /**
         * @stability stable
         */
        resetCriterion(): void;
        /**
         * @stability stable
         */
        get criterionInput(): Macie2FindingsFilterFindingCriteriaCriterion[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html aws_macie2_findings_filter}.
     *
     * @stability stable
     */
    class Macie2FindingsFilter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/macie2_findings_filter.html aws_macie2_findings_filter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: Macie2FindingsFilterConfig);
        private _action?;
        /**
         * @stability stable
         */
        get action(): string;
        /**
         * @stability stable
         */
        set action(value: string);
        /**
         * @stability stable
         */
        get actionInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _position?;
        /**
         * @stability stable
         */
        get position(): number | undefined;
        /**
         * @stability stable
         */
        set position(value: number | undefined);
        /**
         * @stability stable
         */
        resetPosition(): void;
        /**
         * @stability stable
         */
        get positionInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _findingCriteria?;
        private __findingCriteriaOutput;
        /**
         * @stability stable
         */
        get findingCriteria(): Macie2FindingsFilterFindingCriteriaOutputReference;
        /**
         * @stability stable
         */
        putFindingCriteria(value: Macie2FindingsFilterFindingCriteria): void;
        /**
         * @stability stable
         */
        get findingCriteriaInput(): Macie2FindingsFilterFindingCriteria | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface Macie2InvitationAccepterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_invitation_accepter.html#administrator_account_id Macie2InvitationAccepter#administrator_account_id}.
         *
         * @stability stable
         */
        readonly administratorAccountId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_invitation_accepter.html#timeouts Macie2InvitationAccepter#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: Macie2InvitationAccepterTimeouts;
    }
    /**
     * @stability stable
     */
    interface Macie2InvitationAccepterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_invitation_accepter.html#create Macie2InvitationAccepter#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class Macie2InvitationAccepterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/macie2_invitation_accepter.html aws_macie2_invitation_accepter}.
     *
     * @stability stable
     */
    class Macie2InvitationAccepter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/macie2_invitation_accepter.html aws_macie2_invitation_accepter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: Macie2InvitationAccepterConfig);
        private _administratorAccountId?;
        /**
         * @stability stable
         */
        get administratorAccountId(): string;
        /**
         * @stability stable
         */
        set administratorAccountId(value: string);
        /**
         * @stability stable
         */
        get administratorAccountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get invitationId(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): Macie2InvitationAccepterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: Macie2InvitationAccepterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): Macie2InvitationAccepterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface Macie2MemberConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#account_id Macie2Member#account_id}.
         *
         * @stability stable
         */
        readonly accountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#email Macie2Member#email}.
         *
         * @stability stable
         */
        readonly email: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#invitation_disable_email_notification Macie2Member#invitation_disable_email_notification}.
         *
         * @stability stable
         */
        readonly invitationDisableEmailNotification?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#invitation_message Macie2Member#invitation_message}.
         *
         * @stability stable
         */
        readonly invitationMessage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#invite Macie2Member#invite}.
         *
         * @stability stable
         */
        readonly invite?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#status Macie2Member#status}.
         *
         * @stability stable
         */
        readonly status?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#tags Macie2Member#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#tags_all Macie2Member#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#timeouts Macie2Member#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: Macie2MemberTimeouts;
    }
    /**
     * @stability stable
     */
    interface Macie2MemberTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#create Macie2Member#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html#update Macie2Member#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class Macie2MemberTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html aws_macie2_member}.
     *
     * @stability stable
     */
    class Macie2Member extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/macie2_member.html aws_macie2_member} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: Macie2MemberConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string;
        /**
         * @stability stable
         */
        set accountId(value: string);
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get administratorAccountId(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        private _email?;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        set email(value: string);
        /**
         * @stability stable
         */
        get emailInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _invitationDisableEmailNotification?;
        /**
         * @stability stable
         */
        get invitationDisableEmailNotification(): string | undefined;
        /**
         * @stability stable
         */
        set invitationDisableEmailNotification(value: string | undefined);
        /**
         * @stability stable
         */
        resetInvitationDisableEmailNotification(): void;
        /**
         * @stability stable
         */
        get invitationDisableEmailNotificationInput(): string | undefined;
        private _invitationMessage?;
        /**
         * @stability stable
         */
        get invitationMessage(): string | undefined;
        /**
         * @stability stable
         */
        set invitationMessage(value: string | undefined);
        /**
         * @stability stable
         */
        resetInvitationMessage(): void;
        /**
         * @stability stable
         */
        get invitationMessageInput(): string | undefined;
        private _invite?;
        /**
         * @stability stable
         */
        get invite(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set invite(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInvite(): void;
        /**
         * @stability stable
         */
        get inviteInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get invitedAt(): string;
        /**
         * @stability stable
         */
        get masterAccountId(): string;
        /**
         * @stability stable
         */
        get relationshipStatus(): string;
        private _status?;
        /**
         * @stability stable
         */
        get status(): string | undefined;
        /**
         * @stability stable
         */
        set status(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatus(): void;
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get updatedAt(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): Macie2MemberTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: Macie2MemberTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): Macie2MemberTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface Macie2OrganizationAdminAccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/macie2_organization_admin_account.html#admin_account_id Macie2OrganizationAdminAccount#admin_account_id}.
         *
         * @stability stable
         */
        readonly adminAccountId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/macie2_organization_admin_account.html aws_macie2_organization_admin_account}.
     *
     * @stability stable
     */
    class Macie2OrganizationAdminAccount extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/macie2_organization_admin_account.html aws_macie2_organization_admin_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: Macie2OrganizationAdminAccountConfig);
        private _adminAccountId?;
        /**
         * @stability stable
         */
        get adminAccountId(): string;
        /**
         * @stability stable
         */
        set adminAccountId(value: string);
        /**
         * @stability stable
         */
        get adminAccountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
