import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Organizations
*/
export declare namespace Organizations {
    /**
     * @stability stable
     */
    interface OrganizationsAccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html#email OrganizationsAccount#email}.
         *
         * @stability stable
         */
        readonly email: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html#iam_user_access_to_billing OrganizationsAccount#iam_user_access_to_billing}.
         *
         * @stability stable
         */
        readonly iamUserAccessToBilling?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html#name OrganizationsAccount#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html#parent_id OrganizationsAccount#parent_id}.
         *
         * @stability stable
         */
        readonly parentId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html#role_name OrganizationsAccount#role_name}.
         *
         * @stability stable
         */
        readonly roleName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html#tags OrganizationsAccount#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html#tags_all OrganizationsAccount#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html aws_organizations_account}.
     *
     * @stability stable
     */
    class OrganizationsAccount extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_account.html aws_organizations_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: OrganizationsAccountConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _email?;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        set email(value: string);
        /**
         * @stability stable
         */
        get emailInput(): string | undefined;
        private _iamUserAccessToBilling?;
        /**
         * @stability stable
         */
        get iamUserAccessToBilling(): string | undefined;
        /**
         * @stability stable
         */
        set iamUserAccessToBilling(value: string | undefined);
        /**
         * @stability stable
         */
        resetIamUserAccessToBilling(): void;
        /**
         * @stability stable
         */
        get iamUserAccessToBillingInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get joinedMethod(): string;
        /**
         * @stability stable
         */
        get joinedTimestamp(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parentId?;
        /**
         * @stability stable
         */
        get parentId(): string | undefined;
        /**
         * @stability stable
         */
        set parentId(value: string | undefined);
        /**
         * @stability stable
         */
        resetParentId(): void;
        /**
         * @stability stable
         */
        get parentIdInput(): string | undefined;
        private _roleName?;
        /**
         * @stability stable
         */
        get roleName(): string | undefined;
        /**
         * @stability stable
         */
        set roleName(value: string | undefined);
        /**
         * @stability stable
         */
        resetRoleName(): void;
        /**
         * @stability stable
         */
        get roleNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface OrganizationsDelegatedAdministratorConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_delegated_administrator.html#account_id OrganizationsDelegatedAdministrator#account_id}.
         *
         * @stability stable
         */
        readonly accountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_delegated_administrator.html#service_principal OrganizationsDelegatedAdministrator#service_principal}.
         *
         * @stability stable
         */
        readonly servicePrincipal: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/organizations_delegated_administrator.html aws_organizations_delegated_administrator}.
     *
     * @stability stable
     */
    class OrganizationsDelegatedAdministrator extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_delegated_administrator.html aws_organizations_delegated_administrator} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: OrganizationsDelegatedAdministratorConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string;
        /**
         * @stability stable
         */
        set accountId(value: string);
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get delegationEnabledDate(): string;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get joinedMethod(): string;
        /**
         * @stability stable
         */
        get joinedTimestamp(): string;
        /**
         * @stability stable
         */
        get name(): string;
        private _servicePrincipal?;
        /**
         * @stability stable
         */
        get servicePrincipal(): string;
        /**
         * @stability stable
         */
        set servicePrincipal(value: string);
        /**
         * @stability stable
         */
        get servicePrincipalInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface OrganizationsOrganizationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization.html#aws_service_access_principals OrganizationsOrganization#aws_service_access_principals}.
         *
         * @stability stable
         */
        readonly awsServiceAccessPrincipals?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization.html#enabled_policy_types OrganizationsOrganization#enabled_policy_types}.
         *
         * @stability stable
         */
        readonly enabledPolicyTypes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization.html#feature_set OrganizationsOrganization#feature_set}.
         *
         * @stability stable
         */
        readonly featureSet?: string;
    }
    /**
     * @stability stable
     */
    class OrganizationsOrganizationAccounts extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get status(): string;
    }
    /**
     * @stability stable
     */
    class OrganizationsOrganizationNonMasterAccounts extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get status(): string;
    }
    /**
     * @stability stable
     */
    class OrganizationsOrganizationRootsPolicyTypes extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * @stability stable
     */
    class OrganizationsOrganizationRoots extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get policyTypes(): any;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization.html aws_organizations_organization}.
     *
     * @stability stable
     */
    class OrganizationsOrganization extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_organization.html aws_organizations_organization} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: OrganizationsOrganizationConfig);
        /**
         * @stability stable
         */
        accounts(index: string): OrganizationsOrganizationAccounts;
        /**
         * @stability stable
         */
        get arn(): string;
        private _awsServiceAccessPrincipals?;
        /**
         * @stability stable
         */
        get awsServiceAccessPrincipals(): string[] | undefined;
        /**
         * @stability stable
         */
        set awsServiceAccessPrincipals(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAwsServiceAccessPrincipals(): void;
        /**
         * @stability stable
         */
        get awsServiceAccessPrincipalsInput(): string[] | undefined;
        private _enabledPolicyTypes?;
        /**
         * @stability stable
         */
        get enabledPolicyTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set enabledPolicyTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEnabledPolicyTypes(): void;
        /**
         * @stability stable
         */
        get enabledPolicyTypesInput(): string[] | undefined;
        private _featureSet?;
        /**
         * @stability stable
         */
        get featureSet(): string | undefined;
        /**
         * @stability stable
         */
        set featureSet(value: string | undefined);
        /**
         * @stability stable
         */
        resetFeatureSet(): void;
        /**
         * @stability stable
         */
        get featureSetInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get masterAccountArn(): string;
        /**
         * @stability stable
         */
        get masterAccountEmail(): string;
        /**
         * @stability stable
         */
        get masterAccountId(): string;
        /**
         * @stability stable
         */
        nonMasterAccounts(index: string): OrganizationsOrganizationNonMasterAccounts;
        /**
         * @stability stable
         */
        roots(index: string): OrganizationsOrganizationRoots;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface OrganizationsOrganizationalUnitConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organizational_unit.html#name OrganizationsOrganizationalUnit#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organizational_unit.html#parent_id OrganizationsOrganizationalUnit#parent_id}.
         *
         * @stability stable
         */
        readonly parentId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organizational_unit.html#tags OrganizationsOrganizationalUnit#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_organizational_unit.html#tags_all OrganizationsOrganizationalUnit#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class OrganizationsOrganizationalUnitAccounts extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/organizations_organizational_unit.html aws_organizations_organizational_unit}.
     *
     * @stability stable
     */
    class OrganizationsOrganizationalUnit extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_organizational_unit.html aws_organizations_organizational_unit} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: OrganizationsOrganizationalUnitConfig);
        /**
         * @stability stable
         */
        accounts(index: string): OrganizationsOrganizationalUnitAccounts;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parentId?;
        /**
         * @stability stable
         */
        get parentId(): string;
        /**
         * @stability stable
         */
        set parentId(value: string);
        /**
         * @stability stable
         */
        get parentIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface OrganizationsPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html#content OrganizationsPolicy#content}.
         *
         * @stability stable
         */
        readonly content: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html#description OrganizationsPolicy#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html#name OrganizationsPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html#tags OrganizationsPolicy#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html#tags_all OrganizationsPolicy#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html#type OrganizationsPolicy#type}.
         *
         * @stability stable
         */
        readonly type?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html aws_organizations_policy}.
     *
     * @stability stable
     */
    class OrganizationsPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy.html aws_organizations_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: OrganizationsPolicyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _content?;
        /**
         * @stability stable
         */
        get content(): string;
        /**
         * @stability stable
         */
        set content(value: string);
        /**
         * @stability stable
         */
        get contentInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface OrganizationsPolicyAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy_attachment.html#policy_id OrganizationsPolicyAttachment#policy_id}.
         *
         * @stability stable
         */
        readonly policyId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy_attachment.html#target_id OrganizationsPolicyAttachment#target_id}.
         *
         * @stability stable
         */
        readonly targetId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy_attachment.html aws_organizations_policy_attachment}.
     *
     * @stability stable
     */
    class OrganizationsPolicyAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/organizations_policy_attachment.html aws_organizations_policy_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: OrganizationsPolicyAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policyId?;
        /**
         * @stability stable
         */
        get policyId(): string;
        /**
         * @stability stable
         */
        set policyId(value: string);
        /**
         * @stability stable
         */
        get policyIdInput(): string | undefined;
        private _targetId?;
        /**
         * @stability stable
         */
        get targetId(): string;
        /**
         * @stability stable
         */
        set targetId(value: string);
        /**
         * @stability stable
         */
        get targetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsOrganizationsDelegatedAdministratorsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/organizations_delegated_administrators.html#service_principal DataAwsOrganizationsDelegatedAdministrators#service_principal}.
         *
         * @stability stable
         */
        readonly servicePrincipal?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsOrganizationsDelegatedAdministratorsDelegatedAdministrators extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get delegationEnabledDate(): string;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get joinedMethod(): string;
        /**
         * @stability stable
         */
        get joinedTimestamp(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get status(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/organizations_delegated_administrators.html aws_organizations_delegated_administrators}.
     *
     * @stability stable
     */
    class DataAwsOrganizationsDelegatedAdministrators extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/organizations_delegated_administrators.html aws_organizations_delegated_administrators} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsOrganizationsDelegatedAdministratorsConfig);
        /**
         * @stability stable
         */
        delegatedAdministrators(index: string): DataAwsOrganizationsDelegatedAdministratorsDelegatedAdministrators;
        /**
         * @stability stable
         */
        get id(): string;
        private _servicePrincipal?;
        /**
         * @stability stable
         */
        get servicePrincipal(): string | undefined;
        /**
         * @stability stable
         */
        set servicePrincipal(value: string | undefined);
        /**
         * @stability stable
         */
        resetServicePrincipal(): void;
        /**
         * @stability stable
         */
        get servicePrincipalInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsOrganizationsDelegatedServicesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/organizations_delegated_services.html#account_id DataAwsOrganizationsDelegatedServices#account_id}.
         *
         * @stability stable
         */
        readonly accountId: string;
    }
    /**
     * @stability stable
     */
    class DataAwsOrganizationsDelegatedServicesDelegatedServices extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get delegationEnabledDate(): string;
        /**
         * @stability stable
         */
        get servicePrincipal(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/organizations_delegated_services.html aws_organizations_delegated_services}.
     *
     * @stability stable
     */
    class DataAwsOrganizationsDelegatedServices extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/organizations_delegated_services.html aws_organizations_delegated_services} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsOrganizationsDelegatedServicesConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string;
        /**
         * @stability stable
         */
        set accountId(value: string);
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        delegatedServices(index: string): DataAwsOrganizationsDelegatedServicesDelegatedServices;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsOrganizationsOrganizationConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * @stability stable
     */
    class DataAwsOrganizationsOrganizationAccounts extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get status(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsOrganizationsOrganizationNonMasterAccounts extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get status(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsOrganizationsOrganizationRootsPolicyTypes extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsOrganizationsOrganizationRoots extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get policyTypes(): any;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/organizations_organization.html aws_organizations_organization}.
     *
     * @stability stable
     */
    class DataAwsOrganizationsOrganization extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/organizations_organization.html aws_organizations_organization} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsOrganizationsOrganizationConfig);
        /**
         * @stability stable
         */
        accounts(index: string): DataAwsOrganizationsOrganizationAccounts;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get awsServiceAccessPrincipals(): string[];
        /**
         * @stability stable
         */
        get enabledPolicyTypes(): string[];
        /**
         * @stability stable
         */
        get featureSet(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get masterAccountArn(): string;
        /**
         * @stability stable
         */
        get masterAccountEmail(): string;
        /**
         * @stability stable
         */
        get masterAccountId(): string;
        /**
         * @stability stable
         */
        nonMasterAccounts(index: string): DataAwsOrganizationsOrganizationNonMasterAccounts;
        /**
         * @stability stable
         */
        roots(index: string): DataAwsOrganizationsOrganizationRoots;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsOrganizationsOrganizationalUnitsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/organizations_organizational_units.html#parent_id DataAwsOrganizationsOrganizationalUnits#parent_id}.
         *
         * @stability stable
         */
        readonly parentId: string;
    }
    /**
     * @stability stable
     */
    class DataAwsOrganizationsOrganizationalUnitsChildren extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/organizations_organizational_units.html aws_organizations_organizational_units}.
     *
     * @stability stable
     */
    class DataAwsOrganizationsOrganizationalUnits extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/organizations_organizational_units.html aws_organizations_organizational_units} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsOrganizationsOrganizationalUnitsConfig);
        /**
         * @stability stable
         */
        children(index: string): DataAwsOrganizationsOrganizationalUnitsChildren;
        /**
         * @stability stable
         */
        get id(): string;
        private _parentId?;
        /**
         * @stability stable
         */
        get parentId(): string;
        /**
         * @stability stable
         */
        set parentId(value: string);
        /**
         * @stability stable
         */
        get parentIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
