import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Simple Storage Service
*/
export declare namespace S3 {
    /**
     * @stability stable
     */
    interface S3AccessPointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#account_id S3AccessPoint#account_id}.
         *
         * @stability stable
         */
        readonly accountId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#bucket S3AccessPoint#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#name S3AccessPoint#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#policy S3AccessPoint#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * public_access_block_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#public_access_block_configuration S3AccessPoint#public_access_block_configuration}
         *
         * @stability stable
         */
        readonly publicAccessBlockConfiguration?: S3AccessPointPublicAccessBlockConfiguration;
        /**
         * vpc_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#vpc_configuration S3AccessPoint#vpc_configuration}
         *
         * @stability stable
         */
        readonly vpcConfiguration?: S3AccessPointVpcConfiguration;
    }
    /**
     * @stability stable
     */
    interface S3AccessPointPublicAccessBlockConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#block_public_acls S3AccessPoint#block_public_acls}.
         *
         * @stability stable
         */
        readonly blockPublicAcls?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#block_public_policy S3AccessPoint#block_public_policy}.
         *
         * @stability stable
         */
        readonly blockPublicPolicy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#ignore_public_acls S3AccessPoint#ignore_public_acls}.
         *
         * @stability stable
         */
        readonly ignorePublicAcls?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#restrict_public_buckets S3AccessPoint#restrict_public_buckets}.
         *
         * @stability stable
         */
        readonly restrictPublicBuckets?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3AccessPointPublicAccessBlockConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _blockPublicAcls?;
        /**
         * @stability stable
         */
        get blockPublicAcls(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set blockPublicAcls(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBlockPublicAcls(): void;
        /**
         * @stability stable
         */
        get blockPublicAclsInput(): boolean | cdktf.IResolvable | undefined;
        private _blockPublicPolicy?;
        /**
         * @stability stable
         */
        get blockPublicPolicy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set blockPublicPolicy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBlockPublicPolicy(): void;
        /**
         * @stability stable
         */
        get blockPublicPolicyInput(): boolean | cdktf.IResolvable | undefined;
        private _ignorePublicAcls?;
        /**
         * @stability stable
         */
        get ignorePublicAcls(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set ignorePublicAcls(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIgnorePublicAcls(): void;
        /**
         * @stability stable
         */
        get ignorePublicAclsInput(): boolean | cdktf.IResolvable | undefined;
        private _restrictPublicBuckets?;
        /**
         * @stability stable
         */
        get restrictPublicBuckets(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set restrictPublicBuckets(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRestrictPublicBuckets(): void;
        /**
         * @stability stable
         */
        get restrictPublicBucketsInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface S3AccessPointVpcConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html#vpc_id S3AccessPoint#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
    }
    /**
     * @stability stable
     */
    class S3AccessPointVpcConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html aws_s3_access_point}.
     *
     * @stability stable
     */
    class S3AccessPoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_access_point.html aws_s3_access_point} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3AccessPointConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string | undefined;
        /**
         * @stability stable
         */
        set accountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccountId(): void;
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        get hasPublicAccessPolicy(): any;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get networkOrigin(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _publicAccessBlockConfiguration?;
        private __publicAccessBlockConfigurationOutput;
        /**
         * @stability stable
         */
        get publicAccessBlockConfiguration(): S3AccessPointPublicAccessBlockConfigurationOutputReference;
        /**
         * @stability stable
         */
        putPublicAccessBlockConfiguration(value: S3AccessPointPublicAccessBlockConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetPublicAccessBlockConfiguration(): void;
        /**
         * @stability stable
         */
        get publicAccessBlockConfigurationInput(): S3AccessPointPublicAccessBlockConfiguration | undefined;
        private _vpcConfiguration?;
        private __vpcConfigurationOutput;
        /**
         * @stability stable
         */
        get vpcConfiguration(): S3AccessPointVpcConfigurationOutputReference;
        /**
         * @stability stable
         */
        putVpcConfiguration(value: S3AccessPointVpcConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetVpcConfiguration(): void;
        /**
         * @stability stable
         */
        get vpcConfigurationInput(): S3AccessPointVpcConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3AccountPublicAccessBlockConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_account_public_access_block.html#account_id S3AccountPublicAccessBlock#account_id}.
         *
         * @stability stable
         */
        readonly accountId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_account_public_access_block.html#block_public_acls S3AccountPublicAccessBlock#block_public_acls}.
         *
         * @stability stable
         */
        readonly blockPublicAcls?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_account_public_access_block.html#block_public_policy S3AccountPublicAccessBlock#block_public_policy}.
         *
         * @stability stable
         */
        readonly blockPublicPolicy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_account_public_access_block.html#ignore_public_acls S3AccountPublicAccessBlock#ignore_public_acls}.
         *
         * @stability stable
         */
        readonly ignorePublicAcls?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_account_public_access_block.html#restrict_public_buckets S3AccountPublicAccessBlock#restrict_public_buckets}.
         *
         * @stability stable
         */
        readonly restrictPublicBuckets?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_account_public_access_block.html aws_s3_account_public_access_block}.
     *
     * @stability stable
     */
    class S3AccountPublicAccessBlock extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_account_public_access_block.html aws_s3_account_public_access_block} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: S3AccountPublicAccessBlockConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string | undefined;
        /**
         * @stability stable
         */
        set accountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccountId(): void;
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        private _blockPublicAcls?;
        /**
         * @stability stable
         */
        get blockPublicAcls(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set blockPublicAcls(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBlockPublicAcls(): void;
        /**
         * @stability stable
         */
        get blockPublicAclsInput(): boolean | cdktf.IResolvable | undefined;
        private _blockPublicPolicy?;
        /**
         * @stability stable
         */
        get blockPublicPolicy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set blockPublicPolicy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBlockPublicPolicy(): void;
        /**
         * @stability stable
         */
        get blockPublicPolicyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ignorePublicAcls?;
        /**
         * @stability stable
         */
        get ignorePublicAcls(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set ignorePublicAcls(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIgnorePublicAcls(): void;
        /**
         * @stability stable
         */
        get ignorePublicAclsInput(): boolean | cdktf.IResolvable | undefined;
        private _restrictPublicBuckets?;
        /**
         * @stability stable
         */
        get restrictPublicBuckets(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set restrictPublicBuckets(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRestrictPublicBuckets(): void;
        /**
         * @stability stable
         */
        get restrictPublicBucketsInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#acceleration_status S3Bucket#acceleration_status}.
         *
         * @stability stable
         */
        readonly accelerationStatus?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#acl S3Bucket#acl}.
         *
         * @stability stable
         */
        readonly acl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#bucket S3Bucket#bucket}.
         *
         * @stability stable
         */
        readonly bucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#bucket_prefix S3Bucket#bucket_prefix}.
         *
         * @stability stable
         */
        readonly bucketPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#force_destroy S3Bucket#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#hosted_zone_id S3Bucket#hosted_zone_id}.
         *
         * @stability stable
         */
        readonly hostedZoneId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#policy S3Bucket#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#request_payer S3Bucket#request_payer}.
         *
         * @stability stable
         */
        readonly requestPayer?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#tags S3Bucket#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#tags_all S3Bucket#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#website_domain S3Bucket#website_domain}.
         *
         * @stability stable
         */
        readonly websiteDomain?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#website_endpoint S3Bucket#website_endpoint}.
         *
         * @stability stable
         */
        readonly websiteEndpoint?: string;
        /**
         * cors_rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#cors_rule S3Bucket#cors_rule}
         *
         * @stability stable
         */
        readonly corsRule?: S3BucketCorsRule[];
        /**
         * grant block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#grant S3Bucket#grant}
         *
         * @stability stable
         */
        readonly grant?: S3BucketGrant[];
        /**
         * lifecycle_rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#lifecycle_rule S3Bucket#lifecycle_rule}
         *
         * @stability stable
         */
        readonly lifecycleRule?: S3BucketLifecycleRule[];
        /**
         * logging block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#logging S3Bucket#logging}
         *
         * @stability stable
         */
        readonly logging?: S3BucketLogging[];
        /**
         * object_lock_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#object_lock_configuration S3Bucket#object_lock_configuration}
         *
         * @stability stable
         */
        readonly objectLockConfiguration?: S3BucketObjectLockConfiguration;
        /**
         * replication_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#replication_configuration S3Bucket#replication_configuration}
         *
         * @stability stable
         */
        readonly replicationConfiguration?: S3BucketReplicationConfiguration;
        /**
         * server_side_encryption_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#server_side_encryption_configuration S3Bucket#server_side_encryption_configuration}
         *
         * @stability stable
         */
        readonly serverSideEncryptionConfiguration?: S3BucketServerSideEncryptionConfiguration;
        /**
         * versioning block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#versioning S3Bucket#versioning}
         *
         * @stability stable
         */
        readonly versioning?: S3BucketVersioning;
        /**
         * website block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#website S3Bucket#website}
         *
         * @stability stable
         */
        readonly website?: S3BucketWebsite;
    }
    /**
     * @stability stable
     */
    interface S3BucketCorsRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#allowed_headers S3Bucket#allowed_headers}.
         *
         * @stability stable
         */
        readonly allowedHeaders?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#allowed_methods S3Bucket#allowed_methods}.
         *
         * @stability stable
         */
        readonly allowedMethods: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#allowed_origins S3Bucket#allowed_origins}.
         *
         * @stability stable
         */
        readonly allowedOrigins: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#expose_headers S3Bucket#expose_headers}.
         *
         * @stability stable
         */
        readonly exposeHeaders?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#max_age_seconds S3Bucket#max_age_seconds}.
         *
         * @stability stable
         */
        readonly maxAgeSeconds?: number;
    }
    /**
     * @stability stable
     */
    interface S3BucketGrant {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#id S3Bucket#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#permissions S3Bucket#permissions}.
         *
         * @stability stable
         */
        readonly permissions: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#type S3Bucket#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#uri S3Bucket#uri}.
         *
         * @stability stable
         */
        readonly uri?: string;
    }
    /**
     * @stability stable
     */
    interface S3BucketLifecycleRuleExpiration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#date S3Bucket#date}.
         *
         * @stability stable
         */
        readonly date?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#days S3Bucket#days}.
         *
         * @stability stable
         */
        readonly days?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#expired_object_delete_marker S3Bucket#expired_object_delete_marker}.
         *
         * @stability stable
         */
        readonly expiredObjectDeleteMarker?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3BucketLifecycleRuleExpirationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _date?;
        /**
         * @stability stable
         */
        get date(): string | undefined;
        /**
         * @stability stable
         */
        set date(value: string | undefined);
        /**
         * @stability stable
         */
        resetDate(): void;
        /**
         * @stability stable
         */
        get dateInput(): string | undefined;
        private _days?;
        /**
         * @stability stable
         */
        get days(): number | undefined;
        /**
         * @stability stable
         */
        set days(value: number | undefined);
        /**
         * @stability stable
         */
        resetDays(): void;
        /**
         * @stability stable
         */
        get daysInput(): number | undefined;
        private _expiredObjectDeleteMarker?;
        /**
         * @stability stable
         */
        get expiredObjectDeleteMarker(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set expiredObjectDeleteMarker(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetExpiredObjectDeleteMarker(): void;
        /**
         * @stability stable
         */
        get expiredObjectDeleteMarkerInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketLifecycleRuleNoncurrentVersionExpiration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#days S3Bucket#days}.
         *
         * @stability stable
         */
        readonly days?: number;
    }
    /**
     * @stability stable
     */
    class S3BucketLifecycleRuleNoncurrentVersionExpirationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _days?;
        /**
         * @stability stable
         */
        get days(): number | undefined;
        /**
         * @stability stable
         */
        set days(value: number | undefined);
        /**
         * @stability stable
         */
        resetDays(): void;
        /**
         * @stability stable
         */
        get daysInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketLifecycleRuleNoncurrentVersionTransition {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#days S3Bucket#days}.
         *
         * @stability stable
         */
        readonly days?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#storage_class S3Bucket#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass: string;
    }
    /**
     * @stability stable
     */
    interface S3BucketLifecycleRuleTransition {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#date S3Bucket#date}.
         *
         * @stability stable
         */
        readonly date?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#days S3Bucket#days}.
         *
         * @stability stable
         */
        readonly days?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#storage_class S3Bucket#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass: string;
    }
    /**
     * @stability stable
     */
    interface S3BucketLifecycleRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#abort_incomplete_multipart_upload_days S3Bucket#abort_incomplete_multipart_upload_days}.
         *
         * @stability stable
         */
        readonly abortIncompleteMultipartUploadDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#enabled S3Bucket#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#id S3Bucket#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#prefix S3Bucket#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#tags S3Bucket#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * expiration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#expiration S3Bucket#expiration}
         *
         * @stability stable
         */
        readonly expiration?: S3BucketLifecycleRuleExpiration;
        /**
         * noncurrent_version_expiration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#noncurrent_version_expiration S3Bucket#noncurrent_version_expiration}
         *
         * @stability stable
         */
        readonly noncurrentVersionExpiration?: S3BucketLifecycleRuleNoncurrentVersionExpiration;
        /**
         * noncurrent_version_transition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#noncurrent_version_transition S3Bucket#noncurrent_version_transition}
         *
         * @stability stable
         */
        readonly noncurrentVersionTransition?: S3BucketLifecycleRuleNoncurrentVersionTransition[];
        /**
         * transition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#transition S3Bucket#transition}
         *
         * @stability stable
         */
        readonly transition?: S3BucketLifecycleRuleTransition[];
    }
    /**
     * @stability stable
     */
    interface S3BucketLogging {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#target_bucket S3Bucket#target_bucket}.
         *
         * @stability stable
         */
        readonly targetBucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#target_prefix S3Bucket#target_prefix}.
         *
         * @stability stable
         */
        readonly targetPrefix?: string;
    }
    /**
     * @stability stable
     */
    interface S3BucketObjectLockConfigurationRuleDefaultRetention {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#days S3Bucket#days}.
         *
         * @stability stable
         */
        readonly days?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#mode S3Bucket#mode}.
         *
         * @stability stable
         */
        readonly mode: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#years S3Bucket#years}.
         *
         * @stability stable
         */
        readonly years?: number;
    }
    /**
     * @stability stable
     */
    class S3BucketObjectLockConfigurationRuleDefaultRetentionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _days?;
        /**
         * @stability stable
         */
        get days(): number | undefined;
        /**
         * @stability stable
         */
        set days(value: number | undefined);
        /**
         * @stability stable
         */
        resetDays(): void;
        /**
         * @stability stable
         */
        get daysInput(): number | undefined;
        private _mode?;
        /**
         * @stability stable
         */
        get mode(): string;
        /**
         * @stability stable
         */
        set mode(value: string);
        /**
         * @stability stable
         */
        get modeInput(): string | undefined;
        private _years?;
        /**
         * @stability stable
         */
        get years(): number | undefined;
        /**
         * @stability stable
         */
        set years(value: number | undefined);
        /**
         * @stability stable
         */
        resetYears(): void;
        /**
         * @stability stable
         */
        get yearsInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketObjectLockConfigurationRule {
        /**
         * default_retention block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#default_retention S3Bucket#default_retention}
         *
         * @stability stable
         */
        readonly defaultRetention: S3BucketObjectLockConfigurationRuleDefaultRetention;
    }
    /**
     * @stability stable
     */
    class S3BucketObjectLockConfigurationRuleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _defaultRetention?;
        private __defaultRetentionOutput;
        /**
         * @stability stable
         */
        get defaultRetention(): S3BucketObjectLockConfigurationRuleDefaultRetentionOutputReference;
        /**
         * @stability stable
         */
        putDefaultRetention(value: S3BucketObjectLockConfigurationRuleDefaultRetention): void;
        /**
         * @stability stable
         */
        get defaultRetentionInput(): S3BucketObjectLockConfigurationRuleDefaultRetention | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketObjectLockConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#object_lock_enabled S3Bucket#object_lock_enabled}.
         *
         * @stability stable
         */
        readonly objectLockEnabled: string;
        /**
         * rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#rule S3Bucket#rule}
         *
         * @stability stable
         */
        readonly rule?: S3BucketObjectLockConfigurationRule;
    }
    /**
     * @stability stable
     */
    class S3BucketObjectLockConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _objectLockEnabled?;
        /**
         * @stability stable
         */
        get objectLockEnabled(): string;
        /**
         * @stability stable
         */
        set objectLockEnabled(value: string);
        /**
         * @stability stable
         */
        get objectLockEnabledInput(): string | undefined;
        private _rule?;
        private __ruleOutput;
        /**
         * @stability stable
         */
        get rule(): S3BucketObjectLockConfigurationRuleOutputReference;
        /**
         * @stability stable
         */
        putRule(value: S3BucketObjectLockConfigurationRule | undefined): void;
        /**
         * @stability stable
         */
        resetRule(): void;
        /**
         * @stability stable
         */
        get ruleInput(): S3BucketObjectLockConfigurationRule | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#owner S3Bucket#owner}.
         *
         * @stability stable
         */
        readonly owner: string;
    }
    /**
     * @stability stable
     */
    class S3BucketReplicationConfigurationRulesDestinationAccessControlTranslationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _owner?;
        /**
         * @stability stable
         */
        get owner(): string;
        /**
         * @stability stable
         */
        set owner(value: string);
        /**
         * @stability stable
         */
        get ownerInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketReplicationConfigurationRulesDestination {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#account_id S3Bucket#account_id}.
         *
         * @stability stable
         */
        readonly accountId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#bucket S3Bucket#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#replica_kms_key_id S3Bucket#replica_kms_key_id}.
         *
         * @stability stable
         */
        readonly replicaKmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#storage_class S3Bucket#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass?: string;
        /**
         * access_control_translation block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#access_control_translation S3Bucket#access_control_translation}
         *
         * @stability stable
         */
        readonly accessControlTranslation?: S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation;
    }
    /**
     * @stability stable
     */
    class S3BucketReplicationConfigurationRulesDestinationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string | undefined;
        /**
         * @stability stable
         */
        set accountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccountId(): void;
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _replicaKmsKeyId?;
        /**
         * @stability stable
         */
        get replicaKmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set replicaKmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetReplicaKmsKeyId(): void;
        /**
         * @stability stable
         */
        get replicaKmsKeyIdInput(): string | undefined;
        private _storageClass?;
        /**
         * @stability stable
         */
        get storageClass(): string | undefined;
        /**
         * @stability stable
         */
        set storageClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageClass(): void;
        /**
         * @stability stable
         */
        get storageClassInput(): string | undefined;
        private _accessControlTranslation?;
        private __accessControlTranslationOutput;
        /**
         * @stability stable
         */
        get accessControlTranslation(): S3BucketReplicationConfigurationRulesDestinationAccessControlTranslationOutputReference;
        /**
         * @stability stable
         */
        putAccessControlTranslation(value: S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation | undefined): void;
        /**
         * @stability stable
         */
        resetAccessControlTranslation(): void;
        /**
         * @stability stable
         */
        get accessControlTranslationInput(): S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketReplicationConfigurationRulesFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#prefix S3Bucket#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#tags S3Bucket#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3BucketReplicationConfigurationRulesFilterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#enabled S3Bucket#enabled}.
         *
         * @stability stable
         */
        readonly enabled: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjectsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketReplicationConfigurationRulesSourceSelectionCriteria {
        /**
         * sse_kms_encrypted_objects block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#sse_kms_encrypted_objects S3Bucket#sse_kms_encrypted_objects}
         *
         * @stability stable
         */
        readonly sseKmsEncryptedObjects?: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects;
    }
    /**
     * @stability stable
     */
    class S3BucketReplicationConfigurationRulesSourceSelectionCriteriaOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _sseKmsEncryptedObjects?;
        private __sseKmsEncryptedObjectsOutput;
        /**
         * @stability stable
         */
        get sseKmsEncryptedObjects(): S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjectsOutputReference;
        /**
         * @stability stable
         */
        putSseKmsEncryptedObjects(value: S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects | undefined): void;
        /**
         * @stability stable
         */
        resetSseKmsEncryptedObjects(): void;
        /**
         * @stability stable
         */
        get sseKmsEncryptedObjectsInput(): S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketReplicationConfigurationRules {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#delete_marker_replication_status S3Bucket#delete_marker_replication_status}.
         *
         * @stability stable
         */
        readonly deleteMarkerReplicationStatus?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#id S3Bucket#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#prefix S3Bucket#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#priority S3Bucket#priority}.
         *
         * @stability stable
         */
        readonly priority?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#status S3Bucket#status}.
         *
         * @stability stable
         */
        readonly status: string;
        /**
         * destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#destination S3Bucket#destination}
         *
         * @stability stable
         */
        readonly destination: S3BucketReplicationConfigurationRulesDestination;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#filter S3Bucket#filter}
         *
         * @stability stable
         */
        readonly filter?: S3BucketReplicationConfigurationRulesFilter;
        /**
         * source_selection_criteria block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#source_selection_criteria S3Bucket#source_selection_criteria}
         *
         * @stability stable
         */
        readonly sourceSelectionCriteria?: S3BucketReplicationConfigurationRulesSourceSelectionCriteria;
    }
    /**
     * @stability stable
     */
    interface S3BucketReplicationConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#role S3Bucket#role}.
         *
         * @stability stable
         */
        readonly role: string;
        /**
         * rules block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#rules S3Bucket#rules}
         *
         * @stability stable
         */
        readonly rules: S3BucketReplicationConfigurationRules[];
    }
    /**
     * @stability stable
     */
    class S3BucketReplicationConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _role?;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        set role(value: string);
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        private _rules?;
        /**
         * @stability stable
         */
        get rules(): S3BucketReplicationConfigurationRules[];
        /**
         * @stability stable
         */
        set rules(value: S3BucketReplicationConfigurationRules[]);
        /**
         * @stability stable
         */
        get rulesInput(): S3BucketReplicationConfigurationRules[] | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#kms_master_key_id S3Bucket#kms_master_key_id}.
         *
         * @stability stable
         */
        readonly kmsMasterKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#sse_algorithm S3Bucket#sse_algorithm}.
         *
         * @stability stable
         */
        readonly sseAlgorithm: string;
    }
    /**
     * @stability stable
     */
    class S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsMasterKeyId?;
        /**
         * @stability stable
         */
        get kmsMasterKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsMasterKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsMasterKeyId(): void;
        /**
         * @stability stable
         */
        get kmsMasterKeyIdInput(): string | undefined;
        private _sseAlgorithm?;
        /**
         * @stability stable
         */
        get sseAlgorithm(): string;
        /**
         * @stability stable
         */
        set sseAlgorithm(value: string);
        /**
         * @stability stable
         */
        get sseAlgorithmInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketServerSideEncryptionConfigurationRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#bucket_key_enabled S3Bucket#bucket_key_enabled}.
         *
         * @stability stable
         */
        readonly bucketKeyEnabled?: boolean | cdktf.IResolvable;
        /**
         * apply_server_side_encryption_by_default block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#apply_server_side_encryption_by_default S3Bucket#apply_server_side_encryption_by_default}
         *
         * @stability stable
         */
        readonly applyServerSideEncryptionByDefault: S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault;
    }
    /**
     * @stability stable
     */
    class S3BucketServerSideEncryptionConfigurationRuleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketKeyEnabled?;
        /**
         * @stability stable
         */
        get bucketKeyEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set bucketKeyEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBucketKeyEnabled(): void;
        /**
         * @stability stable
         */
        get bucketKeyEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _applyServerSideEncryptionByDefault?;
        private __applyServerSideEncryptionByDefaultOutput;
        /**
         * @stability stable
         */
        get applyServerSideEncryptionByDefault(): S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefaultOutputReference;
        /**
         * @stability stable
         */
        putApplyServerSideEncryptionByDefault(value: S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault): void;
        /**
         * @stability stable
         */
        get applyServerSideEncryptionByDefaultInput(): S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketServerSideEncryptionConfiguration {
        /**
         * rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#rule S3Bucket#rule}
         *
         * @stability stable
         */
        readonly rule: S3BucketServerSideEncryptionConfigurationRule;
    }
    /**
     * @stability stable
     */
    class S3BucketServerSideEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _rule?;
        private __ruleOutput;
        /**
         * @stability stable
         */
        get rule(): S3BucketServerSideEncryptionConfigurationRuleOutputReference;
        /**
         * @stability stable
         */
        putRule(value: S3BucketServerSideEncryptionConfigurationRule): void;
        /**
         * @stability stable
         */
        get ruleInput(): S3BucketServerSideEncryptionConfigurationRule | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketVersioning {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#enabled S3Bucket#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#mfa_delete S3Bucket#mfa_delete}.
         *
         * @stability stable
         */
        readonly mfaDelete?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3BucketVersioningOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _mfaDelete?;
        /**
         * @stability stable
         */
        get mfaDelete(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mfaDelete(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMfaDelete(): void;
        /**
         * @stability stable
         */
        get mfaDeleteInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketWebsite {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#error_document S3Bucket#error_document}.
         *
         * @stability stable
         */
        readonly errorDocument?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#index_document S3Bucket#index_document}.
         *
         * @stability stable
         */
        readonly indexDocument?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#redirect_all_requests_to S3Bucket#redirect_all_requests_to}.
         *
         * @stability stable
         */
        readonly redirectAllRequestsTo?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html#routing_rules S3Bucket#routing_rules}.
         *
         * @stability stable
         */
        readonly routingRules?: string;
    }
    /**
     * @stability stable
     */
    class S3BucketWebsiteOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _errorDocument?;
        /**
         * @stability stable
         */
        get errorDocument(): string | undefined;
        /**
         * @stability stable
         */
        set errorDocument(value: string | undefined);
        /**
         * @stability stable
         */
        resetErrorDocument(): void;
        /**
         * @stability stable
         */
        get errorDocumentInput(): string | undefined;
        private _indexDocument?;
        /**
         * @stability stable
         */
        get indexDocument(): string | undefined;
        /**
         * @stability stable
         */
        set indexDocument(value: string | undefined);
        /**
         * @stability stable
         */
        resetIndexDocument(): void;
        /**
         * @stability stable
         */
        get indexDocumentInput(): string | undefined;
        private _redirectAllRequestsTo?;
        /**
         * @stability stable
         */
        get redirectAllRequestsTo(): string | undefined;
        /**
         * @stability stable
         */
        set redirectAllRequestsTo(value: string | undefined);
        /**
         * @stability stable
         */
        resetRedirectAllRequestsTo(): void;
        /**
         * @stability stable
         */
        get redirectAllRequestsToInput(): string | undefined;
        private _routingRules?;
        /**
         * @stability stable
         */
        get routingRules(): string | undefined;
        /**
         * @stability stable
         */
        set routingRules(value: string | undefined);
        /**
         * @stability stable
         */
        resetRoutingRules(): void;
        /**
         * @stability stable
         */
        get routingRulesInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html aws_s3_bucket}.
     *
     * @stability stable
     */
    class S3Bucket extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket.html aws_s3_bucket} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: S3BucketConfig);
        private _accelerationStatus?;
        /**
         * @stability stable
         */
        get accelerationStatus(): string | undefined;
        /**
         * @stability stable
         */
        set accelerationStatus(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccelerationStatus(): void;
        /**
         * @stability stable
         */
        get accelerationStatusInput(): string | undefined;
        private _acl?;
        /**
         * @stability stable
         */
        get acl(): string | undefined;
        /**
         * @stability stable
         */
        set acl(value: string | undefined);
        /**
         * @stability stable
         */
        resetAcl(): void;
        /**
         * @stability stable
         */
        get aclInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string | undefined;
        /**
         * @stability stable
         */
        set bucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucket(): void;
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get bucketDomainName(): string;
        private _bucketPrefix?;
        /**
         * @stability stable
         */
        get bucketPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set bucketPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketPrefix(): void;
        /**
         * @stability stable
         */
        get bucketPrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        get bucketRegionalDomainName(): string;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        private _hostedZoneId?;
        /**
         * @stability stable
         */
        get hostedZoneId(): string | undefined;
        /**
         * @stability stable
         */
        set hostedZoneId(value: string | undefined);
        /**
         * @stability stable
         */
        resetHostedZoneId(): void;
        /**
         * @stability stable
         */
        get hostedZoneIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        get region(): string;
        private _requestPayer?;
        /**
         * @stability stable
         */
        get requestPayer(): string | undefined;
        /**
         * @stability stable
         */
        set requestPayer(value: string | undefined);
        /**
         * @stability stable
         */
        resetRequestPayer(): void;
        /**
         * @stability stable
         */
        get requestPayerInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _websiteDomain?;
        /**
         * @stability stable
         */
        get websiteDomain(): string | undefined;
        /**
         * @stability stable
         */
        set websiteDomain(value: string | undefined);
        /**
         * @stability stable
         */
        resetWebsiteDomain(): void;
        /**
         * @stability stable
         */
        get websiteDomainInput(): string | undefined;
        private _websiteEndpoint?;
        /**
         * @stability stable
         */
        get websiteEndpoint(): string | undefined;
        /**
         * @stability stable
         */
        set websiteEndpoint(value: string | undefined);
        /**
         * @stability stable
         */
        resetWebsiteEndpoint(): void;
        /**
         * @stability stable
         */
        get websiteEndpointInput(): string | undefined;
        private _corsRule?;
        /**
         * @stability stable
         */
        get corsRule(): S3BucketCorsRule[] | undefined;
        /**
         * @stability stable
         */
        set corsRule(value: S3BucketCorsRule[] | undefined);
        /**
         * @stability stable
         */
        resetCorsRule(): void;
        /**
         * @stability stable
         */
        get corsRuleInput(): S3BucketCorsRule[] | undefined;
        private _grant?;
        /**
         * @stability stable
         */
        get grant(): S3BucketGrant[] | undefined;
        /**
         * @stability stable
         */
        set grant(value: S3BucketGrant[] | undefined);
        /**
         * @stability stable
         */
        resetGrant(): void;
        /**
         * @stability stable
         */
        get grantInput(): S3BucketGrant[] | undefined;
        private _lifecycleRule?;
        /**
         * @stability stable
         */
        get lifecycleRule(): S3BucketLifecycleRule[] | undefined;
        /**
         * @stability stable
         */
        set lifecycleRule(value: S3BucketLifecycleRule[] | undefined);
        /**
         * @stability stable
         */
        resetLifecycleRule(): void;
        /**
         * @stability stable
         */
        get lifecycleRuleInput(): S3BucketLifecycleRule[] | undefined;
        private _logging?;
        /**
         * @stability stable
         */
        get logging(): S3BucketLogging[] | undefined;
        /**
         * @stability stable
         */
        set logging(value: S3BucketLogging[] | undefined);
        /**
         * @stability stable
         */
        resetLogging(): void;
        /**
         * @stability stable
         */
        get loggingInput(): S3BucketLogging[] | undefined;
        private _objectLockConfiguration?;
        private __objectLockConfigurationOutput;
        /**
         * @stability stable
         */
        get objectLockConfiguration(): S3BucketObjectLockConfigurationOutputReference;
        /**
         * @stability stable
         */
        putObjectLockConfiguration(value: S3BucketObjectLockConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetObjectLockConfiguration(): void;
        /**
         * @stability stable
         */
        get objectLockConfigurationInput(): S3BucketObjectLockConfiguration | undefined;
        private _replicationConfiguration?;
        private __replicationConfigurationOutput;
        /**
         * @stability stable
         */
        get replicationConfiguration(): S3BucketReplicationConfigurationOutputReference;
        /**
         * @stability stable
         */
        putReplicationConfiguration(value: S3BucketReplicationConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetReplicationConfiguration(): void;
        /**
         * @stability stable
         */
        get replicationConfigurationInput(): S3BucketReplicationConfiguration | undefined;
        private _serverSideEncryptionConfiguration?;
        private __serverSideEncryptionConfigurationOutput;
        /**
         * @stability stable
         */
        get serverSideEncryptionConfiguration(): S3BucketServerSideEncryptionConfigurationOutputReference;
        /**
         * @stability stable
         */
        putServerSideEncryptionConfiguration(value: S3BucketServerSideEncryptionConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetServerSideEncryptionConfiguration(): void;
        /**
         * @stability stable
         */
        get serverSideEncryptionConfigurationInput(): S3BucketServerSideEncryptionConfiguration | undefined;
        private _versioning?;
        private __versioningOutput;
        /**
         * @stability stable
         */
        get versioning(): S3BucketVersioningOutputReference;
        /**
         * @stability stable
         */
        putVersioning(value: S3BucketVersioning | undefined): void;
        /**
         * @stability stable
         */
        resetVersioning(): void;
        /**
         * @stability stable
         */
        get versioningInput(): S3BucketVersioning | undefined;
        private _website?;
        private __websiteOutput;
        /**
         * @stability stable
         */
        get website(): S3BucketWebsiteOutputReference;
        /**
         * @stability stable
         */
        putWebsite(value: S3BucketWebsite | undefined): void;
        /**
         * @stability stable
         */
        resetWebsite(): void;
        /**
         * @stability stable
         */
        get websiteInput(): S3BucketWebsite | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketAnalyticsConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#bucket S3BucketAnalyticsConfiguration#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#name S3BucketAnalyticsConfiguration#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#filter S3BucketAnalyticsConfiguration#filter}
         *
         * @stability stable
         */
        readonly filter?: S3BucketAnalyticsConfigurationFilter;
        /**
         * storage_class_analysis block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#storage_class_analysis S3BucketAnalyticsConfiguration#storage_class_analysis}
         *
         * @stability stable
         */
        readonly storageClassAnalysis?: S3BucketAnalyticsConfigurationStorageClassAnalysis;
    }
    /**
     * @stability stable
     */
    interface S3BucketAnalyticsConfigurationFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#prefix S3BucketAnalyticsConfiguration#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#tags S3BucketAnalyticsConfiguration#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3BucketAnalyticsConfigurationFilterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#bucket_account_id S3BucketAnalyticsConfiguration#bucket_account_id}.
         *
         * @stability stable
         */
        readonly bucketAccountId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#bucket_arn S3BucketAnalyticsConfiguration#bucket_arn}.
         *
         * @stability stable
         */
        readonly bucketArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#format S3BucketAnalyticsConfiguration#format}.
         *
         * @stability stable
         */
        readonly format?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#prefix S3BucketAnalyticsConfiguration#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
    }
    /**
     * @stability stable
     */
    class S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestinationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketAccountId?;
        /**
         * @stability stable
         */
        get bucketAccountId(): string | undefined;
        /**
         * @stability stable
         */
        set bucketAccountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketAccountId(): void;
        /**
         * @stability stable
         */
        get bucketAccountIdInput(): string | undefined;
        private _bucketArn?;
        /**
         * @stability stable
         */
        get bucketArn(): string;
        /**
         * @stability stable
         */
        set bucketArn(value: string);
        /**
         * @stability stable
         */
        get bucketArnInput(): string | undefined;
        private _format?;
        /**
         * @stability stable
         */
        get format(): string | undefined;
        /**
         * @stability stable
         */
        set format(value: string | undefined);
        /**
         * @stability stable
         */
        resetFormat(): void;
        /**
         * @stability stable
         */
        get formatInput(): string | undefined;
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination {
        /**
         * s3_bucket_destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#s3_bucket_destination S3BucketAnalyticsConfiguration#s3_bucket_destination}
         *
         * @stability stable
         */
        readonly s3BucketDestination: S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination;
    }
    /**
     * @stability stable
     */
    class S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _s3BucketDestination?;
        private __s3BucketDestinationOutput;
        /**
         * @stability stable
         */
        get s3BucketDestination(): S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestinationOutputReference;
        /**
         * @stability stable
         */
        putS3BucketDestination(value: S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination): void;
        /**
         * @stability stable
         */
        get s3BucketDestinationInput(): S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#output_schema_version S3BucketAnalyticsConfiguration#output_schema_version}.
         *
         * @stability stable
         */
        readonly outputSchemaVersion?: string;
        /**
         * destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#destination S3BucketAnalyticsConfiguration#destination}
         *
         * @stability stable
         */
        readonly destination: S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination;
    }
    /**
     * @stability stable
     */
    class S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _outputSchemaVersion?;
        /**
         * @stability stable
         */
        get outputSchemaVersion(): string | undefined;
        /**
         * @stability stable
         */
        set outputSchemaVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutputSchemaVersion(): void;
        /**
         * @stability stable
         */
        get outputSchemaVersionInput(): string | undefined;
        private _destination?;
        private __destinationOutput;
        /**
         * @stability stable
         */
        get destination(): S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationOutputReference;
        /**
         * @stability stable
         */
        putDestination(value: S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination): void;
        /**
         * @stability stable
         */
        get destinationInput(): S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketAnalyticsConfigurationStorageClassAnalysis {
        /**
         * data_export block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html#data_export S3BucketAnalyticsConfiguration#data_export}
         *
         * @stability stable
         */
        readonly dataExport: S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport;
    }
    /**
     * @stability stable
     */
    class S3BucketAnalyticsConfigurationStorageClassAnalysisOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _dataExport?;
        private __dataExportOutput;
        /**
         * @stability stable
         */
        get dataExport(): S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportOutputReference;
        /**
         * @stability stable
         */
        putDataExport(value: S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport): void;
        /**
         * @stability stable
         */
        get dataExportInput(): S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html aws_s3_bucket_analytics_configuration}.
     *
     * @stability stable
     */
    class S3BucketAnalyticsConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_analytics_configuration.html aws_s3_bucket_analytics_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketAnalyticsConfigurationConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _filter?;
        private __filterOutput;
        /**
         * @stability stable
         */
        get filter(): S3BucketAnalyticsConfigurationFilterOutputReference;
        /**
         * @stability stable
         */
        putFilter(value: S3BucketAnalyticsConfigurationFilter | undefined): void;
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): S3BucketAnalyticsConfigurationFilter | undefined;
        private _storageClassAnalysis?;
        private __storageClassAnalysisOutput;
        /**
         * @stability stable
         */
        get storageClassAnalysis(): S3BucketAnalyticsConfigurationStorageClassAnalysisOutputReference;
        /**
         * @stability stable
         */
        putStorageClassAnalysis(value: S3BucketAnalyticsConfigurationStorageClassAnalysis | undefined): void;
        /**
         * @stability stable
         */
        resetStorageClassAnalysis(): void;
        /**
         * @stability stable
         */
        get storageClassAnalysisInput(): S3BucketAnalyticsConfigurationStorageClassAnalysis | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketInventoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#bucket S3BucketInventory#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#enabled S3BucketInventory#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#included_object_versions S3BucketInventory#included_object_versions}.
         *
         * @stability stable
         */
        readonly includedObjectVersions: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#name S3BucketInventory#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#optional_fields S3BucketInventory#optional_fields}.
         *
         * @stability stable
         */
        readonly optionalFields?: string[];
        /**
         * destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#destination S3BucketInventory#destination}
         *
         * @stability stable
         */
        readonly destination: S3BucketInventoryDestination;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#filter S3BucketInventory#filter}
         *
         * @stability stable
         */
        readonly filter?: S3BucketInventoryFilter;
        /**
         * schedule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#schedule S3BucketInventory#schedule}
         *
         * @stability stable
         */
        readonly schedule: S3BucketInventorySchedule;
    }
    /**
     * @stability stable
     */
    interface S3BucketInventoryDestinationBucketEncryptionSseKms {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#key_id S3BucketInventory#key_id}.
         *
         * @stability stable
         */
        readonly keyId: string;
    }
    /**
     * @stability stable
     */
    class S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string;
        /**
         * @stability stable
         */
        set keyId(value: string);
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketInventoryDestinationBucketEncryptionSseS3 {
    }
    /**
     * @stability stable
     */
    class S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    }
    /**
     * @stability stable
     */
    interface S3BucketInventoryDestinationBucketEncryption {
        /**
         * sse_kms block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#sse_kms S3BucketInventory#sse_kms}
         *
         * @stability stable
         */
        readonly sseKms?: S3BucketInventoryDestinationBucketEncryptionSseKms;
        /**
         * sse_s3 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#sse_s3 S3BucketInventory#sse_s3}
         *
         * @stability stable
         */
        readonly sseS3?: S3BucketInventoryDestinationBucketEncryptionSseS3;
    }
    /**
     * @stability stable
     */
    class S3BucketInventoryDestinationBucketEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _sseKms?;
        private __sseKmsOutput;
        /**
         * @stability stable
         */
        get sseKms(): S3BucketInventoryDestinationBucketEncryptionSseKmsOutputReference;
        /**
         * @stability stable
         */
        putSseKms(value: S3BucketInventoryDestinationBucketEncryptionSseKms | undefined): void;
        /**
         * @stability stable
         */
        resetSseKms(): void;
        /**
         * @stability stable
         */
        get sseKmsInput(): S3BucketInventoryDestinationBucketEncryptionSseKms | undefined;
        private _sseS3?;
        private __sseS3Output;
        /**
         * @stability stable
         */
        get sseS3(): S3BucketInventoryDestinationBucketEncryptionSseS3OutputReference;
        /**
         * @stability stable
         */
        putSseS3(value: S3BucketInventoryDestinationBucketEncryptionSseS3 | undefined): void;
        /**
         * @stability stable
         */
        resetSseS3(): void;
        /**
         * @stability stable
         */
        get sseS3Input(): S3BucketInventoryDestinationBucketEncryptionSseS3 | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketInventoryDestinationBucket {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#account_id S3BucketInventory#account_id}.
         *
         * @stability stable
         */
        readonly accountId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#bucket_arn S3BucketInventory#bucket_arn}.
         *
         * @stability stable
         */
        readonly bucketArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#format S3BucketInventory#format}.
         *
         * @stability stable
         */
        readonly format: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#prefix S3BucketInventory#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#encryption S3BucketInventory#encryption}
         *
         * @stability stable
         */
        readonly encryption?: S3BucketInventoryDestinationBucketEncryption;
    }
    /**
     * @stability stable
     */
    class S3BucketInventoryDestinationBucketOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string | undefined;
        /**
         * @stability stable
         */
        set accountId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAccountId(): void;
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        private _bucketArn?;
        /**
         * @stability stable
         */
        get bucketArn(): string;
        /**
         * @stability stable
         */
        set bucketArn(value: string);
        /**
         * @stability stable
         */
        get bucketArnInput(): string | undefined;
        private _format?;
        /**
         * @stability stable
         */
        get format(): string;
        /**
         * @stability stable
         */
        set format(value: string);
        /**
         * @stability stable
         */
        get formatInput(): string | undefined;
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
        private _encryption?;
        private __encryptionOutput;
        /**
         * @stability stable
         */
        get encryption(): S3BucketInventoryDestinationBucketEncryptionOutputReference;
        /**
         * @stability stable
         */
        putEncryption(value: S3BucketInventoryDestinationBucketEncryption | undefined): void;
        /**
         * @stability stable
         */
        resetEncryption(): void;
        /**
         * @stability stable
         */
        get encryptionInput(): S3BucketInventoryDestinationBucketEncryption | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketInventoryDestination {
        /**
         * bucket block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#bucket S3BucketInventory#bucket}
         *
         * @stability stable
         */
        readonly bucket: S3BucketInventoryDestinationBucket;
    }
    /**
     * @stability stable
     */
    class S3BucketInventoryDestinationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucket?;
        private __bucketOutput;
        /**
         * @stability stable
         */
        get bucket(): S3BucketInventoryDestinationBucketOutputReference;
        /**
         * @stability stable
         */
        putBucket(value: S3BucketInventoryDestinationBucket): void;
        /**
         * @stability stable
         */
        get bucketInput(): S3BucketInventoryDestinationBucket | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketInventoryFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#prefix S3BucketInventory#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
    }
    /**
     * @stability stable
     */
    class S3BucketInventoryFilterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface S3BucketInventorySchedule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html#frequency S3BucketInventory#frequency}.
         *
         * @stability stable
         */
        readonly frequency: string;
    }
    /**
     * @stability stable
     */
    class S3BucketInventoryScheduleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _frequency?;
        /**
         * @stability stable
         */
        get frequency(): string;
        /**
         * @stability stable
         */
        set frequency(value: string);
        /**
         * @stability stable
         */
        get frequencyInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html aws_s3_bucket_inventory}.
     *
     * @stability stable
     */
    class S3BucketInventory extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_inventory.html aws_s3_bucket_inventory} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketInventoryConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _includedObjectVersions?;
        /**
         * @stability stable
         */
        get includedObjectVersions(): string;
        /**
         * @stability stable
         */
        set includedObjectVersions(value: string);
        /**
         * @stability stable
         */
        get includedObjectVersionsInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _optionalFields?;
        /**
         * @stability stable
         */
        get optionalFields(): string[] | undefined;
        /**
         * @stability stable
         */
        set optionalFields(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetOptionalFields(): void;
        /**
         * @stability stable
         */
        get optionalFieldsInput(): string[] | undefined;
        private _destination?;
        private __destinationOutput;
        /**
         * @stability stable
         */
        get destination(): S3BucketInventoryDestinationOutputReference;
        /**
         * @stability stable
         */
        putDestination(value: S3BucketInventoryDestination): void;
        /**
         * @stability stable
         */
        get destinationInput(): S3BucketInventoryDestination | undefined;
        private _filter?;
        private __filterOutput;
        /**
         * @stability stable
         */
        get filter(): S3BucketInventoryFilterOutputReference;
        /**
         * @stability stable
         */
        putFilter(value: S3BucketInventoryFilter | undefined): void;
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): S3BucketInventoryFilter | undefined;
        private _schedule?;
        private __scheduleOutput;
        /**
         * @stability stable
         */
        get schedule(): S3BucketInventoryScheduleOutputReference;
        /**
         * @stability stable
         */
        putSchedule(value: S3BucketInventorySchedule): void;
        /**
         * @stability stable
         */
        get scheduleInput(): S3BucketInventorySchedule | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketMetricConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_metric.html#bucket S3BucketMetric#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_metric.html#name S3BucketMetric#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_metric.html#filter S3BucketMetric#filter}
         *
         * @stability stable
         */
        readonly filter?: S3BucketMetricFilter;
    }
    /**
     * @stability stable
     */
    interface S3BucketMetricFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_metric.html#prefix S3BucketMetric#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_metric.html#tags S3BucketMetric#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3BucketMetricFilterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_metric.html aws_s3_bucket_metric}.
     *
     * @stability stable
     */
    class S3BucketMetric extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_metric.html aws_s3_bucket_metric} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketMetricConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _filter?;
        private __filterOutput;
        /**
         * @stability stable
         */
        get filter(): S3BucketMetricFilterOutputReference;
        /**
         * @stability stable
         */
        putFilter(value: S3BucketMetricFilter | undefined): void;
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): S3BucketMetricFilter | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketNotificationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#bucket S3BucketNotification#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * lambda_function block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#lambda_function S3BucketNotification#lambda_function}
         *
         * @stability stable
         */
        readonly lambdaFunction?: S3BucketNotificationLambdaFunction[];
        /**
         * queue block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#queue S3BucketNotification#queue}
         *
         * @stability stable
         */
        readonly queue?: S3BucketNotificationQueue[];
        /**
         * topic block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#topic S3BucketNotification#topic}
         *
         * @stability stable
         */
        readonly topic?: S3BucketNotificationTopic[];
    }
    /**
     * @stability stable
     */
    interface S3BucketNotificationLambdaFunction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#events S3BucketNotification#events}.
         *
         * @stability stable
         */
        readonly events: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#filter_prefix S3BucketNotification#filter_prefix}.
         *
         * @stability stable
         */
        readonly filterPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#filter_suffix S3BucketNotification#filter_suffix}.
         *
         * @stability stable
         */
        readonly filterSuffix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#id S3BucketNotification#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#lambda_function_arn S3BucketNotification#lambda_function_arn}.
         *
         * @stability stable
         */
        readonly lambdaFunctionArn?: string;
    }
    /**
     * @stability stable
     */
    interface S3BucketNotificationQueue {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#events S3BucketNotification#events}.
         *
         * @stability stable
         */
        readonly events: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#filter_prefix S3BucketNotification#filter_prefix}.
         *
         * @stability stable
         */
        readonly filterPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#filter_suffix S3BucketNotification#filter_suffix}.
         *
         * @stability stable
         */
        readonly filterSuffix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#id S3BucketNotification#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#queue_arn S3BucketNotification#queue_arn}.
         *
         * @stability stable
         */
        readonly queueArn: string;
    }
    /**
     * @stability stable
     */
    interface S3BucketNotificationTopic {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#events S3BucketNotification#events}.
         *
         * @stability stable
         */
        readonly events: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#filter_prefix S3BucketNotification#filter_prefix}.
         *
         * @stability stable
         */
        readonly filterPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#filter_suffix S3BucketNotification#filter_suffix}.
         *
         * @stability stable
         */
        readonly filterSuffix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#id S3BucketNotification#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html#topic_arn S3BucketNotification#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html aws_s3_bucket_notification}.
     *
     * @stability stable
     */
    class S3BucketNotification extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_notification.html aws_s3_bucket_notification} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketNotificationConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _lambdaFunction?;
        /**
         * @stability stable
         */
        get lambdaFunction(): S3BucketNotificationLambdaFunction[] | undefined;
        /**
         * @stability stable
         */
        set lambdaFunction(value: S3BucketNotificationLambdaFunction[] | undefined);
        /**
         * @stability stable
         */
        resetLambdaFunction(): void;
        /**
         * @stability stable
         */
        get lambdaFunctionInput(): S3BucketNotificationLambdaFunction[] | undefined;
        private _queue?;
        /**
         * @stability stable
         */
        get queue(): S3BucketNotificationQueue[] | undefined;
        /**
         * @stability stable
         */
        set queue(value: S3BucketNotificationQueue[] | undefined);
        /**
         * @stability stable
         */
        resetQueue(): void;
        /**
         * @stability stable
         */
        get queueInput(): S3BucketNotificationQueue[] | undefined;
        private _topic?;
        /**
         * @stability stable
         */
        get topic(): S3BucketNotificationTopic[] | undefined;
        /**
         * @stability stable
         */
        set topic(value: S3BucketNotificationTopic[] | undefined);
        /**
         * @stability stable
         */
        resetTopic(): void;
        /**
         * @stability stable
         */
        get topicInput(): S3BucketNotificationTopic[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketObjectConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#acl S3BucketObject#acl}.
         *
         * @stability stable
         */
        readonly acl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#bucket S3BucketObject#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#bucket_key_enabled S3BucketObject#bucket_key_enabled}.
         *
         * @stability stable
         */
        readonly bucketKeyEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#cache_control S3BucketObject#cache_control}.
         *
         * @stability stable
         */
        readonly cacheControl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#content S3BucketObject#content}.
         *
         * @stability stable
         */
        readonly content?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#content_base64 S3BucketObject#content_base64}.
         *
         * @stability stable
         */
        readonly contentBase64?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#content_disposition S3BucketObject#content_disposition}.
         *
         * @stability stable
         */
        readonly contentDisposition?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#content_encoding S3BucketObject#content_encoding}.
         *
         * @stability stable
         */
        readonly contentEncoding?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#content_language S3BucketObject#content_language}.
         *
         * @stability stable
         */
        readonly contentLanguage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#content_type S3BucketObject#content_type}.
         *
         * @stability stable
         */
        readonly contentType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#etag S3BucketObject#etag}.
         *
         * @stability stable
         */
        readonly etag?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#force_destroy S3BucketObject#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#key S3BucketObject#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#kms_key_id S3BucketObject#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#metadata S3BucketObject#metadata}.
         *
         * @stability stable
         */
        readonly metadata?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#object_lock_legal_hold_status S3BucketObject#object_lock_legal_hold_status}.
         *
         * @stability stable
         */
        readonly objectLockLegalHoldStatus?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#object_lock_mode S3BucketObject#object_lock_mode}.
         *
         * @stability stable
         */
        readonly objectLockMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#object_lock_retain_until_date S3BucketObject#object_lock_retain_until_date}.
         *
         * @stability stable
         */
        readonly objectLockRetainUntilDate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#server_side_encryption S3BucketObject#server_side_encryption}.
         *
         * @stability stable
         */
        readonly serverSideEncryption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#source S3BucketObject#source}.
         *
         * @stability stable
         */
        readonly source?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#source_hash S3BucketObject#source_hash}.
         *
         * @stability stable
         */
        readonly sourceHash?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#storage_class S3BucketObject#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#tags S3BucketObject#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#tags_all S3BucketObject#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html#website_redirect S3BucketObject#website_redirect}.
         *
         * @stability stable
         */
        readonly websiteRedirect?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html aws_s3_bucket_object}.
     *
     * @stability stable
     */
    class S3BucketObject extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_object.html aws_s3_bucket_object} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketObjectConfig);
        private _acl?;
        /**
         * @stability stable
         */
        get acl(): string | undefined;
        /**
         * @stability stable
         */
        set acl(value: string | undefined);
        /**
         * @stability stable
         */
        resetAcl(): void;
        /**
         * @stability stable
         */
        get aclInput(): string | undefined;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _bucketKeyEnabled?;
        /**
         * @stability stable
         */
        get bucketKeyEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set bucketKeyEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBucketKeyEnabled(): void;
        /**
         * @stability stable
         */
        get bucketKeyEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _cacheControl?;
        /**
         * @stability stable
         */
        get cacheControl(): string | undefined;
        /**
         * @stability stable
         */
        set cacheControl(value: string | undefined);
        /**
         * @stability stable
         */
        resetCacheControl(): void;
        /**
         * @stability stable
         */
        get cacheControlInput(): string | undefined;
        private _content?;
        /**
         * @stability stable
         */
        get content(): string | undefined;
        /**
         * @stability stable
         */
        set content(value: string | undefined);
        /**
         * @stability stable
         */
        resetContent(): void;
        /**
         * @stability stable
         */
        get contentInput(): string | undefined;
        private _contentBase64?;
        /**
         * @stability stable
         */
        get contentBase64(): string | undefined;
        /**
         * @stability stable
         */
        set contentBase64(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentBase64(): void;
        /**
         * @stability stable
         */
        get contentBase64Input(): string | undefined;
        private _contentDisposition?;
        /**
         * @stability stable
         */
        get contentDisposition(): string | undefined;
        /**
         * @stability stable
         */
        set contentDisposition(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentDisposition(): void;
        /**
         * @stability stable
         */
        get contentDispositionInput(): string | undefined;
        private _contentEncoding?;
        /**
         * @stability stable
         */
        get contentEncoding(): string | undefined;
        /**
         * @stability stable
         */
        set contentEncoding(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentEncoding(): void;
        /**
         * @stability stable
         */
        get contentEncodingInput(): string | undefined;
        private _contentLanguage?;
        /**
         * @stability stable
         */
        get contentLanguage(): string | undefined;
        /**
         * @stability stable
         */
        set contentLanguage(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentLanguage(): void;
        /**
         * @stability stable
         */
        get contentLanguageInput(): string | undefined;
        private _contentType?;
        /**
         * @stability stable
         */
        get contentType(): string | undefined;
        /**
         * @stability stable
         */
        set contentType(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentType(): void;
        /**
         * @stability stable
         */
        get contentTypeInput(): string | undefined;
        private _etag?;
        /**
         * @stability stable
         */
        get etag(): string | undefined;
        /**
         * @stability stable
         */
        set etag(value: string | undefined);
        /**
         * @stability stable
         */
        resetEtag(): void;
        /**
         * @stability stable
         */
        get etagInput(): string | undefined;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        set key(value: string);
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _metadata?;
        /**
         * @stability stable
         */
        get metadata(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set metadata(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMetadata(): void;
        /**
         * @stability stable
         */
        get metadataInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _objectLockLegalHoldStatus?;
        /**
         * @stability stable
         */
        get objectLockLegalHoldStatus(): string | undefined;
        /**
         * @stability stable
         */
        set objectLockLegalHoldStatus(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectLockLegalHoldStatus(): void;
        /**
         * @stability stable
         */
        get objectLockLegalHoldStatusInput(): string | undefined;
        private _objectLockMode?;
        /**
         * @stability stable
         */
        get objectLockMode(): string | undefined;
        /**
         * @stability stable
         */
        set objectLockMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectLockMode(): void;
        /**
         * @stability stable
         */
        get objectLockModeInput(): string | undefined;
        private _objectLockRetainUntilDate?;
        /**
         * @stability stable
         */
        get objectLockRetainUntilDate(): string | undefined;
        /**
         * @stability stable
         */
        set objectLockRetainUntilDate(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectLockRetainUntilDate(): void;
        /**
         * @stability stable
         */
        get objectLockRetainUntilDateInput(): string | undefined;
        private _serverSideEncryption?;
        /**
         * @stability stable
         */
        get serverSideEncryption(): string | undefined;
        /**
         * @stability stable
         */
        set serverSideEncryption(value: string | undefined);
        /**
         * @stability stable
         */
        resetServerSideEncryption(): void;
        /**
         * @stability stable
         */
        get serverSideEncryptionInput(): string | undefined;
        private _source?;
        /**
         * @stability stable
         */
        get source(): string | undefined;
        /**
         * @stability stable
         */
        set source(value: string | undefined);
        /**
         * @stability stable
         */
        resetSource(): void;
        /**
         * @stability stable
         */
        get sourceInput(): string | undefined;
        private _sourceHash?;
        /**
         * @stability stable
         */
        get sourceHash(): string | undefined;
        /**
         * @stability stable
         */
        set sourceHash(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceHash(): void;
        /**
         * @stability stable
         */
        get sourceHashInput(): string | undefined;
        private _storageClass?;
        /**
         * @stability stable
         */
        get storageClass(): string | undefined;
        /**
         * @stability stable
         */
        set storageClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageClass(): void;
        /**
         * @stability stable
         */
        get storageClassInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get versionId(): string;
        private _websiteRedirect?;
        /**
         * @stability stable
         */
        get websiteRedirect(): string | undefined;
        /**
         * @stability stable
         */
        set websiteRedirect(value: string | undefined);
        /**
         * @stability stable
         */
        resetWebsiteRedirect(): void;
        /**
         * @stability stable
         */
        get websiteRedirectInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketOwnershipControlsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_ownership_controls.html#bucket S3BucketOwnershipControls#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_ownership_controls.html#rule S3BucketOwnershipControls#rule}
         *
         * @stability stable
         */
        readonly rule: S3BucketOwnershipControlsRule;
    }
    /**
     * @stability stable
     */
    interface S3BucketOwnershipControlsRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_ownership_controls.html#object_ownership S3BucketOwnershipControls#object_ownership}.
         *
         * @stability stable
         */
        readonly objectOwnership: string;
    }
    /**
     * @stability stable
     */
    class S3BucketOwnershipControlsRuleOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _objectOwnership?;
        /**
         * @stability stable
         */
        get objectOwnership(): string;
        /**
         * @stability stable
         */
        set objectOwnership(value: string);
        /**
         * @stability stable
         */
        get objectOwnershipInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_ownership_controls.html aws_s3_bucket_ownership_controls}.
     *
     * @stability stable
     */
    class S3BucketOwnershipControls extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_ownership_controls.html aws_s3_bucket_ownership_controls} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketOwnershipControlsConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _rule?;
        private __ruleOutput;
        /**
         * @stability stable
         */
        get rule(): S3BucketOwnershipControlsRuleOutputReference;
        /**
         * @stability stable
         */
        putRule(value: S3BucketOwnershipControlsRule): void;
        /**
         * @stability stable
         */
        get ruleInput(): S3BucketOwnershipControlsRule | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_policy.html#bucket S3BucketPolicy#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_policy.html#policy S3BucketPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_policy.html aws_s3_bucket_policy}.
     *
     * @stability stable
     */
    class S3BucketPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_policy.html aws_s3_bucket_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketPolicyConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3BucketPublicAccessBlockConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_public_access_block.html#block_public_acls S3BucketPublicAccessBlock#block_public_acls}.
         *
         * @stability stable
         */
        readonly blockPublicAcls?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_public_access_block.html#block_public_policy S3BucketPublicAccessBlock#block_public_policy}.
         *
         * @stability stable
         */
        readonly blockPublicPolicy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_public_access_block.html#bucket S3BucketPublicAccessBlock#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_public_access_block.html#ignore_public_acls S3BucketPublicAccessBlock#ignore_public_acls}.
         *
         * @stability stable
         */
        readonly ignorePublicAcls?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_public_access_block.html#restrict_public_buckets S3BucketPublicAccessBlock#restrict_public_buckets}.
         *
         * @stability stable
         */
        readonly restrictPublicBuckets?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_public_access_block.html aws_s3_bucket_public_access_block}.
     *
     * @stability stable
     */
    class S3BucketPublicAccessBlock extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_bucket_public_access_block.html aws_s3_bucket_public_access_block} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3BucketPublicAccessBlockConfig);
        private _blockPublicAcls?;
        /**
         * @stability stable
         */
        get blockPublicAcls(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set blockPublicAcls(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBlockPublicAcls(): void;
        /**
         * @stability stable
         */
        get blockPublicAclsInput(): boolean | cdktf.IResolvable | undefined;
        private _blockPublicPolicy?;
        /**
         * @stability stable
         */
        get blockPublicPolicy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set blockPublicPolicy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBlockPublicPolicy(): void;
        /**
         * @stability stable
         */
        get blockPublicPolicyInput(): boolean | cdktf.IResolvable | undefined;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ignorePublicAcls?;
        /**
         * @stability stable
         */
        get ignorePublicAcls(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set ignorePublicAcls(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIgnorePublicAcls(): void;
        /**
         * @stability stable
         */
        get ignorePublicAclsInput(): boolean | cdktf.IResolvable | undefined;
        private _restrictPublicBuckets?;
        /**
         * @stability stable
         */
        get restrictPublicBuckets(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set restrictPublicBuckets(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRestrictPublicBuckets(): void;
        /**
         * @stability stable
         */
        get restrictPublicBucketsInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3ObjectCopyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#acl S3ObjectCopy#acl}.
         *
         * @stability stable
         */
        readonly acl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#bucket S3ObjectCopy#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#bucket_key_enabled S3ObjectCopy#bucket_key_enabled}.
         *
         * @stability stable
         */
        readonly bucketKeyEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#cache_control S3ObjectCopy#cache_control}.
         *
         * @stability stable
         */
        readonly cacheControl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#content_disposition S3ObjectCopy#content_disposition}.
         *
         * @stability stable
         */
        readonly contentDisposition?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#content_encoding S3ObjectCopy#content_encoding}.
         *
         * @stability stable
         */
        readonly contentEncoding?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#content_language S3ObjectCopy#content_language}.
         *
         * @stability stable
         */
        readonly contentLanguage?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#content_type S3ObjectCopy#content_type}.
         *
         * @stability stable
         */
        readonly contentType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#copy_if_match S3ObjectCopy#copy_if_match}.
         *
         * @stability stable
         */
        readonly copyIfMatch?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#copy_if_modified_since S3ObjectCopy#copy_if_modified_since}.
         *
         * @stability stable
         */
        readonly copyIfModifiedSince?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#copy_if_none_match S3ObjectCopy#copy_if_none_match}.
         *
         * @stability stable
         */
        readonly copyIfNoneMatch?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#copy_if_unmodified_since S3ObjectCopy#copy_if_unmodified_since}.
         *
         * @stability stable
         */
        readonly copyIfUnmodifiedSince?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#customer_algorithm S3ObjectCopy#customer_algorithm}.
         *
         * @stability stable
         */
        readonly customerAlgorithm?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#customer_key S3ObjectCopy#customer_key}.
         *
         * @stability stable
         */
        readonly customerKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#customer_key_md5 S3ObjectCopy#customer_key_md5}.
         *
         * @stability stable
         */
        readonly customerKeyMd5?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#expected_bucket_owner S3ObjectCopy#expected_bucket_owner}.
         *
         * @stability stable
         */
        readonly expectedBucketOwner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#expected_source_bucket_owner S3ObjectCopy#expected_source_bucket_owner}.
         *
         * @stability stable
         */
        readonly expectedSourceBucketOwner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#expires S3ObjectCopy#expires}.
         *
         * @stability stable
         */
        readonly expires?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#force_destroy S3ObjectCopy#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#key S3ObjectCopy#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#kms_encryption_context S3ObjectCopy#kms_encryption_context}.
         *
         * @stability stable
         */
        readonly kmsEncryptionContext?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#kms_key_id S3ObjectCopy#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#metadata S3ObjectCopy#metadata}.
         *
         * @stability stable
         */
        readonly metadata?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#metadata_directive S3ObjectCopy#metadata_directive}.
         *
         * @stability stable
         */
        readonly metadataDirective?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#object_lock_legal_hold_status S3ObjectCopy#object_lock_legal_hold_status}.
         *
         * @stability stable
         */
        readonly objectLockLegalHoldStatus?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#object_lock_mode S3ObjectCopy#object_lock_mode}.
         *
         * @stability stable
         */
        readonly objectLockMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#object_lock_retain_until_date S3ObjectCopy#object_lock_retain_until_date}.
         *
         * @stability stable
         */
        readonly objectLockRetainUntilDate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#request_payer S3ObjectCopy#request_payer}.
         *
         * @stability stable
         */
        readonly requestPayer?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#server_side_encryption S3ObjectCopy#server_side_encryption}.
         *
         * @stability stable
         */
        readonly serverSideEncryption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#source S3ObjectCopy#source}.
         *
         * @stability stable
         */
        readonly source: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#source_customer_algorithm S3ObjectCopy#source_customer_algorithm}.
         *
         * @stability stable
         */
        readonly sourceCustomerAlgorithm?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#source_customer_key S3ObjectCopy#source_customer_key}.
         *
         * @stability stable
         */
        readonly sourceCustomerKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#source_customer_key_md5 S3ObjectCopy#source_customer_key_md5}.
         *
         * @stability stable
         */
        readonly sourceCustomerKeyMd5?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#storage_class S3ObjectCopy#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#tagging_directive S3ObjectCopy#tagging_directive}.
         *
         * @stability stable
         */
        readonly taggingDirective?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#tags S3ObjectCopy#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#tags_all S3ObjectCopy#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#website_redirect S3ObjectCopy#website_redirect}.
         *
         * @stability stable
         */
        readonly websiteRedirect?: string;
        /**
         * grant block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#grant S3ObjectCopy#grant}
         *
         * @stability stable
         */
        readonly grant?: S3ObjectCopyGrant[];
    }
    /**
     * @stability stable
     */
    interface S3ObjectCopyGrant {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#email S3ObjectCopy#email}.
         *
         * @stability stable
         */
        readonly email?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#id S3ObjectCopy#id}.
         *
         * @stability stable
         */
        readonly id?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#permissions S3ObjectCopy#permissions}.
         *
         * @stability stable
         */
        readonly permissions: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#type S3ObjectCopy#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html#uri S3ObjectCopy#uri}.
         *
         * @stability stable
         */
        readonly uri?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html aws_s3_object_copy}.
     *
     * @stability stable
     */
    class S3ObjectCopy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3_object_copy.html aws_s3_object_copy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3ObjectCopyConfig);
        private _acl?;
        /**
         * @stability stable
         */
        get acl(): string | undefined;
        /**
         * @stability stable
         */
        set acl(value: string | undefined);
        /**
         * @stability stable
         */
        resetAcl(): void;
        /**
         * @stability stable
         */
        get aclInput(): string | undefined;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _bucketKeyEnabled?;
        /**
         * @stability stable
         */
        get bucketKeyEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set bucketKeyEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBucketKeyEnabled(): void;
        /**
         * @stability stable
         */
        get bucketKeyEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _cacheControl?;
        /**
         * @stability stable
         */
        get cacheControl(): string | undefined;
        /**
         * @stability stable
         */
        set cacheControl(value: string | undefined);
        /**
         * @stability stable
         */
        resetCacheControl(): void;
        /**
         * @stability stable
         */
        get cacheControlInput(): string | undefined;
        private _contentDisposition?;
        /**
         * @stability stable
         */
        get contentDisposition(): string | undefined;
        /**
         * @stability stable
         */
        set contentDisposition(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentDisposition(): void;
        /**
         * @stability stable
         */
        get contentDispositionInput(): string | undefined;
        private _contentEncoding?;
        /**
         * @stability stable
         */
        get contentEncoding(): string | undefined;
        /**
         * @stability stable
         */
        set contentEncoding(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentEncoding(): void;
        /**
         * @stability stable
         */
        get contentEncodingInput(): string | undefined;
        private _contentLanguage?;
        /**
         * @stability stable
         */
        get contentLanguage(): string | undefined;
        /**
         * @stability stable
         */
        set contentLanguage(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentLanguage(): void;
        /**
         * @stability stable
         */
        get contentLanguageInput(): string | undefined;
        private _contentType?;
        /**
         * @stability stable
         */
        get contentType(): string | undefined;
        /**
         * @stability stable
         */
        set contentType(value: string | undefined);
        /**
         * @stability stable
         */
        resetContentType(): void;
        /**
         * @stability stable
         */
        get contentTypeInput(): string | undefined;
        private _copyIfMatch?;
        /**
         * @stability stable
         */
        get copyIfMatch(): string | undefined;
        /**
         * @stability stable
         */
        set copyIfMatch(value: string | undefined);
        /**
         * @stability stable
         */
        resetCopyIfMatch(): void;
        /**
         * @stability stable
         */
        get copyIfMatchInput(): string | undefined;
        private _copyIfModifiedSince?;
        /**
         * @stability stable
         */
        get copyIfModifiedSince(): string | undefined;
        /**
         * @stability stable
         */
        set copyIfModifiedSince(value: string | undefined);
        /**
         * @stability stable
         */
        resetCopyIfModifiedSince(): void;
        /**
         * @stability stable
         */
        get copyIfModifiedSinceInput(): string | undefined;
        private _copyIfNoneMatch?;
        /**
         * @stability stable
         */
        get copyIfNoneMatch(): string | undefined;
        /**
         * @stability stable
         */
        set copyIfNoneMatch(value: string | undefined);
        /**
         * @stability stable
         */
        resetCopyIfNoneMatch(): void;
        /**
         * @stability stable
         */
        get copyIfNoneMatchInput(): string | undefined;
        private _copyIfUnmodifiedSince?;
        /**
         * @stability stable
         */
        get copyIfUnmodifiedSince(): string | undefined;
        /**
         * @stability stable
         */
        set copyIfUnmodifiedSince(value: string | undefined);
        /**
         * @stability stable
         */
        resetCopyIfUnmodifiedSince(): void;
        /**
         * @stability stable
         */
        get copyIfUnmodifiedSinceInput(): string | undefined;
        private _customerAlgorithm?;
        /**
         * @stability stable
         */
        get customerAlgorithm(): string | undefined;
        /**
         * @stability stable
         */
        set customerAlgorithm(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerAlgorithm(): void;
        /**
         * @stability stable
         */
        get customerAlgorithmInput(): string | undefined;
        private _customerKey?;
        /**
         * @stability stable
         */
        get customerKey(): string | undefined;
        /**
         * @stability stable
         */
        set customerKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerKey(): void;
        /**
         * @stability stable
         */
        get customerKeyInput(): string | undefined;
        private _customerKeyMd5?;
        /**
         * @stability stable
         */
        get customerKeyMd5(): string | undefined;
        /**
         * @stability stable
         */
        set customerKeyMd5(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerKeyMd5(): void;
        /**
         * @stability stable
         */
        get customerKeyMd5Input(): string | undefined;
        /**
         * @stability stable
         */
        get etag(): string;
        private _expectedBucketOwner?;
        /**
         * @stability stable
         */
        get expectedBucketOwner(): string | undefined;
        /**
         * @stability stable
         */
        set expectedBucketOwner(value: string | undefined);
        /**
         * @stability stable
         */
        resetExpectedBucketOwner(): void;
        /**
         * @stability stable
         */
        get expectedBucketOwnerInput(): string | undefined;
        private _expectedSourceBucketOwner?;
        /**
         * @stability stable
         */
        get expectedSourceBucketOwner(): string | undefined;
        /**
         * @stability stable
         */
        set expectedSourceBucketOwner(value: string | undefined);
        /**
         * @stability stable
         */
        resetExpectedSourceBucketOwner(): void;
        /**
         * @stability stable
         */
        get expectedSourceBucketOwnerInput(): string | undefined;
        /**
         * @stability stable
         */
        get expiration(): string;
        private _expires?;
        /**
         * @stability stable
         */
        get expires(): string | undefined;
        /**
         * @stability stable
         */
        set expires(value: string | undefined);
        /**
         * @stability stable
         */
        resetExpires(): void;
        /**
         * @stability stable
         */
        get expiresInput(): string | undefined;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        set key(value: string);
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        private _kmsEncryptionContext?;
        /**
         * @stability stable
         */
        get kmsEncryptionContext(): string | undefined;
        /**
         * @stability stable
         */
        set kmsEncryptionContext(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsEncryptionContext(): void;
        /**
         * @stability stable
         */
        get kmsEncryptionContextInput(): string | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get lastModified(): string;
        private _metadata?;
        /**
         * @stability stable
         */
        get metadata(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set metadata(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMetadata(): void;
        /**
         * @stability stable
         */
        get metadataInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _metadataDirective?;
        /**
         * @stability stable
         */
        get metadataDirective(): string | undefined;
        /**
         * @stability stable
         */
        set metadataDirective(value: string | undefined);
        /**
         * @stability stable
         */
        resetMetadataDirective(): void;
        /**
         * @stability stable
         */
        get metadataDirectiveInput(): string | undefined;
        private _objectLockLegalHoldStatus?;
        /**
         * @stability stable
         */
        get objectLockLegalHoldStatus(): string | undefined;
        /**
         * @stability stable
         */
        set objectLockLegalHoldStatus(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectLockLegalHoldStatus(): void;
        /**
         * @stability stable
         */
        get objectLockLegalHoldStatusInput(): string | undefined;
        private _objectLockMode?;
        /**
         * @stability stable
         */
        get objectLockMode(): string | undefined;
        /**
         * @stability stable
         */
        set objectLockMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectLockMode(): void;
        /**
         * @stability stable
         */
        get objectLockModeInput(): string | undefined;
        private _objectLockRetainUntilDate?;
        /**
         * @stability stable
         */
        get objectLockRetainUntilDate(): string | undefined;
        /**
         * @stability stable
         */
        set objectLockRetainUntilDate(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectLockRetainUntilDate(): void;
        /**
         * @stability stable
         */
        get objectLockRetainUntilDateInput(): string | undefined;
        /**
         * @stability stable
         */
        get requestCharged(): any;
        private _requestPayer?;
        /**
         * @stability stable
         */
        get requestPayer(): string | undefined;
        /**
         * @stability stable
         */
        set requestPayer(value: string | undefined);
        /**
         * @stability stable
         */
        resetRequestPayer(): void;
        /**
         * @stability stable
         */
        get requestPayerInput(): string | undefined;
        private _serverSideEncryption?;
        /**
         * @stability stable
         */
        get serverSideEncryption(): string | undefined;
        /**
         * @stability stable
         */
        set serverSideEncryption(value: string | undefined);
        /**
         * @stability stable
         */
        resetServerSideEncryption(): void;
        /**
         * @stability stable
         */
        get serverSideEncryptionInput(): string | undefined;
        private _source?;
        /**
         * @stability stable
         */
        get source(): string;
        /**
         * @stability stable
         */
        set source(value: string);
        /**
         * @stability stable
         */
        get sourceInput(): string | undefined;
        private _sourceCustomerAlgorithm?;
        /**
         * @stability stable
         */
        get sourceCustomerAlgorithm(): string | undefined;
        /**
         * @stability stable
         */
        set sourceCustomerAlgorithm(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceCustomerAlgorithm(): void;
        /**
         * @stability stable
         */
        get sourceCustomerAlgorithmInput(): string | undefined;
        private _sourceCustomerKey?;
        /**
         * @stability stable
         */
        get sourceCustomerKey(): string | undefined;
        /**
         * @stability stable
         */
        set sourceCustomerKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceCustomerKey(): void;
        /**
         * @stability stable
         */
        get sourceCustomerKeyInput(): string | undefined;
        private _sourceCustomerKeyMd5?;
        /**
         * @stability stable
         */
        get sourceCustomerKeyMd5(): string | undefined;
        /**
         * @stability stable
         */
        set sourceCustomerKeyMd5(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceCustomerKeyMd5(): void;
        /**
         * @stability stable
         */
        get sourceCustomerKeyMd5Input(): string | undefined;
        /**
         * @stability stable
         */
        get sourceVersionId(): string;
        private _storageClass?;
        /**
         * @stability stable
         */
        get storageClass(): string | undefined;
        /**
         * @stability stable
         */
        set storageClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageClass(): void;
        /**
         * @stability stable
         */
        get storageClassInput(): string | undefined;
        private _taggingDirective?;
        /**
         * @stability stable
         */
        get taggingDirective(): string | undefined;
        /**
         * @stability stable
         */
        set taggingDirective(value: string | undefined);
        /**
         * @stability stable
         */
        resetTaggingDirective(): void;
        /**
         * @stability stable
         */
        get taggingDirectiveInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get versionId(): string;
        private _websiteRedirect?;
        /**
         * @stability stable
         */
        get websiteRedirect(): string | undefined;
        /**
         * @stability stable
         */
        set websiteRedirect(value: string | undefined);
        /**
         * @stability stable
         */
        resetWebsiteRedirect(): void;
        /**
         * @stability stable
         */
        get websiteRedirectInput(): string | undefined;
        private _grant?;
        /**
         * @stability stable
         */
        get grant(): S3ObjectCopyGrant[] | undefined;
        /**
         * @stability stable
         */
        set grant(value: S3ObjectCopyGrant[] | undefined);
        /**
         * @stability stable
         */
        resetGrant(): void;
        /**
         * @stability stable
         */
        get grantInput(): S3ObjectCopyGrant[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3ControlBucketConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket.html#bucket S3ControlBucket#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket.html#outpost_id S3ControlBucket#outpost_id}.
         *
         * @stability stable
         */
        readonly outpostId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket.html#tags S3ControlBucket#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket.html#tags_all S3ControlBucket#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket.html aws_s3control_bucket}.
     *
     * @stability stable
     */
    class S3ControlBucket extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket.html aws_s3control_bucket} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3ControlBucketConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get creationDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _outpostId?;
        /**
         * @stability stable
         */
        get outpostId(): string;
        /**
         * @stability stable
         */
        set outpostId(value: string);
        /**
         * @stability stable
         */
        get outpostIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get publicAccessBlockEnabled(): any;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3ControlBucketLifecycleConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#bucket S3ControlBucketLifecycleConfiguration#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#rule S3ControlBucketLifecycleConfiguration#rule}
         *
         * @stability stable
         */
        readonly rule: S3ControlBucketLifecycleConfigurationRule[];
    }
    /**
     * @stability stable
     */
    interface S3ControlBucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#days_after_initiation S3ControlBucketLifecycleConfiguration#days_after_initiation}.
         *
         * @stability stable
         */
        readonly daysAfterInitiation: number;
    }
    /**
     * @stability stable
     */
    class S3ControlBucketLifecycleConfigurationRuleAbortIncompleteMultipartUploadOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _daysAfterInitiation?;
        /**
         * @stability stable
         */
        get daysAfterInitiation(): number;
        /**
         * @stability stable
         */
        set daysAfterInitiation(value: number);
        /**
         * @stability stable
         */
        get daysAfterInitiationInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface S3ControlBucketLifecycleConfigurationRuleExpiration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#date S3ControlBucketLifecycleConfiguration#date}.
         *
         * @stability stable
         */
        readonly date?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#days S3ControlBucketLifecycleConfiguration#days}.
         *
         * @stability stable
         */
        readonly days?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#expired_object_delete_marker S3ControlBucketLifecycleConfiguration#expired_object_delete_marker}.
         *
         * @stability stable
         */
        readonly expiredObjectDeleteMarker?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3ControlBucketLifecycleConfigurationRuleExpirationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _date?;
        /**
         * @stability stable
         */
        get date(): string | undefined;
        /**
         * @stability stable
         */
        set date(value: string | undefined);
        /**
         * @stability stable
         */
        resetDate(): void;
        /**
         * @stability stable
         */
        get dateInput(): string | undefined;
        private _days?;
        /**
         * @stability stable
         */
        get days(): number | undefined;
        /**
         * @stability stable
         */
        set days(value: number | undefined);
        /**
         * @stability stable
         */
        resetDays(): void;
        /**
         * @stability stable
         */
        get daysInput(): number | undefined;
        private _expiredObjectDeleteMarker?;
        /**
         * @stability stable
         */
        get expiredObjectDeleteMarker(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set expiredObjectDeleteMarker(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetExpiredObjectDeleteMarker(): void;
        /**
         * @stability stable
         */
        get expiredObjectDeleteMarkerInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface S3ControlBucketLifecycleConfigurationRuleFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#prefix S3ControlBucketLifecycleConfiguration#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#tags S3ControlBucketLifecycleConfiguration#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class S3ControlBucketLifecycleConfigurationRuleFilterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
    }
    /**
     * @stability stable
     */
    interface S3ControlBucketLifecycleConfigurationRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#id S3ControlBucketLifecycleConfiguration#id}.
         *
         * @stability stable
         */
        readonly id: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#status S3ControlBucketLifecycleConfiguration#status}.
         *
         * @stability stable
         */
        readonly status?: string;
        /**
         * abort_incomplete_multipart_upload block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#abort_incomplete_multipart_upload S3ControlBucketLifecycleConfiguration#abort_incomplete_multipart_upload}
         *
         * @stability stable
         */
        readonly abortIncompleteMultipartUpload?: S3ControlBucketLifecycleConfigurationRuleAbortIncompleteMultipartUpload;
        /**
         * expiration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#expiration S3ControlBucketLifecycleConfiguration#expiration}
         *
         * @stability stable
         */
        readonly expiration?: S3ControlBucketLifecycleConfigurationRuleExpiration;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html#filter S3ControlBucketLifecycleConfiguration#filter}
         *
         * @stability stable
         */
        readonly filter?: S3ControlBucketLifecycleConfigurationRuleFilter;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html aws_s3control_bucket_lifecycle_configuration}.
     *
     * @stability stable
     */
    class S3ControlBucketLifecycleConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_lifecycle_configuration.html aws_s3control_bucket_lifecycle_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3ControlBucketLifecycleConfigurationConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _rule?;
        /**
         * @stability stable
         */
        get rule(): S3ControlBucketLifecycleConfigurationRule[];
        /**
         * @stability stable
         */
        set rule(value: S3ControlBucketLifecycleConfigurationRule[]);
        /**
         * @stability stable
         */
        get ruleInput(): S3ControlBucketLifecycleConfigurationRule[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3ControlBucketPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_policy.html#bucket S3ControlBucketPolicy#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_policy.html#policy S3ControlBucketPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_policy.html aws_s3control_bucket_policy}.
     *
     * @stability stable
     */
    class S3ControlBucketPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3control_bucket_policy.html aws_s3control_bucket_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3ControlBucketPolicyConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface S3OutpostsEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3outposts_endpoint.html#outpost_id S3OutpostsEndpoint#outpost_id}.
         *
         * @stability stable
         */
        readonly outpostId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3outposts_endpoint.html#security_group_id S3OutpostsEndpoint#security_group_id}.
         *
         * @stability stable
         */
        readonly securityGroupId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/s3outposts_endpoint.html#subnet_id S3OutpostsEndpoint#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId: string;
    }
    /**
     * @stability stable
     */
    class S3OutpostsEndpointNetworkInterfaces extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/s3outposts_endpoint.html aws_s3outposts_endpoint}.
     *
     * @stability stable
     */
    class S3OutpostsEndpoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/s3outposts_endpoint.html aws_s3outposts_endpoint} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: S3OutpostsEndpointConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        /**
         * @stability stable
         */
        get creationTime(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        networkInterfaces(index: string): S3OutpostsEndpointNetworkInterfaces;
        private _outpostId?;
        /**
         * @stability stable
         */
        get outpostId(): string;
        /**
         * @stability stable
         */
        set outpostId(value: string);
        /**
         * @stability stable
         */
        get outpostIdInput(): string | undefined;
        private _securityGroupId?;
        /**
         * @stability stable
         */
        get securityGroupId(): string;
        /**
         * @stability stable
         */
        set securityGroupId(value: string);
        /**
         * @stability stable
         */
        get securityGroupIdInput(): string | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string;
        /**
         * @stability stable
         */
        set subnetId(value: string);
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsS3BucketConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket.html#bucket DataAwsS3Bucket#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket.html aws_s3_bucket}.
     *
     * @stability stable
     */
    class DataAwsS3Bucket extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket.html aws_s3_bucket} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsS3BucketConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get bucketDomainName(): string;
        /**
         * @stability stable
         */
        get bucketRegionalDomainName(): string;
        /**
         * @stability stable
         */
        get hostedZoneId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get region(): string;
        /**
         * @stability stable
         */
        get websiteDomain(): string;
        /**
         * @stability stable
         */
        get websiteEndpoint(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsS3BucketObjectConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_object.html#bucket DataAwsS3BucketObject#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_object.html#key DataAwsS3BucketObject#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_object.html#range DataAwsS3BucketObject#range}.
         *
         * @stability stable
         */
        readonly range?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_object.html#tags DataAwsS3BucketObject#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_object.html#version_id DataAwsS3BucketObject#version_id}.
         *
         * @stability stable
         */
        readonly versionId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_object.html aws_s3_bucket_object}.
     *
     * @stability stable
     */
    class DataAwsS3BucketObject extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_object.html aws_s3_bucket_object} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsS3BucketObjectConfig);
        /**
         * @stability stable
         */
        get body(): string;
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get bucketKeyEnabled(): any;
        /**
         * @stability stable
         */
        get cacheControl(): string;
        /**
         * @stability stable
         */
        get contentDisposition(): string;
        /**
         * @stability stable
         */
        get contentEncoding(): string;
        /**
         * @stability stable
         */
        get contentLanguage(): string;
        /**
         * @stability stable
         */
        get contentLength(): number;
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        get etag(): string;
        /**
         * @stability stable
         */
        get expiration(): string;
        /**
         * @stability stable
         */
        get expires(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _key?;
        /**
         * @stability stable
         */
        get key(): string;
        /**
         * @stability stable
         */
        set key(value: string);
        /**
         * @stability stable
         */
        get keyInput(): string | undefined;
        /**
         * @stability stable
         */
        get lastModified(): string;
        /**
         * @stability stable
         */
        metadata(key: string): string;
        /**
         * @stability stable
         */
        get objectLockLegalHoldStatus(): string;
        /**
         * @stability stable
         */
        get objectLockMode(): string;
        /**
         * @stability stable
         */
        get objectLockRetainUntilDate(): string;
        private _range?;
        /**
         * @stability stable
         */
        get range(): string | undefined;
        /**
         * @stability stable
         */
        set range(value: string | undefined);
        /**
         * @stability stable
         */
        resetRange(): void;
        /**
         * @stability stable
         */
        get rangeInput(): string | undefined;
        /**
         * @stability stable
         */
        get serverSideEncryption(): string;
        /**
         * @stability stable
         */
        get sseKmsKeyId(): string;
        /**
         * @stability stable
         */
        get storageClass(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _versionId?;
        /**
         * @stability stable
         */
        get versionId(): string | undefined;
        /**
         * @stability stable
         */
        set versionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersionId(): void;
        /**
         * @stability stable
         */
        get versionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get websiteRedirectLocation(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsS3BucketObjectsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html#bucket DataAwsS3BucketObjects#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html#delimiter DataAwsS3BucketObjects#delimiter}.
         *
         * @stability stable
         */
        readonly delimiter?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html#encoding_type DataAwsS3BucketObjects#encoding_type}.
         *
         * @stability stable
         */
        readonly encodingType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html#fetch_owner DataAwsS3BucketObjects#fetch_owner}.
         *
         * @stability stable
         */
        readonly fetchOwner?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html#max_keys DataAwsS3BucketObjects#max_keys}.
         *
         * @stability stable
         */
        readonly maxKeys?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html#prefix DataAwsS3BucketObjects#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html#start_after DataAwsS3BucketObjects#start_after}.
         *
         * @stability stable
         */
        readonly startAfter?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html aws_s3_bucket_objects}.
     *
     * @stability stable
     */
    class DataAwsS3BucketObjects extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/s3_bucket_objects.html aws_s3_bucket_objects} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsS3BucketObjectsConfig);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        /**
         * @stability stable
         */
        get commonPrefixes(): string[];
        private _delimiter?;
        /**
         * @stability stable
         */
        get delimiter(): string | undefined;
        /**
         * @stability stable
         */
        set delimiter(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelimiter(): void;
        /**
         * @stability stable
         */
        get delimiterInput(): string | undefined;
        private _encodingType?;
        /**
         * @stability stable
         */
        get encodingType(): string | undefined;
        /**
         * @stability stable
         */
        set encodingType(value: string | undefined);
        /**
         * @stability stable
         */
        resetEncodingType(): void;
        /**
         * @stability stable
         */
        get encodingTypeInput(): string | undefined;
        private _fetchOwner?;
        /**
         * @stability stable
         */
        get fetchOwner(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set fetchOwner(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetFetchOwner(): void;
        /**
         * @stability stable
         */
        get fetchOwnerInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get keys(): string[];
        private _maxKeys?;
        /**
         * @stability stable
         */
        get maxKeys(): number | undefined;
        /**
         * @stability stable
         */
        set maxKeys(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxKeys(): void;
        /**
         * @stability stable
         */
        get maxKeysInput(): number | undefined;
        /**
         * @stability stable
         */
        get owners(): string[];
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
        private _startAfter?;
        /**
         * @stability stable
         */
        get startAfter(): string | undefined;
        /**
         * @stability stable
         */
        set startAfter(value: string | undefined);
        /**
         * @stability stable
         */
        resetStartAfter(): void;
        /**
         * @stability stable
         */
        get startAfterInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
