import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Simple Email Service
*/
export declare namespace SES {
    /**
     * @stability stable
     */
    interface SesActiveReceiptRuleSetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_active_receipt_rule_set.html#rule_set_name SesActiveReceiptRuleSet#rule_set_name}.
         *
         * @stability stable
         */
        readonly ruleSetName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_active_receipt_rule_set.html aws_ses_active_receipt_rule_set}.
     *
     * @stability stable
     */
    class SesActiveReceiptRuleSet extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_active_receipt_rule_set.html aws_ses_active_receipt_rule_set} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesActiveReceiptRuleSetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _ruleSetName?;
        /**
         * @stability stable
         */
        get ruleSetName(): string;
        /**
         * @stability stable
         */
        set ruleSetName(value: string);
        /**
         * @stability stable
         */
        get ruleSetNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesConfigurationSetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set.html#name SesConfigurationSet#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set.html#reputation_metrics_enabled SesConfigurationSet#reputation_metrics_enabled}.
         *
         * @stability stable
         */
        readonly reputationMetricsEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set.html#sending_enabled SesConfigurationSet#sending_enabled}.
         *
         * @stability stable
         */
        readonly sendingEnabled?: boolean | cdktf.IResolvable;
        /**
         * delivery_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set.html#delivery_options SesConfigurationSet#delivery_options}
         *
         * @stability stable
         */
        readonly deliveryOptions?: SesConfigurationSetDeliveryOptions;
    }
    /**
     * @stability stable
     */
    interface SesConfigurationSetDeliveryOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set.html#tls_policy SesConfigurationSet#tls_policy}.
         *
         * @stability stable
         */
        readonly tlsPolicy?: string;
    }
    /**
     * @stability stable
     */
    class SesConfigurationSetDeliveryOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _tlsPolicy?;
        /**
         * @stability stable
         */
        get tlsPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set tlsPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetTlsPolicy(): void;
        /**
         * @stability stable
         */
        get tlsPolicyInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set.html aws_ses_configuration_set}.
     *
     * @stability stable
     */
    class SesConfigurationSet extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_configuration_set.html aws_ses_configuration_set} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesConfigurationSetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastFreshStart(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _reputationMetricsEnabled?;
        /**
         * @stability stable
         */
        get reputationMetricsEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set reputationMetricsEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetReputationMetricsEnabled(): void;
        /**
         * @stability stable
         */
        get reputationMetricsEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _sendingEnabled?;
        /**
         * @stability stable
         */
        get sendingEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set sendingEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSendingEnabled(): void;
        /**
         * @stability stable
         */
        get sendingEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _deliveryOptions?;
        private __deliveryOptionsOutput;
        /**
         * @stability stable
         */
        get deliveryOptions(): SesConfigurationSetDeliveryOptionsOutputReference;
        /**
         * @stability stable
         */
        putDeliveryOptions(value: SesConfigurationSetDeliveryOptions | undefined): void;
        /**
         * @stability stable
         */
        resetDeliveryOptions(): void;
        /**
         * @stability stable
         */
        get deliveryOptionsInput(): SesConfigurationSetDeliveryOptions | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesDomainDkimConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_dkim.html#domain SesDomainDkim#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_dkim.html aws_ses_domain_dkim}.
     *
     * @stability stable
     */
    class SesDomainDkim extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_dkim.html aws_ses_domain_dkim} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesDomainDkimConfig);
        /**
         * @stability stable
         */
        get dkimTokens(): string[];
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesDomainIdentityConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity.html#domain SesDomainIdentity#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity.html aws_ses_domain_identity}.
     *
     * @stability stable
     */
    class SesDomainIdentity extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity.html aws_ses_domain_identity} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesDomainIdentityConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get verificationToken(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesDomainIdentityVerificationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity_verification.html#domain SesDomainIdentityVerification#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity_verification.html#timeouts SesDomainIdentityVerification#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: SesDomainIdentityVerificationTimeouts;
    }
    /**
     * @stability stable
     */
    interface SesDomainIdentityVerificationTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity_verification.html#create SesDomainIdentityVerification#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class SesDomainIdentityVerificationTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity_verification.html aws_ses_domain_identity_verification}.
     *
     * @stability stable
     */
    class SesDomainIdentityVerification extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_identity_verification.html aws_ses_domain_identity_verification} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesDomainIdentityVerificationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): SesDomainIdentityVerificationTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: SesDomainIdentityVerificationTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): SesDomainIdentityVerificationTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesDomainMailFromConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_mail_from.html#behavior_on_mx_failure SesDomainMailFrom#behavior_on_mx_failure}.
         *
         * @stability stable
         */
        readonly behaviorOnMxFailure?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_mail_from.html#domain SesDomainMailFrom#domain}.
         *
         * @stability stable
         */
        readonly domain: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_mail_from.html#mail_from_domain SesDomainMailFrom#mail_from_domain}.
         *
         * @stability stable
         */
        readonly mailFromDomain: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_mail_from.html aws_ses_domain_mail_from}.
     *
     * @stability stable
     */
    class SesDomainMailFrom extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_domain_mail_from.html aws_ses_domain_mail_from} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesDomainMailFromConfig);
        private _behaviorOnMxFailure?;
        /**
         * @stability stable
         */
        get behaviorOnMxFailure(): string | undefined;
        /**
         * @stability stable
         */
        set behaviorOnMxFailure(value: string | undefined);
        /**
         * @stability stable
         */
        resetBehaviorOnMxFailure(): void;
        /**
         * @stability stable
         */
        get behaviorOnMxFailureInput(): string | undefined;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        set domain(value: string);
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _mailFromDomain?;
        /**
         * @stability stable
         */
        get mailFromDomain(): string;
        /**
         * @stability stable
         */
        set mailFromDomain(value: string);
        /**
         * @stability stable
         */
        get mailFromDomainInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesEmailIdentityConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_email_identity.html#email SesEmailIdentity#email}.
         *
         * @stability stable
         */
        readonly email: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_email_identity.html aws_ses_email_identity}.
     *
     * @stability stable
     */
    class SesEmailIdentity extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_email_identity.html aws_ses_email_identity} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesEmailIdentityConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _email?;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        set email(value: string);
        /**
         * @stability stable
         */
        get emailInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesEventDestinationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#configuration_set_name SesEventDestination#configuration_set_name}.
         *
         * @stability stable
         */
        readonly configurationSetName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#enabled SesEventDestination#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#matching_types SesEventDestination#matching_types}.
         *
         * @stability stable
         */
        readonly matchingTypes: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#name SesEventDestination#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * cloudwatch_destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#cloudwatch_destination SesEventDestination#cloudwatch_destination}
         *
         * @stability stable
         */
        readonly cloudwatchDestination?: SesEventDestinationCloudwatchDestination[];
        /**
         * kinesis_destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#kinesis_destination SesEventDestination#kinesis_destination}
         *
         * @stability stable
         */
        readonly kinesisDestination?: SesEventDestinationKinesisDestination;
        /**
         * sns_destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#sns_destination SesEventDestination#sns_destination}
         *
         * @stability stable
         */
        readonly snsDestination?: SesEventDestinationSnsDestination;
    }
    /**
     * @stability stable
     */
    interface SesEventDestinationCloudwatchDestination {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#default_value SesEventDestination#default_value}.
         *
         * @stability stable
         */
        readonly defaultValue: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#dimension_name SesEventDestination#dimension_name}.
         *
         * @stability stable
         */
        readonly dimensionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#value_source SesEventDestination#value_source}.
         *
         * @stability stable
         */
        readonly valueSource: string;
    }
    /**
     * @stability stable
     */
    interface SesEventDestinationKinesisDestination {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#role_arn SesEventDestination#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#stream_arn SesEventDestination#stream_arn}.
         *
         * @stability stable
         */
        readonly streamArn: string;
    }
    /**
     * @stability stable
     */
    class SesEventDestinationKinesisDestinationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _streamArn?;
        /**
         * @stability stable
         */
        get streamArn(): string;
        /**
         * @stability stable
         */
        set streamArn(value: string);
        /**
         * @stability stable
         */
        get streamArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SesEventDestinationSnsDestination {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html#topic_arn SesEventDestination#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn: string;
    }
    /**
     * @stability stable
     */
    class SesEventDestinationSnsDestinationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _topicArn?;
        /**
         * @stability stable
         */
        get topicArn(): string;
        /**
         * @stability stable
         */
        set topicArn(value: string);
        /**
         * @stability stable
         */
        get topicArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html aws_ses_event_destination}.
     *
     * @stability stable
     */
    class SesEventDestination extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_event_destination.html aws_ses_event_destination} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesEventDestinationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _configurationSetName?;
        /**
         * @stability stable
         */
        get configurationSetName(): string;
        /**
         * @stability stable
         */
        set configurationSetName(value: string);
        /**
         * @stability stable
         */
        get configurationSetNameInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _matchingTypes?;
        /**
         * @stability stable
         */
        get matchingTypes(): string[];
        /**
         * @stability stable
         */
        set matchingTypes(value: string[]);
        /**
         * @stability stable
         */
        get matchingTypesInput(): string[] | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _cloudwatchDestination?;
        /**
         * @stability stable
         */
        get cloudwatchDestination(): SesEventDestinationCloudwatchDestination[] | undefined;
        /**
         * @stability stable
         */
        set cloudwatchDestination(value: SesEventDestinationCloudwatchDestination[] | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchDestination(): void;
        /**
         * @stability stable
         */
        get cloudwatchDestinationInput(): SesEventDestinationCloudwatchDestination[] | undefined;
        private _kinesisDestination?;
        private __kinesisDestinationOutput;
        /**
         * @stability stable
         */
        get kinesisDestination(): SesEventDestinationKinesisDestinationOutputReference;
        /**
         * @stability stable
         */
        putKinesisDestination(value: SesEventDestinationKinesisDestination | undefined): void;
        /**
         * @stability stable
         */
        resetKinesisDestination(): void;
        /**
         * @stability stable
         */
        get kinesisDestinationInput(): SesEventDestinationKinesisDestination | undefined;
        private _snsDestination?;
        private __snsDestinationOutput;
        /**
         * @stability stable
         */
        get snsDestination(): SesEventDestinationSnsDestinationOutputReference;
        /**
         * @stability stable
         */
        putSnsDestination(value: SesEventDestinationSnsDestination | undefined): void;
        /**
         * @stability stable
         */
        resetSnsDestination(): void;
        /**
         * @stability stable
         */
        get snsDestinationInput(): SesEventDestinationSnsDestination | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesIdentityNotificationTopicConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_notification_topic.html#identity SesIdentityNotificationTopic#identity}.
         *
         * @stability stable
         */
        readonly identity: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_notification_topic.html#include_original_headers SesIdentityNotificationTopic#include_original_headers}.
         *
         * @stability stable
         */
        readonly includeOriginalHeaders?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_notification_topic.html#notification_type SesIdentityNotificationTopic#notification_type}.
         *
         * @stability stable
         */
        readonly notificationType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_notification_topic.html#topic_arn SesIdentityNotificationTopic#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_notification_topic.html aws_ses_identity_notification_topic}.
     *
     * @stability stable
     */
    class SesIdentityNotificationTopic extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_notification_topic.html aws_ses_identity_notification_topic} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesIdentityNotificationTopicConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _identity?;
        /**
         * @stability stable
         */
        get identity(): string;
        /**
         * @stability stable
         */
        set identity(value: string);
        /**
         * @stability stable
         */
        get identityInput(): string | undefined;
        private _includeOriginalHeaders?;
        /**
         * @stability stable
         */
        get includeOriginalHeaders(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeOriginalHeaders(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeOriginalHeaders(): void;
        /**
         * @stability stable
         */
        get includeOriginalHeadersInput(): boolean | cdktf.IResolvable | undefined;
        private _notificationType?;
        /**
         * @stability stable
         */
        get notificationType(): string;
        /**
         * @stability stable
         */
        set notificationType(value: string);
        /**
         * @stability stable
         */
        get notificationTypeInput(): string | undefined;
        private _topicArn?;
        /**
         * @stability stable
         */
        get topicArn(): string | undefined;
        /**
         * @stability stable
         */
        set topicArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetTopicArn(): void;
        /**
         * @stability stable
         */
        get topicArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesIdentityPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_policy.html#identity SesIdentityPolicy#identity}.
         *
         * @stability stable
         */
        readonly identity: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_policy.html#name SesIdentityPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_policy.html#policy SesIdentityPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_policy.html aws_ses_identity_policy}.
     *
     * @stability stable
     */
    class SesIdentityPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_identity_policy.html aws_ses_identity_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesIdentityPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _identity?;
        /**
         * @stability stable
         */
        get identity(): string;
        /**
         * @stability stable
         */
        set identity(value: string);
        /**
         * @stability stable
         */
        get identityInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesReceiptFilterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_filter.html#cidr SesReceiptFilter#cidr}.
         *
         * @stability stable
         */
        readonly cidr: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_filter.html#name SesReceiptFilter#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_filter.html#policy SesReceiptFilter#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_filter.html aws_ses_receipt_filter}.
     *
     * @stability stable
     */
    class SesReceiptFilter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_filter.html aws_ses_receipt_filter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesReceiptFilterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _cidr?;
        /**
         * @stability stable
         */
        get cidr(): string;
        /**
         * @stability stable
         */
        set cidr(value: string);
        /**
         * @stability stable
         */
        get cidrInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#after SesReceiptRule#after}.
         *
         * @stability stable
         */
        readonly after?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#enabled SesReceiptRule#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#name SesReceiptRule#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#recipients SesReceiptRule#recipients}.
         *
         * @stability stable
         */
        readonly recipients?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#rule_set_name SesReceiptRule#rule_set_name}.
         *
         * @stability stable
         */
        readonly ruleSetName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#scan_enabled SesReceiptRule#scan_enabled}.
         *
         * @stability stable
         */
        readonly scanEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#tls_policy SesReceiptRule#tls_policy}.
         *
         * @stability stable
         */
        readonly tlsPolicy?: string;
        /**
         * add_header_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#add_header_action SesReceiptRule#add_header_action}
         *
         * @stability stable
         */
        readonly addHeaderAction?: SesReceiptRuleAddHeaderAction[];
        /**
         * bounce_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#bounce_action SesReceiptRule#bounce_action}
         *
         * @stability stable
         */
        readonly bounceAction?: SesReceiptRuleBounceAction[];
        /**
         * lambda_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#lambda_action SesReceiptRule#lambda_action}
         *
         * @stability stable
         */
        readonly lambdaAction?: SesReceiptRuleLambdaAction[];
        /**
         * s3_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#s3_action SesReceiptRule#s3_action}
         *
         * @stability stable
         */
        readonly s3Action?: SesReceiptRuleS3Action[];
        /**
         * sns_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#sns_action SesReceiptRule#sns_action}
         *
         * @stability stable
         */
        readonly snsAction?: SesReceiptRuleSnsAction[];
        /**
         * stop_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#stop_action SesReceiptRule#stop_action}
         *
         * @stability stable
         */
        readonly stopAction?: SesReceiptRuleStopAction[];
        /**
         * workmail_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#workmail_action SesReceiptRule#workmail_action}
         *
         * @stability stable
         */
        readonly workmailAction?: SesReceiptRuleWorkmailAction[];
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleAddHeaderAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#header_name SesReceiptRule#header_name}.
         *
         * @stability stable
         */
        readonly headerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#header_value SesReceiptRule#header_value}.
         *
         * @stability stable
         */
        readonly headerValue: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#position SesReceiptRule#position}.
         *
         * @stability stable
         */
        readonly position: number;
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleBounceAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#message SesReceiptRule#message}.
         *
         * @stability stable
         */
        readonly message: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#position SesReceiptRule#position}.
         *
         * @stability stable
         */
        readonly position: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#sender SesReceiptRule#sender}.
         *
         * @stability stable
         */
        readonly sender: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#smtp_reply_code SesReceiptRule#smtp_reply_code}.
         *
         * @stability stable
         */
        readonly smtpReplyCode: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#status_code SesReceiptRule#status_code}.
         *
         * @stability stable
         */
        readonly statusCode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#topic_arn SesReceiptRule#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn?: string;
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleLambdaAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#function_arn SesReceiptRule#function_arn}.
         *
         * @stability stable
         */
        readonly functionArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#invocation_type SesReceiptRule#invocation_type}.
         *
         * @stability stable
         */
        readonly invocationType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#position SesReceiptRule#position}.
         *
         * @stability stable
         */
        readonly position: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#topic_arn SesReceiptRule#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn?: string;
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleS3Action {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#bucket_name SesReceiptRule#bucket_name}.
         *
         * @stability stable
         */
        readonly bucketName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#kms_key_arn SesReceiptRule#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#object_key_prefix SesReceiptRule#object_key_prefix}.
         *
         * @stability stable
         */
        readonly objectKeyPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#position SesReceiptRule#position}.
         *
         * @stability stable
         */
        readonly position: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#topic_arn SesReceiptRule#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn?: string;
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleSnsAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#encoding SesReceiptRule#encoding}.
         *
         * @stability stable
         */
        readonly encoding?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#position SesReceiptRule#position}.
         *
         * @stability stable
         */
        readonly position: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#topic_arn SesReceiptRule#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn: string;
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleStopAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#position SesReceiptRule#position}.
         *
         * @stability stable
         */
        readonly position: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#scope SesReceiptRule#scope}.
         *
         * @stability stable
         */
        readonly scope: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#topic_arn SesReceiptRule#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn?: string;
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleWorkmailAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#organization_arn SesReceiptRule#organization_arn}.
         *
         * @stability stable
         */
        readonly organizationArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#position SesReceiptRule#position}.
         *
         * @stability stable
         */
        readonly position: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html#topic_arn SesReceiptRule#topic_arn}.
         *
         * @stability stable
         */
        readonly topicArn?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html aws_ses_receipt_rule}.
     *
     * @stability stable
     */
    class SesReceiptRule extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule.html aws_ses_receipt_rule} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesReceiptRuleConfig);
        private _after?;
        /**
         * @stability stable
         */
        get after(): string | undefined;
        /**
         * @stability stable
         */
        set after(value: string | undefined);
        /**
         * @stability stable
         */
        resetAfter(): void;
        /**
         * @stability stable
         */
        get afterInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _recipients?;
        /**
         * @stability stable
         */
        get recipients(): string[] | undefined;
        /**
         * @stability stable
         */
        set recipients(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetRecipients(): void;
        /**
         * @stability stable
         */
        get recipientsInput(): string[] | undefined;
        private _ruleSetName?;
        /**
         * @stability stable
         */
        get ruleSetName(): string;
        /**
         * @stability stable
         */
        set ruleSetName(value: string);
        /**
         * @stability stable
         */
        get ruleSetNameInput(): string | undefined;
        private _scanEnabled?;
        /**
         * @stability stable
         */
        get scanEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set scanEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetScanEnabled(): void;
        /**
         * @stability stable
         */
        get scanEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _tlsPolicy?;
        /**
         * @stability stable
         */
        get tlsPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set tlsPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetTlsPolicy(): void;
        /**
         * @stability stable
         */
        get tlsPolicyInput(): string | undefined;
        private _addHeaderAction?;
        /**
         * @stability stable
         */
        get addHeaderAction(): SesReceiptRuleAddHeaderAction[] | undefined;
        /**
         * @stability stable
         */
        set addHeaderAction(value: SesReceiptRuleAddHeaderAction[] | undefined);
        /**
         * @stability stable
         */
        resetAddHeaderAction(): void;
        /**
         * @stability stable
         */
        get addHeaderActionInput(): SesReceiptRuleAddHeaderAction[] | undefined;
        private _bounceAction?;
        /**
         * @stability stable
         */
        get bounceAction(): SesReceiptRuleBounceAction[] | undefined;
        /**
         * @stability stable
         */
        set bounceAction(value: SesReceiptRuleBounceAction[] | undefined);
        /**
         * @stability stable
         */
        resetBounceAction(): void;
        /**
         * @stability stable
         */
        get bounceActionInput(): SesReceiptRuleBounceAction[] | undefined;
        private _lambdaAction?;
        /**
         * @stability stable
         */
        get lambdaAction(): SesReceiptRuleLambdaAction[] | undefined;
        /**
         * @stability stable
         */
        set lambdaAction(value: SesReceiptRuleLambdaAction[] | undefined);
        /**
         * @stability stable
         */
        resetLambdaAction(): void;
        /**
         * @stability stable
         */
        get lambdaActionInput(): SesReceiptRuleLambdaAction[] | undefined;
        private _s3Action?;
        /**
         * @stability stable
         */
        get s3Action(): SesReceiptRuleS3Action[] | undefined;
        /**
         * @stability stable
         */
        set s3Action(value: SesReceiptRuleS3Action[] | undefined);
        /**
         * @stability stable
         */
        resetS3Action(): void;
        /**
         * @stability stable
         */
        get s3ActionInput(): SesReceiptRuleS3Action[] | undefined;
        private _snsAction?;
        /**
         * @stability stable
         */
        get snsAction(): SesReceiptRuleSnsAction[] | undefined;
        /**
         * @stability stable
         */
        set snsAction(value: SesReceiptRuleSnsAction[] | undefined);
        /**
         * @stability stable
         */
        resetSnsAction(): void;
        /**
         * @stability stable
         */
        get snsActionInput(): SesReceiptRuleSnsAction[] | undefined;
        private _stopAction?;
        /**
         * @stability stable
         */
        get stopAction(): SesReceiptRuleStopAction[] | undefined;
        /**
         * @stability stable
         */
        set stopAction(value: SesReceiptRuleStopAction[] | undefined);
        /**
         * @stability stable
         */
        resetStopAction(): void;
        /**
         * @stability stable
         */
        get stopActionInput(): SesReceiptRuleStopAction[] | undefined;
        private _workmailAction?;
        /**
         * @stability stable
         */
        get workmailAction(): SesReceiptRuleWorkmailAction[] | undefined;
        /**
         * @stability stable
         */
        set workmailAction(value: SesReceiptRuleWorkmailAction[] | undefined);
        /**
         * @stability stable
         */
        resetWorkmailAction(): void;
        /**
         * @stability stable
         */
        get workmailActionInput(): SesReceiptRuleWorkmailAction[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesReceiptRuleSetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule_set.html#rule_set_name SesReceiptRuleSet#rule_set_name}.
         *
         * @stability stable
         */
        readonly ruleSetName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule_set.html aws_ses_receipt_rule_set}.
     *
     * @stability stable
     */
    class SesReceiptRuleSet extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_receipt_rule_set.html aws_ses_receipt_rule_set} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesReceiptRuleSetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _ruleSetName?;
        /**
         * @stability stable
         */
        get ruleSetName(): string;
        /**
         * @stability stable
         */
        set ruleSetName(value: string);
        /**
         * @stability stable
         */
        get ruleSetNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SesTemplateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_template.html#html SesTemplate#html}.
         *
         * @stability stable
         */
        readonly html?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_template.html#name SesTemplate#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_template.html#subject SesTemplate#subject}.
         *
         * @stability stable
         */
        readonly subject?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ses_template.html#text SesTemplate#text}.
         *
         * @stability stable
         */
        readonly text?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ses_template.html aws_ses_template}.
     *
     * @stability stable
     */
    class SesTemplate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ses_template.html aws_ses_template} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SesTemplateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _html?;
        /**
         * @stability stable
         */
        get html(): string | undefined;
        /**
         * @stability stable
         */
        set html(value: string | undefined);
        /**
         * @stability stable
         */
        resetHtml(): void;
        /**
         * @stability stable
         */
        get htmlInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _subject?;
        /**
         * @stability stable
         */
        get subject(): string | undefined;
        /**
         * @stability stable
         */
        set subject(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubject(): void;
        /**
         * @stability stable
         */
        get subjectInput(): string | undefined;
        private _text?;
        /**
         * @stability stable
         */
        get text(): string | undefined;
        /**
         * @stability stable
         */
        set text(value: string | undefined);
        /**
         * @stability stable
         */
        resetText(): void;
        /**
         * @stability stable
         */
        get textInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
