import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Step Functions
*/
export declare namespace SFN {
    /**
     * @stability stable
     */
    interface SfnActivityConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_activity.html#name SfnActivity#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_activity.html#tags SfnActivity#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_activity.html#tags_all SfnActivity#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sfn_activity.html aws_sfn_activity}.
     *
     * @stability stable
     */
    class SfnActivity extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sfn_activity.html aws_sfn_activity} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SfnActivityConfig);
        /**
         * @stability stable
         */
        get creationDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SfnStateMachineConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#definition SfnStateMachine#definition}.
         *
         * @stability stable
         */
        readonly definition: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#name SfnStateMachine#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#role_arn SfnStateMachine#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#tags SfnStateMachine#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#tags_all SfnStateMachine#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#type SfnStateMachine#type}.
         *
         * @stability stable
         */
        readonly type?: string;
        /**
         * logging_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#logging_configuration SfnStateMachine#logging_configuration}
         *
         * @stability stable
         */
        readonly loggingConfiguration?: SfnStateMachineLoggingConfiguration;
        /**
         * tracing_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#tracing_configuration SfnStateMachine#tracing_configuration}
         *
         * @stability stable
         */
        readonly tracingConfiguration?: SfnStateMachineTracingConfiguration;
    }
    /**
     * @stability stable
     */
    interface SfnStateMachineLoggingConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#include_execution_data SfnStateMachine#include_execution_data}.
         *
         * @stability stable
         */
        readonly includeExecutionData?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#level SfnStateMachine#level}.
         *
         * @stability stable
         */
        readonly level?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#log_destination SfnStateMachine#log_destination}.
         *
         * @stability stable
         */
        readonly logDestination?: string;
    }
    /**
     * @stability stable
     */
    class SfnStateMachineLoggingConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _includeExecutionData?;
        /**
         * @stability stable
         */
        get includeExecutionData(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeExecutionData(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeExecutionData(): void;
        /**
         * @stability stable
         */
        get includeExecutionDataInput(): boolean | cdktf.IResolvable | undefined;
        private _level?;
        /**
         * @stability stable
         */
        get level(): string | undefined;
        /**
         * @stability stable
         */
        set level(value: string | undefined);
        /**
         * @stability stable
         */
        resetLevel(): void;
        /**
         * @stability stable
         */
        get levelInput(): string | undefined;
        private _logDestination?;
        /**
         * @stability stable
         */
        get logDestination(): string | undefined;
        /**
         * @stability stable
         */
        set logDestination(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogDestination(): void;
        /**
         * @stability stable
         */
        get logDestinationInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SfnStateMachineTracingConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html#enabled SfnStateMachine#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class SfnStateMachineTracingConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html aws_sfn_state_machine}.
     *
     * @stability stable
     */
    class SfnStateMachine extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sfn_state_machine.html aws_sfn_state_machine} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SfnStateMachineConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get creationDate(): string;
        private _definition?;
        /**
         * @stability stable
         */
        get definition(): string;
        /**
         * @stability stable
         */
        set definition(value: string);
        /**
         * @stability stable
         */
        get definitionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string | undefined;
        /**
         * @stability stable
         */
        set type(value: string | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _loggingConfiguration?;
        private __loggingConfigurationOutput;
        /**
         * @stability stable
         */
        get loggingConfiguration(): SfnStateMachineLoggingConfigurationOutputReference;
        /**
         * @stability stable
         */
        putLoggingConfiguration(value: SfnStateMachineLoggingConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetLoggingConfiguration(): void;
        /**
         * @stability stable
         */
        get loggingConfigurationInput(): SfnStateMachineLoggingConfiguration | undefined;
        private _tracingConfiguration?;
        private __tracingConfigurationOutput;
        /**
         * @stability stable
         */
        get tracingConfiguration(): SfnStateMachineTracingConfigurationOutputReference;
        /**
         * @stability stable
         */
        putTracingConfiguration(value: SfnStateMachineTracingConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetTracingConfiguration(): void;
        /**
         * @stability stable
         */
        get tracingConfigurationInput(): SfnStateMachineTracingConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSfnActivityConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sfn_activity.html#name DataAwsSfnActivity#name}.
         *
         * @stability stable
         */
        readonly name?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/sfn_activity.html aws_sfn_activity}.
     *
     * @stability stable
     */
    class DataAwsSfnActivity extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/sfn_activity.html aws_sfn_activity} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsSfnActivityConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get creationDate(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSfnStateMachineConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sfn_state_machine.html#name DataAwsSfnStateMachine#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/sfn_state_machine.html aws_sfn_state_machine}.
     *
     * @stability stable
     */
    class DataAwsSfnStateMachine extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/sfn_state_machine.html aws_sfn_state_machine} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSfnStateMachineConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get creationDate(): string;
        /**
         * @stability stable
         */
        get definition(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
