import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Simple Queue Service
*/
export declare namespace SQS {
    /**
     * @stability stable
     */
    interface SqsQueueConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#content_based_deduplication SqsQueue#content_based_deduplication}.
         *
         * @stability stable
         */
        readonly contentBasedDeduplication?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#deduplication_scope SqsQueue#deduplication_scope}.
         *
         * @stability stable
         */
        readonly deduplicationScope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#delay_seconds SqsQueue#delay_seconds}.
         *
         * @stability stable
         */
        readonly delaySeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#fifo_queue SqsQueue#fifo_queue}.
         *
         * @stability stable
         */
        readonly fifoQueue?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#fifo_throughput_limit SqsQueue#fifo_throughput_limit}.
         *
         * @stability stable
         */
        readonly fifoThroughputLimit?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#kms_data_key_reuse_period_seconds SqsQueue#kms_data_key_reuse_period_seconds}.
         *
         * @stability stable
         */
        readonly kmsDataKeyReusePeriodSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#kms_master_key_id SqsQueue#kms_master_key_id}.
         *
         * @stability stable
         */
        readonly kmsMasterKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#max_message_size SqsQueue#max_message_size}.
         *
         * @stability stable
         */
        readonly maxMessageSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#message_retention_seconds SqsQueue#message_retention_seconds}.
         *
         * @stability stable
         */
        readonly messageRetentionSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#name SqsQueue#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#name_prefix SqsQueue#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#policy SqsQueue#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#receive_wait_time_seconds SqsQueue#receive_wait_time_seconds}.
         *
         * @stability stable
         */
        readonly receiveWaitTimeSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#redrive_policy SqsQueue#redrive_policy}.
         *
         * @stability stable
         */
        readonly redrivePolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#tags SqsQueue#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#tags_all SqsQueue#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html#visibility_timeout_seconds SqsQueue#visibility_timeout_seconds}.
         *
         * @stability stable
         */
        readonly visibilityTimeoutSeconds?: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html aws_sqs_queue}.
     *
     * @stability stable
     */
    class SqsQueue extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue.html aws_sqs_queue} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: SqsQueueConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _contentBasedDeduplication?;
        /**
         * @stability stable
         */
        get contentBasedDeduplication(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set contentBasedDeduplication(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetContentBasedDeduplication(): void;
        /**
         * @stability stable
         */
        get contentBasedDeduplicationInput(): boolean | cdktf.IResolvable | undefined;
        private _deduplicationScope?;
        /**
         * @stability stable
         */
        get deduplicationScope(): string | undefined;
        /**
         * @stability stable
         */
        set deduplicationScope(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeduplicationScope(): void;
        /**
         * @stability stable
         */
        get deduplicationScopeInput(): string | undefined;
        private _delaySeconds?;
        /**
         * @stability stable
         */
        get delaySeconds(): number | undefined;
        /**
         * @stability stable
         */
        set delaySeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetDelaySeconds(): void;
        /**
         * @stability stable
         */
        get delaySecondsInput(): number | undefined;
        private _fifoQueue?;
        /**
         * @stability stable
         */
        get fifoQueue(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set fifoQueue(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetFifoQueue(): void;
        /**
         * @stability stable
         */
        get fifoQueueInput(): boolean | cdktf.IResolvable | undefined;
        private _fifoThroughputLimit?;
        /**
         * @stability stable
         */
        get fifoThroughputLimit(): string | undefined;
        /**
         * @stability stable
         */
        set fifoThroughputLimit(value: string | undefined);
        /**
         * @stability stable
         */
        resetFifoThroughputLimit(): void;
        /**
         * @stability stable
         */
        get fifoThroughputLimitInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsDataKeyReusePeriodSeconds?;
        /**
         * @stability stable
         */
        get kmsDataKeyReusePeriodSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set kmsDataKeyReusePeriodSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetKmsDataKeyReusePeriodSeconds(): void;
        /**
         * @stability stable
         */
        get kmsDataKeyReusePeriodSecondsInput(): number | undefined;
        private _kmsMasterKeyId?;
        /**
         * @stability stable
         */
        get kmsMasterKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsMasterKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsMasterKeyId(): void;
        /**
         * @stability stable
         */
        get kmsMasterKeyIdInput(): string | undefined;
        private _maxMessageSize?;
        /**
         * @stability stable
         */
        get maxMessageSize(): number | undefined;
        /**
         * @stability stable
         */
        set maxMessageSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxMessageSize(): void;
        /**
         * @stability stable
         */
        get maxMessageSizeInput(): number | undefined;
        private _messageRetentionSeconds?;
        /**
         * @stability stable
         */
        get messageRetentionSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set messageRetentionSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetMessageRetentionSeconds(): void;
        /**
         * @stability stable
         */
        get messageRetentionSecondsInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _receiveWaitTimeSeconds?;
        /**
         * @stability stable
         */
        get receiveWaitTimeSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set receiveWaitTimeSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetReceiveWaitTimeSeconds(): void;
        /**
         * @stability stable
         */
        get receiveWaitTimeSecondsInput(): number | undefined;
        private _redrivePolicy?;
        /**
         * @stability stable
         */
        get redrivePolicy(): string | undefined;
        /**
         * @stability stable
         */
        set redrivePolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetRedrivePolicy(): void;
        /**
         * @stability stable
         */
        get redrivePolicyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get url(): string;
        private _visibilityTimeoutSeconds?;
        /**
         * @stability stable
         */
        get visibilityTimeoutSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set visibilityTimeoutSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetVisibilityTimeoutSeconds(): void;
        /**
         * @stability stable
         */
        get visibilityTimeoutSecondsInput(): number | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SqsQueuePolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue_policy.html#policy SqsQueuePolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue_policy.html#queue_url SqsQueuePolicy#queue_url}.
         *
         * @stability stable
         */
        readonly queueUrl: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue_policy.html aws_sqs_queue_policy}.
     *
     * @stability stable
     */
    class SqsQueuePolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sqs_queue_policy.html aws_sqs_queue_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SqsQueuePolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _queueUrl?;
        /**
         * @stability stable
         */
        get queueUrl(): string;
        /**
         * @stability stable
         */
        set queueUrl(value: string);
        /**
         * @stability stable
         */
        get queueUrlInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSqsQueueConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sqs_queue.html#name DataAwsSqsQueue#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sqs_queue.html#tags DataAwsSqsQueue#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/sqs_queue.html aws_sqs_queue}.
     *
     * @stability stable
     */
    class DataAwsSqsQueue extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/sqs_queue.html aws_sqs_queue} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSqsQueueConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get url(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
