import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Systems Manager
*/
export declare namespace SSM {
    /**
     * @stability stable
     */
    interface SsmActivationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html#description SsmActivation#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html#expiration_date SsmActivation#expiration_date}.
         *
         * @stability stable
         */
        readonly expirationDate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html#iam_role SsmActivation#iam_role}.
         *
         * @stability stable
         */
        readonly iamRole: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html#name SsmActivation#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html#registration_limit SsmActivation#registration_limit}.
         *
         * @stability stable
         */
        readonly registrationLimit?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html#tags SsmActivation#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html#tags_all SsmActivation#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html aws_ssm_activation}.
     *
     * @stability stable
     */
    class SsmActivation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_activation.html aws_ssm_activation} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmActivationConfig);
        /**
         * @stability stable
         */
        get activationCode(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _expirationDate?;
        /**
         * @stability stable
         */
        get expirationDate(): string | undefined;
        /**
         * @stability stable
         */
        set expirationDate(value: string | undefined);
        /**
         * @stability stable
         */
        resetExpirationDate(): void;
        /**
         * @stability stable
         */
        get expirationDateInput(): string | undefined;
        /**
         * @stability stable
         */
        get expired(): any;
        private _iamRole?;
        /**
         * @stability stable
         */
        get iamRole(): string;
        /**
         * @stability stable
         */
        set iamRole(value: string);
        /**
         * @stability stable
         */
        get iamRoleInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get registrationCount(): number;
        private _registrationLimit?;
        /**
         * @stability stable
         */
        get registrationLimit(): number | undefined;
        /**
         * @stability stable
         */
        set registrationLimit(value: number | undefined);
        /**
         * @stability stable
         */
        resetRegistrationLimit(): void;
        /**
         * @stability stable
         */
        get registrationLimitInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#apply_only_at_cron_interval SsmAssociation#apply_only_at_cron_interval}.
         *
         * @stability stable
         */
        readonly applyOnlyAtCronInterval?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#association_name SsmAssociation#association_name}.
         *
         * @stability stable
         */
        readonly associationName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#automation_target_parameter_name SsmAssociation#automation_target_parameter_name}.
         *
         * @stability stable
         */
        readonly automationTargetParameterName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#compliance_severity SsmAssociation#compliance_severity}.
         *
         * @stability stable
         */
        readonly complianceSeverity?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#document_version SsmAssociation#document_version}.
         *
         * @stability stable
         */
        readonly documentVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#instance_id SsmAssociation#instance_id}.
         *
         * @stability stable
         */
        readonly instanceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#max_concurrency SsmAssociation#max_concurrency}.
         *
         * @stability stable
         */
        readonly maxConcurrency?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#max_errors SsmAssociation#max_errors}.
         *
         * @stability stable
         */
        readonly maxErrors?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#name SsmAssociation#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#parameters SsmAssociation#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#schedule_expression SsmAssociation#schedule_expression}.
         *
         * @stability stable
         */
        readonly scheduleExpression?: string;
        /**
         * output_location block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#output_location SsmAssociation#output_location}
         *
         * @stability stable
         */
        readonly outputLocation?: SsmAssociationOutputLocation;
        /**
         * targets block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#targets SsmAssociation#targets}
         *
         * @stability stable
         */
        readonly targets?: SsmAssociationTargets[];
    }
    /**
     * @stability stable
     */
    interface SsmAssociationOutputLocation {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#s3_bucket_name SsmAssociation#s3_bucket_name}.
         *
         * @stability stable
         */
        readonly s3BucketName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#s3_key_prefix SsmAssociation#s3_key_prefix}.
         *
         * @stability stable
         */
        readonly s3KeyPrefix?: string;
    }
    /**
     * @stability stable
     */
    class SsmAssociationOutputLocationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _s3BucketName?;
        /**
         * @stability stable
         */
        get s3BucketName(): string;
        /**
         * @stability stable
         */
        set s3BucketName(value: string);
        /**
         * @stability stable
         */
        get s3BucketNameInput(): string | undefined;
        private _s3KeyPrefix?;
        /**
         * @stability stable
         */
        get s3KeyPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set s3KeyPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3KeyPrefix(): void;
        /**
         * @stability stable
         */
        get s3KeyPrefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SsmAssociationTargets {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#key SsmAssociation#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html#values SsmAssociation#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html aws_ssm_association}.
     *
     * @stability stable
     */
    class SsmAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_association.html aws_ssm_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmAssociationConfig);
        private _applyOnlyAtCronInterval?;
        /**
         * @stability stable
         */
        get applyOnlyAtCronInterval(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set applyOnlyAtCronInterval(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetApplyOnlyAtCronInterval(): void;
        /**
         * @stability stable
         */
        get applyOnlyAtCronIntervalInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get associationId(): string;
        private _associationName?;
        /**
         * @stability stable
         */
        get associationName(): string | undefined;
        /**
         * @stability stable
         */
        set associationName(value: string | undefined);
        /**
         * @stability stable
         */
        resetAssociationName(): void;
        /**
         * @stability stable
         */
        get associationNameInput(): string | undefined;
        private _automationTargetParameterName?;
        /**
         * @stability stable
         */
        get automationTargetParameterName(): string | undefined;
        /**
         * @stability stable
         */
        set automationTargetParameterName(value: string | undefined);
        /**
         * @stability stable
         */
        resetAutomationTargetParameterName(): void;
        /**
         * @stability stable
         */
        get automationTargetParameterNameInput(): string | undefined;
        private _complianceSeverity?;
        /**
         * @stability stable
         */
        get complianceSeverity(): string | undefined;
        /**
         * @stability stable
         */
        set complianceSeverity(value: string | undefined);
        /**
         * @stability stable
         */
        resetComplianceSeverity(): void;
        /**
         * @stability stable
         */
        get complianceSeverityInput(): string | undefined;
        private _documentVersion?;
        /**
         * @stability stable
         */
        get documentVersion(): string | undefined;
        /**
         * @stability stable
         */
        set documentVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentVersion(): void;
        /**
         * @stability stable
         */
        get documentVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceId?;
        /**
         * @stability stable
         */
        get instanceId(): string | undefined;
        /**
         * @stability stable
         */
        set instanceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceId(): void;
        /**
         * @stability stable
         */
        get instanceIdInput(): string | undefined;
        private _maxConcurrency?;
        /**
         * @stability stable
         */
        get maxConcurrency(): string | undefined;
        /**
         * @stability stable
         */
        set maxConcurrency(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxConcurrency(): void;
        /**
         * @stability stable
         */
        get maxConcurrencyInput(): string | undefined;
        private _maxErrors?;
        /**
         * @stability stable
         */
        get maxErrors(): string | undefined;
        /**
         * @stability stable
         */
        set maxErrors(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaxErrors(): void;
        /**
         * @stability stable
         */
        get maxErrorsInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _scheduleExpression?;
        /**
         * @stability stable
         */
        get scheduleExpression(): string | undefined;
        /**
         * @stability stable
         */
        set scheduleExpression(value: string | undefined);
        /**
         * @stability stable
         */
        resetScheduleExpression(): void;
        /**
         * @stability stable
         */
        get scheduleExpressionInput(): string | undefined;
        private _outputLocation?;
        private __outputLocationOutput;
        /**
         * @stability stable
         */
        get outputLocation(): SsmAssociationOutputLocationOutputReference;
        /**
         * @stability stable
         */
        putOutputLocation(value: SsmAssociationOutputLocation | undefined): void;
        /**
         * @stability stable
         */
        resetOutputLocation(): void;
        /**
         * @stability stable
         */
        get outputLocationInput(): SsmAssociationOutputLocation | undefined;
        private _targets?;
        /**
         * @stability stable
         */
        get targets(): SsmAssociationTargets[] | undefined;
        /**
         * @stability stable
         */
        set targets(value: SsmAssociationTargets[] | undefined);
        /**
         * @stability stable
         */
        resetTargets(): void;
        /**
         * @stability stable
         */
        get targetsInput(): SsmAssociationTargets[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmDocumentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#content SsmDocument#content}.
         *
         * @stability stable
         */
        readonly content: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#document_format SsmDocument#document_format}.
         *
         * @stability stable
         */
        readonly documentFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#document_type SsmDocument#document_type}.
         *
         * @stability stable
         */
        readonly documentType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#name SsmDocument#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#permissions SsmDocument#permissions}.
         *
         * @stability stable
         */
        readonly permissions?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#tags SsmDocument#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#tags_all SsmDocument#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#target_type SsmDocument#target_type}.
         *
         * @stability stable
         */
        readonly targetType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#version_name SsmDocument#version_name}.
         *
         * @stability stable
         */
        readonly versionName?: string;
        /**
         * attachments_source block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#attachments_source SsmDocument#attachments_source}
         *
         * @stability stable
         */
        readonly attachmentsSource?: SsmDocumentAttachmentsSource[];
    }
    /**
     * @stability stable
     */
    class SsmDocumentParameter extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get defaultValue(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * @stability stable
     */
    interface SsmDocumentAttachmentsSource {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#key SsmDocument#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#name SsmDocument#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html#values SsmDocument#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html aws_ssm_document}.
     *
     * @stability stable
     */
    class SsmDocument extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_document.html aws_ssm_document} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmDocumentConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _content?;
        /**
         * @stability stable
         */
        get content(): string;
        /**
         * @stability stable
         */
        set content(value: string);
        /**
         * @stability stable
         */
        get contentInput(): string | undefined;
        /**
         * @stability stable
         */
        get createdDate(): string;
        /**
         * @stability stable
         */
        get defaultVersion(): string;
        /**
         * @stability stable
         */
        get description(): string;
        private _documentFormat?;
        /**
         * @stability stable
         */
        get documentFormat(): string | undefined;
        /**
         * @stability stable
         */
        set documentFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentFormat(): void;
        /**
         * @stability stable
         */
        get documentFormatInput(): string | undefined;
        private _documentType?;
        /**
         * @stability stable
         */
        get documentType(): string;
        /**
         * @stability stable
         */
        set documentType(value: string);
        /**
         * @stability stable
         */
        get documentTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get documentVersion(): string;
        /**
         * @stability stable
         */
        get hash(): string;
        /**
         * @stability stable
         */
        get hashType(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get latestVersion(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get owner(): string;
        /**
         * @stability stable
         */
        parameter(index: string): SsmDocumentParameter;
        private _permissions?;
        /**
         * @stability stable
         */
        get permissions(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set permissions(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPermissions(): void;
        /**
         * @stability stable
         */
        get permissionsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get platformTypes(): string[];
        /**
         * @stability stable
         */
        get schemaVersion(): string;
        /**
         * @stability stable
         */
        get status(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetType?;
        /**
         * @stability stable
         */
        get targetType(): string | undefined;
        /**
         * @stability stable
         */
        set targetType(value: string | undefined);
        /**
         * @stability stable
         */
        resetTargetType(): void;
        /**
         * @stability stable
         */
        get targetTypeInput(): string | undefined;
        private _versionName?;
        /**
         * @stability stable
         */
        get versionName(): string | undefined;
        /**
         * @stability stable
         */
        set versionName(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersionName(): void;
        /**
         * @stability stable
         */
        get versionNameInput(): string | undefined;
        private _attachmentsSource?;
        /**
         * @stability stable
         */
        get attachmentsSource(): SsmDocumentAttachmentsSource[] | undefined;
        /**
         * @stability stable
         */
        set attachmentsSource(value: SsmDocumentAttachmentsSource[] | undefined);
        /**
         * @stability stable
         */
        resetAttachmentsSource(): void;
        /**
         * @stability stable
         */
        get attachmentsSourceInput(): SsmDocumentAttachmentsSource[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#allow_unassociated_targets SsmMaintenanceWindow#allow_unassociated_targets}.
         *
         * @stability stable
         */
        readonly allowUnassociatedTargets?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#cutoff SsmMaintenanceWindow#cutoff}.
         *
         * @stability stable
         */
        readonly cutoff: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#description SsmMaintenanceWindow#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#duration SsmMaintenanceWindow#duration}.
         *
         * @stability stable
         */
        readonly duration: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#enabled SsmMaintenanceWindow#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#end_date SsmMaintenanceWindow#end_date}.
         *
         * @stability stable
         */
        readonly endDate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#name SsmMaintenanceWindow#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#schedule SsmMaintenanceWindow#schedule}.
         *
         * @stability stable
         */
        readonly schedule: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#schedule_offset SsmMaintenanceWindow#schedule_offset}.
         *
         * @stability stable
         */
        readonly scheduleOffset?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#schedule_timezone SsmMaintenanceWindow#schedule_timezone}.
         *
         * @stability stable
         */
        readonly scheduleTimezone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#start_date SsmMaintenanceWindow#start_date}.
         *
         * @stability stable
         */
        readonly startDate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#tags SsmMaintenanceWindow#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html#tags_all SsmMaintenanceWindow#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html aws_ssm_maintenance_window}.
     *
     * @stability stable
     */
    class SsmMaintenanceWindow extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window.html aws_ssm_maintenance_window} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmMaintenanceWindowConfig);
        private _allowUnassociatedTargets?;
        /**
         * @stability stable
         */
        get allowUnassociatedTargets(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowUnassociatedTargets(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowUnassociatedTargets(): void;
        /**
         * @stability stable
         */
        get allowUnassociatedTargetsInput(): boolean | cdktf.IResolvable | undefined;
        private _cutoff?;
        /**
         * @stability stable
         */
        get cutoff(): number;
        /**
         * @stability stable
         */
        set cutoff(value: number);
        /**
         * @stability stable
         */
        get cutoffInput(): number | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _duration?;
        /**
         * @stability stable
         */
        get duration(): number;
        /**
         * @stability stable
         */
        set duration(value: number);
        /**
         * @stability stable
         */
        get durationInput(): number | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _endDate?;
        /**
         * @stability stable
         */
        get endDate(): string | undefined;
        /**
         * @stability stable
         */
        set endDate(value: string | undefined);
        /**
         * @stability stable
         */
        resetEndDate(): void;
        /**
         * @stability stable
         */
        get endDateInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _schedule?;
        /**
         * @stability stable
         */
        get schedule(): string;
        /**
         * @stability stable
         */
        set schedule(value: string);
        /**
         * @stability stable
         */
        get scheduleInput(): string | undefined;
        private _scheduleOffset?;
        /**
         * @stability stable
         */
        get scheduleOffset(): number | undefined;
        /**
         * @stability stable
         */
        set scheduleOffset(value: number | undefined);
        /**
         * @stability stable
         */
        resetScheduleOffset(): void;
        /**
         * @stability stable
         */
        get scheduleOffsetInput(): number | undefined;
        private _scheduleTimezone?;
        /**
         * @stability stable
         */
        get scheduleTimezone(): string | undefined;
        /**
         * @stability stable
         */
        set scheduleTimezone(value: string | undefined);
        /**
         * @stability stable
         */
        resetScheduleTimezone(): void;
        /**
         * @stability stable
         */
        get scheduleTimezoneInput(): string | undefined;
        private _startDate?;
        /**
         * @stability stable
         */
        get startDate(): string | undefined;
        /**
         * @stability stable
         */
        set startDate(value: string | undefined);
        /**
         * @stability stable
         */
        resetStartDate(): void;
        /**
         * @stability stable
         */
        get startDateInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTargetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#description SsmMaintenanceWindowTarget#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#name SsmMaintenanceWindowTarget#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#owner_information SsmMaintenanceWindowTarget#owner_information}.
         *
         * @stability stable
         */
        readonly ownerInformation?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#resource_type SsmMaintenanceWindowTarget#resource_type}.
         *
         * @stability stable
         */
        readonly resourceType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#window_id SsmMaintenanceWindowTarget#window_id}.
         *
         * @stability stable
         */
        readonly windowId: string;
        /**
         * targets block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#targets SsmMaintenanceWindowTarget#targets}
         *
         * @stability stable
         */
        readonly targets: SsmMaintenanceWindowTargetTargets[];
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTargetTargets {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#key SsmMaintenanceWindowTarget#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html#values SsmMaintenanceWindowTarget#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html aws_ssm_maintenance_window_target}.
     *
     * @stability stable
     */
    class SsmMaintenanceWindowTarget extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_target.html aws_ssm_maintenance_window_target} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmMaintenanceWindowTargetConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _ownerInformation?;
        /**
         * @stability stable
         */
        get ownerInformation(): string | undefined;
        /**
         * @stability stable
         */
        set ownerInformation(value: string | undefined);
        /**
         * @stability stable
         */
        resetOwnerInformation(): void;
        /**
         * @stability stable
         */
        get ownerInformationInput(): string | undefined;
        private _resourceType?;
        /**
         * @stability stable
         */
        get resourceType(): string;
        /**
         * @stability stable
         */
        set resourceType(value: string);
        /**
         * @stability stable
         */
        get resourceTypeInput(): string | undefined;
        private _windowId?;
        /**
         * @stability stable
         */
        get windowId(): string;
        /**
         * @stability stable
         */
        set windowId(value: string);
        /**
         * @stability stable
         */
        get windowIdInput(): string | undefined;
        private _targets?;
        /**
         * @stability stable
         */
        get targets(): SsmMaintenanceWindowTargetTargets[];
        /**
         * @stability stable
         */
        set targets(value: SsmMaintenanceWindowTargetTargets[]);
        /**
         * @stability stable
         */
        get targetsInput(): SsmMaintenanceWindowTargetTargets[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#description SsmMaintenanceWindowTask#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#max_concurrency SsmMaintenanceWindowTask#max_concurrency}.
         *
         * @stability stable
         */
        readonly maxConcurrency: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#max_errors SsmMaintenanceWindowTask#max_errors}.
         *
         * @stability stable
         */
        readonly maxErrors: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#name SsmMaintenanceWindowTask#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#priority SsmMaintenanceWindowTask#priority}.
         *
         * @stability stable
         */
        readonly priority?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#service_role_arn SsmMaintenanceWindowTask#service_role_arn}.
         *
         * @stability stable
         */
        readonly serviceRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#task_arn SsmMaintenanceWindowTask#task_arn}.
         *
         * @stability stable
         */
        readonly taskArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#task_type SsmMaintenanceWindowTask#task_type}.
         *
         * @stability stable
         */
        readonly taskType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#window_id SsmMaintenanceWindowTask#window_id}.
         *
         * @stability stable
         */
        readonly windowId: string;
        /**
         * targets block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#targets SsmMaintenanceWindowTask#targets}
         *
         * @stability stable
         */
        readonly targets?: SsmMaintenanceWindowTaskTargets[];
        /**
         * task_invocation_parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#task_invocation_parameters SsmMaintenanceWindowTask#task_invocation_parameters}
         *
         * @stability stable
         */
        readonly taskInvocationParameters?: SsmMaintenanceWindowTaskTaskInvocationParameters;
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTargets {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#key SsmMaintenanceWindowTask#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#values SsmMaintenanceWindowTask#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#name SsmMaintenanceWindowTask#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#values SsmMaintenanceWindowTask#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#document_version SsmMaintenanceWindowTask#document_version}.
         *
         * @stability stable
         */
        readonly documentVersion?: string;
        /**
         * parameter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#parameter SsmMaintenanceWindowTask#parameter}
         *
         * @stability stable
         */
        readonly parameter?: SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter[];
    }
    /**
     * @stability stable
     */
    class SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _documentVersion?;
        /**
         * @stability stable
         */
        get documentVersion(): string | undefined;
        /**
         * @stability stable
         */
        set documentVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentVersion(): void;
        /**
         * @stability stable
         */
        get documentVersionInput(): string | undefined;
        private _parameter?;
        /**
         * @stability stable
         */
        get parameter(): SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter[] | undefined;
        /**
         * @stability stable
         */
        set parameter(value: SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter[] | undefined);
        /**
         * @stability stable
         */
        resetParameter(): void;
        /**
         * @stability stable
         */
        get parameterInput(): SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter[] | undefined;
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#client_context SsmMaintenanceWindowTask#client_context}.
         *
         * @stability stable
         */
        readonly clientContext?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#payload SsmMaintenanceWindowTask#payload}.
         *
         * @stability stable
         */
        readonly payload?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#qualifier SsmMaintenanceWindowTask#qualifier}.
         *
         * @stability stable
         */
        readonly qualifier?: string;
    }
    /**
     * @stability stable
     */
    class SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParametersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _clientContext?;
        /**
         * @stability stable
         */
        get clientContext(): string | undefined;
        /**
         * @stability stable
         */
        set clientContext(value: string | undefined);
        /**
         * @stability stable
         */
        resetClientContext(): void;
        /**
         * @stability stable
         */
        get clientContextInput(): string | undefined;
        private _payload?;
        /**
         * @stability stable
         */
        get payload(): string | undefined;
        /**
         * @stability stable
         */
        set payload(value: string | undefined);
        /**
         * @stability stable
         */
        resetPayload(): void;
        /**
         * @stability stable
         */
        get payloadInput(): string | undefined;
        private _qualifier?;
        /**
         * @stability stable
         */
        get qualifier(): string | undefined;
        /**
         * @stability stable
         */
        set qualifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetQualifier(): void;
        /**
         * @stability stable
         */
        get qualifierInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersCloudwatchConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#cloudwatch_log_group_name SsmMaintenanceWindowTask#cloudwatch_log_group_name}.
         *
         * @stability stable
         */
        readonly cloudwatchLogGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#cloudwatch_output_enabled SsmMaintenanceWindowTask#cloudwatch_output_enabled}.
         *
         * @stability stable
         */
        readonly cloudwatchOutputEnabled?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersCloudwatchConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cloudwatchLogGroupName?;
        /**
         * @stability stable
         */
        get cloudwatchLogGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set cloudwatchLogGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchLogGroupName(): void;
        /**
         * @stability stable
         */
        get cloudwatchLogGroupNameInput(): string | undefined;
        private _cloudwatchOutputEnabled?;
        /**
         * @stability stable
         */
        get cloudwatchOutputEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set cloudwatchOutputEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchOutputEnabled(): void;
        /**
         * @stability stable
         */
        get cloudwatchOutputEnabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#notification_arn SsmMaintenanceWindowTask#notification_arn}.
         *
         * @stability stable
         */
        readonly notificationArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#notification_events SsmMaintenanceWindowTask#notification_events}.
         *
         * @stability stable
         */
        readonly notificationEvents?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#notification_type SsmMaintenanceWindowTask#notification_type}.
         *
         * @stability stable
         */
        readonly notificationType?: string;
    }
    /**
     * @stability stable
     */
    class SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _notificationArn?;
        /**
         * @stability stable
         */
        get notificationArn(): string | undefined;
        /**
         * @stability stable
         */
        set notificationArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationArn(): void;
        /**
         * @stability stable
         */
        get notificationArnInput(): string | undefined;
        private _notificationEvents?;
        /**
         * @stability stable
         */
        get notificationEvents(): string[] | undefined;
        /**
         * @stability stable
         */
        set notificationEvents(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetNotificationEvents(): void;
        /**
         * @stability stable
         */
        get notificationEventsInput(): string[] | undefined;
        private _notificationType?;
        /**
         * @stability stable
         */
        get notificationType(): string | undefined;
        /**
         * @stability stable
         */
        set notificationType(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationType(): void;
        /**
         * @stability stable
         */
        get notificationTypeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#name SsmMaintenanceWindowTask#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#values SsmMaintenanceWindowTask#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#comment SsmMaintenanceWindowTask#comment}.
         *
         * @stability stable
         */
        readonly comment?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#document_hash SsmMaintenanceWindowTask#document_hash}.
         *
         * @stability stable
         */
        readonly documentHash?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#document_hash_type SsmMaintenanceWindowTask#document_hash_type}.
         *
         * @stability stable
         */
        readonly documentHashType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#document_version SsmMaintenanceWindowTask#document_version}.
         *
         * @stability stable
         */
        readonly documentVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#output_s3_bucket SsmMaintenanceWindowTask#output_s3_bucket}.
         *
         * @stability stable
         */
        readonly outputS3Bucket?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#output_s3_key_prefix SsmMaintenanceWindowTask#output_s3_key_prefix}.
         *
         * @stability stable
         */
        readonly outputS3KeyPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#service_role_arn SsmMaintenanceWindowTask#service_role_arn}.
         *
         * @stability stable
         */
        readonly serviceRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#timeout_seconds SsmMaintenanceWindowTask#timeout_seconds}.
         *
         * @stability stable
         */
        readonly timeoutSeconds?: number;
        /**
         * cloudwatch_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#cloudwatch_config SsmMaintenanceWindowTask#cloudwatch_config}
         *
         * @stability stable
         */
        readonly cloudwatchConfig?: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersCloudwatchConfig;
        /**
         * notification_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#notification_config SsmMaintenanceWindowTask#notification_config}
         *
         * @stability stable
         */
        readonly notificationConfig?: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig;
        /**
         * parameter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#parameter SsmMaintenanceWindowTask#parameter}
         *
         * @stability stable
         */
        readonly parameter?: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter[];
    }
    /**
     * @stability stable
     */
    class SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _comment?;
        /**
         * @stability stable
         */
        get comment(): string | undefined;
        /**
         * @stability stable
         */
        set comment(value: string | undefined);
        /**
         * @stability stable
         */
        resetComment(): void;
        /**
         * @stability stable
         */
        get commentInput(): string | undefined;
        private _documentHash?;
        /**
         * @stability stable
         */
        get documentHash(): string | undefined;
        /**
         * @stability stable
         */
        set documentHash(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentHash(): void;
        /**
         * @stability stable
         */
        get documentHashInput(): string | undefined;
        private _documentHashType?;
        /**
         * @stability stable
         */
        get documentHashType(): string | undefined;
        /**
         * @stability stable
         */
        set documentHashType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentHashType(): void;
        /**
         * @stability stable
         */
        get documentHashTypeInput(): string | undefined;
        private _documentVersion?;
        /**
         * @stability stable
         */
        get documentVersion(): string | undefined;
        /**
         * @stability stable
         */
        set documentVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentVersion(): void;
        /**
         * @stability stable
         */
        get documentVersionInput(): string | undefined;
        private _outputS3Bucket?;
        /**
         * @stability stable
         */
        get outputS3Bucket(): string | undefined;
        /**
         * @stability stable
         */
        set outputS3Bucket(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutputS3Bucket(): void;
        /**
         * @stability stable
         */
        get outputS3BucketInput(): string | undefined;
        private _outputS3KeyPrefix?;
        /**
         * @stability stable
         */
        get outputS3KeyPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set outputS3KeyPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutputS3KeyPrefix(): void;
        /**
         * @stability stable
         */
        get outputS3KeyPrefixInput(): string | undefined;
        private _serviceRoleArn?;
        /**
         * @stability stable
         */
        get serviceRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set serviceRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceRoleArn(): void;
        /**
         * @stability stable
         */
        get serviceRoleArnInput(): string | undefined;
        private _timeoutSeconds?;
        /**
         * @stability stable
         */
        get timeoutSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set timeoutSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeoutSeconds(): void;
        /**
         * @stability stable
         */
        get timeoutSecondsInput(): number | undefined;
        private _cloudwatchConfig?;
        private __cloudwatchConfigOutput;
        /**
         * @stability stable
         */
        get cloudwatchConfig(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersCloudwatchConfigOutputReference;
        /**
         * @stability stable
         */
        putCloudwatchConfig(value: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersCloudwatchConfig | undefined): void;
        /**
         * @stability stable
         */
        resetCloudwatchConfig(): void;
        /**
         * @stability stable
         */
        get cloudwatchConfigInput(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersCloudwatchConfig | undefined;
        private _notificationConfig?;
        private __notificationConfigOutput;
        /**
         * @stability stable
         */
        get notificationConfig(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfigOutputReference;
        /**
         * @stability stable
         */
        putNotificationConfig(value: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig | undefined): void;
        /**
         * @stability stable
         */
        resetNotificationConfig(): void;
        /**
         * @stability stable
         */
        get notificationConfigInput(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig | undefined;
        private _parameter?;
        /**
         * @stability stable
         */
        get parameter(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter[] | undefined;
        /**
         * @stability stable
         */
        set parameter(value: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter[] | undefined);
        /**
         * @stability stable
         */
        resetParameter(): void;
        /**
         * @stability stable
         */
        get parameterInput(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter[] | undefined;
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#input SsmMaintenanceWindowTask#input}.
         *
         * @stability stable
         */
        readonly input?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#name SsmMaintenanceWindowTask#name}.
         *
         * @stability stable
         */
        readonly name?: string;
    }
    /**
     * @stability stable
     */
    class SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParametersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _input?;
        /**
         * @stability stable
         */
        get input(): string | undefined;
        /**
         * @stability stable
         */
        set input(value: string | undefined);
        /**
         * @stability stable
         */
        resetInput(): void;
        /**
         * @stability stable
         */
        get inputInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SsmMaintenanceWindowTaskTaskInvocationParameters {
        /**
         * automation_parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#automation_parameters SsmMaintenanceWindowTask#automation_parameters}
         *
         * @stability stable
         */
        readonly automationParameters?: SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters;
        /**
         * lambda_parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#lambda_parameters SsmMaintenanceWindowTask#lambda_parameters}
         *
         * @stability stable
         */
        readonly lambdaParameters?: SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters;
        /**
         * run_command_parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#run_command_parameters SsmMaintenanceWindowTask#run_command_parameters}
         *
         * @stability stable
         */
        readonly runCommandParameters?: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters;
        /**
         * step_functions_parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html#step_functions_parameters SsmMaintenanceWindowTask#step_functions_parameters}
         *
         * @stability stable
         */
        readonly stepFunctionsParameters?: SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters;
    }
    /**
     * @stability stable
     */
    class SsmMaintenanceWindowTaskTaskInvocationParametersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _automationParameters?;
        private __automationParametersOutput;
        /**
         * @stability stable
         */
        get automationParameters(): SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersOutputReference;
        /**
         * @stability stable
         */
        putAutomationParameters(value: SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters | undefined): void;
        /**
         * @stability stable
         */
        resetAutomationParameters(): void;
        /**
         * @stability stable
         */
        get automationParametersInput(): SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters | undefined;
        private _lambdaParameters?;
        private __lambdaParametersOutput;
        /**
         * @stability stable
         */
        get lambdaParameters(): SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParametersOutputReference;
        /**
         * @stability stable
         */
        putLambdaParameters(value: SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters | undefined): void;
        /**
         * @stability stable
         */
        resetLambdaParameters(): void;
        /**
         * @stability stable
         */
        get lambdaParametersInput(): SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters | undefined;
        private _runCommandParameters?;
        private __runCommandParametersOutput;
        /**
         * @stability stable
         */
        get runCommandParameters(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersOutputReference;
        /**
         * @stability stable
         */
        putRunCommandParameters(value: SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters | undefined): void;
        /**
         * @stability stable
         */
        resetRunCommandParameters(): void;
        /**
         * @stability stable
         */
        get runCommandParametersInput(): SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters | undefined;
        private _stepFunctionsParameters?;
        private __stepFunctionsParametersOutput;
        /**
         * @stability stable
         */
        get stepFunctionsParameters(): SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParametersOutputReference;
        /**
         * @stability stable
         */
        putStepFunctionsParameters(value: SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters | undefined): void;
        /**
         * @stability stable
         */
        resetStepFunctionsParameters(): void;
        /**
         * @stability stable
         */
        get stepFunctionsParametersInput(): SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html aws_ssm_maintenance_window_task}.
     *
     * @stability stable
     */
    class SsmMaintenanceWindowTask extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_maintenance_window_task.html aws_ssm_maintenance_window_task} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmMaintenanceWindowTaskConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _maxConcurrency?;
        /**
         * @stability stable
         */
        get maxConcurrency(): string;
        /**
         * @stability stable
         */
        set maxConcurrency(value: string);
        /**
         * @stability stable
         */
        get maxConcurrencyInput(): string | undefined;
        private _maxErrors?;
        /**
         * @stability stable
         */
        get maxErrors(): string;
        /**
         * @stability stable
         */
        set maxErrors(value: string);
        /**
         * @stability stable
         */
        get maxErrorsInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _priority?;
        /**
         * @stability stable
         */
        get priority(): number | undefined;
        /**
         * @stability stable
         */
        set priority(value: number | undefined);
        /**
         * @stability stable
         */
        resetPriority(): void;
        /**
         * @stability stable
         */
        get priorityInput(): number | undefined;
        private _serviceRoleArn?;
        /**
         * @stability stable
         */
        get serviceRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set serviceRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceRoleArn(): void;
        /**
         * @stability stable
         */
        get serviceRoleArnInput(): string | undefined;
        private _taskArn?;
        /**
         * @stability stable
         */
        get taskArn(): string;
        /**
         * @stability stable
         */
        set taskArn(value: string);
        /**
         * @stability stable
         */
        get taskArnInput(): string | undefined;
        private _taskType?;
        /**
         * @stability stable
         */
        get taskType(): string;
        /**
         * @stability stable
         */
        set taskType(value: string);
        /**
         * @stability stable
         */
        get taskTypeInput(): string | undefined;
        private _windowId?;
        /**
         * @stability stable
         */
        get windowId(): string;
        /**
         * @stability stable
         */
        set windowId(value: string);
        /**
         * @stability stable
         */
        get windowIdInput(): string | undefined;
        private _targets?;
        /**
         * @stability stable
         */
        get targets(): SsmMaintenanceWindowTaskTargets[] | undefined;
        /**
         * @stability stable
         */
        set targets(value: SsmMaintenanceWindowTaskTargets[] | undefined);
        /**
         * @stability stable
         */
        resetTargets(): void;
        /**
         * @stability stable
         */
        get targetsInput(): SsmMaintenanceWindowTaskTargets[] | undefined;
        private _taskInvocationParameters?;
        private __taskInvocationParametersOutput;
        /**
         * @stability stable
         */
        get taskInvocationParameters(): SsmMaintenanceWindowTaskTaskInvocationParametersOutputReference;
        /**
         * @stability stable
         */
        putTaskInvocationParameters(value: SsmMaintenanceWindowTaskTaskInvocationParameters | undefined): void;
        /**
         * @stability stable
         */
        resetTaskInvocationParameters(): void;
        /**
         * @stability stable
         */
        get taskInvocationParametersInput(): SsmMaintenanceWindowTaskTaskInvocationParameters | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmParameterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#allowed_pattern SsmParameter#allowed_pattern}.
         *
         * @stability stable
         */
        readonly allowedPattern?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#data_type SsmParameter#data_type}.
         *
         * @stability stable
         */
        readonly dataType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#description SsmParameter#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#key_id SsmParameter#key_id}.
         *
         * @stability stable
         */
        readonly keyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#name SsmParameter#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#overwrite SsmParameter#overwrite}.
         *
         * @stability stable
         */
        readonly overwrite?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#tags SsmParameter#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#tags_all SsmParameter#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#tier SsmParameter#tier}.
         *
         * @stability stable
         */
        readonly tier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#type SsmParameter#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html#value SsmParameter#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html aws_ssm_parameter}.
     *
     * @stability stable
     */
    class SsmParameter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_parameter.html aws_ssm_parameter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmParameterConfig);
        private _allowedPattern?;
        /**
         * @stability stable
         */
        get allowedPattern(): string | undefined;
        /**
         * @stability stable
         */
        set allowedPattern(value: string | undefined);
        /**
         * @stability stable
         */
        resetAllowedPattern(): void;
        /**
         * @stability stable
         */
        get allowedPatternInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _dataType?;
        /**
         * @stability stable
         */
        get dataType(): string | undefined;
        /**
         * @stability stable
         */
        set dataType(value: string | undefined);
        /**
         * @stability stable
         */
        resetDataType(): void;
        /**
         * @stability stable
         */
        get dataTypeInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _keyId?;
        /**
         * @stability stable
         */
        get keyId(): string | undefined;
        /**
         * @stability stable
         */
        set keyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKeyId(): void;
        /**
         * @stability stable
         */
        get keyIdInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _overwrite?;
        /**
         * @stability stable
         */
        get overwrite(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set overwrite(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetOverwrite(): void;
        /**
         * @stability stable
         */
        get overwriteInput(): boolean | cdktf.IResolvable | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tier?;
        /**
         * @stability stable
         */
        get tier(): string | undefined;
        /**
         * @stability stable
         */
        set tier(value: string | undefined);
        /**
         * @stability stable
         */
        resetTier(): void;
        /**
         * @stability stable
         */
        get tierInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        set value(value: string);
        /**
         * @stability stable
         */
        get valueInput(): string | undefined;
        /**
         * @stability stable
         */
        get version(): number;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmPatchBaselineConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#approved_patches SsmPatchBaseline#approved_patches}.
         *
         * @stability stable
         */
        readonly approvedPatches?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#approved_patches_compliance_level SsmPatchBaseline#approved_patches_compliance_level}.
         *
         * @stability stable
         */
        readonly approvedPatchesComplianceLevel?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#approved_patches_enable_non_security SsmPatchBaseline#approved_patches_enable_non_security}.
         *
         * @stability stable
         */
        readonly approvedPatchesEnableNonSecurity?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#description SsmPatchBaseline#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#name SsmPatchBaseline#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#operating_system SsmPatchBaseline#operating_system}.
         *
         * @stability stable
         */
        readonly operatingSystem?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#rejected_patches SsmPatchBaseline#rejected_patches}.
         *
         * @stability stable
         */
        readonly rejectedPatches?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#rejected_patches_action SsmPatchBaseline#rejected_patches_action}.
         *
         * @stability stable
         */
        readonly rejectedPatchesAction?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#tags SsmPatchBaseline#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#tags_all SsmPatchBaseline#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * approval_rule block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#approval_rule SsmPatchBaseline#approval_rule}
         *
         * @stability stable
         */
        readonly approvalRule?: SsmPatchBaselineApprovalRule[];
        /**
         * global_filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#global_filter SsmPatchBaseline#global_filter}
         *
         * @stability stable
         */
        readonly globalFilter?: SsmPatchBaselineGlobalFilter[];
        /**
         * source block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#source SsmPatchBaseline#source}
         *
         * @stability stable
         */
        readonly source?: SsmPatchBaselineSource[];
    }
    /**
     * @stability stable
     */
    interface SsmPatchBaselineApprovalRulePatchFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#key SsmPatchBaseline#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#values SsmPatchBaseline#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    interface SsmPatchBaselineApprovalRule {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#approve_after_days SsmPatchBaseline#approve_after_days}.
         *
         * @stability stable
         */
        readonly approveAfterDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#approve_until_date SsmPatchBaseline#approve_until_date}.
         *
         * @stability stable
         */
        readonly approveUntilDate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#compliance_level SsmPatchBaseline#compliance_level}.
         *
         * @stability stable
         */
        readonly complianceLevel?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#enable_non_security SsmPatchBaseline#enable_non_security}.
         *
         * @stability stable
         */
        readonly enableNonSecurity?: boolean | cdktf.IResolvable;
        /**
         * patch_filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#patch_filter SsmPatchBaseline#patch_filter}
         *
         * @stability stable
         */
        readonly patchFilter: SsmPatchBaselineApprovalRulePatchFilter[];
    }
    /**
     * @stability stable
     */
    interface SsmPatchBaselineGlobalFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#key SsmPatchBaseline#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#values SsmPatchBaseline#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    interface SsmPatchBaselineSource {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#configuration SsmPatchBaseline#configuration}.
         *
         * @stability stable
         */
        readonly configuration: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#name SsmPatchBaseline#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html#products SsmPatchBaseline#products}.
         *
         * @stability stable
         */
        readonly products: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html aws_ssm_patch_baseline}.
     *
     * @stability stable
     */
    class SsmPatchBaseline extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_baseline.html aws_ssm_patch_baseline} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmPatchBaselineConfig);
        private _approvedPatches?;
        /**
         * @stability stable
         */
        get approvedPatches(): string[] | undefined;
        /**
         * @stability stable
         */
        set approvedPatches(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetApprovedPatches(): void;
        /**
         * @stability stable
         */
        get approvedPatchesInput(): string[] | undefined;
        private _approvedPatchesComplianceLevel?;
        /**
         * @stability stable
         */
        get approvedPatchesComplianceLevel(): string | undefined;
        /**
         * @stability stable
         */
        set approvedPatchesComplianceLevel(value: string | undefined);
        /**
         * @stability stable
         */
        resetApprovedPatchesComplianceLevel(): void;
        /**
         * @stability stable
         */
        get approvedPatchesComplianceLevelInput(): string | undefined;
        private _approvedPatchesEnableNonSecurity?;
        /**
         * @stability stable
         */
        get approvedPatchesEnableNonSecurity(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set approvedPatchesEnableNonSecurity(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetApprovedPatchesEnableNonSecurity(): void;
        /**
         * @stability stable
         */
        get approvedPatchesEnableNonSecurityInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _operatingSystem?;
        /**
         * @stability stable
         */
        get operatingSystem(): string | undefined;
        /**
         * @stability stable
         */
        set operatingSystem(value: string | undefined);
        /**
         * @stability stable
         */
        resetOperatingSystem(): void;
        /**
         * @stability stable
         */
        get operatingSystemInput(): string | undefined;
        private _rejectedPatches?;
        /**
         * @stability stable
         */
        get rejectedPatches(): string[] | undefined;
        /**
         * @stability stable
         */
        set rejectedPatches(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetRejectedPatches(): void;
        /**
         * @stability stable
         */
        get rejectedPatchesInput(): string[] | undefined;
        private _rejectedPatchesAction?;
        /**
         * @stability stable
         */
        get rejectedPatchesAction(): string | undefined;
        /**
         * @stability stable
         */
        set rejectedPatchesAction(value: string | undefined);
        /**
         * @stability stable
         */
        resetRejectedPatchesAction(): void;
        /**
         * @stability stable
         */
        get rejectedPatchesActionInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _approvalRule?;
        /**
         * @stability stable
         */
        get approvalRule(): SsmPatchBaselineApprovalRule[] | undefined;
        /**
         * @stability stable
         */
        set approvalRule(value: SsmPatchBaselineApprovalRule[] | undefined);
        /**
         * @stability stable
         */
        resetApprovalRule(): void;
        /**
         * @stability stable
         */
        get approvalRuleInput(): SsmPatchBaselineApprovalRule[] | undefined;
        private _globalFilter?;
        /**
         * @stability stable
         */
        get globalFilter(): SsmPatchBaselineGlobalFilter[] | undefined;
        /**
         * @stability stable
         */
        set globalFilter(value: SsmPatchBaselineGlobalFilter[] | undefined);
        /**
         * @stability stable
         */
        resetGlobalFilter(): void;
        /**
         * @stability stable
         */
        get globalFilterInput(): SsmPatchBaselineGlobalFilter[] | undefined;
        private _source?;
        /**
         * @stability stable
         */
        get source(): SsmPatchBaselineSource[] | undefined;
        /**
         * @stability stable
         */
        set source(value: SsmPatchBaselineSource[] | undefined);
        /**
         * @stability stable
         */
        resetSource(): void;
        /**
         * @stability stable
         */
        get sourceInput(): SsmPatchBaselineSource[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmPatchGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_group.html#baseline_id SsmPatchGroup#baseline_id}.
         *
         * @stability stable
         */
        readonly baselineId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_group.html#patch_group SsmPatchGroup#patch_group}.
         *
         * @stability stable
         */
        readonly patchGroup: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_group.html aws_ssm_patch_group}.
     *
     * @stability stable
     */
    class SsmPatchGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_patch_group.html aws_ssm_patch_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmPatchGroupConfig);
        private _baselineId?;
        /**
         * @stability stable
         */
        get baselineId(): string;
        /**
         * @stability stable
         */
        set baselineId(value: string);
        /**
         * @stability stable
         */
        get baselineIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _patchGroup?;
        /**
         * @stability stable
         */
        get patchGroup(): string;
        /**
         * @stability stable
         */
        set patchGroup(value: string);
        /**
         * @stability stable
         */
        get patchGroupInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SsmResourceDataSyncConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html#name SsmResourceDataSync#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * s3_destination block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html#s3_destination SsmResourceDataSync#s3_destination}
         *
         * @stability stable
         */
        readonly s3Destination: SsmResourceDataSyncS3Destination;
    }
    /**
     * @stability stable
     */
    interface SsmResourceDataSyncS3Destination {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html#bucket_name SsmResourceDataSync#bucket_name}.
         *
         * @stability stable
         */
        readonly bucketName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html#kms_key_arn SsmResourceDataSync#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html#prefix SsmResourceDataSync#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html#region SsmResourceDataSync#region}.
         *
         * @stability stable
         */
        readonly region: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html#sync_format SsmResourceDataSync#sync_format}.
         *
         * @stability stable
         */
        readonly syncFormat?: string;
    }
    /**
     * @stability stable
     */
    class SsmResourceDataSyncS3DestinationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketName?;
        /**
         * @stability stable
         */
        get bucketName(): string;
        /**
         * @stability stable
         */
        set bucketName(value: string);
        /**
         * @stability stable
         */
        get bucketNameInput(): string | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
        private _region?;
        /**
         * @stability stable
         */
        get region(): string;
        /**
         * @stability stable
         */
        set region(value: string);
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
        private _syncFormat?;
        /**
         * @stability stable
         */
        get syncFormat(): string | undefined;
        /**
         * @stability stable
         */
        set syncFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetSyncFormat(): void;
        /**
         * @stability stable
         */
        get syncFormatInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html aws_ssm_resource_data_sync}.
     *
     * @stability stable
     */
    class SsmResourceDataSync extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/ssm_resource_data_sync.html aws_ssm_resource_data_sync} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SsmResourceDataSyncConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _s3Destination?;
        private __s3DestinationOutput;
        /**
         * @stability stable
         */
        get s3Destination(): SsmResourceDataSyncS3DestinationOutputReference;
        /**
         * @stability stable
         */
        putS3Destination(value: SsmResourceDataSyncS3Destination): void;
        /**
         * @stability stable
         */
        get s3DestinationInput(): SsmResourceDataSyncS3Destination | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSsmDocumentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_document.html#document_format DataAwsSsmDocument#document_format}.
         *
         * @stability stable
         */
        readonly documentFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_document.html#document_version DataAwsSsmDocument#document_version}.
         *
         * @stability stable
         */
        readonly documentVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_document.html#name DataAwsSsmDocument#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ssm_document.html aws_ssm_document}.
     *
     * @stability stable
     */
    class DataAwsSsmDocument extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ssm_document.html aws_ssm_document} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSsmDocumentConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get content(): string;
        private _documentFormat?;
        /**
         * @stability stable
         */
        get documentFormat(): string | undefined;
        /**
         * @stability stable
         */
        set documentFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentFormat(): void;
        /**
         * @stability stable
         */
        get documentFormatInput(): string | undefined;
        /**
         * @stability stable
         */
        get documentType(): string;
        private _documentVersion?;
        /**
         * @stability stable
         */
        get documentVersion(): string | undefined;
        /**
         * @stability stable
         */
        set documentVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetDocumentVersion(): void;
        /**
         * @stability stable
         */
        get documentVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSsmParameterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameter.html#name DataAwsSsmParameter#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameter.html#with_decryption DataAwsSsmParameter#with_decryption}.
         *
         * @stability stable
         */
        readonly withDecryption?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameter.html aws_ssm_parameter}.
     *
     * @stability stable
     */
    class DataAwsSsmParameter extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameter.html aws_ssm_parameter} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSsmParameterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        get value(): string;
        /**
         * @stability stable
         */
        get version(): number;
        private _withDecryption?;
        /**
         * @stability stable
         */
        get withDecryption(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set withDecryption(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWithDecryption(): void;
        /**
         * @stability stable
         */
        get withDecryptionInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSsmParametersByPathConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameters_by_path.html#path DataAwsSsmParametersByPath#path}.
         *
         * @stability stable
         */
        readonly path: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameters_by_path.html#with_decryption DataAwsSsmParametersByPath#with_decryption}.
         *
         * @stability stable
         */
        readonly withDecryption?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameters_by_path.html aws_ssm_parameters_by_path}.
     *
     * @stability stable
     */
    class DataAwsSsmParametersByPath extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ssm_parameters_by_path.html aws_ssm_parameters_by_path} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSsmParametersByPathConfig);
        /**
         * @stability stable
         */
        get arns(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get names(): string[];
        private _path?;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        set path(value: string);
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        /**
         * @stability stable
         */
        get types(): string[];
        /**
         * @stability stable
         */
        get values(): string[];
        private _withDecryption?;
        /**
         * @stability stable
         */
        get withDecryption(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set withDecryption(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetWithDecryption(): void;
        /**
         * @stability stable
         */
        get withDecryptionInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSsmPatchBaselineConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_patch_baseline.html#default_baseline DataAwsSsmPatchBaseline#default_baseline}.
         *
         * @stability stable
         */
        readonly defaultBaseline?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_patch_baseline.html#name_prefix DataAwsSsmPatchBaseline#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_patch_baseline.html#operating_system DataAwsSsmPatchBaseline#operating_system}.
         *
         * @stability stable
         */
        readonly operatingSystem?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/ssm_patch_baseline.html#owner DataAwsSsmPatchBaseline#owner}.
         *
         * @stability stable
         */
        readonly owner: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/ssm_patch_baseline.html aws_ssm_patch_baseline}.
     *
     * @stability stable
     */
    class DataAwsSsmPatchBaseline extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/ssm_patch_baseline.html aws_ssm_patch_baseline} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSsmPatchBaselineConfig);
        private _defaultBaseline?;
        /**
         * @stability stable
         */
        get defaultBaseline(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set defaultBaseline(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDefaultBaseline(): void;
        /**
         * @stability stable
         */
        get defaultBaselineInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _operatingSystem?;
        /**
         * @stability stable
         */
        get operatingSystem(): string | undefined;
        /**
         * @stability stable
         */
        set operatingSystem(value: string | undefined);
        /**
         * @stability stable
         */
        resetOperatingSystem(): void;
        /**
         * @stability stable
         */
        get operatingSystemInput(): string | undefined;
        private _owner?;
        /**
         * @stability stable
         */
        get owner(): string;
        /**
         * @stability stable
         */
        set owner(value: string);
        /**
         * @stability stable
         */
        get ownerInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
