import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Secrets Manager
*/
export declare namespace SecretsManager {
    /**
     * @stability stable
     */
    interface SecretsmanagerSecretConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#description SecretsmanagerSecret#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#force_overwrite_replica_secret SecretsmanagerSecret#force_overwrite_replica_secret}.
         *
         * @stability stable
         */
        readonly forceOverwriteReplicaSecret?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#kms_key_id SecretsmanagerSecret#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#name SecretsmanagerSecret#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#name_prefix SecretsmanagerSecret#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#policy SecretsmanagerSecret#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#recovery_window_in_days SecretsmanagerSecret#recovery_window_in_days}.
         *
         * @stability stable
         */
        readonly recoveryWindowInDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#rotation_lambda_arn SecretsmanagerSecret#rotation_lambda_arn}.
         *
         * @stability stable
         */
        readonly rotationLambdaArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#tags SecretsmanagerSecret#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#tags_all SecretsmanagerSecret#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * replica block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#replica SecretsmanagerSecret#replica}
         *
         * @stability stable
         */
        readonly replica?: SecretsmanagerSecretReplica[];
        /**
         * rotation_rules block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#rotation_rules SecretsmanagerSecret#rotation_rules}
         *
         * @stability stable
         */
        readonly rotationRules?: SecretsmanagerSecretRotationRules;
    }
    /**
     * @stability stable
     */
    interface SecretsmanagerSecretReplica {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#kms_key_id SecretsmanagerSecret#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#region SecretsmanagerSecret#region}.
         *
         * @stability stable
         */
        readonly region: string;
    }
    /**
     * @stability stable
     */
    interface SecretsmanagerSecretRotationRules {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html#automatically_after_days SecretsmanagerSecret#automatically_after_days}.
         *
         * @stability stable
         */
        readonly automaticallyAfterDays: number;
    }
    /**
     * @stability stable
     */
    class SecretsmanagerSecretRotationRulesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _automaticallyAfterDays?;
        /**
         * @stability stable
         */
        get automaticallyAfterDays(): number;
        /**
         * @stability stable
         */
        set automaticallyAfterDays(value: number);
        /**
         * @stability stable
         */
        get automaticallyAfterDaysInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html aws_secretsmanager_secret}.
     *
     * @stability stable
     */
    class SecretsmanagerSecret extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret.html aws_secretsmanager_secret} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: SecretsmanagerSecretConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _forceOverwriteReplicaSecret?;
        /**
         * @stability stable
         */
        get forceOverwriteReplicaSecret(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceOverwriteReplicaSecret(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceOverwriteReplicaSecret(): void;
        /**
         * @stability stable
         */
        get forceOverwriteReplicaSecretInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _recoveryWindowInDays?;
        /**
         * @stability stable
         */
        get recoveryWindowInDays(): number | undefined;
        /**
         * @stability stable
         */
        set recoveryWindowInDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetRecoveryWindowInDays(): void;
        /**
         * @stability stable
         */
        get recoveryWindowInDaysInput(): number | undefined;
        /**
         * @stability stable
         */
        get rotationEnabled(): any;
        private _rotationLambdaArn?;
        /**
         * @stability stable
         */
        get rotationLambdaArn(): string | undefined;
        /**
         * @stability stable
         */
        set rotationLambdaArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetRotationLambdaArn(): void;
        /**
         * @stability stable
         */
        get rotationLambdaArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _replica?;
        /**
         * @stability stable
         */
        get replica(): SecretsmanagerSecretReplica[] | undefined;
        /**
         * @stability stable
         */
        set replica(value: SecretsmanagerSecretReplica[] | undefined);
        /**
         * @stability stable
         */
        resetReplica(): void;
        /**
         * @stability stable
         */
        get replicaInput(): SecretsmanagerSecretReplica[] | undefined;
        private _rotationRules?;
        private __rotationRulesOutput;
        /**
         * @stability stable
         */
        get rotationRules(): SecretsmanagerSecretRotationRulesOutputReference;
        /**
         * @stability stable
         */
        putRotationRules(value: SecretsmanagerSecretRotationRules | undefined): void;
        /**
         * @stability stable
         */
        resetRotationRules(): void;
        /**
         * @stability stable
         */
        get rotationRulesInput(): SecretsmanagerSecretRotationRules | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecretsmanagerSecretPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_policy.html#block_public_policy SecretsmanagerSecretPolicy#block_public_policy}.
         *
         * @stability stable
         */
        readonly blockPublicPolicy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_policy.html#policy SecretsmanagerSecretPolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_policy.html#secret_arn SecretsmanagerSecretPolicy#secret_arn}.
         *
         * @stability stable
         */
        readonly secretArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_policy.html aws_secretsmanager_secret_policy}.
     *
     * @stability stable
     */
    class SecretsmanagerSecretPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_policy.html aws_secretsmanager_secret_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecretsmanagerSecretPolicyConfig);
        private _blockPublicPolicy?;
        /**
         * @stability stable
         */
        get blockPublicPolicy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set blockPublicPolicy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetBlockPublicPolicy(): void;
        /**
         * @stability stable
         */
        get blockPublicPolicyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _secretArn?;
        /**
         * @stability stable
         */
        get secretArn(): string;
        /**
         * @stability stable
         */
        set secretArn(value: string);
        /**
         * @stability stable
         */
        get secretArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecretsmanagerSecretRotationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation.html#rotation_lambda_arn SecretsmanagerSecretRotation#rotation_lambda_arn}.
         *
         * @stability stable
         */
        readonly rotationLambdaArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation.html#secret_id SecretsmanagerSecretRotation#secret_id}.
         *
         * @stability stable
         */
        readonly secretId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation.html#tags SecretsmanagerSecretRotation#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * rotation_rules block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation.html#rotation_rules SecretsmanagerSecretRotation#rotation_rules}
         *
         * @stability stable
         */
        readonly rotationRules: SecretsmanagerSecretRotationRotationRules;
    }
    /**
     * @stability stable
     */
    interface SecretsmanagerSecretRotationRotationRules {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation.html#automatically_after_days SecretsmanagerSecretRotation#automatically_after_days}.
         *
         * @stability stable
         */
        readonly automaticallyAfterDays: number;
    }
    /**
     * @stability stable
     */
    class SecretsmanagerSecretRotationRotationRulesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _automaticallyAfterDays?;
        /**
         * @stability stable
         */
        get automaticallyAfterDays(): number;
        /**
         * @stability stable
         */
        set automaticallyAfterDays(value: number);
        /**
         * @stability stable
         */
        get automaticallyAfterDaysInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation.html aws_secretsmanager_secret_rotation}.
     *
     * @stability stable
     */
    class SecretsmanagerSecretRotation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_rotation.html aws_secretsmanager_secret_rotation} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecretsmanagerSecretRotationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get rotationEnabled(): any;
        private _rotationLambdaArn?;
        /**
         * @stability stable
         */
        get rotationLambdaArn(): string;
        /**
         * @stability stable
         */
        set rotationLambdaArn(value: string);
        /**
         * @stability stable
         */
        get rotationLambdaArnInput(): string | undefined;
        private _secretId?;
        /**
         * @stability stable
         */
        get secretId(): string;
        /**
         * @stability stable
         */
        set secretId(value: string);
        /**
         * @stability stable
         */
        get secretIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _rotationRules?;
        private __rotationRulesOutput;
        /**
         * @stability stable
         */
        get rotationRules(): SecretsmanagerSecretRotationRotationRulesOutputReference;
        /**
         * @stability stable
         */
        putRotationRules(value: SecretsmanagerSecretRotationRotationRules): void;
        /**
         * @stability stable
         */
        get rotationRulesInput(): SecretsmanagerSecretRotationRotationRules | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecretsmanagerSecretVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_version.html#secret_binary SecretsmanagerSecretVersion#secret_binary}.
         *
         * @stability stable
         */
        readonly secretBinary?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_version.html#secret_id SecretsmanagerSecretVersion#secret_id}.
         *
         * @stability stable
         */
        readonly secretId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_version.html#secret_string SecretsmanagerSecretVersion#secret_string}.
         *
         * @stability stable
         */
        readonly secretString?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_version.html#version_stages SecretsmanagerSecretVersion#version_stages}.
         *
         * @stability stable
         */
        readonly versionStages?: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_version.html aws_secretsmanager_secret_version}.
     *
     * @stability stable
     */
    class SecretsmanagerSecretVersion extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/secretsmanager_secret_version.html aws_secretsmanager_secret_version} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecretsmanagerSecretVersionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _secretBinary?;
        /**
         * @stability stable
         */
        get secretBinary(): string | undefined;
        /**
         * @stability stable
         */
        set secretBinary(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecretBinary(): void;
        /**
         * @stability stable
         */
        get secretBinaryInput(): string | undefined;
        private _secretId?;
        /**
         * @stability stable
         */
        get secretId(): string;
        /**
         * @stability stable
         */
        set secretId(value: string);
        /**
         * @stability stable
         */
        get secretIdInput(): string | undefined;
        private _secretString?;
        /**
         * @stability stable
         */
        get secretString(): string | undefined;
        /**
         * @stability stable
         */
        set secretString(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecretString(): void;
        /**
         * @stability stable
         */
        get secretStringInput(): string | undefined;
        /**
         * @stability stable
         */
        get versionId(): string;
        private _versionStages?;
        /**
         * @stability stable
         */
        get versionStages(): string[] | undefined;
        /**
         * @stability stable
         */
        set versionStages(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVersionStages(): void;
        /**
         * @stability stable
         */
        get versionStagesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSecretsmanagerSecretConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret.html#name DataAwsSecretsmanagerSecret#name}.
         *
         * @stability stable
         */
        readonly name?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsSecretsmanagerSecretRotationRules extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get automaticallyAfterDays(): number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret.html aws_secretsmanager_secret}.
     *
     * @stability stable
     */
    class DataAwsSecretsmanagerSecret extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret.html aws_secretsmanager_secret} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsSecretsmanagerSecretConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        get rotationEnabled(): any;
        /**
         * @stability stable
         */
        get rotationLambdaArn(): string;
        /**
         * @stability stable
         */
        rotationRules(index: string): DataAwsSecretsmanagerSecretRotationRules;
        /**
         * @stability stable
         */
        tags(key: string): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSecretsmanagerSecretRotationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation.html#secret_id DataAwsSecretsmanagerSecretRotation#secret_id}.
         *
         * @stability stable
         */
        readonly secretId: string;
    }
    /**
     * @stability stable
     */
    class DataAwsSecretsmanagerSecretRotationRotationRules extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get automaticallyAfterDays(): number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation.html aws_secretsmanager_secret_rotation}.
     *
     * @stability stable
     */
    class DataAwsSecretsmanagerSecretRotation extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_rotation.html aws_secretsmanager_secret_rotation} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSecretsmanagerSecretRotationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get rotationEnabled(): any;
        /**
         * @stability stable
         */
        get rotationLambdaArn(): string;
        /**
         * @stability stable
         */
        rotationRules(index: string): DataAwsSecretsmanagerSecretRotationRotationRules;
        private _secretId?;
        /**
         * @stability stable
         */
        get secretId(): string;
        /**
         * @stability stable
         */
        set secretId(value: string);
        /**
         * @stability stable
         */
        get secretIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSecretsmanagerSecretVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_version.html#secret_id DataAwsSecretsmanagerSecretVersion#secret_id}.
         *
         * @stability stable
         */
        readonly secretId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_version.html#version_id DataAwsSecretsmanagerSecretVersion#version_id}.
         *
         * @stability stable
         */
        readonly versionId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_version.html#version_stage DataAwsSecretsmanagerSecretVersion#version_stage}.
         *
         * @stability stable
         */
        readonly versionStage?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_version.html aws_secretsmanager_secret_version}.
     *
     * @stability stable
     */
    class DataAwsSecretsmanagerSecretVersion extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/secretsmanager_secret_version.html aws_secretsmanager_secret_version} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSecretsmanagerSecretVersionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get secretBinary(): string;
        private _secretId?;
        /**
         * @stability stable
         */
        get secretId(): string;
        /**
         * @stability stable
         */
        set secretId(value: string);
        /**
         * @stability stable
         */
        get secretIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get secretString(): string;
        private _versionId?;
        /**
         * @stability stable
         */
        get versionId(): string | undefined;
        /**
         * @stability stable
         */
        set versionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersionId(): void;
        /**
         * @stability stable
         */
        get versionIdInput(): string | undefined;
        private _versionStage?;
        /**
         * @stability stable
         */
        get versionStage(): string | undefined;
        /**
         * @stability stable
         */
        set versionStage(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersionStage(): void;
        /**
         * @stability stable
         */
        get versionStageInput(): string | undefined;
        /**
         * @stability stable
         */
        get versionStages(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
