import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Security Hub
*/
export declare namespace SecurityHub {
    /**
     * @stability stable
     */
    interface SecurityhubAccountConfig extends cdktf.TerraformMetaArguments {
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_account.html aws_securityhub_account}.
     *
     * @stability stable
     */
    class SecurityhubAccount extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_account.html aws_securityhub_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: SecurityhubAccountConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubActionTargetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_action_target.html#description SecurityhubActionTarget#description}.
         *
         * @stability stable
         */
        readonly description: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_action_target.html#identifier SecurityhubActionTarget#identifier}.
         *
         * @stability stable
         */
        readonly identifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_action_target.html#name SecurityhubActionTarget#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_action_target.html aws_securityhub_action_target}.
     *
     * @stability stable
     */
    class SecurityhubActionTarget extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_action_target.html aws_securityhub_action_target} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubActionTargetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        set description(value: string);
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _identifier?;
        /**
         * @stability stable
         */
        get identifier(): string;
        /**
         * @stability stable
         */
        set identifier(value: string);
        /**
         * @stability stable
         */
        get identifierInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#group_by_attribute SecurityhubInsight#group_by_attribute}.
         *
         * @stability stable
         */
        readonly groupByAttribute: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#name SecurityhubInsight#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * filters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#filters SecurityhubInsight#filters}
         *
         * @stability stable
         */
        readonly filters: SecurityhubInsightFilters;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersAwsAccountId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersCompanyName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersComplianceStatus {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersConfidence {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersCreatedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersCreatedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersCreatedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersCreatedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersCriticality {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersDescription {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFindingProviderFieldsConfidence {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFindingProviderFieldsCriticality {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsProductArn {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFindingProviderFieldsSeverityLabel {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFindingProviderFieldsSeverityOriginal {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFindingProviderFieldsTypes {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFirstObservedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersFirstObservedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersFirstObservedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersFirstObservedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersGeneratorId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersKeyword {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersLastObservedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersLastObservedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersLastObservedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersLastObservedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersMalwareName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersMalwarePath {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersMalwareState {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersMalwareType {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkDestinationDomain {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkDestinationIpv4 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#cidr SecurityhubInsight#cidr}.
         *
         * @stability stable
         */
        readonly cidr: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkDestinationIpv6 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#cidr SecurityhubInsight#cidr}.
         *
         * @stability stable
         */
        readonly cidr: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkDestinationPort {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkDirection {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkProtocol {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkSourceDomain {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkSourceIpv4 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#cidr SecurityhubInsight#cidr}.
         *
         * @stability stable
         */
        readonly cidr: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkSourceIpv6 {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#cidr SecurityhubInsight#cidr}.
         *
         * @stability stable
         */
        readonly cidr: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkSourceMac {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNetworkSourcePort {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNoteText {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNoteUpdatedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersNoteUpdatedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNoteUpdatedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersNoteUpdatedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersNoteUpdatedBy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessLaunchedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersProcessLaunchedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessLaunchedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersProcessLaunchedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessParentPid {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessPath {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessPid {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#eq SecurityhubInsight#eq}.
         *
         * @stability stable
         */
        readonly eq?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#gte SecurityhubInsight#gte}.
         *
         * @stability stable
         */
        readonly gte?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#lte SecurityhubInsight#lte}.
         *
         * @stability stable
         */
        readonly lte?: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessTerminatedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersProcessTerminatedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProcessTerminatedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersProcessTerminatedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProductArn {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProductFields {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#key SecurityhubInsight#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersProductName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersRecommendationText {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersRecordState {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersRelatedFindingsId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersRelatedFindingsProductArn {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceIamInstanceProfileArn {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceImageId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceIpv4Addresses {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#cidr SecurityhubInsight#cidr}.
         *
         * @stability stable
         */
        readonly cidr: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceIpv6Addresses {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#cidr SecurityhubInsight#cidr}.
         *
         * @stability stable
         */
        readonly cidr: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceKeyName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceSubnetId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceType {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsEc2InstanceVpcId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsIamAccessKeyStatus {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsIamAccessKeyUserName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsS3BucketOwnerId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceAwsS3BucketOwnerName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceContainerImageId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceContainerImageName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceContainerLaunchedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersResourceContainerLaunchedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceContainerLaunchedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersResourceContainerLaunchedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceContainerName {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceDetailsOther {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#key SecurityhubInsight#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourcePartition {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceRegion {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceTags {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#key SecurityhubInsight#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersResourceType {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersSeverityLabel {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersSourceUrl {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersThreatIntelIndicatorCategory {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersThreatIntelIndicatorSource {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersThreatIntelIndicatorSourceUrl {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersThreatIntelIndicatorType {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersThreatIntelIndicatorValue {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersTitle {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersType {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersUpdatedAtDateRange {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#unit SecurityhubInsight#unit}.
         *
         * @stability stable
         */
        readonly unit: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: number;
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersUpdatedAtDateRangeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _unit?;
        /**
         * @stability stable
         */
        get unit(): string;
        /**
         * @stability stable
         */
        set unit(value: string);
        /**
         * @stability stable
         */
        get unitInput(): string | undefined;
        private _value?;
        /**
         * @stability stable
         */
        get value(): number;
        /**
         * @stability stable
         */
        set value(value: number);
        /**
         * @stability stable
         */
        get valueInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersUpdatedAt {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#end SecurityhubInsight#end}.
         *
         * @stability stable
         */
        readonly end?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#start SecurityhubInsight#start}.
         *
         * @stability stable
         */
        readonly start?: string;
        /**
         * date_range block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#date_range SecurityhubInsight#date_range}
         *
         * @stability stable
         */
        readonly dateRange?: SecurityhubInsightFiltersUpdatedAtDateRange;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersUserDefinedValues {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#key SecurityhubInsight#key}.
         *
         * @stability stable
         */
        readonly key: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersVerificationState {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFiltersWorkflowStatus {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#comparison SecurityhubInsight#comparison}.
         *
         * @stability stable
         */
        readonly comparison: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#value SecurityhubInsight#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface SecurityhubInsightFilters {
        /**
         * aws_account_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#aws_account_id SecurityhubInsight#aws_account_id}
         *
         * @stability stable
         */
        readonly awsAccountId?: SecurityhubInsightFiltersAwsAccountId[];
        /**
         * company_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#company_name SecurityhubInsight#company_name}
         *
         * @stability stable
         */
        readonly companyName?: SecurityhubInsightFiltersCompanyName[];
        /**
         * compliance_status block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#compliance_status SecurityhubInsight#compliance_status}
         *
         * @stability stable
         */
        readonly complianceStatus?: SecurityhubInsightFiltersComplianceStatus[];
        /**
         * confidence block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#confidence SecurityhubInsight#confidence}
         *
         * @stability stable
         */
        readonly confidence?: SecurityhubInsightFiltersConfidence[];
        /**
         * created_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#created_at SecurityhubInsight#created_at}
         *
         * @stability stable
         */
        readonly createdAt?: SecurityhubInsightFiltersCreatedAt[];
        /**
         * criticality block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#criticality SecurityhubInsight#criticality}
         *
         * @stability stable
         */
        readonly criticality?: SecurityhubInsightFiltersCriticality[];
        /**
         * description block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#description SecurityhubInsight#description}
         *
         * @stability stable
         */
        readonly description?: SecurityhubInsightFiltersDescription[];
        /**
         * finding_provider_fields_confidence block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#finding_provider_fields_confidence SecurityhubInsight#finding_provider_fields_confidence}
         *
         * @stability stable
         */
        readonly findingProviderFieldsConfidence?: SecurityhubInsightFiltersFindingProviderFieldsConfidence[];
        /**
         * finding_provider_fields_criticality block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#finding_provider_fields_criticality SecurityhubInsight#finding_provider_fields_criticality}
         *
         * @stability stable
         */
        readonly findingProviderFieldsCriticality?: SecurityhubInsightFiltersFindingProviderFieldsCriticality[];
        /**
         * finding_provider_fields_related_findings_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#finding_provider_fields_related_findings_id SecurityhubInsight#finding_provider_fields_related_findings_id}
         *
         * @stability stable
         */
        readonly findingProviderFieldsRelatedFindingsId?: SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsId[];
        /**
         * finding_provider_fields_related_findings_product_arn block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#finding_provider_fields_related_findings_product_arn SecurityhubInsight#finding_provider_fields_related_findings_product_arn}
         *
         * @stability stable
         */
        readonly findingProviderFieldsRelatedFindingsProductArn?: SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsProductArn[];
        /**
         * finding_provider_fields_severity_label block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#finding_provider_fields_severity_label SecurityhubInsight#finding_provider_fields_severity_label}
         *
         * @stability stable
         */
        readonly findingProviderFieldsSeverityLabel?: SecurityhubInsightFiltersFindingProviderFieldsSeverityLabel[];
        /**
         * finding_provider_fields_severity_original block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#finding_provider_fields_severity_original SecurityhubInsight#finding_provider_fields_severity_original}
         *
         * @stability stable
         */
        readonly findingProviderFieldsSeverityOriginal?: SecurityhubInsightFiltersFindingProviderFieldsSeverityOriginal[];
        /**
         * finding_provider_fields_types block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#finding_provider_fields_types SecurityhubInsight#finding_provider_fields_types}
         *
         * @stability stable
         */
        readonly findingProviderFieldsTypes?: SecurityhubInsightFiltersFindingProviderFieldsTypes[];
        /**
         * first_observed_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#first_observed_at SecurityhubInsight#first_observed_at}
         *
         * @stability stable
         */
        readonly firstObservedAt?: SecurityhubInsightFiltersFirstObservedAt[];
        /**
         * generator_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#generator_id SecurityhubInsight#generator_id}
         *
         * @stability stable
         */
        readonly generatorId?: SecurityhubInsightFiltersGeneratorId[];
        /**
         * id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#id SecurityhubInsight#id}
         *
         * @stability stable
         */
        readonly id?: SecurityhubInsightFiltersId[];
        /**
         * keyword block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#keyword SecurityhubInsight#keyword}
         *
         * @stability stable
         */
        readonly keyword?: SecurityhubInsightFiltersKeyword[];
        /**
         * last_observed_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#last_observed_at SecurityhubInsight#last_observed_at}
         *
         * @stability stable
         */
        readonly lastObservedAt?: SecurityhubInsightFiltersLastObservedAt[];
        /**
         * malware_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#malware_name SecurityhubInsight#malware_name}
         *
         * @stability stable
         */
        readonly malwareName?: SecurityhubInsightFiltersMalwareName[];
        /**
         * malware_path block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#malware_path SecurityhubInsight#malware_path}
         *
         * @stability stable
         */
        readonly malwarePath?: SecurityhubInsightFiltersMalwarePath[];
        /**
         * malware_state block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#malware_state SecurityhubInsight#malware_state}
         *
         * @stability stable
         */
        readonly malwareState?: SecurityhubInsightFiltersMalwareState[];
        /**
         * malware_type block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#malware_type SecurityhubInsight#malware_type}
         *
         * @stability stable
         */
        readonly malwareType?: SecurityhubInsightFiltersMalwareType[];
        /**
         * network_destination_domain block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_destination_domain SecurityhubInsight#network_destination_domain}
         *
         * @stability stable
         */
        readonly networkDestinationDomain?: SecurityhubInsightFiltersNetworkDestinationDomain[];
        /**
         * network_destination_ipv4 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_destination_ipv4 SecurityhubInsight#network_destination_ipv4}
         *
         * @stability stable
         */
        readonly networkDestinationIpv4?: SecurityhubInsightFiltersNetworkDestinationIpv4[];
        /**
         * network_destination_ipv6 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_destination_ipv6 SecurityhubInsight#network_destination_ipv6}
         *
         * @stability stable
         */
        readonly networkDestinationIpv6?: SecurityhubInsightFiltersNetworkDestinationIpv6[];
        /**
         * network_destination_port block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_destination_port SecurityhubInsight#network_destination_port}
         *
         * @stability stable
         */
        readonly networkDestinationPort?: SecurityhubInsightFiltersNetworkDestinationPort[];
        /**
         * network_direction block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_direction SecurityhubInsight#network_direction}
         *
         * @stability stable
         */
        readonly networkDirection?: SecurityhubInsightFiltersNetworkDirection[];
        /**
         * network_protocol block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_protocol SecurityhubInsight#network_protocol}
         *
         * @stability stable
         */
        readonly networkProtocol?: SecurityhubInsightFiltersNetworkProtocol[];
        /**
         * network_source_domain block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_source_domain SecurityhubInsight#network_source_domain}
         *
         * @stability stable
         */
        readonly networkSourceDomain?: SecurityhubInsightFiltersNetworkSourceDomain[];
        /**
         * network_source_ipv4 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_source_ipv4 SecurityhubInsight#network_source_ipv4}
         *
         * @stability stable
         */
        readonly networkSourceIpv4?: SecurityhubInsightFiltersNetworkSourceIpv4[];
        /**
         * network_source_ipv6 block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_source_ipv6 SecurityhubInsight#network_source_ipv6}
         *
         * @stability stable
         */
        readonly networkSourceIpv6?: SecurityhubInsightFiltersNetworkSourceIpv6[];
        /**
         * network_source_mac block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_source_mac SecurityhubInsight#network_source_mac}
         *
         * @stability stable
         */
        readonly networkSourceMac?: SecurityhubInsightFiltersNetworkSourceMac[];
        /**
         * network_source_port block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#network_source_port SecurityhubInsight#network_source_port}
         *
         * @stability stable
         */
        readonly networkSourcePort?: SecurityhubInsightFiltersNetworkSourcePort[];
        /**
         * note_text block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#note_text SecurityhubInsight#note_text}
         *
         * @stability stable
         */
        readonly noteText?: SecurityhubInsightFiltersNoteText[];
        /**
         * note_updated_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#note_updated_at SecurityhubInsight#note_updated_at}
         *
         * @stability stable
         */
        readonly noteUpdatedAt?: SecurityhubInsightFiltersNoteUpdatedAt[];
        /**
         * note_updated_by block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#note_updated_by SecurityhubInsight#note_updated_by}
         *
         * @stability stable
         */
        readonly noteUpdatedBy?: SecurityhubInsightFiltersNoteUpdatedBy[];
        /**
         * process_launched_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#process_launched_at SecurityhubInsight#process_launched_at}
         *
         * @stability stable
         */
        readonly processLaunchedAt?: SecurityhubInsightFiltersProcessLaunchedAt[];
        /**
         * process_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#process_name SecurityhubInsight#process_name}
         *
         * @stability stable
         */
        readonly processName?: SecurityhubInsightFiltersProcessName[];
        /**
         * process_parent_pid block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#process_parent_pid SecurityhubInsight#process_parent_pid}
         *
         * @stability stable
         */
        readonly processParentPid?: SecurityhubInsightFiltersProcessParentPid[];
        /**
         * process_path block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#process_path SecurityhubInsight#process_path}
         *
         * @stability stable
         */
        readonly processPath?: SecurityhubInsightFiltersProcessPath[];
        /**
         * process_pid block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#process_pid SecurityhubInsight#process_pid}
         *
         * @stability stable
         */
        readonly processPid?: SecurityhubInsightFiltersProcessPid[];
        /**
         * process_terminated_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#process_terminated_at SecurityhubInsight#process_terminated_at}
         *
         * @stability stable
         */
        readonly processTerminatedAt?: SecurityhubInsightFiltersProcessTerminatedAt[];
        /**
         * product_arn block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#product_arn SecurityhubInsight#product_arn}
         *
         * @stability stable
         */
        readonly productArn?: SecurityhubInsightFiltersProductArn[];
        /**
         * product_fields block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#product_fields SecurityhubInsight#product_fields}
         *
         * @stability stable
         */
        readonly productFields?: SecurityhubInsightFiltersProductFields[];
        /**
         * product_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#product_name SecurityhubInsight#product_name}
         *
         * @stability stable
         */
        readonly productName?: SecurityhubInsightFiltersProductName[];
        /**
         * recommendation_text block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#recommendation_text SecurityhubInsight#recommendation_text}
         *
         * @stability stable
         */
        readonly recommendationText?: SecurityhubInsightFiltersRecommendationText[];
        /**
         * record_state block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#record_state SecurityhubInsight#record_state}
         *
         * @stability stable
         */
        readonly recordState?: SecurityhubInsightFiltersRecordState[];
        /**
         * related_findings_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#related_findings_id SecurityhubInsight#related_findings_id}
         *
         * @stability stable
         */
        readonly relatedFindingsId?: SecurityhubInsightFiltersRelatedFindingsId[];
        /**
         * related_findings_product_arn block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#related_findings_product_arn SecurityhubInsight#related_findings_product_arn}
         *
         * @stability stable
         */
        readonly relatedFindingsProductArn?: SecurityhubInsightFiltersRelatedFindingsProductArn[];
        /**
         * resource_aws_ec2_instance_iam_instance_profile_arn block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_iam_instance_profile_arn SecurityhubInsight#resource_aws_ec2_instance_iam_instance_profile_arn}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceIamInstanceProfileArn?: SecurityhubInsightFiltersResourceAwsEc2InstanceIamInstanceProfileArn[];
        /**
         * resource_aws_ec2_instance_image_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_image_id SecurityhubInsight#resource_aws_ec2_instance_image_id}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceImageId?: SecurityhubInsightFiltersResourceAwsEc2InstanceImageId[];
        /**
         * resource_aws_ec2_instance_ipv4_addresses block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_ipv4_addresses SecurityhubInsight#resource_aws_ec2_instance_ipv4_addresses}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceIpv4Addresses?: SecurityhubInsightFiltersResourceAwsEc2InstanceIpv4Addresses[];
        /**
         * resource_aws_ec2_instance_ipv6_addresses block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_ipv6_addresses SecurityhubInsight#resource_aws_ec2_instance_ipv6_addresses}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceIpv6Addresses?: SecurityhubInsightFiltersResourceAwsEc2InstanceIpv6Addresses[];
        /**
         * resource_aws_ec2_instance_key_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_key_name SecurityhubInsight#resource_aws_ec2_instance_key_name}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceKeyName?: SecurityhubInsightFiltersResourceAwsEc2InstanceKeyName[];
        /**
         * resource_aws_ec2_instance_launched_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_launched_at SecurityhubInsight#resource_aws_ec2_instance_launched_at}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceLaunchedAt?: SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAt[];
        /**
         * resource_aws_ec2_instance_subnet_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_subnet_id SecurityhubInsight#resource_aws_ec2_instance_subnet_id}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceSubnetId?: SecurityhubInsightFiltersResourceAwsEc2InstanceSubnetId[];
        /**
         * resource_aws_ec2_instance_type block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_type SecurityhubInsight#resource_aws_ec2_instance_type}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceType?: SecurityhubInsightFiltersResourceAwsEc2InstanceType[];
        /**
         * resource_aws_ec2_instance_vpc_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_ec2_instance_vpc_id SecurityhubInsight#resource_aws_ec2_instance_vpc_id}
         *
         * @stability stable
         */
        readonly resourceAwsEc2InstanceVpcId?: SecurityhubInsightFiltersResourceAwsEc2InstanceVpcId[];
        /**
         * resource_aws_iam_access_key_created_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_iam_access_key_created_at SecurityhubInsight#resource_aws_iam_access_key_created_at}
         *
         * @stability stable
         */
        readonly resourceAwsIamAccessKeyCreatedAt?: SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAt[];
        /**
         * resource_aws_iam_access_key_status block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_iam_access_key_status SecurityhubInsight#resource_aws_iam_access_key_status}
         *
         * @stability stable
         */
        readonly resourceAwsIamAccessKeyStatus?: SecurityhubInsightFiltersResourceAwsIamAccessKeyStatus[];
        /**
         * resource_aws_iam_access_key_user_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_iam_access_key_user_name SecurityhubInsight#resource_aws_iam_access_key_user_name}
         *
         * @stability stable
         */
        readonly resourceAwsIamAccessKeyUserName?: SecurityhubInsightFiltersResourceAwsIamAccessKeyUserName[];
        /**
         * resource_aws_s3_bucket_owner_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_s3_bucket_owner_id SecurityhubInsight#resource_aws_s3_bucket_owner_id}
         *
         * @stability stable
         */
        readonly resourceAwsS3BucketOwnerId?: SecurityhubInsightFiltersResourceAwsS3BucketOwnerId[];
        /**
         * resource_aws_s3_bucket_owner_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_aws_s3_bucket_owner_name SecurityhubInsight#resource_aws_s3_bucket_owner_name}
         *
         * @stability stable
         */
        readonly resourceAwsS3BucketOwnerName?: SecurityhubInsightFiltersResourceAwsS3BucketOwnerName[];
        /**
         * resource_container_image_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_container_image_id SecurityhubInsight#resource_container_image_id}
         *
         * @stability stable
         */
        readonly resourceContainerImageId?: SecurityhubInsightFiltersResourceContainerImageId[];
        /**
         * resource_container_image_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_container_image_name SecurityhubInsight#resource_container_image_name}
         *
         * @stability stable
         */
        readonly resourceContainerImageName?: SecurityhubInsightFiltersResourceContainerImageName[];
        /**
         * resource_container_launched_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_container_launched_at SecurityhubInsight#resource_container_launched_at}
         *
         * @stability stable
         */
        readonly resourceContainerLaunchedAt?: SecurityhubInsightFiltersResourceContainerLaunchedAt[];
        /**
         * resource_container_name block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_container_name SecurityhubInsight#resource_container_name}
         *
         * @stability stable
         */
        readonly resourceContainerName?: SecurityhubInsightFiltersResourceContainerName[];
        /**
         * resource_details_other block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_details_other SecurityhubInsight#resource_details_other}
         *
         * @stability stable
         */
        readonly resourceDetailsOther?: SecurityhubInsightFiltersResourceDetailsOther[];
        /**
         * resource_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_id SecurityhubInsight#resource_id}
         *
         * @stability stable
         */
        readonly resourceId?: SecurityhubInsightFiltersResourceId[];
        /**
         * resource_partition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_partition SecurityhubInsight#resource_partition}
         *
         * @stability stable
         */
        readonly resourcePartition?: SecurityhubInsightFiltersResourcePartition[];
        /**
         * resource_region block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_region SecurityhubInsight#resource_region}
         *
         * @stability stable
         */
        readonly resourceRegion?: SecurityhubInsightFiltersResourceRegion[];
        /**
         * resource_tags block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_tags SecurityhubInsight#resource_tags}
         *
         * @stability stable
         */
        readonly resourceTags?: SecurityhubInsightFiltersResourceTags[];
        /**
         * resource_type block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#resource_type SecurityhubInsight#resource_type}
         *
         * @stability stable
         */
        readonly resourceType?: SecurityhubInsightFiltersResourceType[];
        /**
         * severity_label block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#severity_label SecurityhubInsight#severity_label}
         *
         * @stability stable
         */
        readonly severityLabel?: SecurityhubInsightFiltersSeverityLabel[];
        /**
         * source_url block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#source_url SecurityhubInsight#source_url}
         *
         * @stability stable
         */
        readonly sourceUrl?: SecurityhubInsightFiltersSourceUrl[];
        /**
         * threat_intel_indicator_category block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#threat_intel_indicator_category SecurityhubInsight#threat_intel_indicator_category}
         *
         * @stability stable
         */
        readonly threatIntelIndicatorCategory?: SecurityhubInsightFiltersThreatIntelIndicatorCategory[];
        /**
         * threat_intel_indicator_last_observed_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#threat_intel_indicator_last_observed_at SecurityhubInsight#threat_intel_indicator_last_observed_at}
         *
         * @stability stable
         */
        readonly threatIntelIndicatorLastObservedAt?: SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAt[];
        /**
         * threat_intel_indicator_source block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#threat_intel_indicator_source SecurityhubInsight#threat_intel_indicator_source}
         *
         * @stability stable
         */
        readonly threatIntelIndicatorSource?: SecurityhubInsightFiltersThreatIntelIndicatorSource[];
        /**
         * threat_intel_indicator_source_url block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#threat_intel_indicator_source_url SecurityhubInsight#threat_intel_indicator_source_url}
         *
         * @stability stable
         */
        readonly threatIntelIndicatorSourceUrl?: SecurityhubInsightFiltersThreatIntelIndicatorSourceUrl[];
        /**
         * threat_intel_indicator_type block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#threat_intel_indicator_type SecurityhubInsight#threat_intel_indicator_type}
         *
         * @stability stable
         */
        readonly threatIntelIndicatorType?: SecurityhubInsightFiltersThreatIntelIndicatorType[];
        /**
         * threat_intel_indicator_value block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#threat_intel_indicator_value SecurityhubInsight#threat_intel_indicator_value}
         *
         * @stability stable
         */
        readonly threatIntelIndicatorValue?: SecurityhubInsightFiltersThreatIntelIndicatorValue[];
        /**
         * title block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#title SecurityhubInsight#title}
         *
         * @stability stable
         */
        readonly title?: SecurityhubInsightFiltersTitle[];
        /**
         * type block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#type SecurityhubInsight#type}
         *
         * @stability stable
         */
        readonly type?: SecurityhubInsightFiltersType[];
        /**
         * updated_at block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#updated_at SecurityhubInsight#updated_at}
         *
         * @stability stable
         */
        readonly updatedAt?: SecurityhubInsightFiltersUpdatedAt[];
        /**
         * user_defined_values block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#user_defined_values SecurityhubInsight#user_defined_values}
         *
         * @stability stable
         */
        readonly userDefinedValues?: SecurityhubInsightFiltersUserDefinedValues[];
        /**
         * verification_state block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#verification_state SecurityhubInsight#verification_state}
         *
         * @stability stable
         */
        readonly verificationState?: SecurityhubInsightFiltersVerificationState[];
        /**
         * workflow_status block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html#workflow_status SecurityhubInsight#workflow_status}
         *
         * @stability stable
         */
        readonly workflowStatus?: SecurityhubInsightFiltersWorkflowStatus[];
    }
    /**
     * @stability stable
     */
    class SecurityhubInsightFiltersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _awsAccountId?;
        /**
         * @stability stable
         */
        get awsAccountId(): SecurityhubInsightFiltersAwsAccountId[] | undefined;
        /**
         * @stability stable
         */
        set awsAccountId(value: SecurityhubInsightFiltersAwsAccountId[] | undefined);
        /**
         * @stability stable
         */
        resetAwsAccountId(): void;
        /**
         * @stability stable
         */
        get awsAccountIdInput(): SecurityhubInsightFiltersAwsAccountId[] | undefined;
        private _companyName?;
        /**
         * @stability stable
         */
        get companyName(): SecurityhubInsightFiltersCompanyName[] | undefined;
        /**
         * @stability stable
         */
        set companyName(value: SecurityhubInsightFiltersCompanyName[] | undefined);
        /**
         * @stability stable
         */
        resetCompanyName(): void;
        /**
         * @stability stable
         */
        get companyNameInput(): SecurityhubInsightFiltersCompanyName[] | undefined;
        private _complianceStatus?;
        /**
         * @stability stable
         */
        get complianceStatus(): SecurityhubInsightFiltersComplianceStatus[] | undefined;
        /**
         * @stability stable
         */
        set complianceStatus(value: SecurityhubInsightFiltersComplianceStatus[] | undefined);
        /**
         * @stability stable
         */
        resetComplianceStatus(): void;
        /**
         * @stability stable
         */
        get complianceStatusInput(): SecurityhubInsightFiltersComplianceStatus[] | undefined;
        private _confidence?;
        /**
         * @stability stable
         */
        get confidence(): SecurityhubInsightFiltersConfidence[] | undefined;
        /**
         * @stability stable
         */
        set confidence(value: SecurityhubInsightFiltersConfidence[] | undefined);
        /**
         * @stability stable
         */
        resetConfidence(): void;
        /**
         * @stability stable
         */
        get confidenceInput(): SecurityhubInsightFiltersConfidence[] | undefined;
        private _createdAt?;
        /**
         * @stability stable
         */
        get createdAt(): SecurityhubInsightFiltersCreatedAt[] | undefined;
        /**
         * @stability stable
         */
        set createdAt(value: SecurityhubInsightFiltersCreatedAt[] | undefined);
        /**
         * @stability stable
         */
        resetCreatedAt(): void;
        /**
         * @stability stable
         */
        get createdAtInput(): SecurityhubInsightFiltersCreatedAt[] | undefined;
        private _criticality?;
        /**
         * @stability stable
         */
        get criticality(): SecurityhubInsightFiltersCriticality[] | undefined;
        /**
         * @stability stable
         */
        set criticality(value: SecurityhubInsightFiltersCriticality[] | undefined);
        /**
         * @stability stable
         */
        resetCriticality(): void;
        /**
         * @stability stable
         */
        get criticalityInput(): SecurityhubInsightFiltersCriticality[] | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): SecurityhubInsightFiltersDescription[] | undefined;
        /**
         * @stability stable
         */
        set description(value: SecurityhubInsightFiltersDescription[] | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): SecurityhubInsightFiltersDescription[] | undefined;
        private _findingProviderFieldsConfidence?;
        /**
         * @stability stable
         */
        get findingProviderFieldsConfidence(): SecurityhubInsightFiltersFindingProviderFieldsConfidence[] | undefined;
        /**
         * @stability stable
         */
        set findingProviderFieldsConfidence(value: SecurityhubInsightFiltersFindingProviderFieldsConfidence[] | undefined);
        /**
         * @stability stable
         */
        resetFindingProviderFieldsConfidence(): void;
        /**
         * @stability stable
         */
        get findingProviderFieldsConfidenceInput(): SecurityhubInsightFiltersFindingProviderFieldsConfidence[] | undefined;
        private _findingProviderFieldsCriticality?;
        /**
         * @stability stable
         */
        get findingProviderFieldsCriticality(): SecurityhubInsightFiltersFindingProviderFieldsCriticality[] | undefined;
        /**
         * @stability stable
         */
        set findingProviderFieldsCriticality(value: SecurityhubInsightFiltersFindingProviderFieldsCriticality[] | undefined);
        /**
         * @stability stable
         */
        resetFindingProviderFieldsCriticality(): void;
        /**
         * @stability stable
         */
        get findingProviderFieldsCriticalityInput(): SecurityhubInsightFiltersFindingProviderFieldsCriticality[] | undefined;
        private _findingProviderFieldsRelatedFindingsId?;
        /**
         * @stability stable
         */
        get findingProviderFieldsRelatedFindingsId(): SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsId[] | undefined;
        /**
         * @stability stable
         */
        set findingProviderFieldsRelatedFindingsId(value: SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsId[] | undefined);
        /**
         * @stability stable
         */
        resetFindingProviderFieldsRelatedFindingsId(): void;
        /**
         * @stability stable
         */
        get findingProviderFieldsRelatedFindingsIdInput(): SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsId[] | undefined;
        private _findingProviderFieldsRelatedFindingsProductArn?;
        /**
         * @stability stable
         */
        get findingProviderFieldsRelatedFindingsProductArn(): SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsProductArn[] | undefined;
        /**
         * @stability stable
         */
        set findingProviderFieldsRelatedFindingsProductArn(value: SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsProductArn[] | undefined);
        /**
         * @stability stable
         */
        resetFindingProviderFieldsRelatedFindingsProductArn(): void;
        /**
         * @stability stable
         */
        get findingProviderFieldsRelatedFindingsProductArnInput(): SecurityhubInsightFiltersFindingProviderFieldsRelatedFindingsProductArn[] | undefined;
        private _findingProviderFieldsSeverityLabel?;
        /**
         * @stability stable
         */
        get findingProviderFieldsSeverityLabel(): SecurityhubInsightFiltersFindingProviderFieldsSeverityLabel[] | undefined;
        /**
         * @stability stable
         */
        set findingProviderFieldsSeverityLabel(value: SecurityhubInsightFiltersFindingProviderFieldsSeverityLabel[] | undefined);
        /**
         * @stability stable
         */
        resetFindingProviderFieldsSeverityLabel(): void;
        /**
         * @stability stable
         */
        get findingProviderFieldsSeverityLabelInput(): SecurityhubInsightFiltersFindingProviderFieldsSeverityLabel[] | undefined;
        private _findingProviderFieldsSeverityOriginal?;
        /**
         * @stability stable
         */
        get findingProviderFieldsSeverityOriginal(): SecurityhubInsightFiltersFindingProviderFieldsSeverityOriginal[] | undefined;
        /**
         * @stability stable
         */
        set findingProviderFieldsSeverityOriginal(value: SecurityhubInsightFiltersFindingProviderFieldsSeverityOriginal[] | undefined);
        /**
         * @stability stable
         */
        resetFindingProviderFieldsSeverityOriginal(): void;
        /**
         * @stability stable
         */
        get findingProviderFieldsSeverityOriginalInput(): SecurityhubInsightFiltersFindingProviderFieldsSeverityOriginal[] | undefined;
        private _findingProviderFieldsTypes?;
        /**
         * @stability stable
         */
        get findingProviderFieldsTypes(): SecurityhubInsightFiltersFindingProviderFieldsTypes[] | undefined;
        /**
         * @stability stable
         */
        set findingProviderFieldsTypes(value: SecurityhubInsightFiltersFindingProviderFieldsTypes[] | undefined);
        /**
         * @stability stable
         */
        resetFindingProviderFieldsTypes(): void;
        /**
         * @stability stable
         */
        get findingProviderFieldsTypesInput(): SecurityhubInsightFiltersFindingProviderFieldsTypes[] | undefined;
        private _firstObservedAt?;
        /**
         * @stability stable
         */
        get firstObservedAt(): SecurityhubInsightFiltersFirstObservedAt[] | undefined;
        /**
         * @stability stable
         */
        set firstObservedAt(value: SecurityhubInsightFiltersFirstObservedAt[] | undefined);
        /**
         * @stability stable
         */
        resetFirstObservedAt(): void;
        /**
         * @stability stable
         */
        get firstObservedAtInput(): SecurityhubInsightFiltersFirstObservedAt[] | undefined;
        private _generatorId?;
        /**
         * @stability stable
         */
        get generatorId(): SecurityhubInsightFiltersGeneratorId[] | undefined;
        /**
         * @stability stable
         */
        set generatorId(value: SecurityhubInsightFiltersGeneratorId[] | undefined);
        /**
         * @stability stable
         */
        resetGeneratorId(): void;
        /**
         * @stability stable
         */
        get generatorIdInput(): SecurityhubInsightFiltersGeneratorId[] | undefined;
        private _id?;
        /**
         * @stability stable
         */
        get id(): SecurityhubInsightFiltersId[] | undefined;
        /**
         * @stability stable
         */
        set id(value: SecurityhubInsightFiltersId[] | undefined);
        /**
         * @stability stable
         */
        resetId(): void;
        /**
         * @stability stable
         */
        get idInput(): SecurityhubInsightFiltersId[] | undefined;
        private _keyword?;
        /**
         * @stability stable
         */
        get keyword(): SecurityhubInsightFiltersKeyword[] | undefined;
        /**
         * @stability stable
         */
        set keyword(value: SecurityhubInsightFiltersKeyword[] | undefined);
        /**
         * @stability stable
         */
        resetKeyword(): void;
        /**
         * @stability stable
         */
        get keywordInput(): SecurityhubInsightFiltersKeyword[] | undefined;
        private _lastObservedAt?;
        /**
         * @stability stable
         */
        get lastObservedAt(): SecurityhubInsightFiltersLastObservedAt[] | undefined;
        /**
         * @stability stable
         */
        set lastObservedAt(value: SecurityhubInsightFiltersLastObservedAt[] | undefined);
        /**
         * @stability stable
         */
        resetLastObservedAt(): void;
        /**
         * @stability stable
         */
        get lastObservedAtInput(): SecurityhubInsightFiltersLastObservedAt[] | undefined;
        private _malwareName?;
        /**
         * @stability stable
         */
        get malwareName(): SecurityhubInsightFiltersMalwareName[] | undefined;
        /**
         * @stability stable
         */
        set malwareName(value: SecurityhubInsightFiltersMalwareName[] | undefined);
        /**
         * @stability stable
         */
        resetMalwareName(): void;
        /**
         * @stability stable
         */
        get malwareNameInput(): SecurityhubInsightFiltersMalwareName[] | undefined;
        private _malwarePath?;
        /**
         * @stability stable
         */
        get malwarePath(): SecurityhubInsightFiltersMalwarePath[] | undefined;
        /**
         * @stability stable
         */
        set malwarePath(value: SecurityhubInsightFiltersMalwarePath[] | undefined);
        /**
         * @stability stable
         */
        resetMalwarePath(): void;
        /**
         * @stability stable
         */
        get malwarePathInput(): SecurityhubInsightFiltersMalwarePath[] | undefined;
        private _malwareState?;
        /**
         * @stability stable
         */
        get malwareState(): SecurityhubInsightFiltersMalwareState[] | undefined;
        /**
         * @stability stable
         */
        set malwareState(value: SecurityhubInsightFiltersMalwareState[] | undefined);
        /**
         * @stability stable
         */
        resetMalwareState(): void;
        /**
         * @stability stable
         */
        get malwareStateInput(): SecurityhubInsightFiltersMalwareState[] | undefined;
        private _malwareType?;
        /**
         * @stability stable
         */
        get malwareType(): SecurityhubInsightFiltersMalwareType[] | undefined;
        /**
         * @stability stable
         */
        set malwareType(value: SecurityhubInsightFiltersMalwareType[] | undefined);
        /**
         * @stability stable
         */
        resetMalwareType(): void;
        /**
         * @stability stable
         */
        get malwareTypeInput(): SecurityhubInsightFiltersMalwareType[] | undefined;
        private _networkDestinationDomain?;
        /**
         * @stability stable
         */
        get networkDestinationDomain(): SecurityhubInsightFiltersNetworkDestinationDomain[] | undefined;
        /**
         * @stability stable
         */
        set networkDestinationDomain(value: SecurityhubInsightFiltersNetworkDestinationDomain[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkDestinationDomain(): void;
        /**
         * @stability stable
         */
        get networkDestinationDomainInput(): SecurityhubInsightFiltersNetworkDestinationDomain[] | undefined;
        private _networkDestinationIpv4?;
        /**
         * @stability stable
         */
        get networkDestinationIpv4(): SecurityhubInsightFiltersNetworkDestinationIpv4[] | undefined;
        /**
         * @stability stable
         */
        set networkDestinationIpv4(value: SecurityhubInsightFiltersNetworkDestinationIpv4[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkDestinationIpv4(): void;
        /**
         * @stability stable
         */
        get networkDestinationIpv4Input(): SecurityhubInsightFiltersNetworkDestinationIpv4[] | undefined;
        private _networkDestinationIpv6?;
        /**
         * @stability stable
         */
        get networkDestinationIpv6(): SecurityhubInsightFiltersNetworkDestinationIpv6[] | undefined;
        /**
         * @stability stable
         */
        set networkDestinationIpv6(value: SecurityhubInsightFiltersNetworkDestinationIpv6[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkDestinationIpv6(): void;
        /**
         * @stability stable
         */
        get networkDestinationIpv6Input(): SecurityhubInsightFiltersNetworkDestinationIpv6[] | undefined;
        private _networkDestinationPort?;
        /**
         * @stability stable
         */
        get networkDestinationPort(): SecurityhubInsightFiltersNetworkDestinationPort[] | undefined;
        /**
         * @stability stable
         */
        set networkDestinationPort(value: SecurityhubInsightFiltersNetworkDestinationPort[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkDestinationPort(): void;
        /**
         * @stability stable
         */
        get networkDestinationPortInput(): SecurityhubInsightFiltersNetworkDestinationPort[] | undefined;
        private _networkDirection?;
        /**
         * @stability stable
         */
        get networkDirection(): SecurityhubInsightFiltersNetworkDirection[] | undefined;
        /**
         * @stability stable
         */
        set networkDirection(value: SecurityhubInsightFiltersNetworkDirection[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkDirection(): void;
        /**
         * @stability stable
         */
        get networkDirectionInput(): SecurityhubInsightFiltersNetworkDirection[] | undefined;
        private _networkProtocol?;
        /**
         * @stability stable
         */
        get networkProtocol(): SecurityhubInsightFiltersNetworkProtocol[] | undefined;
        /**
         * @stability stable
         */
        set networkProtocol(value: SecurityhubInsightFiltersNetworkProtocol[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkProtocol(): void;
        /**
         * @stability stable
         */
        get networkProtocolInput(): SecurityhubInsightFiltersNetworkProtocol[] | undefined;
        private _networkSourceDomain?;
        /**
         * @stability stable
         */
        get networkSourceDomain(): SecurityhubInsightFiltersNetworkSourceDomain[] | undefined;
        /**
         * @stability stable
         */
        set networkSourceDomain(value: SecurityhubInsightFiltersNetworkSourceDomain[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkSourceDomain(): void;
        /**
         * @stability stable
         */
        get networkSourceDomainInput(): SecurityhubInsightFiltersNetworkSourceDomain[] | undefined;
        private _networkSourceIpv4?;
        /**
         * @stability stable
         */
        get networkSourceIpv4(): SecurityhubInsightFiltersNetworkSourceIpv4[] | undefined;
        /**
         * @stability stable
         */
        set networkSourceIpv4(value: SecurityhubInsightFiltersNetworkSourceIpv4[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkSourceIpv4(): void;
        /**
         * @stability stable
         */
        get networkSourceIpv4Input(): SecurityhubInsightFiltersNetworkSourceIpv4[] | undefined;
        private _networkSourceIpv6?;
        /**
         * @stability stable
         */
        get networkSourceIpv6(): SecurityhubInsightFiltersNetworkSourceIpv6[] | undefined;
        /**
         * @stability stable
         */
        set networkSourceIpv6(value: SecurityhubInsightFiltersNetworkSourceIpv6[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkSourceIpv6(): void;
        /**
         * @stability stable
         */
        get networkSourceIpv6Input(): SecurityhubInsightFiltersNetworkSourceIpv6[] | undefined;
        private _networkSourceMac?;
        /**
         * @stability stable
         */
        get networkSourceMac(): SecurityhubInsightFiltersNetworkSourceMac[] | undefined;
        /**
         * @stability stable
         */
        set networkSourceMac(value: SecurityhubInsightFiltersNetworkSourceMac[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkSourceMac(): void;
        /**
         * @stability stable
         */
        get networkSourceMacInput(): SecurityhubInsightFiltersNetworkSourceMac[] | undefined;
        private _networkSourcePort?;
        /**
         * @stability stable
         */
        get networkSourcePort(): SecurityhubInsightFiltersNetworkSourcePort[] | undefined;
        /**
         * @stability stable
         */
        set networkSourcePort(value: SecurityhubInsightFiltersNetworkSourcePort[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkSourcePort(): void;
        /**
         * @stability stable
         */
        get networkSourcePortInput(): SecurityhubInsightFiltersNetworkSourcePort[] | undefined;
        private _noteText?;
        /**
         * @stability stable
         */
        get noteText(): SecurityhubInsightFiltersNoteText[] | undefined;
        /**
         * @stability stable
         */
        set noteText(value: SecurityhubInsightFiltersNoteText[] | undefined);
        /**
         * @stability stable
         */
        resetNoteText(): void;
        /**
         * @stability stable
         */
        get noteTextInput(): SecurityhubInsightFiltersNoteText[] | undefined;
        private _noteUpdatedAt?;
        /**
         * @stability stable
         */
        get noteUpdatedAt(): SecurityhubInsightFiltersNoteUpdatedAt[] | undefined;
        /**
         * @stability stable
         */
        set noteUpdatedAt(value: SecurityhubInsightFiltersNoteUpdatedAt[] | undefined);
        /**
         * @stability stable
         */
        resetNoteUpdatedAt(): void;
        /**
         * @stability stable
         */
        get noteUpdatedAtInput(): SecurityhubInsightFiltersNoteUpdatedAt[] | undefined;
        private _noteUpdatedBy?;
        /**
         * @stability stable
         */
        get noteUpdatedBy(): SecurityhubInsightFiltersNoteUpdatedBy[] | undefined;
        /**
         * @stability stable
         */
        set noteUpdatedBy(value: SecurityhubInsightFiltersNoteUpdatedBy[] | undefined);
        /**
         * @stability stable
         */
        resetNoteUpdatedBy(): void;
        /**
         * @stability stable
         */
        get noteUpdatedByInput(): SecurityhubInsightFiltersNoteUpdatedBy[] | undefined;
        private _processLaunchedAt?;
        /**
         * @stability stable
         */
        get processLaunchedAt(): SecurityhubInsightFiltersProcessLaunchedAt[] | undefined;
        /**
         * @stability stable
         */
        set processLaunchedAt(value: SecurityhubInsightFiltersProcessLaunchedAt[] | undefined);
        /**
         * @stability stable
         */
        resetProcessLaunchedAt(): void;
        /**
         * @stability stable
         */
        get processLaunchedAtInput(): SecurityhubInsightFiltersProcessLaunchedAt[] | undefined;
        private _processName?;
        /**
         * @stability stable
         */
        get processName(): SecurityhubInsightFiltersProcessName[] | undefined;
        /**
         * @stability stable
         */
        set processName(value: SecurityhubInsightFiltersProcessName[] | undefined);
        /**
         * @stability stable
         */
        resetProcessName(): void;
        /**
         * @stability stable
         */
        get processNameInput(): SecurityhubInsightFiltersProcessName[] | undefined;
        private _processParentPid?;
        /**
         * @stability stable
         */
        get processParentPid(): SecurityhubInsightFiltersProcessParentPid[] | undefined;
        /**
         * @stability stable
         */
        set processParentPid(value: SecurityhubInsightFiltersProcessParentPid[] | undefined);
        /**
         * @stability stable
         */
        resetProcessParentPid(): void;
        /**
         * @stability stable
         */
        get processParentPidInput(): SecurityhubInsightFiltersProcessParentPid[] | undefined;
        private _processPath?;
        /**
         * @stability stable
         */
        get processPath(): SecurityhubInsightFiltersProcessPath[] | undefined;
        /**
         * @stability stable
         */
        set processPath(value: SecurityhubInsightFiltersProcessPath[] | undefined);
        /**
         * @stability stable
         */
        resetProcessPath(): void;
        /**
         * @stability stable
         */
        get processPathInput(): SecurityhubInsightFiltersProcessPath[] | undefined;
        private _processPid?;
        /**
         * @stability stable
         */
        get processPid(): SecurityhubInsightFiltersProcessPid[] | undefined;
        /**
         * @stability stable
         */
        set processPid(value: SecurityhubInsightFiltersProcessPid[] | undefined);
        /**
         * @stability stable
         */
        resetProcessPid(): void;
        /**
         * @stability stable
         */
        get processPidInput(): SecurityhubInsightFiltersProcessPid[] | undefined;
        private _processTerminatedAt?;
        /**
         * @stability stable
         */
        get processTerminatedAt(): SecurityhubInsightFiltersProcessTerminatedAt[] | undefined;
        /**
         * @stability stable
         */
        set processTerminatedAt(value: SecurityhubInsightFiltersProcessTerminatedAt[] | undefined);
        /**
         * @stability stable
         */
        resetProcessTerminatedAt(): void;
        /**
         * @stability stable
         */
        get processTerminatedAtInput(): SecurityhubInsightFiltersProcessTerminatedAt[] | undefined;
        private _productArn?;
        /**
         * @stability stable
         */
        get productArn(): SecurityhubInsightFiltersProductArn[] | undefined;
        /**
         * @stability stable
         */
        set productArn(value: SecurityhubInsightFiltersProductArn[] | undefined);
        /**
         * @stability stable
         */
        resetProductArn(): void;
        /**
         * @stability stable
         */
        get productArnInput(): SecurityhubInsightFiltersProductArn[] | undefined;
        private _productFields?;
        /**
         * @stability stable
         */
        get productFields(): SecurityhubInsightFiltersProductFields[] | undefined;
        /**
         * @stability stable
         */
        set productFields(value: SecurityhubInsightFiltersProductFields[] | undefined);
        /**
         * @stability stable
         */
        resetProductFields(): void;
        /**
         * @stability stable
         */
        get productFieldsInput(): SecurityhubInsightFiltersProductFields[] | undefined;
        private _productName?;
        /**
         * @stability stable
         */
        get productName(): SecurityhubInsightFiltersProductName[] | undefined;
        /**
         * @stability stable
         */
        set productName(value: SecurityhubInsightFiltersProductName[] | undefined);
        /**
         * @stability stable
         */
        resetProductName(): void;
        /**
         * @stability stable
         */
        get productNameInput(): SecurityhubInsightFiltersProductName[] | undefined;
        private _recommendationText?;
        /**
         * @stability stable
         */
        get recommendationText(): SecurityhubInsightFiltersRecommendationText[] | undefined;
        /**
         * @stability stable
         */
        set recommendationText(value: SecurityhubInsightFiltersRecommendationText[] | undefined);
        /**
         * @stability stable
         */
        resetRecommendationText(): void;
        /**
         * @stability stable
         */
        get recommendationTextInput(): SecurityhubInsightFiltersRecommendationText[] | undefined;
        private _recordState?;
        /**
         * @stability stable
         */
        get recordState(): SecurityhubInsightFiltersRecordState[] | undefined;
        /**
         * @stability stable
         */
        set recordState(value: SecurityhubInsightFiltersRecordState[] | undefined);
        /**
         * @stability stable
         */
        resetRecordState(): void;
        /**
         * @stability stable
         */
        get recordStateInput(): SecurityhubInsightFiltersRecordState[] | undefined;
        private _relatedFindingsId?;
        /**
         * @stability stable
         */
        get relatedFindingsId(): SecurityhubInsightFiltersRelatedFindingsId[] | undefined;
        /**
         * @stability stable
         */
        set relatedFindingsId(value: SecurityhubInsightFiltersRelatedFindingsId[] | undefined);
        /**
         * @stability stable
         */
        resetRelatedFindingsId(): void;
        /**
         * @stability stable
         */
        get relatedFindingsIdInput(): SecurityhubInsightFiltersRelatedFindingsId[] | undefined;
        private _relatedFindingsProductArn?;
        /**
         * @stability stable
         */
        get relatedFindingsProductArn(): SecurityhubInsightFiltersRelatedFindingsProductArn[] | undefined;
        /**
         * @stability stable
         */
        set relatedFindingsProductArn(value: SecurityhubInsightFiltersRelatedFindingsProductArn[] | undefined);
        /**
         * @stability stable
         */
        resetRelatedFindingsProductArn(): void;
        /**
         * @stability stable
         */
        get relatedFindingsProductArnInput(): SecurityhubInsightFiltersRelatedFindingsProductArn[] | undefined;
        private _resourceAwsEc2InstanceIamInstanceProfileArn?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceIamInstanceProfileArn(): SecurityhubInsightFiltersResourceAwsEc2InstanceIamInstanceProfileArn[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceIamInstanceProfileArn(value: SecurityhubInsightFiltersResourceAwsEc2InstanceIamInstanceProfileArn[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceIamInstanceProfileArn(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceIamInstanceProfileArnInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceIamInstanceProfileArn[] | undefined;
        private _resourceAwsEc2InstanceImageId?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceImageId(): SecurityhubInsightFiltersResourceAwsEc2InstanceImageId[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceImageId(value: SecurityhubInsightFiltersResourceAwsEc2InstanceImageId[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceImageId(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceImageIdInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceImageId[] | undefined;
        private _resourceAwsEc2InstanceIpv4Addresses?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceIpv4Addresses(): SecurityhubInsightFiltersResourceAwsEc2InstanceIpv4Addresses[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceIpv4Addresses(value: SecurityhubInsightFiltersResourceAwsEc2InstanceIpv4Addresses[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceIpv4Addresses(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceIpv4AddressesInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceIpv4Addresses[] | undefined;
        private _resourceAwsEc2InstanceIpv6Addresses?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceIpv6Addresses(): SecurityhubInsightFiltersResourceAwsEc2InstanceIpv6Addresses[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceIpv6Addresses(value: SecurityhubInsightFiltersResourceAwsEc2InstanceIpv6Addresses[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceIpv6Addresses(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceIpv6AddressesInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceIpv6Addresses[] | undefined;
        private _resourceAwsEc2InstanceKeyName?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceKeyName(): SecurityhubInsightFiltersResourceAwsEc2InstanceKeyName[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceKeyName(value: SecurityhubInsightFiltersResourceAwsEc2InstanceKeyName[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceKeyName(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceKeyNameInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceKeyName[] | undefined;
        private _resourceAwsEc2InstanceLaunchedAt?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceLaunchedAt(): SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAt[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceLaunchedAt(value: SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAt[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceLaunchedAt(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceLaunchedAtInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceLaunchedAt[] | undefined;
        private _resourceAwsEc2InstanceSubnetId?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceSubnetId(): SecurityhubInsightFiltersResourceAwsEc2InstanceSubnetId[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceSubnetId(value: SecurityhubInsightFiltersResourceAwsEc2InstanceSubnetId[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceSubnetId(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceSubnetIdInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceSubnetId[] | undefined;
        private _resourceAwsEc2InstanceType?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceType(): SecurityhubInsightFiltersResourceAwsEc2InstanceType[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceType(value: SecurityhubInsightFiltersResourceAwsEc2InstanceType[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceType(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceTypeInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceType[] | undefined;
        private _resourceAwsEc2InstanceVpcId?;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceVpcId(): SecurityhubInsightFiltersResourceAwsEc2InstanceVpcId[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsEc2InstanceVpcId(value: SecurityhubInsightFiltersResourceAwsEc2InstanceVpcId[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsEc2InstanceVpcId(): void;
        /**
         * @stability stable
         */
        get resourceAwsEc2InstanceVpcIdInput(): SecurityhubInsightFiltersResourceAwsEc2InstanceVpcId[] | undefined;
        private _resourceAwsIamAccessKeyCreatedAt?;
        /**
         * @stability stable
         */
        get resourceAwsIamAccessKeyCreatedAt(): SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAt[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsIamAccessKeyCreatedAt(value: SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAt[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsIamAccessKeyCreatedAt(): void;
        /**
         * @stability stable
         */
        get resourceAwsIamAccessKeyCreatedAtInput(): SecurityhubInsightFiltersResourceAwsIamAccessKeyCreatedAt[] | undefined;
        private _resourceAwsIamAccessKeyStatus?;
        /**
         * @stability stable
         */
        get resourceAwsIamAccessKeyStatus(): SecurityhubInsightFiltersResourceAwsIamAccessKeyStatus[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsIamAccessKeyStatus(value: SecurityhubInsightFiltersResourceAwsIamAccessKeyStatus[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsIamAccessKeyStatus(): void;
        /**
         * @stability stable
         */
        get resourceAwsIamAccessKeyStatusInput(): SecurityhubInsightFiltersResourceAwsIamAccessKeyStatus[] | undefined;
        private _resourceAwsIamAccessKeyUserName?;
        /**
         * @stability stable
         */
        get resourceAwsIamAccessKeyUserName(): SecurityhubInsightFiltersResourceAwsIamAccessKeyUserName[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsIamAccessKeyUserName(value: SecurityhubInsightFiltersResourceAwsIamAccessKeyUserName[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsIamAccessKeyUserName(): void;
        /**
         * @stability stable
         */
        get resourceAwsIamAccessKeyUserNameInput(): SecurityhubInsightFiltersResourceAwsIamAccessKeyUserName[] | undefined;
        private _resourceAwsS3BucketOwnerId?;
        /**
         * @stability stable
         */
        get resourceAwsS3BucketOwnerId(): SecurityhubInsightFiltersResourceAwsS3BucketOwnerId[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsS3BucketOwnerId(value: SecurityhubInsightFiltersResourceAwsS3BucketOwnerId[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsS3BucketOwnerId(): void;
        /**
         * @stability stable
         */
        get resourceAwsS3BucketOwnerIdInput(): SecurityhubInsightFiltersResourceAwsS3BucketOwnerId[] | undefined;
        private _resourceAwsS3BucketOwnerName?;
        /**
         * @stability stable
         */
        get resourceAwsS3BucketOwnerName(): SecurityhubInsightFiltersResourceAwsS3BucketOwnerName[] | undefined;
        /**
         * @stability stable
         */
        set resourceAwsS3BucketOwnerName(value: SecurityhubInsightFiltersResourceAwsS3BucketOwnerName[] | undefined);
        /**
         * @stability stable
         */
        resetResourceAwsS3BucketOwnerName(): void;
        /**
         * @stability stable
         */
        get resourceAwsS3BucketOwnerNameInput(): SecurityhubInsightFiltersResourceAwsS3BucketOwnerName[] | undefined;
        private _resourceContainerImageId?;
        /**
         * @stability stable
         */
        get resourceContainerImageId(): SecurityhubInsightFiltersResourceContainerImageId[] | undefined;
        /**
         * @stability stable
         */
        set resourceContainerImageId(value: SecurityhubInsightFiltersResourceContainerImageId[] | undefined);
        /**
         * @stability stable
         */
        resetResourceContainerImageId(): void;
        /**
         * @stability stable
         */
        get resourceContainerImageIdInput(): SecurityhubInsightFiltersResourceContainerImageId[] | undefined;
        private _resourceContainerImageName?;
        /**
         * @stability stable
         */
        get resourceContainerImageName(): SecurityhubInsightFiltersResourceContainerImageName[] | undefined;
        /**
         * @stability stable
         */
        set resourceContainerImageName(value: SecurityhubInsightFiltersResourceContainerImageName[] | undefined);
        /**
         * @stability stable
         */
        resetResourceContainerImageName(): void;
        /**
         * @stability stable
         */
        get resourceContainerImageNameInput(): SecurityhubInsightFiltersResourceContainerImageName[] | undefined;
        private _resourceContainerLaunchedAt?;
        /**
         * @stability stable
         */
        get resourceContainerLaunchedAt(): SecurityhubInsightFiltersResourceContainerLaunchedAt[] | undefined;
        /**
         * @stability stable
         */
        set resourceContainerLaunchedAt(value: SecurityhubInsightFiltersResourceContainerLaunchedAt[] | undefined);
        /**
         * @stability stable
         */
        resetResourceContainerLaunchedAt(): void;
        /**
         * @stability stable
         */
        get resourceContainerLaunchedAtInput(): SecurityhubInsightFiltersResourceContainerLaunchedAt[] | undefined;
        private _resourceContainerName?;
        /**
         * @stability stable
         */
        get resourceContainerName(): SecurityhubInsightFiltersResourceContainerName[] | undefined;
        /**
         * @stability stable
         */
        set resourceContainerName(value: SecurityhubInsightFiltersResourceContainerName[] | undefined);
        /**
         * @stability stable
         */
        resetResourceContainerName(): void;
        /**
         * @stability stable
         */
        get resourceContainerNameInput(): SecurityhubInsightFiltersResourceContainerName[] | undefined;
        private _resourceDetailsOther?;
        /**
         * @stability stable
         */
        get resourceDetailsOther(): SecurityhubInsightFiltersResourceDetailsOther[] | undefined;
        /**
         * @stability stable
         */
        set resourceDetailsOther(value: SecurityhubInsightFiltersResourceDetailsOther[] | undefined);
        /**
         * @stability stable
         */
        resetResourceDetailsOther(): void;
        /**
         * @stability stable
         */
        get resourceDetailsOtherInput(): SecurityhubInsightFiltersResourceDetailsOther[] | undefined;
        private _resourceId?;
        /**
         * @stability stable
         */
        get resourceId(): SecurityhubInsightFiltersResourceId[] | undefined;
        /**
         * @stability stable
         */
        set resourceId(value: SecurityhubInsightFiltersResourceId[] | undefined);
        /**
         * @stability stable
         */
        resetResourceId(): void;
        /**
         * @stability stable
         */
        get resourceIdInput(): SecurityhubInsightFiltersResourceId[] | undefined;
        private _resourcePartition?;
        /**
         * @stability stable
         */
        get resourcePartition(): SecurityhubInsightFiltersResourcePartition[] | undefined;
        /**
         * @stability stable
         */
        set resourcePartition(value: SecurityhubInsightFiltersResourcePartition[] | undefined);
        /**
         * @stability stable
         */
        resetResourcePartition(): void;
        /**
         * @stability stable
         */
        get resourcePartitionInput(): SecurityhubInsightFiltersResourcePartition[] | undefined;
        private _resourceRegion?;
        /**
         * @stability stable
         */
        get resourceRegion(): SecurityhubInsightFiltersResourceRegion[] | undefined;
        /**
         * @stability stable
         */
        set resourceRegion(value: SecurityhubInsightFiltersResourceRegion[] | undefined);
        /**
         * @stability stable
         */
        resetResourceRegion(): void;
        /**
         * @stability stable
         */
        get resourceRegionInput(): SecurityhubInsightFiltersResourceRegion[] | undefined;
        private _resourceTags?;
        /**
         * @stability stable
         */
        get resourceTags(): SecurityhubInsightFiltersResourceTags[] | undefined;
        /**
         * @stability stable
         */
        set resourceTags(value: SecurityhubInsightFiltersResourceTags[] | undefined);
        /**
         * @stability stable
         */
        resetResourceTags(): void;
        /**
         * @stability stable
         */
        get resourceTagsInput(): SecurityhubInsightFiltersResourceTags[] | undefined;
        private _resourceType?;
        /**
         * @stability stable
         */
        get resourceType(): SecurityhubInsightFiltersResourceType[] | undefined;
        /**
         * @stability stable
         */
        set resourceType(value: SecurityhubInsightFiltersResourceType[] | undefined);
        /**
         * @stability stable
         */
        resetResourceType(): void;
        /**
         * @stability stable
         */
        get resourceTypeInput(): SecurityhubInsightFiltersResourceType[] | undefined;
        private _severityLabel?;
        /**
         * @stability stable
         */
        get severityLabel(): SecurityhubInsightFiltersSeverityLabel[] | undefined;
        /**
         * @stability stable
         */
        set severityLabel(value: SecurityhubInsightFiltersSeverityLabel[] | undefined);
        /**
         * @stability stable
         */
        resetSeverityLabel(): void;
        /**
         * @stability stable
         */
        get severityLabelInput(): SecurityhubInsightFiltersSeverityLabel[] | undefined;
        private _sourceUrl?;
        /**
         * @stability stable
         */
        get sourceUrl(): SecurityhubInsightFiltersSourceUrl[] | undefined;
        /**
         * @stability stable
         */
        set sourceUrl(value: SecurityhubInsightFiltersSourceUrl[] | undefined);
        /**
         * @stability stable
         */
        resetSourceUrl(): void;
        /**
         * @stability stable
         */
        get sourceUrlInput(): SecurityhubInsightFiltersSourceUrl[] | undefined;
        private _threatIntelIndicatorCategory?;
        /**
         * @stability stable
         */
        get threatIntelIndicatorCategory(): SecurityhubInsightFiltersThreatIntelIndicatorCategory[] | undefined;
        /**
         * @stability stable
         */
        set threatIntelIndicatorCategory(value: SecurityhubInsightFiltersThreatIntelIndicatorCategory[] | undefined);
        /**
         * @stability stable
         */
        resetThreatIntelIndicatorCategory(): void;
        /**
         * @stability stable
         */
        get threatIntelIndicatorCategoryInput(): SecurityhubInsightFiltersThreatIntelIndicatorCategory[] | undefined;
        private _threatIntelIndicatorLastObservedAt?;
        /**
         * @stability stable
         */
        get threatIntelIndicatorLastObservedAt(): SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAt[] | undefined;
        /**
         * @stability stable
         */
        set threatIntelIndicatorLastObservedAt(value: SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAt[] | undefined);
        /**
         * @stability stable
         */
        resetThreatIntelIndicatorLastObservedAt(): void;
        /**
         * @stability stable
         */
        get threatIntelIndicatorLastObservedAtInput(): SecurityhubInsightFiltersThreatIntelIndicatorLastObservedAt[] | undefined;
        private _threatIntelIndicatorSource?;
        /**
         * @stability stable
         */
        get threatIntelIndicatorSource(): SecurityhubInsightFiltersThreatIntelIndicatorSource[] | undefined;
        /**
         * @stability stable
         */
        set threatIntelIndicatorSource(value: SecurityhubInsightFiltersThreatIntelIndicatorSource[] | undefined);
        /**
         * @stability stable
         */
        resetThreatIntelIndicatorSource(): void;
        /**
         * @stability stable
         */
        get threatIntelIndicatorSourceInput(): SecurityhubInsightFiltersThreatIntelIndicatorSource[] | undefined;
        private _threatIntelIndicatorSourceUrl?;
        /**
         * @stability stable
         */
        get threatIntelIndicatorSourceUrl(): SecurityhubInsightFiltersThreatIntelIndicatorSourceUrl[] | undefined;
        /**
         * @stability stable
         */
        set threatIntelIndicatorSourceUrl(value: SecurityhubInsightFiltersThreatIntelIndicatorSourceUrl[] | undefined);
        /**
         * @stability stable
         */
        resetThreatIntelIndicatorSourceUrl(): void;
        /**
         * @stability stable
         */
        get threatIntelIndicatorSourceUrlInput(): SecurityhubInsightFiltersThreatIntelIndicatorSourceUrl[] | undefined;
        private _threatIntelIndicatorType?;
        /**
         * @stability stable
         */
        get threatIntelIndicatorType(): SecurityhubInsightFiltersThreatIntelIndicatorType[] | undefined;
        /**
         * @stability stable
         */
        set threatIntelIndicatorType(value: SecurityhubInsightFiltersThreatIntelIndicatorType[] | undefined);
        /**
         * @stability stable
         */
        resetThreatIntelIndicatorType(): void;
        /**
         * @stability stable
         */
        get threatIntelIndicatorTypeInput(): SecurityhubInsightFiltersThreatIntelIndicatorType[] | undefined;
        private _threatIntelIndicatorValue?;
        /**
         * @stability stable
         */
        get threatIntelIndicatorValue(): SecurityhubInsightFiltersThreatIntelIndicatorValue[] | undefined;
        /**
         * @stability stable
         */
        set threatIntelIndicatorValue(value: SecurityhubInsightFiltersThreatIntelIndicatorValue[] | undefined);
        /**
         * @stability stable
         */
        resetThreatIntelIndicatorValue(): void;
        /**
         * @stability stable
         */
        get threatIntelIndicatorValueInput(): SecurityhubInsightFiltersThreatIntelIndicatorValue[] | undefined;
        private _title?;
        /**
         * @stability stable
         */
        get title(): SecurityhubInsightFiltersTitle[] | undefined;
        /**
         * @stability stable
         */
        set title(value: SecurityhubInsightFiltersTitle[] | undefined);
        /**
         * @stability stable
         */
        resetTitle(): void;
        /**
         * @stability stable
         */
        get titleInput(): SecurityhubInsightFiltersTitle[] | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): SecurityhubInsightFiltersType[] | undefined;
        /**
         * @stability stable
         */
        set type(value: SecurityhubInsightFiltersType[] | undefined);
        /**
         * @stability stable
         */
        resetType(): void;
        /**
         * @stability stable
         */
        get typeInput(): SecurityhubInsightFiltersType[] | undefined;
        private _updatedAt?;
        /**
         * @stability stable
         */
        get updatedAt(): SecurityhubInsightFiltersUpdatedAt[] | undefined;
        /**
         * @stability stable
         */
        set updatedAt(value: SecurityhubInsightFiltersUpdatedAt[] | undefined);
        /**
         * @stability stable
         */
        resetUpdatedAt(): void;
        /**
         * @stability stable
         */
        get updatedAtInput(): SecurityhubInsightFiltersUpdatedAt[] | undefined;
        private _userDefinedValues?;
        /**
         * @stability stable
         */
        get userDefinedValues(): SecurityhubInsightFiltersUserDefinedValues[] | undefined;
        /**
         * @stability stable
         */
        set userDefinedValues(value: SecurityhubInsightFiltersUserDefinedValues[] | undefined);
        /**
         * @stability stable
         */
        resetUserDefinedValues(): void;
        /**
         * @stability stable
         */
        get userDefinedValuesInput(): SecurityhubInsightFiltersUserDefinedValues[] | undefined;
        private _verificationState?;
        /**
         * @stability stable
         */
        get verificationState(): SecurityhubInsightFiltersVerificationState[] | undefined;
        /**
         * @stability stable
         */
        set verificationState(value: SecurityhubInsightFiltersVerificationState[] | undefined);
        /**
         * @stability stable
         */
        resetVerificationState(): void;
        /**
         * @stability stable
         */
        get verificationStateInput(): SecurityhubInsightFiltersVerificationState[] | undefined;
        private _workflowStatus?;
        /**
         * @stability stable
         */
        get workflowStatus(): SecurityhubInsightFiltersWorkflowStatus[] | undefined;
        /**
         * @stability stable
         */
        set workflowStatus(value: SecurityhubInsightFiltersWorkflowStatus[] | undefined);
        /**
         * @stability stable
         */
        resetWorkflowStatus(): void;
        /**
         * @stability stable
         */
        get workflowStatusInput(): SecurityhubInsightFiltersWorkflowStatus[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html aws_securityhub_insight}.
     *
     * @stability stable
     */
    class SecurityhubInsight extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_insight.html aws_securityhub_insight} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubInsightConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _groupByAttribute?;
        /**
         * @stability stable
         */
        get groupByAttribute(): string;
        /**
         * @stability stable
         */
        set groupByAttribute(value: string);
        /**
         * @stability stable
         */
        get groupByAttributeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _filters?;
        private __filtersOutput;
        /**
         * @stability stable
         */
        get filters(): SecurityhubInsightFiltersOutputReference;
        /**
         * @stability stable
         */
        putFilters(value: SecurityhubInsightFilters): void;
        /**
         * @stability stable
         */
        get filtersInput(): SecurityhubInsightFilters | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubInviteAccepterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_invite_accepter.html#master_id SecurityhubInviteAccepter#master_id}.
         *
         * @stability stable
         */
        readonly masterId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_invite_accepter.html aws_securityhub_invite_accepter}.
     *
     * @stability stable
     */
    class SecurityhubInviteAccepter extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_invite_accepter.html aws_securityhub_invite_accepter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubInviteAccepterConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get invitationId(): string;
        private _masterId?;
        /**
         * @stability stable
         */
        get masterId(): string;
        /**
         * @stability stable
         */
        set masterId(value: string);
        /**
         * @stability stable
         */
        get masterIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubMemberConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_member.html#account_id SecurityhubMember#account_id}.
         *
         * @stability stable
         */
        readonly accountId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_member.html#email SecurityhubMember#email}.
         *
         * @stability stable
         */
        readonly email: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_member.html#invite SecurityhubMember#invite}.
         *
         * @stability stable
         */
        readonly invite?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_member.html aws_securityhub_member}.
     *
     * @stability stable
     */
    class SecurityhubMember extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_member.html aws_securityhub_member} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubMemberConfig);
        private _accountId?;
        /**
         * @stability stable
         */
        get accountId(): string;
        /**
         * @stability stable
         */
        set accountId(value: string);
        /**
         * @stability stable
         */
        get accountIdInput(): string | undefined;
        private _email?;
        /**
         * @stability stable
         */
        get email(): string;
        /**
         * @stability stable
         */
        set email(value: string);
        /**
         * @stability stable
         */
        get emailInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _invite?;
        /**
         * @stability stable
         */
        get invite(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set invite(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInvite(): void;
        /**
         * @stability stable
         */
        get inviteInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get masterId(): string;
        /**
         * @stability stable
         */
        get memberStatus(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubOrganizationAdminAccountConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_organization_admin_account.html#admin_account_id SecurityhubOrganizationAdminAccount#admin_account_id}.
         *
         * @stability stable
         */
        readonly adminAccountId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_organization_admin_account.html aws_securityhub_organization_admin_account}.
     *
     * @stability stable
     */
    class SecurityhubOrganizationAdminAccount extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_organization_admin_account.html aws_securityhub_organization_admin_account} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubOrganizationAdminAccountConfig);
        private _adminAccountId?;
        /**
         * @stability stable
         */
        get adminAccountId(): string;
        /**
         * @stability stable
         */
        set adminAccountId(value: string);
        /**
         * @stability stable
         */
        get adminAccountIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubOrganizationConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_organization_configuration.html#auto_enable SecurityhubOrganizationConfiguration#auto_enable}.
         *
         * @stability stable
         */
        readonly autoEnable: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_organization_configuration.html aws_securityhub_organization_configuration}.
     *
     * @stability stable
     */
    class SecurityhubOrganizationConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_organization_configuration.html aws_securityhub_organization_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubOrganizationConfigurationConfig);
        private _autoEnable?;
        /**
         * @stability stable
         */
        get autoEnable(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set autoEnable(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get autoEnableInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubProductSubscriptionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_product_subscription.html#product_arn SecurityhubProductSubscription#product_arn}.
         *
         * @stability stable
         */
        readonly productArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_product_subscription.html aws_securityhub_product_subscription}.
     *
     * @stability stable
     */
    class SecurityhubProductSubscription extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_product_subscription.html aws_securityhub_product_subscription} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubProductSubscriptionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _productArn?;
        /**
         * @stability stable
         */
        get productArn(): string;
        /**
         * @stability stable
         */
        set productArn(value: string);
        /**
         * @stability stable
         */
        get productArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubStandardsControlConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_control.html#control_status SecurityhubStandardsControl#control_status}.
         *
         * @stability stable
         */
        readonly controlStatus: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_control.html#disabled_reason SecurityhubStandardsControl#disabled_reason}.
         *
         * @stability stable
         */
        readonly disabledReason?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_control.html#standards_control_arn SecurityhubStandardsControl#standards_control_arn}.
         *
         * @stability stable
         */
        readonly standardsControlArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_control.html aws_securityhub_standards_control}.
     *
     * @stability stable
     */
    class SecurityhubStandardsControl extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_control.html aws_securityhub_standards_control} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubStandardsControlConfig);
        /**
         * @stability stable
         */
        get controlId(): string;
        private _controlStatus?;
        /**
         * @stability stable
         */
        get controlStatus(): string;
        /**
         * @stability stable
         */
        set controlStatus(value: string);
        /**
         * @stability stable
         */
        get controlStatusInput(): string | undefined;
        /**
         * @stability stable
         */
        get controlStatusUpdatedAt(): string;
        /**
         * @stability stable
         */
        get description(): string;
        private _disabledReason?;
        /**
         * @stability stable
         */
        get disabledReason(): string | undefined;
        /**
         * @stability stable
         */
        set disabledReason(value: string | undefined);
        /**
         * @stability stable
         */
        resetDisabledReason(): void;
        /**
         * @stability stable
         */
        get disabledReasonInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get relatedRequirements(): string[];
        /**
         * @stability stable
         */
        get remediationUrl(): string;
        /**
         * @stability stable
         */
        get severityRating(): string;
        private _standardsControlArn?;
        /**
         * @stability stable
         */
        get standardsControlArn(): string;
        /**
         * @stability stable
         */
        set standardsControlArn(value: string);
        /**
         * @stability stable
         */
        get standardsControlArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get title(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityhubStandardsSubscriptionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_subscription.html#standards_arn SecurityhubStandardsSubscription#standards_arn}.
         *
         * @stability stable
         */
        readonly standardsArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_subscription.html aws_securityhub_standards_subscription}.
     *
     * @stability stable
     */
    class SecurityhubStandardsSubscription extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/securityhub_standards_subscription.html aws_securityhub_standards_subscription} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityhubStandardsSubscriptionConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _standardsArn?;
        /**
         * @stability stable
         */
        get standardsArn(): string;
        /**
         * @stability stable
         */
        set standardsArn(value: string);
        /**
         * @stability stable
         */
        get standardsArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
