import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Storage Gateway
*/
export declare namespace StorageGateway {
    /**
     * @stability stable
     */
    interface StoragegatewayCacheConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cache.html#disk_id StoragegatewayCache#disk_id}.
         *
         * @stability stable
         */
        readonly diskId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cache.html#gateway_arn StoragegatewayCache#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cache.html aws_storagegateway_cache}.
     *
     * @stability stable
     */
    class StoragegatewayCache extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cache.html aws_storagegateway_cache} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayCacheConfig);
        private _diskId?;
        /**
         * @stability stable
         */
        get diskId(): string;
        /**
         * @stability stable
         */
        set diskId(value: string);
        /**
         * @stability stable
         */
        get diskIdInput(): string | undefined;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayCachedIscsiVolumeConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#gateway_arn StoragegatewayCachedIscsiVolume#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#kms_encrypted StoragegatewayCachedIscsiVolume#kms_encrypted}.
         *
         * @stability stable
         */
        readonly kmsEncrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#kms_key StoragegatewayCachedIscsiVolume#kms_key}.
         *
         * @stability stable
         */
        readonly kmsKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#network_interface_id StoragegatewayCachedIscsiVolume#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#snapshot_id StoragegatewayCachedIscsiVolume#snapshot_id}.
         *
         * @stability stable
         */
        readonly snapshotId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#source_volume_arn StoragegatewayCachedIscsiVolume#source_volume_arn}.
         *
         * @stability stable
         */
        readonly sourceVolumeArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#tags StoragegatewayCachedIscsiVolume#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#tags_all StoragegatewayCachedIscsiVolume#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#target_name StoragegatewayCachedIscsiVolume#target_name}.
         *
         * @stability stable
         */
        readonly targetName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html#volume_size_in_bytes StoragegatewayCachedIscsiVolume#volume_size_in_bytes}.
         *
         * @stability stable
         */
        readonly volumeSizeInBytes: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html aws_storagegateway_cached_iscsi_volume}.
     *
     * @stability stable
     */
    class StoragegatewayCachedIscsiVolume extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_cached_iscsi_volume.html aws_storagegateway_cached_iscsi_volume} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayCachedIscsiVolumeConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get chapEnabled(): any;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsEncrypted?;
        /**
         * @stability stable
         */
        get kmsEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set kmsEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetKmsEncrypted(): void;
        /**
         * @stability stable
         */
        get kmsEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _kmsKey?;
        /**
         * @stability stable
         */
        get kmsKey(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKey(): void;
        /**
         * @stability stable
         */
        get kmsKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get lunNumber(): number;
        private _networkInterfaceId?;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        set networkInterfaceId(value: string);
        /**
         * @stability stable
         */
        get networkInterfaceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get networkInterfacePort(): number;
        private _snapshotId?;
        /**
         * @stability stable
         */
        get snapshotId(): string | undefined;
        /**
         * @stability stable
         */
        set snapshotId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSnapshotId(): void;
        /**
         * @stability stable
         */
        get snapshotIdInput(): string | undefined;
        private _sourceVolumeArn?;
        /**
         * @stability stable
         */
        get sourceVolumeArn(): string | undefined;
        /**
         * @stability stable
         */
        set sourceVolumeArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceVolumeArn(): void;
        /**
         * @stability stable
         */
        get sourceVolumeArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get targetArn(): string;
        private _targetName?;
        /**
         * @stability stable
         */
        get targetName(): string;
        /**
         * @stability stable
         */
        set targetName(value: string);
        /**
         * @stability stable
         */
        get targetNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get volumeArn(): string;
        /**
         * @stability stable
         */
        get volumeId(): string;
        private _volumeSizeInBytes?;
        /**
         * @stability stable
         */
        get volumeSizeInBytes(): number;
        /**
         * @stability stable
         */
        set volumeSizeInBytes(value: number);
        /**
         * @stability stable
         */
        get volumeSizeInBytesInput(): number | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayFileSystemAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#audit_destination_arn StoragegatewayFileSystemAssociation#audit_destination_arn}.
         *
         * @stability stable
         */
        readonly auditDestinationArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#gateway_arn StoragegatewayFileSystemAssociation#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#location_arn StoragegatewayFileSystemAssociation#location_arn}.
         *
         * @stability stable
         */
        readonly locationArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#password StoragegatewayFileSystemAssociation#password}.
         *
         * @stability stable
         */
        readonly password: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#tags StoragegatewayFileSystemAssociation#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#tags_all StoragegatewayFileSystemAssociation#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#username StoragegatewayFileSystemAssociation#username}.
         *
         * @stability stable
         */
        readonly username: string;
        /**
         * cache_attributes block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#cache_attributes StoragegatewayFileSystemAssociation#cache_attributes}
         *
         * @stability stable
         */
        readonly cacheAttributes?: StoragegatewayFileSystemAssociationCacheAttributes;
    }
    /**
     * @stability stable
     */
    interface StoragegatewayFileSystemAssociationCacheAttributes {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html#cache_stale_timeout_in_seconds StoragegatewayFileSystemAssociation#cache_stale_timeout_in_seconds}.
         *
         * @stability stable
         */
        readonly cacheStaleTimeoutInSeconds?: number;
    }
    /**
     * @stability stable
     */
    class StoragegatewayFileSystemAssociationCacheAttributesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cacheStaleTimeoutInSeconds?;
        /**
         * @stability stable
         */
        get cacheStaleTimeoutInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set cacheStaleTimeoutInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetCacheStaleTimeoutInSeconds(): void;
        /**
         * @stability stable
         */
        get cacheStaleTimeoutInSecondsInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html aws_storagegateway_file_system_association}.
     *
     * @stability stable
     */
    class StoragegatewayFileSystemAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_file_system_association.html aws_storagegateway_file_system_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayFileSystemAssociationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _auditDestinationArn?;
        /**
         * @stability stable
         */
        get auditDestinationArn(): string | undefined;
        /**
         * @stability stable
         */
        set auditDestinationArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuditDestinationArn(): void;
        /**
         * @stability stable
         */
        get auditDestinationArnInput(): string | undefined;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _locationArn?;
        /**
         * @stability stable
         */
        get locationArn(): string;
        /**
         * @stability stable
         */
        set locationArn(value: string);
        /**
         * @stability stable
         */
        get locationArnInput(): string | undefined;
        private _password?;
        /**
         * @stability stable
         */
        get password(): string;
        /**
         * @stability stable
         */
        set password(value: string);
        /**
         * @stability stable
         */
        get passwordInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _username?;
        /**
         * @stability stable
         */
        get username(): string;
        /**
         * @stability stable
         */
        set username(value: string);
        /**
         * @stability stable
         */
        get usernameInput(): string | undefined;
        private _cacheAttributes?;
        private __cacheAttributesOutput;
        /**
         * @stability stable
         */
        get cacheAttributes(): StoragegatewayFileSystemAssociationCacheAttributesOutputReference;
        /**
         * @stability stable
         */
        putCacheAttributes(value: StoragegatewayFileSystemAssociationCacheAttributes | undefined): void;
        /**
         * @stability stable
         */
        resetCacheAttributes(): void;
        /**
         * @stability stable
         */
        get cacheAttributesInput(): StoragegatewayFileSystemAssociationCacheAttributes | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#activation_key StoragegatewayGateway#activation_key}.
         *
         * @stability stable
         */
        readonly activationKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#average_download_rate_limit_in_bits_per_sec StoragegatewayGateway#average_download_rate_limit_in_bits_per_sec}.
         *
         * @stability stable
         */
        readonly averageDownloadRateLimitInBitsPerSec?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#average_upload_rate_limit_in_bits_per_sec StoragegatewayGateway#average_upload_rate_limit_in_bits_per_sec}.
         *
         * @stability stable
         */
        readonly averageUploadRateLimitInBitsPerSec?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#cloudwatch_log_group_arn StoragegatewayGateway#cloudwatch_log_group_arn}.
         *
         * @stability stable
         */
        readonly cloudwatchLogGroupArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#gateway_ip_address StoragegatewayGateway#gateway_ip_address}.
         *
         * @stability stable
         */
        readonly gatewayIpAddress?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#gateway_name StoragegatewayGateway#gateway_name}.
         *
         * @stability stable
         */
        readonly gatewayName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#gateway_timezone StoragegatewayGateway#gateway_timezone}.
         *
         * @stability stable
         */
        readonly gatewayTimezone: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#gateway_type StoragegatewayGateway#gateway_type}.
         *
         * @stability stable
         */
        readonly gatewayType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#gateway_vpc_endpoint StoragegatewayGateway#gateway_vpc_endpoint}.
         *
         * @stability stable
         */
        readonly gatewayVpcEndpoint?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#medium_changer_type StoragegatewayGateway#medium_changer_type}.
         *
         * @stability stable
         */
        readonly mediumChangerType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#smb_file_share_visibility StoragegatewayGateway#smb_file_share_visibility}.
         *
         * @stability stable
         */
        readonly smbFileShareVisibility?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#smb_guest_password StoragegatewayGateway#smb_guest_password}.
         *
         * @stability stable
         */
        readonly smbGuestPassword?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#smb_security_strategy StoragegatewayGateway#smb_security_strategy}.
         *
         * @stability stable
         */
        readonly smbSecurityStrategy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#tags StoragegatewayGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#tags_all StoragegatewayGateway#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#tape_drive_type StoragegatewayGateway#tape_drive_type}.
         *
         * @stability stable
         */
        readonly tapeDriveType?: string;
        /**
         * smb_active_directory_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#smb_active_directory_settings StoragegatewayGateway#smb_active_directory_settings}
         *
         * @stability stable
         */
        readonly smbActiveDirectorySettings?: StoragegatewayGatewaySmbActiveDirectorySettings;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#timeouts StoragegatewayGateway#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: StoragegatewayGatewayTimeouts;
    }
    /**
     * @stability stable
     */
    class StoragegatewayGatewayGatewayNetworkInterface extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get ipv4Address(): string;
    }
    /**
     * @stability stable
     */
    interface StoragegatewayGatewaySmbActiveDirectorySettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#domain_controllers StoragegatewayGateway#domain_controllers}.
         *
         * @stability stable
         */
        readonly domainControllers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#domain_name StoragegatewayGateway#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#organizational_unit StoragegatewayGateway#organizational_unit}.
         *
         * @stability stable
         */
        readonly organizationalUnit?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#password StoragegatewayGateway#password}.
         *
         * @stability stable
         */
        readonly password: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#timeout_in_seconds StoragegatewayGateway#timeout_in_seconds}.
         *
         * @stability stable
         */
        readonly timeoutInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#username StoragegatewayGateway#username}.
         *
         * @stability stable
         */
        readonly username: string;
    }
    /**
     * @stability stable
     */
    class StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _domainControllers?;
        /**
         * @stability stable
         */
        get domainControllers(): string[] | undefined;
        /**
         * @stability stable
         */
        set domainControllers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetDomainControllers(): void;
        /**
         * @stability stable
         */
        get domainControllersInput(): string[] | undefined;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        private _organizationalUnit?;
        /**
         * @stability stable
         */
        get organizationalUnit(): string | undefined;
        /**
         * @stability stable
         */
        set organizationalUnit(value: string | undefined);
        /**
         * @stability stable
         */
        resetOrganizationalUnit(): void;
        /**
         * @stability stable
         */
        get organizationalUnitInput(): string | undefined;
        private _password?;
        /**
         * @stability stable
         */
        get password(): string;
        /**
         * @stability stable
         */
        set password(value: string);
        /**
         * @stability stable
         */
        get passwordInput(): string | undefined;
        private _timeoutInSeconds?;
        /**
         * @stability stable
         */
        get timeoutInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set timeoutInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeoutInSeconds(): void;
        /**
         * @stability stable
         */
        get timeoutInSecondsInput(): number | undefined;
        private _username?;
        /**
         * @stability stable
         */
        get username(): string;
        /**
         * @stability stable
         */
        set username(value: string);
        /**
         * @stability stable
         */
        get usernameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface StoragegatewayGatewayTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html#create StoragegatewayGateway#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class StoragegatewayGatewayTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html aws_storagegateway_gateway}.
     *
     * @stability stable
     */
    class StoragegatewayGateway extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_gateway.html aws_storagegateway_gateway} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayGatewayConfig);
        private _activationKey?;
        /**
         * @stability stable
         */
        get activationKey(): string | undefined;
        /**
         * @stability stable
         */
        set activationKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetActivationKey(): void;
        /**
         * @stability stable
         */
        get activationKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _averageDownloadRateLimitInBitsPerSec?;
        /**
         * @stability stable
         */
        get averageDownloadRateLimitInBitsPerSec(): number | undefined;
        /**
         * @stability stable
         */
        set averageDownloadRateLimitInBitsPerSec(value: number | undefined);
        /**
         * @stability stable
         */
        resetAverageDownloadRateLimitInBitsPerSec(): void;
        /**
         * @stability stable
         */
        get averageDownloadRateLimitInBitsPerSecInput(): number | undefined;
        private _averageUploadRateLimitInBitsPerSec?;
        /**
         * @stability stable
         */
        get averageUploadRateLimitInBitsPerSec(): number | undefined;
        /**
         * @stability stable
         */
        set averageUploadRateLimitInBitsPerSec(value: number | undefined);
        /**
         * @stability stable
         */
        resetAverageUploadRateLimitInBitsPerSec(): void;
        /**
         * @stability stable
         */
        get averageUploadRateLimitInBitsPerSecInput(): number | undefined;
        private _cloudwatchLogGroupArn?;
        /**
         * @stability stable
         */
        get cloudwatchLogGroupArn(): string | undefined;
        /**
         * @stability stable
         */
        set cloudwatchLogGroupArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchLogGroupArn(): void;
        /**
         * @stability stable
         */
        get cloudwatchLogGroupArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get ec2InstanceId(): string;
        /**
         * @stability stable
         */
        get endpointType(): string;
        /**
         * @stability stable
         */
        get gatewayId(): string;
        private _gatewayIpAddress?;
        /**
         * @stability stable
         */
        get gatewayIpAddress(): string | undefined;
        /**
         * @stability stable
         */
        set gatewayIpAddress(value: string | undefined);
        /**
         * @stability stable
         */
        resetGatewayIpAddress(): void;
        /**
         * @stability stable
         */
        get gatewayIpAddressInput(): string | undefined;
        private _gatewayName?;
        /**
         * @stability stable
         */
        get gatewayName(): string;
        /**
         * @stability stable
         */
        set gatewayName(value: string);
        /**
         * @stability stable
         */
        get gatewayNameInput(): string | undefined;
        /**
         * @stability stable
         */
        gatewayNetworkInterface(index: string): StoragegatewayGatewayGatewayNetworkInterface;
        private _gatewayTimezone?;
        /**
         * @stability stable
         */
        get gatewayTimezone(): string;
        /**
         * @stability stable
         */
        set gatewayTimezone(value: string);
        /**
         * @stability stable
         */
        get gatewayTimezoneInput(): string | undefined;
        private _gatewayType?;
        /**
         * @stability stable
         */
        get gatewayType(): string | undefined;
        /**
         * @stability stable
         */
        set gatewayType(value: string | undefined);
        /**
         * @stability stable
         */
        resetGatewayType(): void;
        /**
         * @stability stable
         */
        get gatewayTypeInput(): string | undefined;
        private _gatewayVpcEndpoint?;
        /**
         * @stability stable
         */
        get gatewayVpcEndpoint(): string | undefined;
        /**
         * @stability stable
         */
        set gatewayVpcEndpoint(value: string | undefined);
        /**
         * @stability stable
         */
        resetGatewayVpcEndpoint(): void;
        /**
         * @stability stable
         */
        get gatewayVpcEndpointInput(): string | undefined;
        /**
         * @stability stable
         */
        get hostEnvironment(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _mediumChangerType?;
        /**
         * @stability stable
         */
        get mediumChangerType(): string | undefined;
        /**
         * @stability stable
         */
        set mediumChangerType(value: string | undefined);
        /**
         * @stability stable
         */
        resetMediumChangerType(): void;
        /**
         * @stability stable
         */
        get mediumChangerTypeInput(): string | undefined;
        private _smbFileShareVisibility?;
        /**
         * @stability stable
         */
        get smbFileShareVisibility(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set smbFileShareVisibility(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSmbFileShareVisibility(): void;
        /**
         * @stability stable
         */
        get smbFileShareVisibilityInput(): boolean | cdktf.IResolvable | undefined;
        private _smbGuestPassword?;
        /**
         * @stability stable
         */
        get smbGuestPassword(): string | undefined;
        /**
         * @stability stable
         */
        set smbGuestPassword(value: string | undefined);
        /**
         * @stability stable
         */
        resetSmbGuestPassword(): void;
        /**
         * @stability stable
         */
        get smbGuestPasswordInput(): string | undefined;
        private _smbSecurityStrategy?;
        /**
         * @stability stable
         */
        get smbSecurityStrategy(): string | undefined;
        /**
         * @stability stable
         */
        set smbSecurityStrategy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSmbSecurityStrategy(): void;
        /**
         * @stability stable
         */
        get smbSecurityStrategyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tapeDriveType?;
        /**
         * @stability stable
         */
        get tapeDriveType(): string | undefined;
        /**
         * @stability stable
         */
        set tapeDriveType(value: string | undefined);
        /**
         * @stability stable
         */
        resetTapeDriveType(): void;
        /**
         * @stability stable
         */
        get tapeDriveTypeInput(): string | undefined;
        private _smbActiveDirectorySettings?;
        private __smbActiveDirectorySettingsOutput;
        /**
         * @stability stable
         */
        get smbActiveDirectorySettings(): StoragegatewayGatewaySmbActiveDirectorySettingsOutputReference;
        /**
         * @stability stable
         */
        putSmbActiveDirectorySettings(value: StoragegatewayGatewaySmbActiveDirectorySettings | undefined): void;
        /**
         * @stability stable
         */
        resetSmbActiveDirectorySettings(): void;
        /**
         * @stability stable
         */
        get smbActiveDirectorySettingsInput(): StoragegatewayGatewaySmbActiveDirectorySettings | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): StoragegatewayGatewayTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: StoragegatewayGatewayTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): StoragegatewayGatewayTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayNfsFileShareConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#client_list StoragegatewayNfsFileShare#client_list}.
         *
         * @stability stable
         */
        readonly clientList: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#default_storage_class StoragegatewayNfsFileShare#default_storage_class}.
         *
         * @stability stable
         */
        readonly defaultStorageClass?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#file_share_name StoragegatewayNfsFileShare#file_share_name}.
         *
         * @stability stable
         */
        readonly fileShareName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#gateway_arn StoragegatewayNfsFileShare#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#guess_mime_type_enabled StoragegatewayNfsFileShare#guess_mime_type_enabled}.
         *
         * @stability stable
         */
        readonly guessMimeTypeEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#kms_encrypted StoragegatewayNfsFileShare#kms_encrypted}.
         *
         * @stability stable
         */
        readonly kmsEncrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#kms_key_arn StoragegatewayNfsFileShare#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#location_arn StoragegatewayNfsFileShare#location_arn}.
         *
         * @stability stable
         */
        readonly locationArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#notification_policy StoragegatewayNfsFileShare#notification_policy}.
         *
         * @stability stable
         */
        readonly notificationPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#object_acl StoragegatewayNfsFileShare#object_acl}.
         *
         * @stability stable
         */
        readonly objectAcl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#read_only StoragegatewayNfsFileShare#read_only}.
         *
         * @stability stable
         */
        readonly readOnly?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#requester_pays StoragegatewayNfsFileShare#requester_pays}.
         *
         * @stability stable
         */
        readonly requesterPays?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#role_arn StoragegatewayNfsFileShare#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#squash StoragegatewayNfsFileShare#squash}.
         *
         * @stability stable
         */
        readonly squash?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#tags StoragegatewayNfsFileShare#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#tags_all StoragegatewayNfsFileShare#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * cache_attributes block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#cache_attributes StoragegatewayNfsFileShare#cache_attributes}
         *
         * @stability stable
         */
        readonly cacheAttributes?: StoragegatewayNfsFileShareCacheAttributes;
        /**
         * nfs_file_share_defaults block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#nfs_file_share_defaults StoragegatewayNfsFileShare#nfs_file_share_defaults}
         *
         * @stability stable
         */
        readonly nfsFileShareDefaults?: StoragegatewayNfsFileShareNfsFileShareDefaults;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#timeouts StoragegatewayNfsFileShare#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: StoragegatewayNfsFileShareTimeouts;
    }
    /**
     * @stability stable
     */
    interface StoragegatewayNfsFileShareCacheAttributes {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#cache_stale_timeout_in_seconds StoragegatewayNfsFileShare#cache_stale_timeout_in_seconds}.
         *
         * @stability stable
         */
        readonly cacheStaleTimeoutInSeconds?: number;
    }
    /**
     * @stability stable
     */
    class StoragegatewayNfsFileShareCacheAttributesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cacheStaleTimeoutInSeconds?;
        /**
         * @stability stable
         */
        get cacheStaleTimeoutInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set cacheStaleTimeoutInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetCacheStaleTimeoutInSeconds(): void;
        /**
         * @stability stable
         */
        get cacheStaleTimeoutInSecondsInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface StoragegatewayNfsFileShareNfsFileShareDefaults {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#directory_mode StoragegatewayNfsFileShare#directory_mode}.
         *
         * @stability stable
         */
        readonly directoryMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#file_mode StoragegatewayNfsFileShare#file_mode}.
         *
         * @stability stable
         */
        readonly fileMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#group_id StoragegatewayNfsFileShare#group_id}.
         *
         * @stability stable
         */
        readonly groupId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#owner_id StoragegatewayNfsFileShare#owner_id}.
         *
         * @stability stable
         */
        readonly ownerId?: string;
    }
    /**
     * @stability stable
     */
    class StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _directoryMode?;
        /**
         * @stability stable
         */
        get directoryMode(): string | undefined;
        /**
         * @stability stable
         */
        set directoryMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetDirectoryMode(): void;
        /**
         * @stability stable
         */
        get directoryModeInput(): string | undefined;
        private _fileMode?;
        /**
         * @stability stable
         */
        get fileMode(): string | undefined;
        /**
         * @stability stable
         */
        set fileMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileMode(): void;
        /**
         * @stability stable
         */
        get fileModeInput(): string | undefined;
        private _groupId?;
        /**
         * @stability stable
         */
        get groupId(): string | undefined;
        /**
         * @stability stable
         */
        set groupId(value: string | undefined);
        /**
         * @stability stable
         */
        resetGroupId(): void;
        /**
         * @stability stable
         */
        get groupIdInput(): string | undefined;
        private _ownerId?;
        /**
         * @stability stable
         */
        get ownerId(): string | undefined;
        /**
         * @stability stable
         */
        set ownerId(value: string | undefined);
        /**
         * @stability stable
         */
        resetOwnerId(): void;
        /**
         * @stability stable
         */
        get ownerIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface StoragegatewayNfsFileShareTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#create StoragegatewayNfsFileShare#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#delete StoragegatewayNfsFileShare#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html#update StoragegatewayNfsFileShare#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class StoragegatewayNfsFileShareTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html aws_storagegateway_nfs_file_share}.
     *
     * @stability stable
     */
    class StoragegatewayNfsFileShare extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_nfs_file_share.html aws_storagegateway_nfs_file_share} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayNfsFileShareConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _clientList?;
        /**
         * @stability stable
         */
        get clientList(): string[];
        /**
         * @stability stable
         */
        set clientList(value: string[]);
        /**
         * @stability stable
         */
        get clientListInput(): string[] | undefined;
        private _defaultStorageClass?;
        /**
         * @stability stable
         */
        get defaultStorageClass(): string | undefined;
        /**
         * @stability stable
         */
        set defaultStorageClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefaultStorageClass(): void;
        /**
         * @stability stable
         */
        get defaultStorageClassInput(): string | undefined;
        private _fileShareName?;
        /**
         * @stability stable
         */
        get fileShareName(): string | undefined;
        /**
         * @stability stable
         */
        set fileShareName(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileShareName(): void;
        /**
         * @stability stable
         */
        get fileShareNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get fileshareId(): string;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        private _guessMimeTypeEnabled?;
        /**
         * @stability stable
         */
        get guessMimeTypeEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set guessMimeTypeEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetGuessMimeTypeEnabled(): void;
        /**
         * @stability stable
         */
        get guessMimeTypeEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsEncrypted?;
        /**
         * @stability stable
         */
        get kmsEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set kmsEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetKmsEncrypted(): void;
        /**
         * @stability stable
         */
        get kmsEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _locationArn?;
        /**
         * @stability stable
         */
        get locationArn(): string;
        /**
         * @stability stable
         */
        set locationArn(value: string);
        /**
         * @stability stable
         */
        get locationArnInput(): string | undefined;
        private _notificationPolicy?;
        /**
         * @stability stable
         */
        get notificationPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set notificationPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationPolicy(): void;
        /**
         * @stability stable
         */
        get notificationPolicyInput(): string | undefined;
        private _objectAcl?;
        /**
         * @stability stable
         */
        get objectAcl(): string | undefined;
        /**
         * @stability stable
         */
        set objectAcl(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectAcl(): void;
        /**
         * @stability stable
         */
        get objectAclInput(): string | undefined;
        /**
         * @stability stable
         */
        get path(): string;
        private _readOnly?;
        /**
         * @stability stable
         */
        get readOnly(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set readOnly(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetReadOnly(): void;
        /**
         * @stability stable
         */
        get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
        private _requesterPays?;
        /**
         * @stability stable
         */
        get requesterPays(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requesterPays(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequesterPays(): void;
        /**
         * @stability stable
         */
        get requesterPaysInput(): boolean | cdktf.IResolvable | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _squash?;
        /**
         * @stability stable
         */
        get squash(): string | undefined;
        /**
         * @stability stable
         */
        set squash(value: string | undefined);
        /**
         * @stability stable
         */
        resetSquash(): void;
        /**
         * @stability stable
         */
        get squashInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _cacheAttributes?;
        private __cacheAttributesOutput;
        /**
         * @stability stable
         */
        get cacheAttributes(): StoragegatewayNfsFileShareCacheAttributesOutputReference;
        /**
         * @stability stable
         */
        putCacheAttributes(value: StoragegatewayNfsFileShareCacheAttributes | undefined): void;
        /**
         * @stability stable
         */
        resetCacheAttributes(): void;
        /**
         * @stability stable
         */
        get cacheAttributesInput(): StoragegatewayNfsFileShareCacheAttributes | undefined;
        private _nfsFileShareDefaults?;
        private __nfsFileShareDefaultsOutput;
        /**
         * @stability stable
         */
        get nfsFileShareDefaults(): StoragegatewayNfsFileShareNfsFileShareDefaultsOutputReference;
        /**
         * @stability stable
         */
        putNfsFileShareDefaults(value: StoragegatewayNfsFileShareNfsFileShareDefaults | undefined): void;
        /**
         * @stability stable
         */
        resetNfsFileShareDefaults(): void;
        /**
         * @stability stable
         */
        get nfsFileShareDefaultsInput(): StoragegatewayNfsFileShareNfsFileShareDefaults | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): StoragegatewayNfsFileShareTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: StoragegatewayNfsFileShareTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): StoragegatewayNfsFileShareTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewaySmbFileShareConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#access_based_enumeration StoragegatewaySmbFileShare#access_based_enumeration}.
         *
         * @stability stable
         */
        readonly accessBasedEnumeration?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#admin_user_list StoragegatewaySmbFileShare#admin_user_list}.
         *
         * @stability stable
         */
        readonly adminUserList?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#audit_destination_arn StoragegatewaySmbFileShare#audit_destination_arn}.
         *
         * @stability stable
         */
        readonly auditDestinationArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#authentication StoragegatewaySmbFileShare#authentication}.
         *
         * @stability stable
         */
        readonly authentication?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#bucket_region StoragegatewaySmbFileShare#bucket_region}.
         *
         * @stability stable
         */
        readonly bucketRegion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#case_sensitivity StoragegatewaySmbFileShare#case_sensitivity}.
         *
         * @stability stable
         */
        readonly caseSensitivity?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#default_storage_class StoragegatewaySmbFileShare#default_storage_class}.
         *
         * @stability stable
         */
        readonly defaultStorageClass?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#file_share_name StoragegatewaySmbFileShare#file_share_name}.
         *
         * @stability stable
         */
        readonly fileShareName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#gateway_arn StoragegatewaySmbFileShare#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#guess_mime_type_enabled StoragegatewaySmbFileShare#guess_mime_type_enabled}.
         *
         * @stability stable
         */
        readonly guessMimeTypeEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#invalid_user_list StoragegatewaySmbFileShare#invalid_user_list}.
         *
         * @stability stable
         */
        readonly invalidUserList?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#kms_encrypted StoragegatewaySmbFileShare#kms_encrypted}.
         *
         * @stability stable
         */
        readonly kmsEncrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#kms_key_arn StoragegatewaySmbFileShare#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#location_arn StoragegatewaySmbFileShare#location_arn}.
         *
         * @stability stable
         */
        readonly locationArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#notification_policy StoragegatewaySmbFileShare#notification_policy}.
         *
         * @stability stable
         */
        readonly notificationPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#object_acl StoragegatewaySmbFileShare#object_acl}.
         *
         * @stability stable
         */
        readonly objectAcl?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#oplocks_enabled StoragegatewaySmbFileShare#oplocks_enabled}.
         *
         * @stability stable
         */
        readonly oplocksEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#read_only StoragegatewaySmbFileShare#read_only}.
         *
         * @stability stable
         */
        readonly readOnly?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#requester_pays StoragegatewaySmbFileShare#requester_pays}.
         *
         * @stability stable
         */
        readonly requesterPays?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#role_arn StoragegatewaySmbFileShare#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#smb_acl_enabled StoragegatewaySmbFileShare#smb_acl_enabled}.
         *
         * @stability stable
         */
        readonly smbAclEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#tags StoragegatewaySmbFileShare#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#tags_all StoragegatewaySmbFileShare#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#valid_user_list StoragegatewaySmbFileShare#valid_user_list}.
         *
         * @stability stable
         */
        readonly validUserList?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#vpc_endpoint_dns_name StoragegatewaySmbFileShare#vpc_endpoint_dns_name}.
         *
         * @stability stable
         */
        readonly vpcEndpointDnsName?: string;
        /**
         * cache_attributes block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#cache_attributes StoragegatewaySmbFileShare#cache_attributes}
         *
         * @stability stable
         */
        readonly cacheAttributes?: StoragegatewaySmbFileShareCacheAttributes;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#timeouts StoragegatewaySmbFileShare#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: StoragegatewaySmbFileShareTimeouts;
    }
    /**
     * @stability stable
     */
    interface StoragegatewaySmbFileShareCacheAttributes {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#cache_stale_timeout_in_seconds StoragegatewaySmbFileShare#cache_stale_timeout_in_seconds}.
         *
         * @stability stable
         */
        readonly cacheStaleTimeoutInSeconds?: number;
    }
    /**
     * @stability stable
     */
    class StoragegatewaySmbFileShareCacheAttributesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cacheStaleTimeoutInSeconds?;
        /**
         * @stability stable
         */
        get cacheStaleTimeoutInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set cacheStaleTimeoutInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetCacheStaleTimeoutInSeconds(): void;
        /**
         * @stability stable
         */
        get cacheStaleTimeoutInSecondsInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface StoragegatewaySmbFileShareTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#create StoragegatewaySmbFileShare#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#delete StoragegatewaySmbFileShare#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html#update StoragegatewaySmbFileShare#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class StoragegatewaySmbFileShareTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html aws_storagegateway_smb_file_share}.
     *
     * @stability stable
     */
    class StoragegatewaySmbFileShare extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_smb_file_share.html aws_storagegateway_smb_file_share} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewaySmbFileShareConfig);
        private _accessBasedEnumeration?;
        /**
         * @stability stable
         */
        get accessBasedEnumeration(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set accessBasedEnumeration(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAccessBasedEnumeration(): void;
        /**
         * @stability stable
         */
        get accessBasedEnumerationInput(): boolean | cdktf.IResolvable | undefined;
        private _adminUserList?;
        /**
         * @stability stable
         */
        get adminUserList(): string[] | undefined;
        /**
         * @stability stable
         */
        set adminUserList(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAdminUserList(): void;
        /**
         * @stability stable
         */
        get adminUserListInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _auditDestinationArn?;
        /**
         * @stability stable
         */
        get auditDestinationArn(): string | undefined;
        /**
         * @stability stable
         */
        set auditDestinationArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuditDestinationArn(): void;
        /**
         * @stability stable
         */
        get auditDestinationArnInput(): string | undefined;
        private _authentication?;
        /**
         * @stability stable
         */
        get authentication(): string | undefined;
        /**
         * @stability stable
         */
        set authentication(value: string | undefined);
        /**
         * @stability stable
         */
        resetAuthentication(): void;
        /**
         * @stability stable
         */
        get authenticationInput(): string | undefined;
        private _bucketRegion?;
        /**
         * @stability stable
         */
        get bucketRegion(): string | undefined;
        /**
         * @stability stable
         */
        set bucketRegion(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketRegion(): void;
        /**
         * @stability stable
         */
        get bucketRegionInput(): string | undefined;
        private _caseSensitivity?;
        /**
         * @stability stable
         */
        get caseSensitivity(): string | undefined;
        /**
         * @stability stable
         */
        set caseSensitivity(value: string | undefined);
        /**
         * @stability stable
         */
        resetCaseSensitivity(): void;
        /**
         * @stability stable
         */
        get caseSensitivityInput(): string | undefined;
        private _defaultStorageClass?;
        /**
         * @stability stable
         */
        get defaultStorageClass(): string | undefined;
        /**
         * @stability stable
         */
        set defaultStorageClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefaultStorageClass(): void;
        /**
         * @stability stable
         */
        get defaultStorageClassInput(): string | undefined;
        private _fileShareName?;
        /**
         * @stability stable
         */
        get fileShareName(): string | undefined;
        /**
         * @stability stable
         */
        set fileShareName(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileShareName(): void;
        /**
         * @stability stable
         */
        get fileShareNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get fileshareId(): string;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        private _guessMimeTypeEnabled?;
        /**
         * @stability stable
         */
        get guessMimeTypeEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set guessMimeTypeEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetGuessMimeTypeEnabled(): void;
        /**
         * @stability stable
         */
        get guessMimeTypeEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _invalidUserList?;
        /**
         * @stability stable
         */
        get invalidUserList(): string[] | undefined;
        /**
         * @stability stable
         */
        set invalidUserList(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetInvalidUserList(): void;
        /**
         * @stability stable
         */
        get invalidUserListInput(): string[] | undefined;
        private _kmsEncrypted?;
        /**
         * @stability stable
         */
        get kmsEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set kmsEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetKmsEncrypted(): void;
        /**
         * @stability stable
         */
        get kmsEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _locationArn?;
        /**
         * @stability stable
         */
        get locationArn(): string;
        /**
         * @stability stable
         */
        set locationArn(value: string);
        /**
         * @stability stable
         */
        get locationArnInput(): string | undefined;
        private _notificationPolicy?;
        /**
         * @stability stable
         */
        get notificationPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set notificationPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationPolicy(): void;
        /**
         * @stability stable
         */
        get notificationPolicyInput(): string | undefined;
        private _objectAcl?;
        /**
         * @stability stable
         */
        get objectAcl(): string | undefined;
        /**
         * @stability stable
         */
        set objectAcl(value: string | undefined);
        /**
         * @stability stable
         */
        resetObjectAcl(): void;
        /**
         * @stability stable
         */
        get objectAclInput(): string | undefined;
        private _oplocksEnabled?;
        /**
         * @stability stable
         */
        get oplocksEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set oplocksEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetOplocksEnabled(): void;
        /**
         * @stability stable
         */
        get oplocksEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get path(): string;
        private _readOnly?;
        /**
         * @stability stable
         */
        get readOnly(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set readOnly(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetReadOnly(): void;
        /**
         * @stability stable
         */
        get readOnlyInput(): boolean | cdktf.IResolvable | undefined;
        private _requesterPays?;
        /**
         * @stability stable
         */
        get requesterPays(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requesterPays(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequesterPays(): void;
        /**
         * @stability stable
         */
        get requesterPaysInput(): boolean | cdktf.IResolvable | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _smbAclEnabled?;
        /**
         * @stability stable
         */
        get smbAclEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set smbAclEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSmbAclEnabled(): void;
        /**
         * @stability stable
         */
        get smbAclEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _validUserList?;
        /**
         * @stability stable
         */
        get validUserList(): string[] | undefined;
        /**
         * @stability stable
         */
        set validUserList(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetValidUserList(): void;
        /**
         * @stability stable
         */
        get validUserListInput(): string[] | undefined;
        private _vpcEndpointDnsName?;
        /**
         * @stability stable
         */
        get vpcEndpointDnsName(): string | undefined;
        /**
         * @stability stable
         */
        set vpcEndpointDnsName(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcEndpointDnsName(): void;
        /**
         * @stability stable
         */
        get vpcEndpointDnsNameInput(): string | undefined;
        private _cacheAttributes?;
        private __cacheAttributesOutput;
        /**
         * @stability stable
         */
        get cacheAttributes(): StoragegatewaySmbFileShareCacheAttributesOutputReference;
        /**
         * @stability stable
         */
        putCacheAttributes(value: StoragegatewaySmbFileShareCacheAttributes | undefined): void;
        /**
         * @stability stable
         */
        resetCacheAttributes(): void;
        /**
         * @stability stable
         */
        get cacheAttributesInput(): StoragegatewaySmbFileShareCacheAttributes | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): StoragegatewaySmbFileShareTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: StoragegatewaySmbFileShareTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): StoragegatewaySmbFileShareTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayStoredIscsiVolumeConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#disk_id StoragegatewayStoredIscsiVolume#disk_id}.
         *
         * @stability stable
         */
        readonly diskId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#gateway_arn StoragegatewayStoredIscsiVolume#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#kms_encrypted StoragegatewayStoredIscsiVolume#kms_encrypted}.
         *
         * @stability stable
         */
        readonly kmsEncrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#kms_key StoragegatewayStoredIscsiVolume#kms_key}.
         *
         * @stability stable
         */
        readonly kmsKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#network_interface_id StoragegatewayStoredIscsiVolume#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#preserve_existing_data StoragegatewayStoredIscsiVolume#preserve_existing_data}.
         *
         * @stability stable
         */
        readonly preserveExistingData: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#snapshot_id StoragegatewayStoredIscsiVolume#snapshot_id}.
         *
         * @stability stable
         */
        readonly snapshotId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#tags StoragegatewayStoredIscsiVolume#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#tags_all StoragegatewayStoredIscsiVolume#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html#target_name StoragegatewayStoredIscsiVolume#target_name}.
         *
         * @stability stable
         */
        readonly targetName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html aws_storagegateway_stored_iscsi_volume}.
     *
     * @stability stable
     */
    class StoragegatewayStoredIscsiVolume extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_stored_iscsi_volume.html aws_storagegateway_stored_iscsi_volume} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayStoredIscsiVolumeConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get chapEnabled(): any;
        private _diskId?;
        /**
         * @stability stable
         */
        get diskId(): string;
        /**
         * @stability stable
         */
        set diskId(value: string);
        /**
         * @stability stable
         */
        get diskIdInput(): string | undefined;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsEncrypted?;
        /**
         * @stability stable
         */
        get kmsEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set kmsEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetKmsEncrypted(): void;
        /**
         * @stability stable
         */
        get kmsEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _kmsKey?;
        /**
         * @stability stable
         */
        get kmsKey(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKey(): void;
        /**
         * @stability stable
         */
        get kmsKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get lunNumber(): number;
        private _networkInterfaceId?;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        set networkInterfaceId(value: string);
        /**
         * @stability stable
         */
        get networkInterfaceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get networkInterfacePort(): number;
        private _preserveExistingData?;
        /**
         * @stability stable
         */
        get preserveExistingData(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set preserveExistingData(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get preserveExistingDataInput(): boolean | cdktf.IResolvable | undefined;
        private _snapshotId?;
        /**
         * @stability stable
         */
        get snapshotId(): string | undefined;
        /**
         * @stability stable
         */
        set snapshotId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSnapshotId(): void;
        /**
         * @stability stable
         */
        get snapshotIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get targetArn(): string;
        private _targetName?;
        /**
         * @stability stable
         */
        get targetName(): string;
        /**
         * @stability stable
         */
        set targetName(value: string);
        /**
         * @stability stable
         */
        get targetNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get volumeAttachmentStatus(): string;
        /**
         * @stability stable
         */
        get volumeId(): string;
        /**
         * @stability stable
         */
        get volumeSizeInBytes(): number;
        /**
         * @stability stable
         */
        get volumeStatus(): string;
        /**
         * @stability stable
         */
        get volumeType(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayTapePoolConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html#pool_name StoragegatewayTapePool#pool_name}.
         *
         * @stability stable
         */
        readonly poolName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html#retention_lock_time_in_days StoragegatewayTapePool#retention_lock_time_in_days}.
         *
         * @stability stable
         */
        readonly retentionLockTimeInDays?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html#retention_lock_type StoragegatewayTapePool#retention_lock_type}.
         *
         * @stability stable
         */
        readonly retentionLockType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html#storage_class StoragegatewayTapePool#storage_class}.
         *
         * @stability stable
         */
        readonly storageClass: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html#tags StoragegatewayTapePool#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html#tags_all StoragegatewayTapePool#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html aws_storagegateway_tape_pool}.
     *
     * @stability stable
     */
    class StoragegatewayTapePool extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_tape_pool.html aws_storagegateway_tape_pool} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayTapePoolConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _poolName?;
        /**
         * @stability stable
         */
        get poolName(): string;
        /**
         * @stability stable
         */
        set poolName(value: string);
        /**
         * @stability stable
         */
        get poolNameInput(): string | undefined;
        private _retentionLockTimeInDays?;
        /**
         * @stability stable
         */
        get retentionLockTimeInDays(): number | undefined;
        /**
         * @stability stable
         */
        set retentionLockTimeInDays(value: number | undefined);
        /**
         * @stability stable
         */
        resetRetentionLockTimeInDays(): void;
        /**
         * @stability stable
         */
        get retentionLockTimeInDaysInput(): number | undefined;
        private _retentionLockType?;
        /**
         * @stability stable
         */
        get retentionLockType(): string | undefined;
        /**
         * @stability stable
         */
        set retentionLockType(value: string | undefined);
        /**
         * @stability stable
         */
        resetRetentionLockType(): void;
        /**
         * @stability stable
         */
        get retentionLockTypeInput(): string | undefined;
        private _storageClass?;
        /**
         * @stability stable
         */
        get storageClass(): string;
        /**
         * @stability stable
         */
        set storageClass(value: string);
        /**
         * @stability stable
         */
        get storageClassInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayUploadBufferConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_upload_buffer.html#disk_id StoragegatewayUploadBuffer#disk_id}.
         *
         * @stability stable
         */
        readonly diskId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_upload_buffer.html#disk_path StoragegatewayUploadBuffer#disk_path}.
         *
         * @stability stable
         */
        readonly diskPath?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_upload_buffer.html#gateway_arn StoragegatewayUploadBuffer#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_upload_buffer.html aws_storagegateway_upload_buffer}.
     *
     * @stability stable
     */
    class StoragegatewayUploadBuffer extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_upload_buffer.html aws_storagegateway_upload_buffer} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayUploadBufferConfig);
        private _diskId?;
        /**
         * @stability stable
         */
        get diskId(): string | undefined;
        /**
         * @stability stable
         */
        set diskId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDiskId(): void;
        /**
         * @stability stable
         */
        get diskIdInput(): string | undefined;
        private _diskPath?;
        /**
         * @stability stable
         */
        get diskPath(): string | undefined;
        /**
         * @stability stable
         */
        set diskPath(value: string | undefined);
        /**
         * @stability stable
         */
        resetDiskPath(): void;
        /**
         * @stability stable
         */
        get diskPathInput(): string | undefined;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface StoragegatewayWorkingStorageConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_working_storage.html#disk_id StoragegatewayWorkingStorage#disk_id}.
         *
         * @stability stable
         */
        readonly diskId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_working_storage.html#gateway_arn StoragegatewayWorkingStorage#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_working_storage.html aws_storagegateway_working_storage}.
     *
     * @stability stable
     */
    class StoragegatewayWorkingStorage extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/storagegateway_working_storage.html aws_storagegateway_working_storage} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: StoragegatewayWorkingStorageConfig);
        private _diskId?;
        /**
         * @stability stable
         */
        get diskId(): string;
        /**
         * @stability stable
         */
        set diskId(value: string);
        /**
         * @stability stable
         */
        get diskIdInput(): string | undefined;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsStoragegatewayLocalDiskConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/storagegateway_local_disk.html#disk_node DataAwsStoragegatewayLocalDisk#disk_node}.
         *
         * @stability stable
         */
        readonly diskNode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/storagegateway_local_disk.html#disk_path DataAwsStoragegatewayLocalDisk#disk_path}.
         *
         * @stability stable
         */
        readonly diskPath?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/storagegateway_local_disk.html#gateway_arn DataAwsStoragegatewayLocalDisk#gateway_arn}.
         *
         * @stability stable
         */
        readonly gatewayArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/storagegateway_local_disk.html aws_storagegateway_local_disk}.
     *
     * @stability stable
     */
    class DataAwsStoragegatewayLocalDisk extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/storagegateway_local_disk.html aws_storagegateway_local_disk} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsStoragegatewayLocalDiskConfig);
        /**
         * @stability stable
         */
        get diskId(): string;
        private _diskNode?;
        /**
         * @stability stable
         */
        get diskNode(): string | undefined;
        /**
         * @stability stable
         */
        set diskNode(value: string | undefined);
        /**
         * @stability stable
         */
        resetDiskNode(): void;
        /**
         * @stability stable
         */
        get diskNodeInput(): string | undefined;
        private _diskPath?;
        /**
         * @stability stable
         */
        get diskPath(): string | undefined;
        /**
         * @stability stable
         */
        set diskPath(value: string | undefined);
        /**
         * @stability stable
         */
        resetDiskPath(): void;
        /**
         * @stability stable
         */
        get diskPathInput(): string | undefined;
        private _gatewayArn?;
        /**
         * @stability stable
         */
        get gatewayArn(): string;
        /**
         * @stability stable
         */
        set gatewayArn(value: string);
        /**
         * @stability stable
         */
        get gatewayArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
