import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Timestream Write
*/
export declare namespace TimestreamWrite {
    /**
     * @stability stable
     */
    interface TimestreamwriteDatabaseConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_database.html#database_name TimestreamwriteDatabase#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_database.html#kms_key_id TimestreamwriteDatabase#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_database.html#tags TimestreamwriteDatabase#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_database.html#tags_all TimestreamwriteDatabase#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_database.html aws_timestreamwrite_database}.
     *
     * @stability stable
     */
    class TimestreamwriteDatabase extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_database.html aws_timestreamwrite_database} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: TimestreamwriteDatabaseConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get tableCount(): number;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface TimestreamwriteTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html#database_name TimestreamwriteTable#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html#table_name TimestreamwriteTable#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html#tags TimestreamwriteTable#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html#tags_all TimestreamwriteTable#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * retention_properties block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html#retention_properties TimestreamwriteTable#retention_properties}
         *
         * @stability stable
         */
        readonly retentionProperties?: TimestreamwriteTableRetentionProperties;
    }
    /**
     * @stability stable
     */
    interface TimestreamwriteTableRetentionProperties {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html#magnetic_store_retention_period_in_days TimestreamwriteTable#magnetic_store_retention_period_in_days}.
         *
         * @stability stable
         */
        readonly magneticStoreRetentionPeriodInDays: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html#memory_store_retention_period_in_hours TimestreamwriteTable#memory_store_retention_period_in_hours}.
         *
         * @stability stable
         */
        readonly memoryStoreRetentionPeriodInHours: number;
    }
    /**
     * @stability stable
     */
    class TimestreamwriteTableRetentionPropertiesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _magneticStoreRetentionPeriodInDays?;
        /**
         * @stability stable
         */
        get magneticStoreRetentionPeriodInDays(): number;
        /**
         * @stability stable
         */
        set magneticStoreRetentionPeriodInDays(value: number);
        /**
         * @stability stable
         */
        get magneticStoreRetentionPeriodInDaysInput(): number | undefined;
        private _memoryStoreRetentionPeriodInHours?;
        /**
         * @stability stable
         */
        get memoryStoreRetentionPeriodInHours(): number;
        /**
         * @stability stable
         */
        set memoryStoreRetentionPeriodInHours(value: number);
        /**
         * @stability stable
         */
        get memoryStoreRetentionPeriodInHoursInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html aws_timestreamwrite_table}.
     *
     * @stability stable
     */
    class TimestreamwriteTable extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/timestreamwrite_table.html aws_timestreamwrite_table} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: TimestreamwriteTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _retentionProperties?;
        private __retentionPropertiesOutput;
        /**
         * @stability stable
         */
        get retentionProperties(): TimestreamwriteTableRetentionPropertiesOutputReference;
        /**
         * @stability stable
         */
        putRetentionProperties(value: TimestreamwriteTableRetentionProperties | undefined): void;
        /**
         * @stability stable
         */
        resetRetentionProperties(): void;
        /**
         * @stability stable
         */
        get retentionPropertiesInput(): TimestreamwriteTableRetentionProperties | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
