import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Transfer
*/
export declare namespace Transfer {
    /**
     * @stability stable
     */
    interface TransferAccessConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#external_id TransferAccess#external_id}.
         *
         * @stability stable
         */
        readonly externalId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#home_directory TransferAccess#home_directory}.
         *
         * @stability stable
         */
        readonly homeDirectory?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#home_directory_type TransferAccess#home_directory_type}.
         *
         * @stability stable
         */
        readonly homeDirectoryType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#policy TransferAccess#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#role TransferAccess#role}.
         *
         * @stability stable
         */
        readonly role?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#server_id TransferAccess#server_id}.
         *
         * @stability stable
         */
        readonly serverId: string;
        /**
         * home_directory_mappings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#home_directory_mappings TransferAccess#home_directory_mappings}
         *
         * @stability stable
         */
        readonly homeDirectoryMappings?: TransferAccessHomeDirectoryMappings[];
        /**
         * posix_profile block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#posix_profile TransferAccess#posix_profile}
         *
         * @stability stable
         */
        readonly posixProfile?: TransferAccessPosixProfile;
    }
    /**
     * @stability stable
     */
    interface TransferAccessHomeDirectoryMappings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#entry TransferAccess#entry}.
         *
         * @stability stable
         */
        readonly entry: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#target TransferAccess#target}.
         *
         * @stability stable
         */
        readonly target: string;
    }
    /**
     * @stability stable
     */
    interface TransferAccessPosixProfile {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#gid TransferAccess#gid}.
         *
         * @stability stable
         */
        readonly gid: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#secondary_gids TransferAccess#secondary_gids}.
         *
         * @stability stable
         */
        readonly secondaryGids?: number[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html#uid TransferAccess#uid}.
         *
         * @stability stable
         */
        readonly uid: number;
    }
    /**
     * @stability stable
     */
    class TransferAccessPosixProfileOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _gid?;
        /**
         * @stability stable
         */
        get gid(): number;
        /**
         * @stability stable
         */
        set gid(value: number);
        /**
         * @stability stable
         */
        get gidInput(): number | undefined;
        private _secondaryGids?;
        /**
         * @stability stable
         */
        get secondaryGids(): number[] | undefined;
        /**
         * @stability stable
         */
        set secondaryGids(value: number[] | undefined);
        /**
         * @stability stable
         */
        resetSecondaryGids(): void;
        /**
         * @stability stable
         */
        get secondaryGidsInput(): number[] | undefined;
        private _uid?;
        /**
         * @stability stable
         */
        get uid(): number;
        /**
         * @stability stable
         */
        set uid(value: number);
        /**
         * @stability stable
         */
        get uidInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html aws_transfer_access}.
     *
     * @stability stable
     */
    class TransferAccess extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_access.html aws_transfer_access} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: TransferAccessConfig);
        private _externalId?;
        /**
         * @stability stable
         */
        get externalId(): string;
        /**
         * @stability stable
         */
        set externalId(value: string);
        /**
         * @stability stable
         */
        get externalIdInput(): string | undefined;
        private _homeDirectory?;
        /**
         * @stability stable
         */
        get homeDirectory(): string | undefined;
        /**
         * @stability stable
         */
        set homeDirectory(value: string | undefined);
        /**
         * @stability stable
         */
        resetHomeDirectory(): void;
        /**
         * @stability stable
         */
        get homeDirectoryInput(): string | undefined;
        private _homeDirectoryType?;
        /**
         * @stability stable
         */
        get homeDirectoryType(): string | undefined;
        /**
         * @stability stable
         */
        set homeDirectoryType(value: string | undefined);
        /**
         * @stability stable
         */
        resetHomeDirectoryType(): void;
        /**
         * @stability stable
         */
        get homeDirectoryTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string | undefined;
        /**
         * @stability stable
         */
        set role(value: string | undefined);
        /**
         * @stability stable
         */
        resetRole(): void;
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        private _serverId?;
        /**
         * @stability stable
         */
        get serverId(): string;
        /**
         * @stability stable
         */
        set serverId(value: string);
        /**
         * @stability stable
         */
        get serverIdInput(): string | undefined;
        private _homeDirectoryMappings?;
        /**
         * @stability stable
         */
        get homeDirectoryMappings(): TransferAccessHomeDirectoryMappings[] | undefined;
        /**
         * @stability stable
         */
        set homeDirectoryMappings(value: TransferAccessHomeDirectoryMappings[] | undefined);
        /**
         * @stability stable
         */
        resetHomeDirectoryMappings(): void;
        /**
         * @stability stable
         */
        get homeDirectoryMappingsInput(): TransferAccessHomeDirectoryMappings[] | undefined;
        private _posixProfile?;
        private __posixProfileOutput;
        /**
         * @stability stable
         */
        get posixProfile(): TransferAccessPosixProfileOutputReference;
        /**
         * @stability stable
         */
        putPosixProfile(value: TransferAccessPosixProfile | undefined): void;
        /**
         * @stability stable
         */
        resetPosixProfile(): void;
        /**
         * @stability stable
         */
        get posixProfileInput(): TransferAccessPosixProfile | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface TransferServerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#certificate TransferServer#certificate}.
         *
         * @stability stable
         */
        readonly certificate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#directory_id TransferServer#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#domain TransferServer#domain}.
         *
         * @stability stable
         */
        readonly domain?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#endpoint_type TransferServer#endpoint_type}.
         *
         * @stability stable
         */
        readonly endpointType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#force_destroy TransferServer#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#host_key TransferServer#host_key}.
         *
         * @stability stable
         */
        readonly hostKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#identity_provider_type TransferServer#identity_provider_type}.
         *
         * @stability stable
         */
        readonly identityProviderType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#invocation_role TransferServer#invocation_role}.
         *
         * @stability stable
         */
        readonly invocationRole?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#logging_role TransferServer#logging_role}.
         *
         * @stability stable
         */
        readonly loggingRole?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#protocols TransferServer#protocols}.
         *
         * @stability stable
         */
        readonly protocols?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#security_policy_name TransferServer#security_policy_name}.
         *
         * @stability stable
         */
        readonly securityPolicyName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#tags TransferServer#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#tags_all TransferServer#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#url TransferServer#url}.
         *
         * @stability stable
         */
        readonly url?: string;
        /**
         * endpoint_details block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#endpoint_details TransferServer#endpoint_details}
         *
         * @stability stable
         */
        readonly endpointDetails?: TransferServerEndpointDetails;
    }
    /**
     * @stability stable
     */
    interface TransferServerEndpointDetails {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#address_allocation_ids TransferServer#address_allocation_ids}.
         *
         * @stability stable
         */
        readonly addressAllocationIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#security_group_ids TransferServer#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#subnet_ids TransferServer#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#vpc_endpoint_id TransferServer#vpc_endpoint_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html#vpc_id TransferServer#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
    }
    /**
     * @stability stable
     */
    class TransferServerEndpointDetailsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _addressAllocationIds?;
        /**
         * @stability stable
         */
        get addressAllocationIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set addressAllocationIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAddressAllocationIds(): void;
        /**
         * @stability stable
         */
        get addressAllocationIdsInput(): string[] | undefined;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnetIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetIds(): void;
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _vpcEndpointId?;
        /**
         * @stability stable
         */
        get vpcEndpointId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcEndpointId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcEndpointId(): void;
        /**
         * @stability stable
         */
        get vpcEndpointIdInput(): string | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html aws_transfer_server}.
     *
     * @stability stable
     */
    class TransferServer extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_server.html aws_transfer_server} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: TransferServerConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _certificate?;
        /**
         * @stability stable
         */
        get certificate(): string | undefined;
        /**
         * @stability stable
         */
        set certificate(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificate(): void;
        /**
         * @stability stable
         */
        get certificateInput(): string | undefined;
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string | undefined;
        /**
         * @stability stable
         */
        set directoryId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDirectoryId(): void;
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string | undefined;
        /**
         * @stability stable
         */
        set domain(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomain(): void;
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        private _endpointType?;
        /**
         * @stability stable
         */
        get endpointType(): string | undefined;
        /**
         * @stability stable
         */
        set endpointType(value: string | undefined);
        /**
         * @stability stable
         */
        resetEndpointType(): void;
        /**
         * @stability stable
         */
        get endpointTypeInput(): string | undefined;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        private _hostKey?;
        /**
         * @stability stable
         */
        get hostKey(): string | undefined;
        /**
         * @stability stable
         */
        set hostKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetHostKey(): void;
        /**
         * @stability stable
         */
        get hostKeyInput(): string | undefined;
        /**
         * @stability stable
         */
        get hostKeyFingerprint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _identityProviderType?;
        /**
         * @stability stable
         */
        get identityProviderType(): string | undefined;
        /**
         * @stability stable
         */
        set identityProviderType(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdentityProviderType(): void;
        /**
         * @stability stable
         */
        get identityProviderTypeInput(): string | undefined;
        private _invocationRole?;
        /**
         * @stability stable
         */
        get invocationRole(): string | undefined;
        /**
         * @stability stable
         */
        set invocationRole(value: string | undefined);
        /**
         * @stability stable
         */
        resetInvocationRole(): void;
        /**
         * @stability stable
         */
        get invocationRoleInput(): string | undefined;
        private _loggingRole?;
        /**
         * @stability stable
         */
        get loggingRole(): string | undefined;
        /**
         * @stability stable
         */
        set loggingRole(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoggingRole(): void;
        /**
         * @stability stable
         */
        get loggingRoleInput(): string | undefined;
        private _protocols?;
        /**
         * @stability stable
         */
        get protocols(): string[] | undefined;
        /**
         * @stability stable
         */
        set protocols(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetProtocols(): void;
        /**
         * @stability stable
         */
        get protocolsInput(): string[] | undefined;
        private _securityPolicyName?;
        /**
         * @stability stable
         */
        get securityPolicyName(): string | undefined;
        /**
         * @stability stable
         */
        set securityPolicyName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecurityPolicyName(): void;
        /**
         * @stability stable
         */
        get securityPolicyNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _url?;
        /**
         * @stability stable
         */
        get url(): string | undefined;
        /**
         * @stability stable
         */
        set url(value: string | undefined);
        /**
         * @stability stable
         */
        resetUrl(): void;
        /**
         * @stability stable
         */
        get urlInput(): string | undefined;
        private _endpointDetails?;
        private __endpointDetailsOutput;
        /**
         * @stability stable
         */
        get endpointDetails(): TransferServerEndpointDetailsOutputReference;
        /**
         * @stability stable
         */
        putEndpointDetails(value: TransferServerEndpointDetails | undefined): void;
        /**
         * @stability stable
         */
        resetEndpointDetails(): void;
        /**
         * @stability stable
         */
        get endpointDetailsInput(): TransferServerEndpointDetails | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface TransferSshKeyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_ssh_key.html#body TransferSshKey#body}.
         *
         * @stability stable
         */
        readonly body: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_ssh_key.html#server_id TransferSshKey#server_id}.
         *
         * @stability stable
         */
        readonly serverId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_ssh_key.html#user_name TransferSshKey#user_name}.
         *
         * @stability stable
         */
        readonly userName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/transfer_ssh_key.html aws_transfer_ssh_key}.
     *
     * @stability stable
     */
    class TransferSshKey extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_ssh_key.html aws_transfer_ssh_key} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: TransferSshKeyConfig);
        private _body?;
        /**
         * @stability stable
         */
        get body(): string;
        /**
         * @stability stable
         */
        set body(value: string);
        /**
         * @stability stable
         */
        get bodyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _serverId?;
        /**
         * @stability stable
         */
        get serverId(): string;
        /**
         * @stability stable
         */
        set serverId(value: string);
        /**
         * @stability stable
         */
        get serverIdInput(): string | undefined;
        private _userName?;
        /**
         * @stability stable
         */
        get userName(): string;
        /**
         * @stability stable
         */
        set userName(value: string);
        /**
         * @stability stable
         */
        get userNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface TransferUserConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#home_directory TransferUser#home_directory}.
         *
         * @stability stable
         */
        readonly homeDirectory?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#home_directory_type TransferUser#home_directory_type}.
         *
         * @stability stable
         */
        readonly homeDirectoryType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#policy TransferUser#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#role TransferUser#role}.
         *
         * @stability stable
         */
        readonly role: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#server_id TransferUser#server_id}.
         *
         * @stability stable
         */
        readonly serverId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#tags TransferUser#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#tags_all TransferUser#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#user_name TransferUser#user_name}.
         *
         * @stability stable
         */
        readonly userName: string;
        /**
         * home_directory_mappings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#home_directory_mappings TransferUser#home_directory_mappings}
         *
         * @stability stable
         */
        readonly homeDirectoryMappings?: TransferUserHomeDirectoryMappings[];
        /**
         * posix_profile block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#posix_profile TransferUser#posix_profile}
         *
         * @stability stable
         */
        readonly posixProfile?: TransferUserPosixProfile;
    }
    /**
     * @stability stable
     */
    interface TransferUserHomeDirectoryMappings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#entry TransferUser#entry}.
         *
         * @stability stable
         */
        readonly entry: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#target TransferUser#target}.
         *
         * @stability stable
         */
        readonly target: string;
    }
    /**
     * @stability stable
     */
    interface TransferUserPosixProfile {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#gid TransferUser#gid}.
         *
         * @stability stable
         */
        readonly gid: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#secondary_gids TransferUser#secondary_gids}.
         *
         * @stability stable
         */
        readonly secondaryGids?: number[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html#uid TransferUser#uid}.
         *
         * @stability stable
         */
        readonly uid: number;
    }
    /**
     * @stability stable
     */
    class TransferUserPosixProfileOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _gid?;
        /**
         * @stability stable
         */
        get gid(): number;
        /**
         * @stability stable
         */
        set gid(value: number);
        /**
         * @stability stable
         */
        get gidInput(): number | undefined;
        private _secondaryGids?;
        /**
         * @stability stable
         */
        get secondaryGids(): number[] | undefined;
        /**
         * @stability stable
         */
        set secondaryGids(value: number[] | undefined);
        /**
         * @stability stable
         */
        resetSecondaryGids(): void;
        /**
         * @stability stable
         */
        get secondaryGidsInput(): number[] | undefined;
        private _uid?;
        /**
         * @stability stable
         */
        get uid(): number;
        /**
         * @stability stable
         */
        set uid(value: number);
        /**
         * @stability stable
         */
        get uidInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html aws_transfer_user}.
     *
     * @stability stable
     */
    class TransferUser extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/transfer_user.html aws_transfer_user} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: TransferUserConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _homeDirectory?;
        /**
         * @stability stable
         */
        get homeDirectory(): string | undefined;
        /**
         * @stability stable
         */
        set homeDirectory(value: string | undefined);
        /**
         * @stability stable
         */
        resetHomeDirectory(): void;
        /**
         * @stability stable
         */
        get homeDirectoryInput(): string | undefined;
        private _homeDirectoryType?;
        /**
         * @stability stable
         */
        get homeDirectoryType(): string | undefined;
        /**
         * @stability stable
         */
        set homeDirectoryType(value: string | undefined);
        /**
         * @stability stable
         */
        resetHomeDirectoryType(): void;
        /**
         * @stability stable
         */
        get homeDirectoryTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        set role(value: string);
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        private _serverId?;
        /**
         * @stability stable
         */
        get serverId(): string;
        /**
         * @stability stable
         */
        set serverId(value: string);
        /**
         * @stability stable
         */
        get serverIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _userName?;
        /**
         * @stability stable
         */
        get userName(): string;
        /**
         * @stability stable
         */
        set userName(value: string);
        /**
         * @stability stable
         */
        get userNameInput(): string | undefined;
        private _homeDirectoryMappings?;
        /**
         * @stability stable
         */
        get homeDirectoryMappings(): TransferUserHomeDirectoryMappings[] | undefined;
        /**
         * @stability stable
         */
        set homeDirectoryMappings(value: TransferUserHomeDirectoryMappings[] | undefined);
        /**
         * @stability stable
         */
        resetHomeDirectoryMappings(): void;
        /**
         * @stability stable
         */
        get homeDirectoryMappingsInput(): TransferUserHomeDirectoryMappings[] | undefined;
        private _posixProfile?;
        private __posixProfileOutput;
        /**
         * @stability stable
         */
        get posixProfile(): TransferUserPosixProfileOutputReference;
        /**
         * @stability stable
         */
        putPosixProfile(value: TransferUserPosixProfile | undefined): void;
        /**
         * @stability stable
         */
        resetPosixProfile(): void;
        /**
         * @stability stable
         */
        get posixProfileInput(): TransferUserPosixProfile | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsTransferServerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/transfer_server.html#server_id DataAwsTransferServer#server_id}.
         *
         * @stability stable
         */
        readonly serverId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/transfer_server.html aws_transfer_server}.
     *
     * @stability stable
     */
    class DataAwsTransferServer extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/transfer_server.html aws_transfer_server} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsTransferServerConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificate(): string;
        /**
         * @stability stable
         */
        get domain(): string;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get endpointType(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get identityProviderType(): string;
        /**
         * @stability stable
         */
        get invocationRole(): string;
        /**
         * @stability stable
         */
        get loggingRole(): string;
        /**
         * @stability stable
         */
        get protocols(): string[];
        /**
         * @stability stable
         */
        get securityPolicyName(): string;
        private _serverId?;
        /**
         * @stability stable
         */
        get serverId(): string;
        /**
         * @stability stable
         */
        set serverId(value: string);
        /**
         * @stability stable
         */
        get serverIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get url(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
