import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS WorkSpaces
*/
export declare namespace Workspaces {
    /**
     * @stability stable
     */
    interface WorkspacesDirectoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#directory_id WorkspacesDirectory#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#ip_group_ids WorkspacesDirectory#ip_group_ids}.
         *
         * @stability stable
         */
        readonly ipGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#subnet_ids WorkspacesDirectory#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#tags WorkspacesDirectory#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#tags_all WorkspacesDirectory#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * self_service_permissions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#self_service_permissions WorkspacesDirectory#self_service_permissions}
         *
         * @stability stable
         */
        readonly selfServicePermissions?: WorkspacesDirectorySelfServicePermissions;
        /**
         * workspace_access_properties block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#workspace_access_properties WorkspacesDirectory#workspace_access_properties}
         *
         * @stability stable
         */
        readonly workspaceAccessProperties?: WorkspacesDirectoryWorkspaceAccessProperties;
        /**
         * workspace_creation_properties block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#workspace_creation_properties WorkspacesDirectory#workspace_creation_properties}
         *
         * @stability stable
         */
        readonly workspaceCreationProperties?: WorkspacesDirectoryWorkspaceCreationProperties;
    }
    /**
     * @stability stable
     */
    interface WorkspacesDirectorySelfServicePermissions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#change_compute_type WorkspacesDirectory#change_compute_type}.
         *
         * @stability stable
         */
        readonly changeComputeType?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#increase_volume_size WorkspacesDirectory#increase_volume_size}.
         *
         * @stability stable
         */
        readonly increaseVolumeSize?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#rebuild_workspace WorkspacesDirectory#rebuild_workspace}.
         *
         * @stability stable
         */
        readonly rebuildWorkspace?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#restart_workspace WorkspacesDirectory#restart_workspace}.
         *
         * @stability stable
         */
        readonly restartWorkspace?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#switch_running_mode WorkspacesDirectory#switch_running_mode}.
         *
         * @stability stable
         */
        readonly switchRunningMode?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class WorkspacesDirectorySelfServicePermissionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _changeComputeType?;
        /**
         * @stability stable
         */
        get changeComputeType(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set changeComputeType(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetChangeComputeType(): void;
        /**
         * @stability stable
         */
        get changeComputeTypeInput(): boolean | cdktf.IResolvable | undefined;
        private _increaseVolumeSize?;
        /**
         * @stability stable
         */
        get increaseVolumeSize(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set increaseVolumeSize(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncreaseVolumeSize(): void;
        /**
         * @stability stable
         */
        get increaseVolumeSizeInput(): boolean | cdktf.IResolvable | undefined;
        private _rebuildWorkspace?;
        /**
         * @stability stable
         */
        get rebuildWorkspace(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set rebuildWorkspace(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRebuildWorkspace(): void;
        /**
         * @stability stable
         */
        get rebuildWorkspaceInput(): boolean | cdktf.IResolvable | undefined;
        private _restartWorkspace?;
        /**
         * @stability stable
         */
        get restartWorkspace(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set restartWorkspace(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRestartWorkspace(): void;
        /**
         * @stability stable
         */
        get restartWorkspaceInput(): boolean | cdktf.IResolvable | undefined;
        private _switchRunningMode?;
        /**
         * @stability stable
         */
        get switchRunningMode(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set switchRunningMode(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSwitchRunningMode(): void;
        /**
         * @stability stable
         */
        get switchRunningModeInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface WorkspacesDirectoryWorkspaceAccessProperties {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_android WorkspacesDirectory#device_type_android}.
         *
         * @stability stable
         */
        readonly deviceTypeAndroid?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_chromeos WorkspacesDirectory#device_type_chromeos}.
         *
         * @stability stable
         */
        readonly deviceTypeChromeos?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_ios WorkspacesDirectory#device_type_ios}.
         *
         * @stability stable
         */
        readonly deviceTypeIos?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_linux WorkspacesDirectory#device_type_linux}.
         *
         * @stability stable
         */
        readonly deviceTypeLinux?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_osx WorkspacesDirectory#device_type_osx}.
         *
         * @stability stable
         */
        readonly deviceTypeOsx?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_web WorkspacesDirectory#device_type_web}.
         *
         * @stability stable
         */
        readonly deviceTypeWeb?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_windows WorkspacesDirectory#device_type_windows}.
         *
         * @stability stable
         */
        readonly deviceTypeWindows?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#device_type_zeroclient WorkspacesDirectory#device_type_zeroclient}.
         *
         * @stability stable
         */
        readonly deviceTypeZeroclient?: string;
    }
    /**
     * @stability stable
     */
    class WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _deviceTypeAndroid?;
        /**
         * @stability stable
         */
        get deviceTypeAndroid(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeAndroid(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeAndroid(): void;
        /**
         * @stability stable
         */
        get deviceTypeAndroidInput(): string | undefined;
        private _deviceTypeChromeos?;
        /**
         * @stability stable
         */
        get deviceTypeChromeos(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeChromeos(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeChromeos(): void;
        /**
         * @stability stable
         */
        get deviceTypeChromeosInput(): string | undefined;
        private _deviceTypeIos?;
        /**
         * @stability stable
         */
        get deviceTypeIos(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeIos(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeIos(): void;
        /**
         * @stability stable
         */
        get deviceTypeIosInput(): string | undefined;
        private _deviceTypeLinux?;
        /**
         * @stability stable
         */
        get deviceTypeLinux(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeLinux(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeLinux(): void;
        /**
         * @stability stable
         */
        get deviceTypeLinuxInput(): string | undefined;
        private _deviceTypeOsx?;
        /**
         * @stability stable
         */
        get deviceTypeOsx(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeOsx(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeOsx(): void;
        /**
         * @stability stable
         */
        get deviceTypeOsxInput(): string | undefined;
        private _deviceTypeWeb?;
        /**
         * @stability stable
         */
        get deviceTypeWeb(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeWeb(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeWeb(): void;
        /**
         * @stability stable
         */
        get deviceTypeWebInput(): string | undefined;
        private _deviceTypeWindows?;
        /**
         * @stability stable
         */
        get deviceTypeWindows(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeWindows(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeWindows(): void;
        /**
         * @stability stable
         */
        get deviceTypeWindowsInput(): string | undefined;
        private _deviceTypeZeroclient?;
        /**
         * @stability stable
         */
        get deviceTypeZeroclient(): string | undefined;
        /**
         * @stability stable
         */
        set deviceTypeZeroclient(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceTypeZeroclient(): void;
        /**
         * @stability stable
         */
        get deviceTypeZeroclientInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface WorkspacesDirectoryWorkspaceCreationProperties {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#custom_security_group_id WorkspacesDirectory#custom_security_group_id}.
         *
         * @stability stable
         */
        readonly customSecurityGroupId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#default_ou WorkspacesDirectory#default_ou}.
         *
         * @stability stable
         */
        readonly defaultOu?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#enable_internet_access WorkspacesDirectory#enable_internet_access}.
         *
         * @stability stable
         */
        readonly enableInternetAccess?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#enable_maintenance_mode WorkspacesDirectory#enable_maintenance_mode}.
         *
         * @stability stable
         */
        readonly enableMaintenanceMode?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html#user_enabled_as_local_administrator WorkspacesDirectory#user_enabled_as_local_administrator}.
         *
         * @stability stable
         */
        readonly userEnabledAsLocalAdministrator?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _customSecurityGroupId?;
        /**
         * @stability stable
         */
        get customSecurityGroupId(): string | undefined;
        /**
         * @stability stable
         */
        set customSecurityGroupId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomSecurityGroupId(): void;
        /**
         * @stability stable
         */
        get customSecurityGroupIdInput(): string | undefined;
        private _defaultOu?;
        /**
         * @stability stable
         */
        get defaultOu(): string | undefined;
        /**
         * @stability stable
         */
        set defaultOu(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefaultOu(): void;
        /**
         * @stability stable
         */
        get defaultOuInput(): string | undefined;
        private _enableInternetAccess?;
        /**
         * @stability stable
         */
        get enableInternetAccess(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableInternetAccess(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableInternetAccess(): void;
        /**
         * @stability stable
         */
        get enableInternetAccessInput(): boolean | cdktf.IResolvable | undefined;
        private _enableMaintenanceMode?;
        /**
         * @stability stable
         */
        get enableMaintenanceMode(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableMaintenanceMode(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableMaintenanceMode(): void;
        /**
         * @stability stable
         */
        get enableMaintenanceModeInput(): boolean | cdktf.IResolvable | undefined;
        private _userEnabledAsLocalAdministrator?;
        /**
         * @stability stable
         */
        get userEnabledAsLocalAdministrator(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set userEnabledAsLocalAdministrator(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetUserEnabledAsLocalAdministrator(): void;
        /**
         * @stability stable
         */
        get userEnabledAsLocalAdministratorInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html aws_workspaces_directory}.
     *
     * @stability stable
     */
    class WorkspacesDirectory extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_directory.html aws_workspaces_directory} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: WorkspacesDirectoryConfig);
        /**
         * @stability stable
         */
        get alias(): string;
        /**
         * @stability stable
         */
        get customerUserName(): string;
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string;
        /**
         * @stability stable
         */
        set directoryId(value: string);
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get directoryName(): string;
        /**
         * @stability stable
         */
        get directoryType(): string;
        /**
         * @stability stable
         */
        get dnsIpAddresses(): string[];
        /**
         * @stability stable
         */
        get iamRoleId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipGroupIds?;
        /**
         * @stability stable
         */
        get ipGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set ipGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetIpGroupIds(): void;
        /**
         * @stability stable
         */
        get ipGroupIdsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get registrationCode(): string;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnetIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetIds(): void;
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get workspaceSecurityGroupId(): string;
        private _selfServicePermissions?;
        private __selfServicePermissionsOutput;
        /**
         * @stability stable
         */
        get selfServicePermissions(): WorkspacesDirectorySelfServicePermissionsOutputReference;
        /**
         * @stability stable
         */
        putSelfServicePermissions(value: WorkspacesDirectorySelfServicePermissions | undefined): void;
        /**
         * @stability stable
         */
        resetSelfServicePermissions(): void;
        /**
         * @stability stable
         */
        get selfServicePermissionsInput(): WorkspacesDirectorySelfServicePermissions | undefined;
        private _workspaceAccessProperties?;
        private __workspaceAccessPropertiesOutput;
        /**
         * @stability stable
         */
        get workspaceAccessProperties(): WorkspacesDirectoryWorkspaceAccessPropertiesOutputReference;
        /**
         * @stability stable
         */
        putWorkspaceAccessProperties(value: WorkspacesDirectoryWorkspaceAccessProperties | undefined): void;
        /**
         * @stability stable
         */
        resetWorkspaceAccessProperties(): void;
        /**
         * @stability stable
         */
        get workspaceAccessPropertiesInput(): WorkspacesDirectoryWorkspaceAccessProperties | undefined;
        private _workspaceCreationProperties?;
        private __workspaceCreationPropertiesOutput;
        /**
         * @stability stable
         */
        get workspaceCreationProperties(): WorkspacesDirectoryWorkspaceCreationPropertiesOutputReference;
        /**
         * @stability stable
         */
        putWorkspaceCreationProperties(value: WorkspacesDirectoryWorkspaceCreationProperties | undefined): void;
        /**
         * @stability stable
         */
        resetWorkspaceCreationProperties(): void;
        /**
         * @stability stable
         */
        get workspaceCreationPropertiesInput(): WorkspacesDirectoryWorkspaceCreationProperties | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface WorkspacesIpGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html#description WorkspacesIpGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html#name WorkspacesIpGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html#tags WorkspacesIpGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html#tags_all WorkspacesIpGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * rules block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html#rules WorkspacesIpGroup#rules}
         *
         * @stability stable
         */
        readonly rules?: WorkspacesIpGroupRules[];
    }
    /**
     * @stability stable
     */
    interface WorkspacesIpGroupRules {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html#description WorkspacesIpGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html#source WorkspacesIpGroup#source}.
         *
         * @stability stable
         */
        readonly source: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html aws_workspaces_ip_group}.
     *
     * @stability stable
     */
    class WorkspacesIpGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_ip_group.html aws_workspaces_ip_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: WorkspacesIpGroupConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _rules?;
        /**
         * @stability stable
         */
        get rules(): WorkspacesIpGroupRules[] | undefined;
        /**
         * @stability stable
         */
        set rules(value: WorkspacesIpGroupRules[] | undefined);
        /**
         * @stability stable
         */
        resetRules(): void;
        /**
         * @stability stable
         */
        get rulesInput(): WorkspacesIpGroupRules[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface WorkspacesWorkspaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#bundle_id WorkspacesWorkspace#bundle_id}.
         *
         * @stability stable
         */
        readonly bundleId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#directory_id WorkspacesWorkspace#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#root_volume_encryption_enabled WorkspacesWorkspace#root_volume_encryption_enabled}.
         *
         * @stability stable
         */
        readonly rootVolumeEncryptionEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#tags WorkspacesWorkspace#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#tags_all WorkspacesWorkspace#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#user_name WorkspacesWorkspace#user_name}.
         *
         * @stability stable
         */
        readonly userName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#user_volume_encryption_enabled WorkspacesWorkspace#user_volume_encryption_enabled}.
         *
         * @stability stable
         */
        readonly userVolumeEncryptionEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#volume_encryption_key WorkspacesWorkspace#volume_encryption_key}.
         *
         * @stability stable
         */
        readonly volumeEncryptionKey?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#timeouts WorkspacesWorkspace#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: WorkspacesWorkspaceTimeouts;
        /**
         * workspace_properties block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#workspace_properties WorkspacesWorkspace#workspace_properties}
         *
         * @stability stable
         */
        readonly workspaceProperties?: WorkspacesWorkspaceWorkspaceProperties;
    }
    /**
     * @stability stable
     */
    interface WorkspacesWorkspaceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#create WorkspacesWorkspace#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#delete WorkspacesWorkspace#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#update WorkspacesWorkspace#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class WorkspacesWorkspaceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface WorkspacesWorkspaceWorkspaceProperties {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#compute_type_name WorkspacesWorkspace#compute_type_name}.
         *
         * @stability stable
         */
        readonly computeTypeName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#root_volume_size_gib WorkspacesWorkspace#root_volume_size_gib}.
         *
         * @stability stable
         */
        readonly rootVolumeSizeGib?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#running_mode WorkspacesWorkspace#running_mode}.
         *
         * @stability stable
         */
        readonly runningMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#running_mode_auto_stop_timeout_in_minutes WorkspacesWorkspace#running_mode_auto_stop_timeout_in_minutes}.
         *
         * @stability stable
         */
        readonly runningModeAutoStopTimeoutInMinutes?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html#user_volume_size_gib WorkspacesWorkspace#user_volume_size_gib}.
         *
         * @stability stable
         */
        readonly userVolumeSizeGib?: number;
    }
    /**
     * @stability stable
     */
    class WorkspacesWorkspaceWorkspacePropertiesOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _computeTypeName?;
        /**
         * @stability stable
         */
        get computeTypeName(): string | undefined;
        /**
         * @stability stable
         */
        set computeTypeName(value: string | undefined);
        /**
         * @stability stable
         */
        resetComputeTypeName(): void;
        /**
         * @stability stable
         */
        get computeTypeNameInput(): string | undefined;
        private _rootVolumeSizeGib?;
        /**
         * @stability stable
         */
        get rootVolumeSizeGib(): number | undefined;
        /**
         * @stability stable
         */
        set rootVolumeSizeGib(value: number | undefined);
        /**
         * @stability stable
         */
        resetRootVolumeSizeGib(): void;
        /**
         * @stability stable
         */
        get rootVolumeSizeGibInput(): number | undefined;
        private _runningMode?;
        /**
         * @stability stable
         */
        get runningMode(): string | undefined;
        /**
         * @stability stable
         */
        set runningMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetRunningMode(): void;
        /**
         * @stability stable
         */
        get runningModeInput(): string | undefined;
        private _runningModeAutoStopTimeoutInMinutes?;
        /**
         * @stability stable
         */
        get runningModeAutoStopTimeoutInMinutes(): number | undefined;
        /**
         * @stability stable
         */
        set runningModeAutoStopTimeoutInMinutes(value: number | undefined);
        /**
         * @stability stable
         */
        resetRunningModeAutoStopTimeoutInMinutes(): void;
        /**
         * @stability stable
         */
        get runningModeAutoStopTimeoutInMinutesInput(): number | undefined;
        private _userVolumeSizeGib?;
        /**
         * @stability stable
         */
        get userVolumeSizeGib(): number | undefined;
        /**
         * @stability stable
         */
        set userVolumeSizeGib(value: number | undefined);
        /**
         * @stability stable
         */
        resetUserVolumeSizeGib(): void;
        /**
         * @stability stable
         */
        get userVolumeSizeGibInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html aws_workspaces_workspace}.
     *
     * @stability stable
     */
    class WorkspacesWorkspace extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/workspaces_workspace.html aws_workspaces_workspace} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: WorkspacesWorkspaceConfig);
        private _bundleId?;
        /**
         * @stability stable
         */
        get bundleId(): string;
        /**
         * @stability stable
         */
        set bundleId(value: string);
        /**
         * @stability stable
         */
        get bundleIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get computerName(): string;
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string;
        /**
         * @stability stable
         */
        set directoryId(value: string);
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipAddress(): string;
        private _rootVolumeEncryptionEnabled?;
        /**
         * @stability stable
         */
        get rootVolumeEncryptionEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set rootVolumeEncryptionEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRootVolumeEncryptionEnabled(): void;
        /**
         * @stability stable
         */
        get rootVolumeEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get state(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _userName?;
        /**
         * @stability stable
         */
        get userName(): string;
        /**
         * @stability stable
         */
        set userName(value: string);
        /**
         * @stability stable
         */
        get userNameInput(): string | undefined;
        private _userVolumeEncryptionEnabled?;
        /**
         * @stability stable
         */
        get userVolumeEncryptionEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set userVolumeEncryptionEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetUserVolumeEncryptionEnabled(): void;
        /**
         * @stability stable
         */
        get userVolumeEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _volumeEncryptionKey?;
        /**
         * @stability stable
         */
        get volumeEncryptionKey(): string | undefined;
        /**
         * @stability stable
         */
        set volumeEncryptionKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetVolumeEncryptionKey(): void;
        /**
         * @stability stable
         */
        get volumeEncryptionKeyInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): WorkspacesWorkspaceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: WorkspacesWorkspaceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): WorkspacesWorkspaceTimeouts | undefined;
        private _workspaceProperties?;
        private __workspacePropertiesOutput;
        /**
         * @stability stable
         */
        get workspaceProperties(): WorkspacesWorkspaceWorkspacePropertiesOutputReference;
        /**
         * @stability stable
         */
        putWorkspaceProperties(value: WorkspacesWorkspaceWorkspaceProperties | undefined): void;
        /**
         * @stability stable
         */
        resetWorkspaceProperties(): void;
        /**
         * @stability stable
         */
        get workspacePropertiesInput(): WorkspacesWorkspaceWorkspaceProperties | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsWorkspacesBundleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_bundle.html#bundle_id DataAwsWorkspacesBundle#bundle_id}.
         *
         * @stability stable
         */
        readonly bundleId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_bundle.html#name DataAwsWorkspacesBundle#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_bundle.html#owner DataAwsWorkspacesBundle#owner}.
         *
         * @stability stable
         */
        readonly owner?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsWorkspacesBundleComputeType extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get name(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsWorkspacesBundleRootStorage extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get capacity(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsWorkspacesBundleUserStorage extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get capacity(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/workspaces_bundle.html aws_workspaces_bundle}.
     *
     * @stability stable
     */
    class DataAwsWorkspacesBundle extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/workspaces_bundle.html aws_workspaces_bundle} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsWorkspacesBundleConfig);
        private _bundleId?;
        /**
         * @stability stable
         */
        get bundleId(): string | undefined;
        /**
         * @stability stable
         */
        set bundleId(value: string | undefined);
        /**
         * @stability stable
         */
        resetBundleId(): void;
        /**
         * @stability stable
         */
        get bundleIdInput(): string | undefined;
        /**
         * @stability stable
         */
        computeType(index: string): DataAwsWorkspacesBundleComputeType;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _owner?;
        /**
         * @stability stable
         */
        get owner(): string | undefined;
        /**
         * @stability stable
         */
        set owner(value: string | undefined);
        /**
         * @stability stable
         */
        resetOwner(): void;
        /**
         * @stability stable
         */
        get ownerInput(): string | undefined;
        /**
         * @stability stable
         */
        rootStorage(index: string): DataAwsWorkspacesBundleRootStorage;
        /**
         * @stability stable
         */
        userStorage(index: string): DataAwsWorkspacesBundleUserStorage;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsWorkspacesDirectoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory.html#directory_id DataAwsWorkspacesDirectory#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory.html#tags DataAwsWorkspacesDirectory#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsWorkspacesDirectorySelfServicePermissions extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get changeComputeType(): any;
        /**
         * @stability stable
         */
        get increaseVolumeSize(): any;
        /**
         * @stability stable
         */
        get rebuildWorkspace(): any;
        /**
         * @stability stable
         */
        get restartWorkspace(): any;
        /**
         * @stability stable
         */
        get switchRunningMode(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsWorkspacesDirectoryWorkspaceAccessProperties extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get deviceTypeAndroid(): string;
        /**
         * @stability stable
         */
        get deviceTypeChromeos(): string;
        /**
         * @stability stable
         */
        get deviceTypeIos(): string;
        /**
         * @stability stable
         */
        get deviceTypeLinux(): string;
        /**
         * @stability stable
         */
        get deviceTypeOsx(): string;
        /**
         * @stability stable
         */
        get deviceTypeWeb(): string;
        /**
         * @stability stable
         */
        get deviceTypeWindows(): string;
        /**
         * @stability stable
         */
        get deviceTypeZeroclient(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsWorkspacesDirectoryWorkspaceCreationProperties extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get customSecurityGroupId(): string;
        /**
         * @stability stable
         */
        get defaultOu(): string;
        /**
         * @stability stable
         */
        get enableInternetAccess(): any;
        /**
         * @stability stable
         */
        get enableMaintenanceMode(): any;
        /**
         * @stability stable
         */
        get userEnabledAsLocalAdministrator(): any;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory.html aws_workspaces_directory}.
     *
     * @stability stable
     */
    class DataAwsWorkspacesDirectory extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/workspaces_directory.html aws_workspaces_directory} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsWorkspacesDirectoryConfig);
        /**
         * @stability stable
         */
        get alias(): string;
        /**
         * @stability stable
         */
        get customerUserName(): string;
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string;
        /**
         * @stability stable
         */
        set directoryId(value: string);
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get directoryName(): string;
        /**
         * @stability stable
         */
        get directoryType(): string;
        /**
         * @stability stable
         */
        get dnsIpAddresses(): string[];
        /**
         * @stability stable
         */
        get iamRoleId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipGroupIds(): string[];
        /**
         * @stability stable
         */
        get registrationCode(): string;
        /**
         * @stability stable
         */
        selfServicePermissions(index: string): DataAwsWorkspacesDirectorySelfServicePermissions;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        workspaceAccessProperties(index: string): DataAwsWorkspacesDirectoryWorkspaceAccessProperties;
        /**
         * @stability stable
         */
        workspaceCreationProperties(index: string): DataAwsWorkspacesDirectoryWorkspaceCreationProperties;
        /**
         * @stability stable
         */
        get workspaceSecurityGroupId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsWorkspacesImageConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_image.html#image_id DataAwsWorkspacesImage#image_id}.
         *
         * @stability stable
         */
        readonly imageId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/workspaces_image.html aws_workspaces_image}.
     *
     * @stability stable
     */
    class DataAwsWorkspacesImage extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/workspaces_image.html aws_workspaces_image} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsWorkspacesImageConfig);
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _imageId?;
        /**
         * @stability stable
         */
        get imageId(): string;
        /**
         * @stability stable
         */
        set imageId(value: string);
        /**
         * @stability stable
         */
        get imageIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get operatingSystemType(): string;
        /**
         * @stability stable
         */
        get requiredTenancy(): string;
        /**
         * @stability stable
         */
        get state(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsWorkspacesWorkspaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_workspace.html#directory_id DataAwsWorkspacesWorkspace#directory_id}.
         *
         * @stability stable
         */
        readonly directoryId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_workspace.html#tags DataAwsWorkspacesWorkspace#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_workspace.html#user_name DataAwsWorkspacesWorkspace#user_name}.
         *
         * @stability stable
         */
        readonly userName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/workspaces_workspace.html#workspace_id DataAwsWorkspacesWorkspace#workspace_id}.
         *
         * @stability stable
         */
        readonly workspaceId?: string;
    }
    /**
     * @stability stable
     */
    class DataAwsWorkspacesWorkspaceWorkspaceProperties extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get computeTypeName(): string;
        /**
         * @stability stable
         */
        get rootVolumeSizeGib(): number;
        /**
         * @stability stable
         */
        get runningMode(): string;
        /**
         * @stability stable
         */
        get runningModeAutoStopTimeoutInMinutes(): number;
        /**
         * @stability stable
         */
        get userVolumeSizeGib(): number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/workspaces_workspace.html aws_workspaces_workspace}.
     *
     * @stability stable
     */
    class DataAwsWorkspacesWorkspace extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/workspaces_workspace.html aws_workspaces_workspace} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsWorkspacesWorkspaceConfig);
        /**
         * @stability stable
         */
        get bundleId(): string;
        /**
         * @stability stable
         */
        get computerName(): string;
        private _directoryId?;
        /**
         * @stability stable
         */
        get directoryId(): string | undefined;
        /**
         * @stability stable
         */
        set directoryId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDirectoryId(): void;
        /**
         * @stability stable
         */
        get directoryIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipAddress(): string;
        /**
         * @stability stable
         */
        get rootVolumeEncryptionEnabled(): any;
        /**
         * @stability stable
         */
        get state(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _userName?;
        /**
         * @stability stable
         */
        get userName(): string | undefined;
        /**
         * @stability stable
         */
        set userName(value: string | undefined);
        /**
         * @stability stable
         */
        resetUserName(): void;
        /**
         * @stability stable
         */
        get userNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get userVolumeEncryptionEnabled(): any;
        /**
         * @stability stable
         */
        get volumeEncryptionKey(): string;
        private _workspaceId?;
        /**
         * @stability stable
         */
        get workspaceId(): string | undefined;
        /**
         * @stability stable
         */
        set workspaceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetWorkspaceId(): void;
        /**
         * @stability stable
         */
        get workspaceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        workspaceProperties(index: string): DataAwsWorkspacesWorkspaceWorkspaceProperties;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
