import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Elastic Load Balancer
*/
export declare namespace ELB {
    /**
     * @stability stable
     */
    interface AlbConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#customer_owned_ipv4_pool Alb#customer_owned_ipv4_pool}.
         *
         * @stability stable
         */
        readonly customerOwnedIpv4Pool?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#drop_invalid_header_fields Alb#drop_invalid_header_fields}.
         *
         * @stability stable
         */
        readonly dropInvalidHeaderFields?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#enable_cross_zone_load_balancing Alb#enable_cross_zone_load_balancing}.
         *
         * @stability stable
         */
        readonly enableCrossZoneLoadBalancing?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#enable_deletion_protection Alb#enable_deletion_protection}.
         *
         * @stability stable
         */
        readonly enableDeletionProtection?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#enable_http2 Alb#enable_http2}.
         *
         * @stability stable
         */
        readonly enableHttp2?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#idle_timeout Alb#idle_timeout}.
         *
         * @stability stable
         */
        readonly idleTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#internal Alb#internal}.
         *
         * @stability stable
         */
        readonly internal?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#ip_address_type Alb#ip_address_type}.
         *
         * @stability stable
         */
        readonly ipAddressType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#load_balancer_type Alb#load_balancer_type}.
         *
         * @stability stable
         */
        readonly loadBalancerType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#name Alb#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#name_prefix Alb#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#security_groups Alb#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#subnets Alb#subnets}.
         *
         * @stability stable
         */
        readonly subnets?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#tags Alb#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#tags_all Alb#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * access_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#access_logs Alb#access_logs}
         *
         * @stability stable
         */
        readonly accessLogs?: AlbAccessLogs;
        /**
         * subnet_mapping block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#subnet_mapping Alb#subnet_mapping}
         *
         * @stability stable
         */
        readonly subnetMapping?: AlbSubnetMapping[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#timeouts Alb#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: AlbTimeouts;
    }
    /**
     * @stability stable
     */
    interface AlbAccessLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#bucket Alb#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#enabled Alb#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#prefix Alb#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
    }
    /**
     * @stability stable
     */
    class AlbAccessLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbSubnetMapping {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#allocation_id Alb#allocation_id}.
         *
         * @stability stable
         */
        readonly allocationId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#ipv6_address Alb#ipv6_address}.
         *
         * @stability stable
         */
        readonly ipv6Address?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#private_ipv4_address Alb#private_ipv4_address}.
         *
         * @stability stable
         */
        readonly privateIpv4Address?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#subnet_id Alb#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId: string;
    }
    /**
     * @stability stable
     */
    interface AlbTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#create Alb#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#delete Alb#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb.html#update Alb#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class AlbTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb.html aws_alb}.
     *
     * @stability stable
     */
    class Alb extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb.html aws_alb} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: AlbConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        private _customerOwnedIpv4Pool?;
        /**
         * @stability stable
         */
        get customerOwnedIpv4Pool(): string | undefined;
        /**
         * @stability stable
         */
        set customerOwnedIpv4Pool(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerOwnedIpv4Pool(): void;
        /**
         * @stability stable
         */
        get customerOwnedIpv4PoolInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        private _dropInvalidHeaderFields?;
        /**
         * @stability stable
         */
        get dropInvalidHeaderFields(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set dropInvalidHeaderFields(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDropInvalidHeaderFields(): void;
        /**
         * @stability stable
         */
        get dropInvalidHeaderFieldsInput(): boolean | cdktf.IResolvable | undefined;
        private _enableCrossZoneLoadBalancing?;
        /**
         * @stability stable
         */
        get enableCrossZoneLoadBalancing(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableCrossZoneLoadBalancing(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableCrossZoneLoadBalancing(): void;
        /**
         * @stability stable
         */
        get enableCrossZoneLoadBalancingInput(): boolean | cdktf.IResolvable | undefined;
        private _enableDeletionProtection?;
        /**
         * @stability stable
         */
        get enableDeletionProtection(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableDeletionProtection(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableDeletionProtection(): void;
        /**
         * @stability stable
         */
        get enableDeletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
        private _enableHttp2?;
        /**
         * @stability stable
         */
        get enableHttp2(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableHttp2(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableHttp2(): void;
        /**
         * @stability stable
         */
        get enableHttp2Input(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _idleTimeout?;
        /**
         * @stability stable
         */
        get idleTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set idleTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetIdleTimeout(): void;
        /**
         * @stability stable
         */
        get idleTimeoutInput(): number | undefined;
        private _internal?;
        /**
         * @stability stable
         */
        get internal(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set internal(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInternal(): void;
        /**
         * @stability stable
         */
        get internalInput(): boolean | cdktf.IResolvable | undefined;
        private _ipAddressType?;
        /**
         * @stability stable
         */
        get ipAddressType(): string | undefined;
        /**
         * @stability stable
         */
        set ipAddressType(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpAddressType(): void;
        /**
         * @stability stable
         */
        get ipAddressTypeInput(): string | undefined;
        private _loadBalancerType?;
        /**
         * @stability stable
         */
        get loadBalancerType(): string | undefined;
        /**
         * @stability stable
         */
        set loadBalancerType(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancerType(): void;
        /**
         * @stability stable
         */
        get loadBalancerTypeInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _subnets?;
        /**
         * @stability stable
         */
        get subnets(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnets(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnets(): void;
        /**
         * @stability stable
         */
        get subnetsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        get zoneId(): string;
        private _accessLogs?;
        private __accessLogsOutput;
        /**
         * @stability stable
         */
        get accessLogs(): AlbAccessLogsOutputReference;
        /**
         * @stability stable
         */
        putAccessLogs(value: AlbAccessLogs | undefined): void;
        /**
         * @stability stable
         */
        resetAccessLogs(): void;
        /**
         * @stability stable
         */
        get accessLogsInput(): AlbAccessLogs | undefined;
        private _subnetMapping?;
        /**
         * @stability stable
         */
        get subnetMapping(): AlbSubnetMapping[] | undefined;
        /**
         * @stability stable
         */
        set subnetMapping(value: AlbSubnetMapping[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetMapping(): void;
        /**
         * @stability stable
         */
        get subnetMappingInput(): AlbSubnetMapping[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): AlbTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: AlbTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): AlbTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AlbListenerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#alpn_policy AlbListener#alpn_policy}.
         *
         * @stability stable
         */
        readonly alpnPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#certificate_arn AlbListener#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#load_balancer_arn AlbListener#load_balancer_arn}.
         *
         * @stability stable
         */
        readonly loadBalancerArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#port AlbListener#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#protocol AlbListener#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#ssl_policy AlbListener#ssl_policy}.
         *
         * @stability stable
         */
        readonly sslPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#tags AlbListener#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#tags_all AlbListener#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * default_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#default_action AlbListener#default_action}
         *
         * @stability stable
         */
        readonly defaultAction: AlbListenerDefaultAction[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#timeouts AlbListener#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: AlbListenerTimeouts;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultActionAuthenticateCognito {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#authentication_request_extra_params AlbListener#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#on_unauthenticated_request AlbListener#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#scope AlbListener#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#session_cookie_name AlbListener#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#session_timeout AlbListener#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#user_pool_arn AlbListener#user_pool_arn}.
         *
         * @stability stable
         */
        readonly userPoolArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#user_pool_client_id AlbListener#user_pool_client_id}.
         *
         * @stability stable
         */
        readonly userPoolClientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#user_pool_domain AlbListener#user_pool_domain}.
         *
         * @stability stable
         */
        readonly userPoolDomain: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerDefaultActionAuthenticateCognitoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _userPoolArn?;
        /**
         * @stability stable
         */
        get userPoolArn(): string;
        /**
         * @stability stable
         */
        set userPoolArn(value: string);
        /**
         * @stability stable
         */
        get userPoolArnInput(): string | undefined;
        private _userPoolClientId?;
        /**
         * @stability stable
         */
        get userPoolClientId(): string;
        /**
         * @stability stable
         */
        set userPoolClientId(value: string);
        /**
         * @stability stable
         */
        get userPoolClientIdInput(): string | undefined;
        private _userPoolDomain?;
        /**
         * @stability stable
         */
        get userPoolDomain(): string;
        /**
         * @stability stable
         */
        set userPoolDomain(value: string);
        /**
         * @stability stable
         */
        get userPoolDomainInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultActionAuthenticateOidc {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#authentication_request_extra_params AlbListener#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#authorization_endpoint AlbListener#authorization_endpoint}.
         *
         * @stability stable
         */
        readonly authorizationEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#client_id AlbListener#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#client_secret AlbListener#client_secret}.
         *
         * @stability stable
         */
        readonly clientSecret: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#issuer AlbListener#issuer}.
         *
         * @stability stable
         */
        readonly issuer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#on_unauthenticated_request AlbListener#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#scope AlbListener#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#session_cookie_name AlbListener#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#session_timeout AlbListener#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#token_endpoint AlbListener#token_endpoint}.
         *
         * @stability stable
         */
        readonly tokenEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#user_info_endpoint AlbListener#user_info_endpoint}.
         *
         * @stability stable
         */
        readonly userInfoEndpoint: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerDefaultActionAuthenticateOidcOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _authorizationEndpoint?;
        /**
         * @stability stable
         */
        get authorizationEndpoint(): string;
        /**
         * @stability stable
         */
        set authorizationEndpoint(value: string);
        /**
         * @stability stable
         */
        get authorizationEndpointInput(): string | undefined;
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _clientSecret?;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        /**
         * @stability stable
         */
        set clientSecret(value: string);
        /**
         * @stability stable
         */
        get clientSecretInput(): string | undefined;
        private _issuer?;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        set issuer(value: string);
        /**
         * @stability stable
         */
        get issuerInput(): string | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _tokenEndpoint?;
        /**
         * @stability stable
         */
        get tokenEndpoint(): string;
        /**
         * @stability stable
         */
        set tokenEndpoint(value: string);
        /**
         * @stability stable
         */
        get tokenEndpointInput(): string | undefined;
        private _userInfoEndpoint?;
        /**
         * @stability stable
         */
        get userInfoEndpoint(): string;
        /**
         * @stability stable
         */
        set userInfoEndpoint(value: string);
        /**
         * @stability stable
         */
        get userInfoEndpointInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultActionFixedResponse {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#content_type AlbListener#content_type}.
         *
         * @stability stable
         */
        readonly contentType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#message_body AlbListener#message_body}.
         *
         * @stability stable
         */
        readonly messageBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#status_code AlbListener#status_code}.
         *
         * @stability stable
         */
        readonly statusCode?: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerDefaultActionFixedResponseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _contentType?;
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        set contentType(value: string);
        /**
         * @stability stable
         */
        get contentTypeInput(): string | undefined;
        private _messageBody?;
        /**
         * @stability stable
         */
        get messageBody(): string | undefined;
        /**
         * @stability stable
         */
        set messageBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageBody(): void;
        /**
         * @stability stable
         */
        get messageBodyInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string | undefined;
        /**
         * @stability stable
         */
        set statusCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatusCode(): void;
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultActionForwardStickiness {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#duration AlbListener#duration}.
         *
         * @stability stable
         */
        readonly duration: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#enabled AlbListener#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class AlbListenerDefaultActionForwardStickinessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _duration?;
        /**
         * @stability stable
         */
        get duration(): number;
        /**
         * @stability stable
         */
        set duration(value: number);
        /**
         * @stability stable
         */
        get durationInput(): number | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultActionForwardTargetGroup {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#arn AlbListener#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#weight AlbListener#weight}.
         *
         * @stability stable
         */
        readonly weight?: number;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultActionForward {
        /**
         * stickiness block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#stickiness AlbListener#stickiness}
         *
         * @stability stable
         */
        readonly stickiness?: AlbListenerDefaultActionForwardStickiness;
        /**
         * target_group block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#target_group AlbListener#target_group}
         *
         * @stability stable
         */
        readonly targetGroup: AlbListenerDefaultActionForwardTargetGroup[];
    }
    /**
     * @stability stable
     */
    class AlbListenerDefaultActionForwardOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _stickiness?;
        private __stickinessOutput;
        /**
         * @stability stable
         */
        get stickiness(): AlbListenerDefaultActionForwardStickinessOutputReference;
        /**
         * @stability stable
         */
        putStickiness(value: AlbListenerDefaultActionForwardStickiness | undefined): void;
        /**
         * @stability stable
         */
        resetStickiness(): void;
        /**
         * @stability stable
         */
        get stickinessInput(): AlbListenerDefaultActionForwardStickiness | undefined;
        private _targetGroup?;
        /**
         * @stability stable
         */
        get targetGroup(): AlbListenerDefaultActionForwardTargetGroup[];
        /**
         * @stability stable
         */
        set targetGroup(value: AlbListenerDefaultActionForwardTargetGroup[]);
        /**
         * @stability stable
         */
        get targetGroupInput(): AlbListenerDefaultActionForwardTargetGroup[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultActionRedirect {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#host AlbListener#host}.
         *
         * @stability stable
         */
        readonly host?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#path AlbListener#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#port AlbListener#port}.
         *
         * @stability stable
         */
        readonly port?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#protocol AlbListener#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#query AlbListener#query}.
         *
         * @stability stable
         */
        readonly query?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#status_code AlbListener#status_code}.
         *
         * @stability stable
         */
        readonly statusCode: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerDefaultActionRedirectOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _host?;
        /**
         * @stability stable
         */
        get host(): string | undefined;
        /**
         * @stability stable
         */
        set host(value: string | undefined);
        /**
         * @stability stable
         */
        resetHost(): void;
        /**
         * @stability stable
         */
        get hostInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): string | undefined;
        /**
         * @stability stable
         */
        set port(value: string | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _query?;
        /**
         * @stability stable
         */
        get query(): string | undefined;
        /**
         * @stability stable
         */
        set query(value: string | undefined);
        /**
         * @stability stable
         */
        resetQuery(): void;
        /**
         * @stability stable
         */
        get queryInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string;
        /**
         * @stability stable
         */
        set statusCode(value: string);
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerDefaultAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#order AlbListener#order}.
         *
         * @stability stable
         */
        readonly order?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#target_group_arn AlbListener#target_group_arn}.
         *
         * @stability stable
         */
        readonly targetGroupArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#type AlbListener#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * authenticate_cognito block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#authenticate_cognito AlbListener#authenticate_cognito}
         *
         * @stability stable
         */
        readonly authenticateCognito?: AlbListenerDefaultActionAuthenticateCognito;
        /**
         * authenticate_oidc block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#authenticate_oidc AlbListener#authenticate_oidc}
         *
         * @stability stable
         */
        readonly authenticateOidc?: AlbListenerDefaultActionAuthenticateOidc;
        /**
         * fixed_response block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#fixed_response AlbListener#fixed_response}
         *
         * @stability stable
         */
        readonly fixedResponse?: AlbListenerDefaultActionFixedResponse;
        /**
         * forward block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#forward AlbListener#forward}
         *
         * @stability stable
         */
        readonly forward?: AlbListenerDefaultActionForward;
        /**
         * redirect block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#redirect AlbListener#redirect}
         *
         * @stability stable
         */
        readonly redirect?: AlbListenerDefaultActionRedirect;
    }
    /**
     * @stability stable
     */
    interface AlbListenerTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html#read AlbListener#read}.
         *
         * @stability stable
         */
        readonly read?: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _read?;
        /**
         * @stability stable
         */
        get read(): string | undefined;
        /**
         * @stability stable
         */
        set read(value: string | undefined);
        /**
         * @stability stable
         */
        resetRead(): void;
        /**
         * @stability stable
         */
        get readInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html aws_alb_listener}.
     *
     * @stability stable
     */
    class AlbListener extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb_listener.html aws_alb_listener} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AlbListenerConfig);
        private _alpnPolicy?;
        /**
         * @stability stable
         */
        get alpnPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set alpnPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetAlpnPolicy(): void;
        /**
         * @stability stable
         */
        get alpnPolicyInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set certificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateArn(): void;
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _loadBalancerArn?;
        /**
         * @stability stable
         */
        get loadBalancerArn(): string;
        /**
         * @stability stable
         */
        set loadBalancerArn(value: string);
        /**
         * @stability stable
         */
        get loadBalancerArnInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _sslPolicy?;
        /**
         * @stability stable
         */
        get sslPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set sslPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSslPolicy(): void;
        /**
         * @stability stable
         */
        get sslPolicyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _defaultAction?;
        /**
         * @stability stable
         */
        get defaultAction(): AlbListenerDefaultAction[];
        /**
         * @stability stable
         */
        set defaultAction(value: AlbListenerDefaultAction[]);
        /**
         * @stability stable
         */
        get defaultActionInput(): AlbListenerDefaultAction[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): AlbListenerTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: AlbListenerTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): AlbListenerTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AlbListenerCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_certificate.html#certificate_arn AlbListenerCertificate#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_certificate.html#listener_arn AlbListenerCertificate#listener_arn}.
         *
         * @stability stable
         */
        readonly listenerArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_certificate.html aws_alb_listener_certificate}.
     *
     * @stability stable
     */
    class AlbListenerCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_certificate.html aws_alb_listener_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AlbListenerCertificateConfig);
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string;
        /**
         * @stability stable
         */
        set certificateArn(value: string);
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _listenerArn?;
        /**
         * @stability stable
         */
        get listenerArn(): string;
        /**
         * @stability stable
         */
        set listenerArn(value: string);
        /**
         * @stability stable
         */
        get listenerArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#listener_arn AlbListenerRule#listener_arn}.
         *
         * @stability stable
         */
        readonly listenerArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#priority AlbListenerRule#priority}.
         *
         * @stability stable
         */
        readonly priority?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#tags AlbListenerRule#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#tags_all AlbListenerRule#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#action AlbListenerRule#action}
         *
         * @stability stable
         */
        readonly action: AlbListenerRuleAction[];
        /**
         * condition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#condition AlbListenerRule#condition}
         *
         * @stability stable
         */
        readonly condition: AlbListenerRuleCondition[];
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleActionAuthenticateCognito {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#authentication_request_extra_params AlbListenerRule#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#on_unauthenticated_request AlbListenerRule#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#scope AlbListenerRule#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#session_cookie_name AlbListenerRule#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#session_timeout AlbListenerRule#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#user_pool_arn AlbListenerRule#user_pool_arn}.
         *
         * @stability stable
         */
        readonly userPoolArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#user_pool_client_id AlbListenerRule#user_pool_client_id}.
         *
         * @stability stable
         */
        readonly userPoolClientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#user_pool_domain AlbListenerRule#user_pool_domain}.
         *
         * @stability stable
         */
        readonly userPoolDomain: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleActionAuthenticateCognitoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _userPoolArn?;
        /**
         * @stability stable
         */
        get userPoolArn(): string;
        /**
         * @stability stable
         */
        set userPoolArn(value: string);
        /**
         * @stability stable
         */
        get userPoolArnInput(): string | undefined;
        private _userPoolClientId?;
        /**
         * @stability stable
         */
        get userPoolClientId(): string;
        /**
         * @stability stable
         */
        set userPoolClientId(value: string);
        /**
         * @stability stable
         */
        get userPoolClientIdInput(): string | undefined;
        private _userPoolDomain?;
        /**
         * @stability stable
         */
        get userPoolDomain(): string;
        /**
         * @stability stable
         */
        set userPoolDomain(value: string);
        /**
         * @stability stable
         */
        get userPoolDomainInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleActionAuthenticateOidc {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#authentication_request_extra_params AlbListenerRule#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#authorization_endpoint AlbListenerRule#authorization_endpoint}.
         *
         * @stability stable
         */
        readonly authorizationEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#client_id AlbListenerRule#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#client_secret AlbListenerRule#client_secret}.
         *
         * @stability stable
         */
        readonly clientSecret: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#issuer AlbListenerRule#issuer}.
         *
         * @stability stable
         */
        readonly issuer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#on_unauthenticated_request AlbListenerRule#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#scope AlbListenerRule#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#session_cookie_name AlbListenerRule#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#session_timeout AlbListenerRule#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#token_endpoint AlbListenerRule#token_endpoint}.
         *
         * @stability stable
         */
        readonly tokenEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#user_info_endpoint AlbListenerRule#user_info_endpoint}.
         *
         * @stability stable
         */
        readonly userInfoEndpoint: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleActionAuthenticateOidcOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _authorizationEndpoint?;
        /**
         * @stability stable
         */
        get authorizationEndpoint(): string;
        /**
         * @stability stable
         */
        set authorizationEndpoint(value: string);
        /**
         * @stability stable
         */
        get authorizationEndpointInput(): string | undefined;
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _clientSecret?;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        /**
         * @stability stable
         */
        set clientSecret(value: string);
        /**
         * @stability stable
         */
        get clientSecretInput(): string | undefined;
        private _issuer?;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        set issuer(value: string);
        /**
         * @stability stable
         */
        get issuerInput(): string | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _tokenEndpoint?;
        /**
         * @stability stable
         */
        get tokenEndpoint(): string;
        /**
         * @stability stable
         */
        set tokenEndpoint(value: string);
        /**
         * @stability stable
         */
        get tokenEndpointInput(): string | undefined;
        private _userInfoEndpoint?;
        /**
         * @stability stable
         */
        get userInfoEndpoint(): string;
        /**
         * @stability stable
         */
        set userInfoEndpoint(value: string);
        /**
         * @stability stable
         */
        get userInfoEndpointInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleActionFixedResponse {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#content_type AlbListenerRule#content_type}.
         *
         * @stability stable
         */
        readonly contentType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#message_body AlbListenerRule#message_body}.
         *
         * @stability stable
         */
        readonly messageBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#status_code AlbListenerRule#status_code}.
         *
         * @stability stable
         */
        readonly statusCode?: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleActionFixedResponseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _contentType?;
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        set contentType(value: string);
        /**
         * @stability stable
         */
        get contentTypeInput(): string | undefined;
        private _messageBody?;
        /**
         * @stability stable
         */
        get messageBody(): string | undefined;
        /**
         * @stability stable
         */
        set messageBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageBody(): void;
        /**
         * @stability stable
         */
        get messageBodyInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string | undefined;
        /**
         * @stability stable
         */
        set statusCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatusCode(): void;
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleActionForwardStickiness {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#duration AlbListenerRule#duration}.
         *
         * @stability stable
         */
        readonly duration: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#enabled AlbListenerRule#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleActionForwardStickinessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _duration?;
        /**
         * @stability stable
         */
        get duration(): number;
        /**
         * @stability stable
         */
        set duration(value: number);
        /**
         * @stability stable
         */
        get durationInput(): number | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleActionForwardTargetGroup {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#arn AlbListenerRule#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#weight AlbListenerRule#weight}.
         *
         * @stability stable
         */
        readonly weight?: number;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleActionForward {
        /**
         * stickiness block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#stickiness AlbListenerRule#stickiness}
         *
         * @stability stable
         */
        readonly stickiness?: AlbListenerRuleActionForwardStickiness;
        /**
         * target_group block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#target_group AlbListenerRule#target_group}
         *
         * @stability stable
         */
        readonly targetGroup: AlbListenerRuleActionForwardTargetGroup[];
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleActionForwardOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _stickiness?;
        private __stickinessOutput;
        /**
         * @stability stable
         */
        get stickiness(): AlbListenerRuleActionForwardStickinessOutputReference;
        /**
         * @stability stable
         */
        putStickiness(value: AlbListenerRuleActionForwardStickiness | undefined): void;
        /**
         * @stability stable
         */
        resetStickiness(): void;
        /**
         * @stability stable
         */
        get stickinessInput(): AlbListenerRuleActionForwardStickiness | undefined;
        private _targetGroup?;
        /**
         * @stability stable
         */
        get targetGroup(): AlbListenerRuleActionForwardTargetGroup[];
        /**
         * @stability stable
         */
        set targetGroup(value: AlbListenerRuleActionForwardTargetGroup[]);
        /**
         * @stability stable
         */
        get targetGroupInput(): AlbListenerRuleActionForwardTargetGroup[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleActionRedirect {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#host AlbListenerRule#host}.
         *
         * @stability stable
         */
        readonly host?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#path AlbListenerRule#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#port AlbListenerRule#port}.
         *
         * @stability stable
         */
        readonly port?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#protocol AlbListenerRule#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#query AlbListenerRule#query}.
         *
         * @stability stable
         */
        readonly query?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#status_code AlbListenerRule#status_code}.
         *
         * @stability stable
         */
        readonly statusCode: string;
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleActionRedirectOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _host?;
        /**
         * @stability stable
         */
        get host(): string | undefined;
        /**
         * @stability stable
         */
        set host(value: string | undefined);
        /**
         * @stability stable
         */
        resetHost(): void;
        /**
         * @stability stable
         */
        get hostInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): string | undefined;
        /**
         * @stability stable
         */
        set port(value: string | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _query?;
        /**
         * @stability stable
         */
        get query(): string | undefined;
        /**
         * @stability stable
         */
        set query(value: string | undefined);
        /**
         * @stability stable
         */
        resetQuery(): void;
        /**
         * @stability stable
         */
        get queryInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string;
        /**
         * @stability stable
         */
        set statusCode(value: string);
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#order AlbListenerRule#order}.
         *
         * @stability stable
         */
        readonly order?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#target_group_arn AlbListenerRule#target_group_arn}.
         *
         * @stability stable
         */
        readonly targetGroupArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#type AlbListenerRule#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * authenticate_cognito block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#authenticate_cognito AlbListenerRule#authenticate_cognito}
         *
         * @stability stable
         */
        readonly authenticateCognito?: AlbListenerRuleActionAuthenticateCognito;
        /**
         * authenticate_oidc block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#authenticate_oidc AlbListenerRule#authenticate_oidc}
         *
         * @stability stable
         */
        readonly authenticateOidc?: AlbListenerRuleActionAuthenticateOidc;
        /**
         * fixed_response block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#fixed_response AlbListenerRule#fixed_response}
         *
         * @stability stable
         */
        readonly fixedResponse?: AlbListenerRuleActionFixedResponse;
        /**
         * forward block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#forward AlbListenerRule#forward}
         *
         * @stability stable
         */
        readonly forward?: AlbListenerRuleActionForward;
        /**
         * redirect block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#redirect AlbListenerRule#redirect}
         *
         * @stability stable
         */
        readonly redirect?: AlbListenerRuleActionRedirect;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleConditionHostHeader {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#values AlbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleConditionHostHeaderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleConditionHttpHeader {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#http_header_name AlbListenerRule#http_header_name}.
         *
         * @stability stable
         */
        readonly httpHeaderName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#values AlbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleConditionHttpHeaderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _httpHeaderName?;
        /**
         * @stability stable
         */
        get httpHeaderName(): string;
        /**
         * @stability stable
         */
        set httpHeaderName(value: string);
        /**
         * @stability stable
         */
        get httpHeaderNameInput(): string | undefined;
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleConditionHttpRequestMethod {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#values AlbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleConditionHttpRequestMethodOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleConditionPathPattern {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#values AlbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleConditionPathPatternOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleConditionQueryString {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#key AlbListenerRule#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#value AlbListenerRule#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleConditionSourceIp {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#values AlbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class AlbListenerRuleConditionSourceIpOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbListenerRuleCondition {
        /**
         * host_header block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#host_header AlbListenerRule#host_header}
         *
         * @stability stable
         */
        readonly hostHeader?: AlbListenerRuleConditionHostHeader;
        /**
         * http_header block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#http_header AlbListenerRule#http_header}
         *
         * @stability stable
         */
        readonly httpHeader?: AlbListenerRuleConditionHttpHeader;
        /**
         * http_request_method block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#http_request_method AlbListenerRule#http_request_method}
         *
         * @stability stable
         */
        readonly httpRequestMethod?: AlbListenerRuleConditionHttpRequestMethod;
        /**
         * path_pattern block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#path_pattern AlbListenerRule#path_pattern}
         *
         * @stability stable
         */
        readonly pathPattern?: AlbListenerRuleConditionPathPattern;
        /**
         * query_string block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#query_string AlbListenerRule#query_string}
         *
         * @stability stable
         */
        readonly queryString?: AlbListenerRuleConditionQueryString[];
        /**
         * source_ip block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html#source_ip AlbListenerRule#source_ip}
         *
         * @stability stable
         */
        readonly sourceIp?: AlbListenerRuleConditionSourceIp;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html aws_alb_listener_rule}.
     *
     * @stability stable
     */
    class AlbListenerRule extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb_listener_rule.html aws_alb_listener_rule} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AlbListenerRuleConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _listenerArn?;
        /**
         * @stability stable
         */
        get listenerArn(): string;
        /**
         * @stability stable
         */
        set listenerArn(value: string);
        /**
         * @stability stable
         */
        get listenerArnInput(): string | undefined;
        private _priority?;
        /**
         * @stability stable
         */
        get priority(): number | undefined;
        /**
         * @stability stable
         */
        set priority(value: number | undefined);
        /**
         * @stability stable
         */
        resetPriority(): void;
        /**
         * @stability stable
         */
        get priorityInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _action?;
        /**
         * @stability stable
         */
        get action(): AlbListenerRuleAction[];
        /**
         * @stability stable
         */
        set action(value: AlbListenerRuleAction[]);
        /**
         * @stability stable
         */
        get actionInput(): AlbListenerRuleAction[] | undefined;
        private _condition?;
        /**
         * @stability stable
         */
        get condition(): AlbListenerRuleCondition[];
        /**
         * @stability stable
         */
        set condition(value: AlbListenerRuleCondition[]);
        /**
         * @stability stable
         */
        get conditionInput(): AlbListenerRuleCondition[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AlbTargetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#deregistration_delay AlbTargetGroup#deregistration_delay}.
         *
         * @stability stable
         */
        readonly deregistrationDelay?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#lambda_multi_value_headers_enabled AlbTargetGroup#lambda_multi_value_headers_enabled}.
         *
         * @stability stable
         */
        readonly lambdaMultiValueHeadersEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#load_balancing_algorithm_type AlbTargetGroup#load_balancing_algorithm_type}.
         *
         * @stability stable
         */
        readonly loadBalancingAlgorithmType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#name AlbTargetGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#name_prefix AlbTargetGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#port AlbTargetGroup#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#preserve_client_ip AlbTargetGroup#preserve_client_ip}.
         *
         * @stability stable
         */
        readonly preserveClientIp?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#protocol AlbTargetGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#protocol_version AlbTargetGroup#protocol_version}.
         *
         * @stability stable
         */
        readonly protocolVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#proxy_protocol_v2 AlbTargetGroup#proxy_protocol_v2}.
         *
         * @stability stable
         */
        readonly proxyProtocolV2?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#slow_start AlbTargetGroup#slow_start}.
         *
         * @stability stable
         */
        readonly slowStart?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#tags AlbTargetGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#tags_all AlbTargetGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#target_type AlbTargetGroup#target_type}.
         *
         * @stability stable
         */
        readonly targetType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#vpc_id AlbTargetGroup#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * health_check block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#health_check AlbTargetGroup#health_check}
         *
         * @stability stable
         */
        readonly healthCheck?: AlbTargetGroupHealthCheck;
        /**
         * stickiness block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#stickiness AlbTargetGroup#stickiness}
         *
         * @stability stable
         */
        readonly stickiness?: AlbTargetGroupStickiness;
    }
    /**
     * @stability stable
     */
    interface AlbTargetGroupHealthCheck {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#enabled AlbTargetGroup#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#healthy_threshold AlbTargetGroup#healthy_threshold}.
         *
         * @stability stable
         */
        readonly healthyThreshold?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#interval AlbTargetGroup#interval}.
         *
         * @stability stable
         */
        readonly interval?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#matcher AlbTargetGroup#matcher}.
         *
         * @stability stable
         */
        readonly matcher?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#path AlbTargetGroup#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#port AlbTargetGroup#port}.
         *
         * @stability stable
         */
        readonly port?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#protocol AlbTargetGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#timeout AlbTargetGroup#timeout}.
         *
         * @stability stable
         */
        readonly timeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#unhealthy_threshold AlbTargetGroup#unhealthy_threshold}.
         *
         * @stability stable
         */
        readonly unhealthyThreshold?: number;
    }
    /**
     * @stability stable
     */
    class AlbTargetGroupHealthCheckOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _healthyThreshold?;
        /**
         * @stability stable
         */
        get healthyThreshold(): number | undefined;
        /**
         * @stability stable
         */
        set healthyThreshold(value: number | undefined);
        /**
         * @stability stable
         */
        resetHealthyThreshold(): void;
        /**
         * @stability stable
         */
        get healthyThresholdInput(): number | undefined;
        private _interval?;
        /**
         * @stability stable
         */
        get interval(): number | undefined;
        /**
         * @stability stable
         */
        set interval(value: number | undefined);
        /**
         * @stability stable
         */
        resetInterval(): void;
        /**
         * @stability stable
         */
        get intervalInput(): number | undefined;
        private _matcher?;
        /**
         * @stability stable
         */
        get matcher(): string | undefined;
        /**
         * @stability stable
         */
        set matcher(value: string | undefined);
        /**
         * @stability stable
         */
        resetMatcher(): void;
        /**
         * @stability stable
         */
        get matcherInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): string | undefined;
        /**
         * @stability stable
         */
        set port(value: string | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _timeout?;
        /**
         * @stability stable
         */
        get timeout(): number | undefined;
        /**
         * @stability stable
         */
        set timeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeout(): void;
        /**
         * @stability stable
         */
        get timeoutInput(): number | undefined;
        private _unhealthyThreshold?;
        /**
         * @stability stable
         */
        get unhealthyThreshold(): number | undefined;
        /**
         * @stability stable
         */
        set unhealthyThreshold(value: number | undefined);
        /**
         * @stability stable
         */
        resetUnhealthyThreshold(): void;
        /**
         * @stability stable
         */
        get unhealthyThresholdInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface AlbTargetGroupStickiness {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#cookie_duration AlbTargetGroup#cookie_duration}.
         *
         * @stability stable
         */
        readonly cookieDuration?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#cookie_name AlbTargetGroup#cookie_name}.
         *
         * @stability stable
         */
        readonly cookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#enabled AlbTargetGroup#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html#type AlbTargetGroup#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    class AlbTargetGroupStickinessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cookieDuration?;
        /**
         * @stability stable
         */
        get cookieDuration(): number | undefined;
        /**
         * @stability stable
         */
        set cookieDuration(value: number | undefined);
        /**
         * @stability stable
         */
        resetCookieDuration(): void;
        /**
         * @stability stable
         */
        get cookieDurationInput(): number | undefined;
        private _cookieName?;
        /**
         * @stability stable
         */
        get cookieName(): string | undefined;
        /**
         * @stability stable
         */
        set cookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetCookieName(): void;
        /**
         * @stability stable
         */
        get cookieNameInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html aws_alb_target_group}.
     *
     * @stability stable
     */
    class AlbTargetGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group.html aws_alb_target_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: AlbTargetGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        private _deregistrationDelay?;
        /**
         * @stability stable
         */
        get deregistrationDelay(): string | undefined;
        /**
         * @stability stable
         */
        set deregistrationDelay(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeregistrationDelay(): void;
        /**
         * @stability stable
         */
        get deregistrationDelayInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _lambdaMultiValueHeadersEnabled?;
        /**
         * @stability stable
         */
        get lambdaMultiValueHeadersEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set lambdaMultiValueHeadersEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetLambdaMultiValueHeadersEnabled(): void;
        /**
         * @stability stable
         */
        get lambdaMultiValueHeadersEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _loadBalancingAlgorithmType?;
        /**
         * @stability stable
         */
        get loadBalancingAlgorithmType(): string | undefined;
        /**
         * @stability stable
         */
        set loadBalancingAlgorithmType(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancingAlgorithmType(): void;
        /**
         * @stability stable
         */
        get loadBalancingAlgorithmTypeInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _preserveClientIp?;
        /**
         * @stability stable
         */
        get preserveClientIp(): string | undefined;
        /**
         * @stability stable
         */
        set preserveClientIp(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreserveClientIp(): void;
        /**
         * @stability stable
         */
        get preserveClientIpInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _protocolVersion?;
        /**
         * @stability stable
         */
        get protocolVersion(): string | undefined;
        /**
         * @stability stable
         */
        set protocolVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocolVersion(): void;
        /**
         * @stability stable
         */
        get protocolVersionInput(): string | undefined;
        private _proxyProtocolV2?;
        /**
         * @stability stable
         */
        get proxyProtocolV2(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set proxyProtocolV2(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetProxyProtocolV2(): void;
        /**
         * @stability stable
         */
        get proxyProtocolV2Input(): boolean | cdktf.IResolvable | undefined;
        private _slowStart?;
        /**
         * @stability stable
         */
        get slowStart(): number | undefined;
        /**
         * @stability stable
         */
        set slowStart(value: number | undefined);
        /**
         * @stability stable
         */
        resetSlowStart(): void;
        /**
         * @stability stable
         */
        get slowStartInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetType?;
        /**
         * @stability stable
         */
        get targetType(): string | undefined;
        /**
         * @stability stable
         */
        set targetType(value: string | undefined);
        /**
         * @stability stable
         */
        resetTargetType(): void;
        /**
         * @stability stable
         */
        get targetTypeInput(): string | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _healthCheck?;
        private __healthCheckOutput;
        /**
         * @stability stable
         */
        get healthCheck(): AlbTargetGroupHealthCheckOutputReference;
        /**
         * @stability stable
         */
        putHealthCheck(value: AlbTargetGroupHealthCheck | undefined): void;
        /**
         * @stability stable
         */
        resetHealthCheck(): void;
        /**
         * @stability stable
         */
        get healthCheckInput(): AlbTargetGroupHealthCheck | undefined;
        private _stickiness?;
        private __stickinessOutput;
        /**
         * @stability stable
         */
        get stickiness(): AlbTargetGroupStickinessOutputReference;
        /**
         * @stability stable
         */
        putStickiness(value: AlbTargetGroupStickiness | undefined): void;
        /**
         * @stability stable
         */
        resetStickiness(): void;
        /**
         * @stability stable
         */
        get stickinessInput(): AlbTargetGroupStickiness | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AlbTargetGroupAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group_attachment.html#availability_zone AlbTargetGroupAttachment#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group_attachment.html#port AlbTargetGroupAttachment#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group_attachment.html#target_group_arn AlbTargetGroupAttachment#target_group_arn}.
         *
         * @stability stable
         */
        readonly targetGroupArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group_attachment.html#target_id AlbTargetGroupAttachment#target_id}.
         *
         * @stability stable
         */
        readonly targetId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group_attachment.html aws_alb_target_group_attachment}.
     *
     * @stability stable
     */
    class AlbTargetGroupAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/alb_target_group_attachment.html aws_alb_target_group_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AlbTargetGroupAttachmentConfig);
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _targetGroupArn?;
        /**
         * @stability stable
         */
        get targetGroupArn(): string;
        /**
         * @stability stable
         */
        set targetGroupArn(value: string);
        /**
         * @stability stable
         */
        get targetGroupArnInput(): string | undefined;
        private _targetId?;
        /**
         * @stability stable
         */
        get targetId(): string;
        /**
         * @stability stable
         */
        set targetId(value: string);
        /**
         * @stability stable
         */
        get targetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface AppCookieStickinessPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/app_cookie_stickiness_policy.html#cookie_name AppCookieStickinessPolicy#cookie_name}.
         *
         * @stability stable
         */
        readonly cookieName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/app_cookie_stickiness_policy.html#lb_port AppCookieStickinessPolicy#lb_port}.
         *
         * @stability stable
         */
        readonly lbPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/app_cookie_stickiness_policy.html#load_balancer AppCookieStickinessPolicy#load_balancer}.
         *
         * @stability stable
         */
        readonly loadBalancer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/app_cookie_stickiness_policy.html#name AppCookieStickinessPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/app_cookie_stickiness_policy.html aws_app_cookie_stickiness_policy}.
     *
     * @stability stable
     */
    class AppCookieStickinessPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/app_cookie_stickiness_policy.html aws_app_cookie_stickiness_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: AppCookieStickinessPolicyConfig);
        private _cookieName?;
        /**
         * @stability stable
         */
        get cookieName(): string;
        /**
         * @stability stable
         */
        set cookieName(value: string);
        /**
         * @stability stable
         */
        get cookieNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _lbPort?;
        /**
         * @stability stable
         */
        get lbPort(): number;
        /**
         * @stability stable
         */
        set lbPort(value: number);
        /**
         * @stability stable
         */
        get lbPortInput(): number | undefined;
        private _loadBalancer?;
        /**
         * @stability stable
         */
        get loadBalancer(): string;
        /**
         * @stability stable
         */
        set loadBalancer(value: string);
        /**
         * @stability stable
         */
        get loadBalancerInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#customer_owned_ipv4_pool Lb#customer_owned_ipv4_pool}.
         *
         * @stability stable
         */
        readonly customerOwnedIpv4Pool?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#drop_invalid_header_fields Lb#drop_invalid_header_fields}.
         *
         * @stability stable
         */
        readonly dropInvalidHeaderFields?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#enable_cross_zone_load_balancing Lb#enable_cross_zone_load_balancing}.
         *
         * @stability stable
         */
        readonly enableCrossZoneLoadBalancing?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#enable_deletion_protection Lb#enable_deletion_protection}.
         *
         * @stability stable
         */
        readonly enableDeletionProtection?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#enable_http2 Lb#enable_http2}.
         *
         * @stability stable
         */
        readonly enableHttp2?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#idle_timeout Lb#idle_timeout}.
         *
         * @stability stable
         */
        readonly idleTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#internal Lb#internal}.
         *
         * @stability stable
         */
        readonly internal?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#ip_address_type Lb#ip_address_type}.
         *
         * @stability stable
         */
        readonly ipAddressType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#load_balancer_type Lb#load_balancer_type}.
         *
         * @stability stable
         */
        readonly loadBalancerType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#name Lb#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#name_prefix Lb#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#security_groups Lb#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#subnets Lb#subnets}.
         *
         * @stability stable
         */
        readonly subnets?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#tags Lb#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#tags_all Lb#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * access_logs block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#access_logs Lb#access_logs}
         *
         * @stability stable
         */
        readonly accessLogs?: LbAccessLogs;
        /**
         * subnet_mapping block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#subnet_mapping Lb#subnet_mapping}
         *
         * @stability stable
         */
        readonly subnetMapping?: LbSubnetMapping[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#timeouts Lb#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: LbTimeouts;
    }
    /**
     * @stability stable
     */
    interface LbAccessLogs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#bucket Lb#bucket}.
         *
         * @stability stable
         */
        readonly bucket: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#enabled Lb#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#prefix Lb#prefix}.
         *
         * @stability stable
         */
        readonly prefix?: string;
    }
    /**
     * @stability stable
     */
    class LbAccessLogsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucket?;
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        set bucket(value: string);
        /**
         * @stability stable
         */
        get bucketInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _prefix?;
        /**
         * @stability stable
         */
        get prefix(): string | undefined;
        /**
         * @stability stable
         */
        set prefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrefix(): void;
        /**
         * @stability stable
         */
        get prefixInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbSubnetMapping {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#allocation_id Lb#allocation_id}.
         *
         * @stability stable
         */
        readonly allocationId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#ipv6_address Lb#ipv6_address}.
         *
         * @stability stable
         */
        readonly ipv6Address?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#private_ipv4_address Lb#private_ipv4_address}.
         *
         * @stability stable
         */
        readonly privateIpv4Address?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#subnet_id Lb#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId: string;
    }
    /**
     * @stability stable
     */
    interface LbTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#create Lb#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#delete Lb#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb.html#update Lb#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class LbTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb.html aws_lb}.
     *
     * @stability stable
     */
    class Lb extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb.html aws_lb} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: LbConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        private _customerOwnedIpv4Pool?;
        /**
         * @stability stable
         */
        get customerOwnedIpv4Pool(): string | undefined;
        /**
         * @stability stable
         */
        set customerOwnedIpv4Pool(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerOwnedIpv4Pool(): void;
        /**
         * @stability stable
         */
        get customerOwnedIpv4PoolInput(): string | undefined;
        /**
         * @stability stable
         */
        get dnsName(): string;
        private _dropInvalidHeaderFields?;
        /**
         * @stability stable
         */
        get dropInvalidHeaderFields(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set dropInvalidHeaderFields(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDropInvalidHeaderFields(): void;
        /**
         * @stability stable
         */
        get dropInvalidHeaderFieldsInput(): boolean | cdktf.IResolvable | undefined;
        private _enableCrossZoneLoadBalancing?;
        /**
         * @stability stable
         */
        get enableCrossZoneLoadBalancing(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableCrossZoneLoadBalancing(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableCrossZoneLoadBalancing(): void;
        /**
         * @stability stable
         */
        get enableCrossZoneLoadBalancingInput(): boolean | cdktf.IResolvable | undefined;
        private _enableDeletionProtection?;
        /**
         * @stability stable
         */
        get enableDeletionProtection(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableDeletionProtection(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableDeletionProtection(): void;
        /**
         * @stability stable
         */
        get enableDeletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
        private _enableHttp2?;
        /**
         * @stability stable
         */
        get enableHttp2(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableHttp2(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableHttp2(): void;
        /**
         * @stability stable
         */
        get enableHttp2Input(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _idleTimeout?;
        /**
         * @stability stable
         */
        get idleTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set idleTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetIdleTimeout(): void;
        /**
         * @stability stable
         */
        get idleTimeoutInput(): number | undefined;
        private _internal?;
        /**
         * @stability stable
         */
        get internal(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set internal(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetInternal(): void;
        /**
         * @stability stable
         */
        get internalInput(): boolean | cdktf.IResolvable | undefined;
        private _ipAddressType?;
        /**
         * @stability stable
         */
        get ipAddressType(): string | undefined;
        /**
         * @stability stable
         */
        set ipAddressType(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpAddressType(): void;
        /**
         * @stability stable
         */
        get ipAddressTypeInput(): string | undefined;
        private _loadBalancerType?;
        /**
         * @stability stable
         */
        get loadBalancerType(): string | undefined;
        /**
         * @stability stable
         */
        set loadBalancerType(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancerType(): void;
        /**
         * @stability stable
         */
        get loadBalancerTypeInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _subnets?;
        /**
         * @stability stable
         */
        get subnets(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnets(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnets(): void;
        /**
         * @stability stable
         */
        get subnetsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        get zoneId(): string;
        private _accessLogs?;
        private __accessLogsOutput;
        /**
         * @stability stable
         */
        get accessLogs(): LbAccessLogsOutputReference;
        /**
         * @stability stable
         */
        putAccessLogs(value: LbAccessLogs | undefined): void;
        /**
         * @stability stable
         */
        resetAccessLogs(): void;
        /**
         * @stability stable
         */
        get accessLogsInput(): LbAccessLogs | undefined;
        private _subnetMapping?;
        /**
         * @stability stable
         */
        get subnetMapping(): LbSubnetMapping[] | undefined;
        /**
         * @stability stable
         */
        set subnetMapping(value: LbSubnetMapping[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetMapping(): void;
        /**
         * @stability stable
         */
        get subnetMappingInput(): LbSubnetMapping[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): LbTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: LbTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): LbTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbCookieStickinessPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_cookie_stickiness_policy.html#cookie_expiration_period LbCookieStickinessPolicy#cookie_expiration_period}.
         *
         * @stability stable
         */
        readonly cookieExpirationPeriod?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_cookie_stickiness_policy.html#lb_port LbCookieStickinessPolicy#lb_port}.
         *
         * @stability stable
         */
        readonly lbPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_cookie_stickiness_policy.html#load_balancer LbCookieStickinessPolicy#load_balancer}.
         *
         * @stability stable
         */
        readonly loadBalancer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_cookie_stickiness_policy.html#name LbCookieStickinessPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_cookie_stickiness_policy.html aws_lb_cookie_stickiness_policy}.
     *
     * @stability stable
     */
    class LbCookieStickinessPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_cookie_stickiness_policy.html aws_lb_cookie_stickiness_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LbCookieStickinessPolicyConfig);
        private _cookieExpirationPeriod?;
        /**
         * @stability stable
         */
        get cookieExpirationPeriod(): number | undefined;
        /**
         * @stability stable
         */
        set cookieExpirationPeriod(value: number | undefined);
        /**
         * @stability stable
         */
        resetCookieExpirationPeriod(): void;
        /**
         * @stability stable
         */
        get cookieExpirationPeriodInput(): number | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _lbPort?;
        /**
         * @stability stable
         */
        get lbPort(): number;
        /**
         * @stability stable
         */
        set lbPort(value: number);
        /**
         * @stability stable
         */
        get lbPortInput(): number | undefined;
        private _loadBalancer?;
        /**
         * @stability stable
         */
        get loadBalancer(): string;
        /**
         * @stability stable
         */
        set loadBalancer(value: string);
        /**
         * @stability stable
         */
        get loadBalancerInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbListenerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#alpn_policy LbListener#alpn_policy}.
         *
         * @stability stable
         */
        readonly alpnPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#certificate_arn LbListener#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#load_balancer_arn LbListener#load_balancer_arn}.
         *
         * @stability stable
         */
        readonly loadBalancerArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#port LbListener#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#protocol LbListener#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#ssl_policy LbListener#ssl_policy}.
         *
         * @stability stable
         */
        readonly sslPolicy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#tags LbListener#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#tags_all LbListener#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * default_action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#default_action LbListener#default_action}
         *
         * @stability stable
         */
        readonly defaultAction: LbListenerDefaultAction[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#timeouts LbListener#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: LbListenerTimeouts;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultActionAuthenticateCognito {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#authentication_request_extra_params LbListener#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#on_unauthenticated_request LbListener#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#scope LbListener#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#session_cookie_name LbListener#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#session_timeout LbListener#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#user_pool_arn LbListener#user_pool_arn}.
         *
         * @stability stable
         */
        readonly userPoolArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#user_pool_client_id LbListener#user_pool_client_id}.
         *
         * @stability stable
         */
        readonly userPoolClientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#user_pool_domain LbListener#user_pool_domain}.
         *
         * @stability stable
         */
        readonly userPoolDomain: string;
    }
    /**
     * @stability stable
     */
    class LbListenerDefaultActionAuthenticateCognitoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _userPoolArn?;
        /**
         * @stability stable
         */
        get userPoolArn(): string;
        /**
         * @stability stable
         */
        set userPoolArn(value: string);
        /**
         * @stability stable
         */
        get userPoolArnInput(): string | undefined;
        private _userPoolClientId?;
        /**
         * @stability stable
         */
        get userPoolClientId(): string;
        /**
         * @stability stable
         */
        set userPoolClientId(value: string);
        /**
         * @stability stable
         */
        get userPoolClientIdInput(): string | undefined;
        private _userPoolDomain?;
        /**
         * @stability stable
         */
        get userPoolDomain(): string;
        /**
         * @stability stable
         */
        set userPoolDomain(value: string);
        /**
         * @stability stable
         */
        get userPoolDomainInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultActionAuthenticateOidc {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#authentication_request_extra_params LbListener#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#authorization_endpoint LbListener#authorization_endpoint}.
         *
         * @stability stable
         */
        readonly authorizationEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#client_id LbListener#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#client_secret LbListener#client_secret}.
         *
         * @stability stable
         */
        readonly clientSecret: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#issuer LbListener#issuer}.
         *
         * @stability stable
         */
        readonly issuer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#on_unauthenticated_request LbListener#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#scope LbListener#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#session_cookie_name LbListener#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#session_timeout LbListener#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#token_endpoint LbListener#token_endpoint}.
         *
         * @stability stable
         */
        readonly tokenEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#user_info_endpoint LbListener#user_info_endpoint}.
         *
         * @stability stable
         */
        readonly userInfoEndpoint: string;
    }
    /**
     * @stability stable
     */
    class LbListenerDefaultActionAuthenticateOidcOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _authorizationEndpoint?;
        /**
         * @stability stable
         */
        get authorizationEndpoint(): string;
        /**
         * @stability stable
         */
        set authorizationEndpoint(value: string);
        /**
         * @stability stable
         */
        get authorizationEndpointInput(): string | undefined;
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _clientSecret?;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        /**
         * @stability stable
         */
        set clientSecret(value: string);
        /**
         * @stability stable
         */
        get clientSecretInput(): string | undefined;
        private _issuer?;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        set issuer(value: string);
        /**
         * @stability stable
         */
        get issuerInput(): string | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _tokenEndpoint?;
        /**
         * @stability stable
         */
        get tokenEndpoint(): string;
        /**
         * @stability stable
         */
        set tokenEndpoint(value: string);
        /**
         * @stability stable
         */
        get tokenEndpointInput(): string | undefined;
        private _userInfoEndpoint?;
        /**
         * @stability stable
         */
        get userInfoEndpoint(): string;
        /**
         * @stability stable
         */
        set userInfoEndpoint(value: string);
        /**
         * @stability stable
         */
        get userInfoEndpointInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultActionFixedResponse {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#content_type LbListener#content_type}.
         *
         * @stability stable
         */
        readonly contentType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#message_body LbListener#message_body}.
         *
         * @stability stable
         */
        readonly messageBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#status_code LbListener#status_code}.
         *
         * @stability stable
         */
        readonly statusCode?: string;
    }
    /**
     * @stability stable
     */
    class LbListenerDefaultActionFixedResponseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _contentType?;
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        set contentType(value: string);
        /**
         * @stability stable
         */
        get contentTypeInput(): string | undefined;
        private _messageBody?;
        /**
         * @stability stable
         */
        get messageBody(): string | undefined;
        /**
         * @stability stable
         */
        set messageBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageBody(): void;
        /**
         * @stability stable
         */
        get messageBodyInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string | undefined;
        /**
         * @stability stable
         */
        set statusCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatusCode(): void;
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultActionForwardStickiness {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#duration LbListener#duration}.
         *
         * @stability stable
         */
        readonly duration: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#enabled LbListener#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class LbListenerDefaultActionForwardStickinessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _duration?;
        /**
         * @stability stable
         */
        get duration(): number;
        /**
         * @stability stable
         */
        set duration(value: number);
        /**
         * @stability stable
         */
        get durationInput(): number | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultActionForwardTargetGroup {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#arn LbListener#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#weight LbListener#weight}.
         *
         * @stability stable
         */
        readonly weight?: number;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultActionForward {
        /**
         * stickiness block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#stickiness LbListener#stickiness}
         *
         * @stability stable
         */
        readonly stickiness?: LbListenerDefaultActionForwardStickiness;
        /**
         * target_group block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#target_group LbListener#target_group}
         *
         * @stability stable
         */
        readonly targetGroup: LbListenerDefaultActionForwardTargetGroup[];
    }
    /**
     * @stability stable
     */
    class LbListenerDefaultActionForwardOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _stickiness?;
        private __stickinessOutput;
        /**
         * @stability stable
         */
        get stickiness(): LbListenerDefaultActionForwardStickinessOutputReference;
        /**
         * @stability stable
         */
        putStickiness(value: LbListenerDefaultActionForwardStickiness | undefined): void;
        /**
         * @stability stable
         */
        resetStickiness(): void;
        /**
         * @stability stable
         */
        get stickinessInput(): LbListenerDefaultActionForwardStickiness | undefined;
        private _targetGroup?;
        /**
         * @stability stable
         */
        get targetGroup(): LbListenerDefaultActionForwardTargetGroup[];
        /**
         * @stability stable
         */
        set targetGroup(value: LbListenerDefaultActionForwardTargetGroup[]);
        /**
         * @stability stable
         */
        get targetGroupInput(): LbListenerDefaultActionForwardTargetGroup[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultActionRedirect {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#host LbListener#host}.
         *
         * @stability stable
         */
        readonly host?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#path LbListener#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#port LbListener#port}.
         *
         * @stability stable
         */
        readonly port?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#protocol LbListener#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#query LbListener#query}.
         *
         * @stability stable
         */
        readonly query?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#status_code LbListener#status_code}.
         *
         * @stability stable
         */
        readonly statusCode: string;
    }
    /**
     * @stability stable
     */
    class LbListenerDefaultActionRedirectOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _host?;
        /**
         * @stability stable
         */
        get host(): string | undefined;
        /**
         * @stability stable
         */
        set host(value: string | undefined);
        /**
         * @stability stable
         */
        resetHost(): void;
        /**
         * @stability stable
         */
        get hostInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): string | undefined;
        /**
         * @stability stable
         */
        set port(value: string | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _query?;
        /**
         * @stability stable
         */
        get query(): string | undefined;
        /**
         * @stability stable
         */
        set query(value: string | undefined);
        /**
         * @stability stable
         */
        resetQuery(): void;
        /**
         * @stability stable
         */
        get queryInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string;
        /**
         * @stability stable
         */
        set statusCode(value: string);
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerDefaultAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#order LbListener#order}.
         *
         * @stability stable
         */
        readonly order?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#target_group_arn LbListener#target_group_arn}.
         *
         * @stability stable
         */
        readonly targetGroupArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#type LbListener#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * authenticate_cognito block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#authenticate_cognito LbListener#authenticate_cognito}
         *
         * @stability stable
         */
        readonly authenticateCognito?: LbListenerDefaultActionAuthenticateCognito;
        /**
         * authenticate_oidc block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#authenticate_oidc LbListener#authenticate_oidc}
         *
         * @stability stable
         */
        readonly authenticateOidc?: LbListenerDefaultActionAuthenticateOidc;
        /**
         * fixed_response block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#fixed_response LbListener#fixed_response}
         *
         * @stability stable
         */
        readonly fixedResponse?: LbListenerDefaultActionFixedResponse;
        /**
         * forward block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#forward LbListener#forward}
         *
         * @stability stable
         */
        readonly forward?: LbListenerDefaultActionForward;
        /**
         * redirect block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#redirect LbListener#redirect}
         *
         * @stability stable
         */
        readonly redirect?: LbListenerDefaultActionRedirect;
    }
    /**
     * @stability stable
     */
    interface LbListenerTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html#read LbListener#read}.
         *
         * @stability stable
         */
        readonly read?: string;
    }
    /**
     * @stability stable
     */
    class LbListenerTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _read?;
        /**
         * @stability stable
         */
        get read(): string | undefined;
        /**
         * @stability stable
         */
        set read(value: string | undefined);
        /**
         * @stability stable
         */
        resetRead(): void;
        /**
         * @stability stable
         */
        get readInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html aws_lb_listener}.
     *
     * @stability stable
     */
    class LbListener extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_listener.html aws_lb_listener} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LbListenerConfig);
        private _alpnPolicy?;
        /**
         * @stability stable
         */
        get alpnPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set alpnPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetAlpnPolicy(): void;
        /**
         * @stability stable
         */
        get alpnPolicyInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string | undefined;
        /**
         * @stability stable
         */
        set certificateArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetCertificateArn(): void;
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _loadBalancerArn?;
        /**
         * @stability stable
         */
        get loadBalancerArn(): string;
        /**
         * @stability stable
         */
        set loadBalancerArn(value: string);
        /**
         * @stability stable
         */
        get loadBalancerArnInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _sslPolicy?;
        /**
         * @stability stable
         */
        get sslPolicy(): string | undefined;
        /**
         * @stability stable
         */
        set sslPolicy(value: string | undefined);
        /**
         * @stability stable
         */
        resetSslPolicy(): void;
        /**
         * @stability stable
         */
        get sslPolicyInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _defaultAction?;
        /**
         * @stability stable
         */
        get defaultAction(): LbListenerDefaultAction[];
        /**
         * @stability stable
         */
        set defaultAction(value: LbListenerDefaultAction[]);
        /**
         * @stability stable
         */
        get defaultActionInput(): LbListenerDefaultAction[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): LbListenerTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: LbListenerTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): LbListenerTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbListenerCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_certificate.html#certificate_arn LbListenerCertificate#certificate_arn}.
         *
         * @stability stable
         */
        readonly certificateArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_certificate.html#listener_arn LbListenerCertificate#listener_arn}.
         *
         * @stability stable
         */
        readonly listenerArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_certificate.html aws_lb_listener_certificate}.
     *
     * @stability stable
     */
    class LbListenerCertificate extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_certificate.html aws_lb_listener_certificate} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LbListenerCertificateConfig);
        private _certificateArn?;
        /**
         * @stability stable
         */
        get certificateArn(): string;
        /**
         * @stability stable
         */
        set certificateArn(value: string);
        /**
         * @stability stable
         */
        get certificateArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _listenerArn?;
        /**
         * @stability stable
         */
        get listenerArn(): string;
        /**
         * @stability stable
         */
        set listenerArn(value: string);
        /**
         * @stability stable
         */
        get listenerArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#listener_arn LbListenerRule#listener_arn}.
         *
         * @stability stable
         */
        readonly listenerArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#priority LbListenerRule#priority}.
         *
         * @stability stable
         */
        readonly priority?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#tags LbListenerRule#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#tags_all LbListenerRule#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * action block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#action LbListenerRule#action}
         *
         * @stability stable
         */
        readonly action: LbListenerRuleAction[];
        /**
         * condition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#condition LbListenerRule#condition}
         *
         * @stability stable
         */
        readonly condition: LbListenerRuleCondition[];
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleActionAuthenticateCognito {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#authentication_request_extra_params LbListenerRule#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#on_unauthenticated_request LbListenerRule#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#scope LbListenerRule#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#session_cookie_name LbListenerRule#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#session_timeout LbListenerRule#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#user_pool_arn LbListenerRule#user_pool_arn}.
         *
         * @stability stable
         */
        readonly userPoolArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#user_pool_client_id LbListenerRule#user_pool_client_id}.
         *
         * @stability stable
         */
        readonly userPoolClientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#user_pool_domain LbListenerRule#user_pool_domain}.
         *
         * @stability stable
         */
        readonly userPoolDomain: string;
    }
    /**
     * @stability stable
     */
    class LbListenerRuleActionAuthenticateCognitoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _userPoolArn?;
        /**
         * @stability stable
         */
        get userPoolArn(): string;
        /**
         * @stability stable
         */
        set userPoolArn(value: string);
        /**
         * @stability stable
         */
        get userPoolArnInput(): string | undefined;
        private _userPoolClientId?;
        /**
         * @stability stable
         */
        get userPoolClientId(): string;
        /**
         * @stability stable
         */
        set userPoolClientId(value: string);
        /**
         * @stability stable
         */
        get userPoolClientIdInput(): string | undefined;
        private _userPoolDomain?;
        /**
         * @stability stable
         */
        get userPoolDomain(): string;
        /**
         * @stability stable
         */
        set userPoolDomain(value: string);
        /**
         * @stability stable
         */
        get userPoolDomainInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleActionAuthenticateOidc {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#authentication_request_extra_params LbListenerRule#authentication_request_extra_params}.
         *
         * @stability stable
         */
        readonly authenticationRequestExtraParams?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#authorization_endpoint LbListenerRule#authorization_endpoint}.
         *
         * @stability stable
         */
        readonly authorizationEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#client_id LbListenerRule#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#client_secret LbListenerRule#client_secret}.
         *
         * @stability stable
         */
        readonly clientSecret: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#issuer LbListenerRule#issuer}.
         *
         * @stability stable
         */
        readonly issuer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#on_unauthenticated_request LbListenerRule#on_unauthenticated_request}.
         *
         * @stability stable
         */
        readonly onUnauthenticatedRequest?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#scope LbListenerRule#scope}.
         *
         * @stability stable
         */
        readonly scope?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#session_cookie_name LbListenerRule#session_cookie_name}.
         *
         * @stability stable
         */
        readonly sessionCookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#session_timeout LbListenerRule#session_timeout}.
         *
         * @stability stable
         */
        readonly sessionTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#token_endpoint LbListenerRule#token_endpoint}.
         *
         * @stability stable
         */
        readonly tokenEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#user_info_endpoint LbListenerRule#user_info_endpoint}.
         *
         * @stability stable
         */
        readonly userInfoEndpoint: string;
    }
    /**
     * @stability stable
     */
    class LbListenerRuleActionAuthenticateOidcOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authenticationRequestExtraParams?;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set authenticationRequestExtraParams(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAuthenticationRequestExtraParams(): void;
        /**
         * @stability stable
         */
        get authenticationRequestExtraParamsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _authorizationEndpoint?;
        /**
         * @stability stable
         */
        get authorizationEndpoint(): string;
        /**
         * @stability stable
         */
        set authorizationEndpoint(value: string);
        /**
         * @stability stable
         */
        get authorizationEndpointInput(): string | undefined;
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _clientSecret?;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        /**
         * @stability stable
         */
        set clientSecret(value: string);
        /**
         * @stability stable
         */
        get clientSecretInput(): string | undefined;
        private _issuer?;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        set issuer(value: string);
        /**
         * @stability stable
         */
        get issuerInput(): string | undefined;
        private _onUnauthenticatedRequest?;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string | undefined;
        /**
         * @stability stable
         */
        set onUnauthenticatedRequest(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnUnauthenticatedRequest(): void;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequestInput(): string | undefined;
        private _scope?;
        /**
         * @stability stable
         */
        get scope(): string | undefined;
        /**
         * @stability stable
         */
        set scope(value: string | undefined);
        /**
         * @stability stable
         */
        resetScope(): void;
        /**
         * @stability stable
         */
        get scopeInput(): string | undefined;
        private _sessionCookieName?;
        /**
         * @stability stable
         */
        get sessionCookieName(): string | undefined;
        /**
         * @stability stable
         */
        set sessionCookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSessionCookieName(): void;
        /**
         * @stability stable
         */
        get sessionCookieNameInput(): string | undefined;
        private _sessionTimeout?;
        /**
         * @stability stable
         */
        get sessionTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set sessionTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetSessionTimeout(): void;
        /**
         * @stability stable
         */
        get sessionTimeoutInput(): number | undefined;
        private _tokenEndpoint?;
        /**
         * @stability stable
         */
        get tokenEndpoint(): string;
        /**
         * @stability stable
         */
        set tokenEndpoint(value: string);
        /**
         * @stability stable
         */
        get tokenEndpointInput(): string | undefined;
        private _userInfoEndpoint?;
        /**
         * @stability stable
         */
        get userInfoEndpoint(): string;
        /**
         * @stability stable
         */
        set userInfoEndpoint(value: string);
        /**
         * @stability stable
         */
        get userInfoEndpointInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleActionFixedResponse {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#content_type LbListenerRule#content_type}.
         *
         * @stability stable
         */
        readonly contentType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#message_body LbListenerRule#message_body}.
         *
         * @stability stable
         */
        readonly messageBody?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#status_code LbListenerRule#status_code}.
         *
         * @stability stable
         */
        readonly statusCode?: string;
    }
    /**
     * @stability stable
     */
    class LbListenerRuleActionFixedResponseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _contentType?;
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        set contentType(value: string);
        /**
         * @stability stable
         */
        get contentTypeInput(): string | undefined;
        private _messageBody?;
        /**
         * @stability stable
         */
        get messageBody(): string | undefined;
        /**
         * @stability stable
         */
        set messageBody(value: string | undefined);
        /**
         * @stability stable
         */
        resetMessageBody(): void;
        /**
         * @stability stable
         */
        get messageBodyInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string | undefined;
        /**
         * @stability stable
         */
        set statusCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatusCode(): void;
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleActionForwardStickiness {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#duration LbListenerRule#duration}.
         *
         * @stability stable
         */
        readonly duration: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#enabled LbListenerRule#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class LbListenerRuleActionForwardStickinessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _duration?;
        /**
         * @stability stable
         */
        get duration(): number;
        /**
         * @stability stable
         */
        set duration(value: number);
        /**
         * @stability stable
         */
        get durationInput(): number | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleActionForwardTargetGroup {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#arn LbListenerRule#arn}.
         *
         * @stability stable
         */
        readonly arn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#weight LbListenerRule#weight}.
         *
         * @stability stable
         */
        readonly weight?: number;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleActionForward {
        /**
         * stickiness block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#stickiness LbListenerRule#stickiness}
         *
         * @stability stable
         */
        readonly stickiness?: LbListenerRuleActionForwardStickiness;
        /**
         * target_group block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#target_group LbListenerRule#target_group}
         *
         * @stability stable
         */
        readonly targetGroup: LbListenerRuleActionForwardTargetGroup[];
    }
    /**
     * @stability stable
     */
    class LbListenerRuleActionForwardOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _stickiness?;
        private __stickinessOutput;
        /**
         * @stability stable
         */
        get stickiness(): LbListenerRuleActionForwardStickinessOutputReference;
        /**
         * @stability stable
         */
        putStickiness(value: LbListenerRuleActionForwardStickiness | undefined): void;
        /**
         * @stability stable
         */
        resetStickiness(): void;
        /**
         * @stability stable
         */
        get stickinessInput(): LbListenerRuleActionForwardStickiness | undefined;
        private _targetGroup?;
        /**
         * @stability stable
         */
        get targetGroup(): LbListenerRuleActionForwardTargetGroup[];
        /**
         * @stability stable
         */
        set targetGroup(value: LbListenerRuleActionForwardTargetGroup[]);
        /**
         * @stability stable
         */
        get targetGroupInput(): LbListenerRuleActionForwardTargetGroup[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleActionRedirect {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#host LbListenerRule#host}.
         *
         * @stability stable
         */
        readonly host?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#path LbListenerRule#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#port LbListenerRule#port}.
         *
         * @stability stable
         */
        readonly port?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#protocol LbListenerRule#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#query LbListenerRule#query}.
         *
         * @stability stable
         */
        readonly query?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#status_code LbListenerRule#status_code}.
         *
         * @stability stable
         */
        readonly statusCode: string;
    }
    /**
     * @stability stable
     */
    class LbListenerRuleActionRedirectOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _host?;
        /**
         * @stability stable
         */
        get host(): string | undefined;
        /**
         * @stability stable
         */
        set host(value: string | undefined);
        /**
         * @stability stable
         */
        resetHost(): void;
        /**
         * @stability stable
         */
        get hostInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): string | undefined;
        /**
         * @stability stable
         */
        set port(value: string | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _query?;
        /**
         * @stability stable
         */
        get query(): string | undefined;
        /**
         * @stability stable
         */
        set query(value: string | undefined);
        /**
         * @stability stable
         */
        resetQuery(): void;
        /**
         * @stability stable
         */
        get queryInput(): string | undefined;
        private _statusCode?;
        /**
         * @stability stable
         */
        get statusCode(): string;
        /**
         * @stability stable
         */
        set statusCode(value: string);
        /**
         * @stability stable
         */
        get statusCodeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleAction {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#order LbListenerRule#order}.
         *
         * @stability stable
         */
        readonly order?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#target_group_arn LbListenerRule#target_group_arn}.
         *
         * @stability stable
         */
        readonly targetGroupArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#type LbListenerRule#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * authenticate_cognito block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#authenticate_cognito LbListenerRule#authenticate_cognito}
         *
         * @stability stable
         */
        readonly authenticateCognito?: LbListenerRuleActionAuthenticateCognito;
        /**
         * authenticate_oidc block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#authenticate_oidc LbListenerRule#authenticate_oidc}
         *
         * @stability stable
         */
        readonly authenticateOidc?: LbListenerRuleActionAuthenticateOidc;
        /**
         * fixed_response block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#fixed_response LbListenerRule#fixed_response}
         *
         * @stability stable
         */
        readonly fixedResponse?: LbListenerRuleActionFixedResponse;
        /**
         * forward block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#forward LbListenerRule#forward}
         *
         * @stability stable
         */
        readonly forward?: LbListenerRuleActionForward;
        /**
         * redirect block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#redirect LbListenerRule#redirect}
         *
         * @stability stable
         */
        readonly redirect?: LbListenerRuleActionRedirect;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleConditionHostHeader {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#values LbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class LbListenerRuleConditionHostHeaderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleConditionHttpHeader {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#http_header_name LbListenerRule#http_header_name}.
         *
         * @stability stable
         */
        readonly httpHeaderName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#values LbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class LbListenerRuleConditionHttpHeaderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _httpHeaderName?;
        /**
         * @stability stable
         */
        get httpHeaderName(): string;
        /**
         * @stability stable
         */
        set httpHeaderName(value: string);
        /**
         * @stability stable
         */
        get httpHeaderNameInput(): string | undefined;
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleConditionHttpRequestMethod {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#values LbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class LbListenerRuleConditionHttpRequestMethodOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleConditionPathPattern {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#values LbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class LbListenerRuleConditionPathPatternOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleConditionQueryString {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#key LbListenerRule#key}.
         *
         * @stability stable
         */
        readonly key?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#value LbListenerRule#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleConditionSourceIp {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#values LbListenerRule#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * @stability stable
     */
    class LbListenerRuleConditionSourceIpOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _values?;
        /**
         * @stability stable
         */
        get values(): string[];
        /**
         * @stability stable
         */
        set values(value: string[]);
        /**
         * @stability stable
         */
        get valuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface LbListenerRuleCondition {
        /**
         * host_header block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#host_header LbListenerRule#host_header}
         *
         * @stability stable
         */
        readonly hostHeader?: LbListenerRuleConditionHostHeader;
        /**
         * http_header block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#http_header LbListenerRule#http_header}
         *
         * @stability stable
         */
        readonly httpHeader?: LbListenerRuleConditionHttpHeader;
        /**
         * http_request_method block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#http_request_method LbListenerRule#http_request_method}
         *
         * @stability stable
         */
        readonly httpRequestMethod?: LbListenerRuleConditionHttpRequestMethod;
        /**
         * path_pattern block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#path_pattern LbListenerRule#path_pattern}
         *
         * @stability stable
         */
        readonly pathPattern?: LbListenerRuleConditionPathPattern;
        /**
         * query_string block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#query_string LbListenerRule#query_string}
         *
         * @stability stable
         */
        readonly queryString?: LbListenerRuleConditionQueryString[];
        /**
         * source_ip block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html#source_ip LbListenerRule#source_ip}
         *
         * @stability stable
         */
        readonly sourceIp?: LbListenerRuleConditionSourceIp;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html aws_lb_listener_rule}.
     *
     * @stability stable
     */
    class LbListenerRule extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_listener_rule.html aws_lb_listener_rule} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LbListenerRuleConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _listenerArn?;
        /**
         * @stability stable
         */
        get listenerArn(): string;
        /**
         * @stability stable
         */
        set listenerArn(value: string);
        /**
         * @stability stable
         */
        get listenerArnInput(): string | undefined;
        private _priority?;
        /**
         * @stability stable
         */
        get priority(): number | undefined;
        /**
         * @stability stable
         */
        set priority(value: number | undefined);
        /**
         * @stability stable
         */
        resetPriority(): void;
        /**
         * @stability stable
         */
        get priorityInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _action?;
        /**
         * @stability stable
         */
        get action(): LbListenerRuleAction[];
        /**
         * @stability stable
         */
        set action(value: LbListenerRuleAction[]);
        /**
         * @stability stable
         */
        get actionInput(): LbListenerRuleAction[] | undefined;
        private _condition?;
        /**
         * @stability stable
         */
        get condition(): LbListenerRuleCondition[];
        /**
         * @stability stable
         */
        set condition(value: LbListenerRuleCondition[]);
        /**
         * @stability stable
         */
        get conditionInput(): LbListenerRuleCondition[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbSslNegotiationPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html#lb_port LbSslNegotiationPolicy#lb_port}.
         *
         * @stability stable
         */
        readonly lbPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html#load_balancer LbSslNegotiationPolicy#load_balancer}.
         *
         * @stability stable
         */
        readonly loadBalancer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html#name LbSslNegotiationPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * attribute block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html#attribute LbSslNegotiationPolicy#attribute}
         *
         * @stability stable
         */
        readonly attribute?: LbSslNegotiationPolicyAttribute[];
    }
    /**
     * @stability stable
     */
    interface LbSslNegotiationPolicyAttribute {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html#name LbSslNegotiationPolicy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html#value LbSslNegotiationPolicy#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html aws_lb_ssl_negotiation_policy}.
     *
     * @stability stable
     */
    class LbSslNegotiationPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_ssl_negotiation_policy.html aws_lb_ssl_negotiation_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LbSslNegotiationPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _lbPort?;
        /**
         * @stability stable
         */
        get lbPort(): number;
        /**
         * @stability stable
         */
        set lbPort(value: number);
        /**
         * @stability stable
         */
        get lbPortInput(): number | undefined;
        private _loadBalancer?;
        /**
         * @stability stable
         */
        get loadBalancer(): string;
        /**
         * @stability stable
         */
        set loadBalancer(value: string);
        /**
         * @stability stable
         */
        get loadBalancerInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _attribute?;
        /**
         * @stability stable
         */
        get attribute(): LbSslNegotiationPolicyAttribute[] | undefined;
        /**
         * @stability stable
         */
        set attribute(value: LbSslNegotiationPolicyAttribute[] | undefined);
        /**
         * @stability stable
         */
        resetAttribute(): void;
        /**
         * @stability stable
         */
        get attributeInput(): LbSslNegotiationPolicyAttribute[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbTargetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#deregistration_delay LbTargetGroup#deregistration_delay}.
         *
         * @stability stable
         */
        readonly deregistrationDelay?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#lambda_multi_value_headers_enabled LbTargetGroup#lambda_multi_value_headers_enabled}.
         *
         * @stability stable
         */
        readonly lambdaMultiValueHeadersEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#load_balancing_algorithm_type LbTargetGroup#load_balancing_algorithm_type}.
         *
         * @stability stable
         */
        readonly loadBalancingAlgorithmType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#name LbTargetGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#name_prefix LbTargetGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#port LbTargetGroup#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#preserve_client_ip LbTargetGroup#preserve_client_ip}.
         *
         * @stability stable
         */
        readonly preserveClientIp?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#protocol LbTargetGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#protocol_version LbTargetGroup#protocol_version}.
         *
         * @stability stable
         */
        readonly protocolVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#proxy_protocol_v2 LbTargetGroup#proxy_protocol_v2}.
         *
         * @stability stable
         */
        readonly proxyProtocolV2?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#slow_start LbTargetGroup#slow_start}.
         *
         * @stability stable
         */
        readonly slowStart?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#tags LbTargetGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#tags_all LbTargetGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#target_type LbTargetGroup#target_type}.
         *
         * @stability stable
         */
        readonly targetType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#vpc_id LbTargetGroup#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * health_check block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#health_check LbTargetGroup#health_check}
         *
         * @stability stable
         */
        readonly healthCheck?: LbTargetGroupHealthCheck;
        /**
         * stickiness block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#stickiness LbTargetGroup#stickiness}
         *
         * @stability stable
         */
        readonly stickiness?: LbTargetGroupStickiness;
    }
    /**
     * @stability stable
     */
    interface LbTargetGroupHealthCheck {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#enabled LbTargetGroup#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#healthy_threshold LbTargetGroup#healthy_threshold}.
         *
         * @stability stable
         */
        readonly healthyThreshold?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#interval LbTargetGroup#interval}.
         *
         * @stability stable
         */
        readonly interval?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#matcher LbTargetGroup#matcher}.
         *
         * @stability stable
         */
        readonly matcher?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#path LbTargetGroup#path}.
         *
         * @stability stable
         */
        readonly path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#port LbTargetGroup#port}.
         *
         * @stability stable
         */
        readonly port?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#protocol LbTargetGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#timeout LbTargetGroup#timeout}.
         *
         * @stability stable
         */
        readonly timeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#unhealthy_threshold LbTargetGroup#unhealthy_threshold}.
         *
         * @stability stable
         */
        readonly unhealthyThreshold?: number;
    }
    /**
     * @stability stable
     */
    class LbTargetGroupHealthCheckOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _healthyThreshold?;
        /**
         * @stability stable
         */
        get healthyThreshold(): number | undefined;
        /**
         * @stability stable
         */
        set healthyThreshold(value: number | undefined);
        /**
         * @stability stable
         */
        resetHealthyThreshold(): void;
        /**
         * @stability stable
         */
        get healthyThresholdInput(): number | undefined;
        private _interval?;
        /**
         * @stability stable
         */
        get interval(): number | undefined;
        /**
         * @stability stable
         */
        set interval(value: number | undefined);
        /**
         * @stability stable
         */
        resetInterval(): void;
        /**
         * @stability stable
         */
        get intervalInput(): number | undefined;
        private _matcher?;
        /**
         * @stability stable
         */
        get matcher(): string | undefined;
        /**
         * @stability stable
         */
        set matcher(value: string | undefined);
        /**
         * @stability stable
         */
        resetMatcher(): void;
        /**
         * @stability stable
         */
        get matcherInput(): string | undefined;
        private _path?;
        /**
         * @stability stable
         */
        get path(): string | undefined;
        /**
         * @stability stable
         */
        set path(value: string | undefined);
        /**
         * @stability stable
         */
        resetPath(): void;
        /**
         * @stability stable
         */
        get pathInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): string | undefined;
        /**
         * @stability stable
         */
        set port(value: string | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _timeout?;
        /**
         * @stability stable
         */
        get timeout(): number | undefined;
        /**
         * @stability stable
         */
        set timeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeout(): void;
        /**
         * @stability stable
         */
        get timeoutInput(): number | undefined;
        private _unhealthyThreshold?;
        /**
         * @stability stable
         */
        get unhealthyThreshold(): number | undefined;
        /**
         * @stability stable
         */
        set unhealthyThreshold(value: number | undefined);
        /**
         * @stability stable
         */
        resetUnhealthyThreshold(): void;
        /**
         * @stability stable
         */
        get unhealthyThresholdInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface LbTargetGroupStickiness {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#cookie_duration LbTargetGroup#cookie_duration}.
         *
         * @stability stable
         */
        readonly cookieDuration?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#cookie_name LbTargetGroup#cookie_name}.
         *
         * @stability stable
         */
        readonly cookieName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#enabled LbTargetGroup#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html#type LbTargetGroup#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * @stability stable
     */
    class LbTargetGroupStickinessOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cookieDuration?;
        /**
         * @stability stable
         */
        get cookieDuration(): number | undefined;
        /**
         * @stability stable
         */
        set cookieDuration(value: number | undefined);
        /**
         * @stability stable
         */
        resetCookieDuration(): void;
        /**
         * @stability stable
         */
        get cookieDurationInput(): number | undefined;
        private _cookieName?;
        /**
         * @stability stable
         */
        get cookieName(): string | undefined;
        /**
         * @stability stable
         */
        set cookieName(value: string | undefined);
        /**
         * @stability stable
         */
        resetCookieName(): void;
        /**
         * @stability stable
         */
        get cookieNameInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html aws_lb_target_group}.
     *
     * @stability stable
     */
    class LbTargetGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group.html aws_lb_target_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: LbTargetGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        private _deregistrationDelay?;
        /**
         * @stability stable
         */
        get deregistrationDelay(): string | undefined;
        /**
         * @stability stable
         */
        set deregistrationDelay(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeregistrationDelay(): void;
        /**
         * @stability stable
         */
        get deregistrationDelayInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _lambdaMultiValueHeadersEnabled?;
        /**
         * @stability stable
         */
        get lambdaMultiValueHeadersEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set lambdaMultiValueHeadersEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetLambdaMultiValueHeadersEnabled(): void;
        /**
         * @stability stable
         */
        get lambdaMultiValueHeadersEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _loadBalancingAlgorithmType?;
        /**
         * @stability stable
         */
        get loadBalancingAlgorithmType(): string | undefined;
        /**
         * @stability stable
         */
        set loadBalancingAlgorithmType(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancingAlgorithmType(): void;
        /**
         * @stability stable
         */
        get loadBalancingAlgorithmTypeInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _preserveClientIp?;
        /**
         * @stability stable
         */
        get preserveClientIp(): string | undefined;
        /**
         * @stability stable
         */
        set preserveClientIp(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreserveClientIp(): void;
        /**
         * @stability stable
         */
        get preserveClientIpInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string | undefined;
        /**
         * @stability stable
         */
        set protocol(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocol(): void;
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _protocolVersion?;
        /**
         * @stability stable
         */
        get protocolVersion(): string | undefined;
        /**
         * @stability stable
         */
        set protocolVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetProtocolVersion(): void;
        /**
         * @stability stable
         */
        get protocolVersionInput(): string | undefined;
        private _proxyProtocolV2?;
        /**
         * @stability stable
         */
        get proxyProtocolV2(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set proxyProtocolV2(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetProxyProtocolV2(): void;
        /**
         * @stability stable
         */
        get proxyProtocolV2Input(): boolean | cdktf.IResolvable | undefined;
        private _slowStart?;
        /**
         * @stability stable
         */
        get slowStart(): number | undefined;
        /**
         * @stability stable
         */
        set slowStart(value: number | undefined);
        /**
         * @stability stable
         */
        resetSlowStart(): void;
        /**
         * @stability stable
         */
        get slowStartInput(): number | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetType?;
        /**
         * @stability stable
         */
        get targetType(): string | undefined;
        /**
         * @stability stable
         */
        set targetType(value: string | undefined);
        /**
         * @stability stable
         */
        resetTargetType(): void;
        /**
         * @stability stable
         */
        get targetTypeInput(): string | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _healthCheck?;
        private __healthCheckOutput;
        /**
         * @stability stable
         */
        get healthCheck(): LbTargetGroupHealthCheckOutputReference;
        /**
         * @stability stable
         */
        putHealthCheck(value: LbTargetGroupHealthCheck | undefined): void;
        /**
         * @stability stable
         */
        resetHealthCheck(): void;
        /**
         * @stability stable
         */
        get healthCheckInput(): LbTargetGroupHealthCheck | undefined;
        private _stickiness?;
        private __stickinessOutput;
        /**
         * @stability stable
         */
        get stickiness(): LbTargetGroupStickinessOutputReference;
        /**
         * @stability stable
         */
        putStickiness(value: LbTargetGroupStickiness | undefined): void;
        /**
         * @stability stable
         */
        resetStickiness(): void;
        /**
         * @stability stable
         */
        get stickinessInput(): LbTargetGroupStickiness | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LbTargetGroupAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group_attachment.html#availability_zone LbTargetGroupAttachment#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group_attachment.html#port LbTargetGroupAttachment#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group_attachment.html#target_group_arn LbTargetGroupAttachment#target_group_arn}.
         *
         * @stability stable
         */
        readonly targetGroupArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group_attachment.html#target_id LbTargetGroupAttachment#target_id}.
         *
         * @stability stable
         */
        readonly targetId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group_attachment.html aws_lb_target_group_attachment}.
     *
     * @stability stable
     */
    class LbTargetGroupAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/lb_target_group_attachment.html aws_lb_target_group_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LbTargetGroupAttachmentConfig);
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _targetGroupArn?;
        /**
         * @stability stable
         */
        get targetGroupArn(): string;
        /**
         * @stability stable
         */
        set targetGroupArn(value: string);
        /**
         * @stability stable
         */
        get targetGroupArnInput(): string | undefined;
        private _targetId?;
        /**
         * @stability stable
         */
        get targetId(): string;
        /**
         * @stability stable
         */
        set targetId(value: string);
        /**
         * @stability stable
         */
        get targetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LoadBalancerBackendServerPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_backend_server_policy.html#instance_port LoadBalancerBackendServerPolicy#instance_port}.
         *
         * @stability stable
         */
        readonly instancePort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_backend_server_policy.html#load_balancer_name LoadBalancerBackendServerPolicy#load_balancer_name}.
         *
         * @stability stable
         */
        readonly loadBalancerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_backend_server_policy.html#policy_names LoadBalancerBackendServerPolicy#policy_names}.
         *
         * @stability stable
         */
        readonly policyNames?: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_backend_server_policy.html aws_load_balancer_backend_server_policy}.
     *
     * @stability stable
     */
    class LoadBalancerBackendServerPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_backend_server_policy.html aws_load_balancer_backend_server_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LoadBalancerBackendServerPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _instancePort?;
        /**
         * @stability stable
         */
        get instancePort(): number;
        /**
         * @stability stable
         */
        set instancePort(value: number);
        /**
         * @stability stable
         */
        get instancePortInput(): number | undefined;
        private _loadBalancerName?;
        /**
         * @stability stable
         */
        get loadBalancerName(): string;
        /**
         * @stability stable
         */
        set loadBalancerName(value: string);
        /**
         * @stability stable
         */
        get loadBalancerNameInput(): string | undefined;
        private _policyNames?;
        /**
         * @stability stable
         */
        get policyNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set policyNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPolicyNames(): void;
        /**
         * @stability stable
         */
        get policyNamesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LoadBalancerListenerPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_listener_policy.html#load_balancer_name LoadBalancerListenerPolicy#load_balancer_name}.
         *
         * @stability stable
         */
        readonly loadBalancerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_listener_policy.html#load_balancer_port LoadBalancerListenerPolicy#load_balancer_port}.
         *
         * @stability stable
         */
        readonly loadBalancerPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_listener_policy.html#policy_names LoadBalancerListenerPolicy#policy_names}.
         *
         * @stability stable
         */
        readonly policyNames?: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_listener_policy.html aws_load_balancer_listener_policy}.
     *
     * @stability stable
     */
    class LoadBalancerListenerPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_listener_policy.html aws_load_balancer_listener_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LoadBalancerListenerPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _loadBalancerName?;
        /**
         * @stability stable
         */
        get loadBalancerName(): string;
        /**
         * @stability stable
         */
        set loadBalancerName(value: string);
        /**
         * @stability stable
         */
        get loadBalancerNameInput(): string | undefined;
        private _loadBalancerPort?;
        /**
         * @stability stable
         */
        get loadBalancerPort(): number;
        /**
         * @stability stable
         */
        set loadBalancerPort(value: number);
        /**
         * @stability stable
         */
        get loadBalancerPortInput(): number | undefined;
        private _policyNames?;
        /**
         * @stability stable
         */
        get policyNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set policyNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPolicyNames(): void;
        /**
         * @stability stable
         */
        get policyNamesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface LoadBalancerPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html#load_balancer_name LoadBalancerPolicy#load_balancer_name}.
         *
         * @stability stable
         */
        readonly loadBalancerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html#policy_name LoadBalancerPolicy#policy_name}.
         *
         * @stability stable
         */
        readonly policyName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html#policy_type_name LoadBalancerPolicy#policy_type_name}.
         *
         * @stability stable
         */
        readonly policyTypeName: string;
        /**
         * policy_attribute block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html#policy_attribute LoadBalancerPolicy#policy_attribute}
         *
         * @stability stable
         */
        readonly policyAttribute?: LoadBalancerPolicyPolicyAttribute[];
    }
    /**
     * @stability stable
     */
    interface LoadBalancerPolicyPolicyAttribute {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html#name LoadBalancerPolicy#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html#value LoadBalancerPolicy#value}.
         *
         * @stability stable
         */
        readonly value?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html aws_load_balancer_policy}.
     *
     * @stability stable
     */
    class LoadBalancerPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/load_balancer_policy.html aws_load_balancer_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: LoadBalancerPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _loadBalancerName?;
        /**
         * @stability stable
         */
        get loadBalancerName(): string;
        /**
         * @stability stable
         */
        set loadBalancerName(value: string);
        /**
         * @stability stable
         */
        get loadBalancerNameInput(): string | undefined;
        private _policyName?;
        /**
         * @stability stable
         */
        get policyName(): string;
        /**
         * @stability stable
         */
        set policyName(value: string);
        /**
         * @stability stable
         */
        get policyNameInput(): string | undefined;
        private _policyTypeName?;
        /**
         * @stability stable
         */
        get policyTypeName(): string;
        /**
         * @stability stable
         */
        set policyTypeName(value: string);
        /**
         * @stability stable
         */
        get policyTypeNameInput(): string | undefined;
        private _policyAttribute?;
        /**
         * @stability stable
         */
        get policyAttribute(): LoadBalancerPolicyPolicyAttribute[] | undefined;
        /**
         * @stability stable
         */
        set policyAttribute(value: LoadBalancerPolicyPolicyAttribute[] | undefined);
        /**
         * @stability stable
         */
        resetPolicyAttribute(): void;
        /**
         * @stability stable
         */
        get policyAttributeInput(): LoadBalancerPolicyPolicyAttribute[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface ProxyProtocolPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/proxy_protocol_policy.html#instance_ports ProxyProtocolPolicy#instance_ports}.
         *
         * @stability stable
         */
        readonly instancePorts: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/proxy_protocol_policy.html#load_balancer ProxyProtocolPolicy#load_balancer}.
         *
         * @stability stable
         */
        readonly loadBalancer: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/proxy_protocol_policy.html aws_proxy_protocol_policy}.
     *
     * @stability stable
     */
    class ProxyProtocolPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/proxy_protocol_policy.html aws_proxy_protocol_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: ProxyProtocolPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _instancePorts?;
        /**
         * @stability stable
         */
        get instancePorts(): string[];
        /**
         * @stability stable
         */
        set instancePorts(value: string[]);
        /**
         * @stability stable
         */
        get instancePortsInput(): string[] | undefined;
        private _loadBalancer?;
        /**
         * @stability stable
         */
        get loadBalancer(): string;
        /**
         * @stability stable
         */
        set loadBalancer(value: string);
        /**
         * @stability stable
         */
        get loadBalancerInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAlbConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb.html#name DataAwsAlb#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb.html#tags DataAwsAlb#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbAccessLogs extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get prefix(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbSubnetMapping extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get allocationId(): string;
        /**
         * @stability stable
         */
        get ipv6Address(): string;
        /**
         * @stability stable
         */
        get outpostId(): string;
        /**
         * @stability stable
         */
        get privateIpv4Address(): string;
        /**
         * @stability stable
         */
        get subnetId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/alb.html aws_alb}.
     *
     * @stability stable
     */
    class DataAwsAlb extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/alb.html aws_alb} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsAlbConfig);
        /**
         * @stability stable
         */
        accessLogs(index: string): DataAwsAlbAccessLogs;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        /**
         * @stability stable
         */
        get customerOwnedIpv4Pool(): string;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get dropInvalidHeaderFields(): any;
        /**
         * @stability stable
         */
        get enableDeletionProtection(): any;
        /**
         * @stability stable
         */
        get enableHttp2(): any;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get idleTimeout(): number;
        /**
         * @stability stable
         */
        get internal(): any;
        /**
         * @stability stable
         */
        get ipAddressType(): string;
        /**
         * @stability stable
         */
        get loadBalancerType(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get securityGroups(): string[];
        /**
         * @stability stable
         */
        subnetMapping(index: string): DataAwsAlbSubnetMapping;
        /**
         * @stability stable
         */
        get subnets(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        get zoneId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAlbListenerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_listener.html#load_balancer_arn DataAwsAlbListener#load_balancer_arn}.
         *
         * @stability stable
         */
        readonly loadBalancerArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_listener.html#port DataAwsAlbListener#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_listener.html#tags DataAwsAlbListener#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultActionAuthenticateCognito extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): any;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string;
        /**
         * @stability stable
         */
        get scope(): string;
        /**
         * @stability stable
         */
        get sessionCookieName(): string;
        /**
         * @stability stable
         */
        get sessionTimeout(): number;
        /**
         * @stability stable
         */
        get userPoolArn(): string;
        /**
         * @stability stable
         */
        get userPoolClientId(): string;
        /**
         * @stability stable
         */
        get userPoolDomain(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultActionAuthenticateOidc extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): any;
        /**
         * @stability stable
         */
        get authorizationEndpoint(): string;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string;
        /**
         * @stability stable
         */
        get scope(): string;
        /**
         * @stability stable
         */
        get sessionCookieName(): string;
        /**
         * @stability stable
         */
        get sessionTimeout(): number;
        /**
         * @stability stable
         */
        get tokenEndpoint(): string;
        /**
         * @stability stable
         */
        get userInfoEndpoint(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultActionFixedResponse extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        get messageBody(): string;
        /**
         * @stability stable
         */
        get statusCode(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultActionForwardStickiness extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get duration(): number;
        /**
         * @stability stable
         */
        get enabled(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultActionForwardTargetGroup extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get weight(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultActionForward extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get stickiness(): any;
        /**
         * @stability stable
         */
        get targetGroup(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultActionRedirect extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get host(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get port(): string;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get query(): string;
        /**
         * @stability stable
         */
        get statusCode(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbListenerDefaultAction extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get authenticateCognito(): any;
        /**
         * @stability stable
         */
        get authenticateOidc(): any;
        /**
         * @stability stable
         */
        get fixedResponse(): any;
        /**
         * @stability stable
         */
        get forward(): any;
        /**
         * @stability stable
         */
        get order(): number;
        /**
         * @stability stable
         */
        get redirect(): any;
        /**
         * @stability stable
         */
        get targetGroupArn(): string;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/alb_listener.html aws_alb_listener}.
     *
     * @stability stable
     */
    class DataAwsAlbListener extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/alb_listener.html aws_alb_listener} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsAlbListenerConfig);
        /**
         * @stability stable
         */
        get alpnPolicy(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificateArn(): string;
        /**
         * @stability stable
         */
        defaultAction(index: string): DataAwsAlbListenerDefaultAction;
        /**
         * @stability stable
         */
        get id(): string;
        private _loadBalancerArn?;
        /**
         * @stability stable
         */
        get loadBalancerArn(): string | undefined;
        /**
         * @stability stable
         */
        set loadBalancerArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancerArn(): void;
        /**
         * @stability stable
         */
        get loadBalancerArnInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get sslPolicy(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsAlbTargetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group.html#name DataAwsAlbTargetGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group.html#tags DataAwsAlbTargetGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbTargetGroupHealthCheck extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get healthyThreshold(): number;
        /**
         * @stability stable
         */
        get interval(): number;
        /**
         * @stability stable
         */
        get matcher(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get port(): string;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get timeout(): number;
        /**
         * @stability stable
         */
        get unhealthyThreshold(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsAlbTargetGroupStickiness extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get cookieDuration(): number;
        /**
         * @stability stable
         */
        get cookieName(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group.html aws_alb_target_group}.
     *
     * @stability stable
     */
    class DataAwsAlbTargetGroup extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/alb_target_group.html aws_alb_target_group} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsAlbTargetGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        /**
         * @stability stable
         */
        get deregistrationDelay(): number;
        /**
         * @stability stable
         */
        healthCheck(index: string): DataAwsAlbTargetGroupHealthCheck;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lambdaMultiValueHeadersEnabled(): any;
        /**
         * @stability stable
         */
        get loadBalancingAlgorithmType(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get preserveClientIp(): string;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get protocolVersion(): string;
        /**
         * @stability stable
         */
        get proxyProtocolV2(): any;
        /**
         * @stability stable
         */
        get slowStart(): number;
        /**
         * @stability stable
         */
        stickiness(index: string): DataAwsAlbTargetGroupStickiness;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get targetType(): string;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLbConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb.html#name DataAwsLb#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb.html#tags DataAwsLb#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsLbAccessLogs extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get bucket(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get prefix(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLbSubnetMapping extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get allocationId(): string;
        /**
         * @stability stable
         */
        get ipv6Address(): string;
        /**
         * @stability stable
         */
        get outpostId(): string;
        /**
         * @stability stable
         */
        get privateIpv4Address(): string;
        /**
         * @stability stable
         */
        get subnetId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lb.html aws_lb}.
     *
     * @stability stable
     */
    class DataAwsLb extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lb.html aws_lb} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsLbConfig);
        /**
         * @stability stable
         */
        accessLogs(index: string): DataAwsLbAccessLogs;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        /**
         * @stability stable
         */
        get customerOwnedIpv4Pool(): string;
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get dropInvalidHeaderFields(): any;
        /**
         * @stability stable
         */
        get enableDeletionProtection(): any;
        /**
         * @stability stable
         */
        get enableHttp2(): any;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get idleTimeout(): number;
        /**
         * @stability stable
         */
        get internal(): any;
        /**
         * @stability stable
         */
        get ipAddressType(): string;
        /**
         * @stability stable
         */
        get loadBalancerType(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get securityGroups(): string[];
        /**
         * @stability stable
         */
        subnetMapping(index: string): DataAwsLbSubnetMapping;
        /**
         * @stability stable
         */
        get subnets(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        get zoneId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLbListenerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener.html#load_balancer_arn DataAwsLbListener#load_balancer_arn}.
         *
         * @stability stable
         */
        readonly loadBalancerArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener.html#port DataAwsLbListener#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_listener.html#tags DataAwsLbListener#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultActionAuthenticateCognito extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): any;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string;
        /**
         * @stability stable
         */
        get scope(): string;
        /**
         * @stability stable
         */
        get sessionCookieName(): string;
        /**
         * @stability stable
         */
        get sessionTimeout(): number;
        /**
         * @stability stable
         */
        get userPoolArn(): string;
        /**
         * @stability stable
         */
        get userPoolClientId(): string;
        /**
         * @stability stable
         */
        get userPoolDomain(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultActionAuthenticateOidc extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get authenticationRequestExtraParams(): any;
        /**
         * @stability stable
         */
        get authorizationEndpoint(): string;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        get onUnauthenticatedRequest(): string;
        /**
         * @stability stable
         */
        get scope(): string;
        /**
         * @stability stable
         */
        get sessionCookieName(): string;
        /**
         * @stability stable
         */
        get sessionTimeout(): number;
        /**
         * @stability stable
         */
        get tokenEndpoint(): string;
        /**
         * @stability stable
         */
        get userInfoEndpoint(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultActionFixedResponse extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get contentType(): string;
        /**
         * @stability stable
         */
        get messageBody(): string;
        /**
         * @stability stable
         */
        get statusCode(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultActionForwardStickiness extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get duration(): number;
        /**
         * @stability stable
         */
        get enabled(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultActionForwardTargetGroup extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get weight(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultActionForward extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get stickiness(): any;
        /**
         * @stability stable
         */
        get targetGroup(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultActionRedirect extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get host(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get port(): string;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get query(): string;
        /**
         * @stability stable
         */
        get statusCode(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsLbListenerDefaultAction extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get authenticateCognito(): any;
        /**
         * @stability stable
         */
        get authenticateOidc(): any;
        /**
         * @stability stable
         */
        get fixedResponse(): any;
        /**
         * @stability stable
         */
        get forward(): any;
        /**
         * @stability stable
         */
        get order(): number;
        /**
         * @stability stable
         */
        get redirect(): any;
        /**
         * @stability stable
         */
        get targetGroupArn(): string;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lb_listener.html aws_lb_listener}.
     *
     * @stability stable
     */
    class DataAwsLbListener extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lb_listener.html aws_lb_listener} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsLbListenerConfig);
        /**
         * @stability stable
         */
        get alpnPolicy(): string;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificateArn(): string;
        /**
         * @stability stable
         */
        defaultAction(index: string): DataAwsLbListenerDefaultAction;
        /**
         * @stability stable
         */
        get id(): string;
        private _loadBalancerArn?;
        /**
         * @stability stable
         */
        get loadBalancerArn(): string | undefined;
        /**
         * @stability stable
         */
        set loadBalancerArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetLoadBalancerArn(): void;
        /**
         * @stability stable
         */
        get loadBalancerArnInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get sslPolicy(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsLbTargetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group.html#name DataAwsLbTargetGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group.html#tags DataAwsLbTargetGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsLbTargetGroupHealthCheck extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get healthyThreshold(): number;
        /**
         * @stability stable
         */
        get interval(): number;
        /**
         * @stability stable
         */
        get matcher(): string;
        /**
         * @stability stable
         */
        get path(): string;
        /**
         * @stability stable
         */
        get port(): string;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get timeout(): number;
        /**
         * @stability stable
         */
        get unhealthyThreshold(): number;
    }
    /**
     * @stability stable
     */
    class DataAwsLbTargetGroupStickiness extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get cookieDuration(): number;
        /**
         * @stability stable
         */
        get cookieName(): string;
        /**
         * @stability stable
         */
        get enabled(): any;
        /**
         * @stability stable
         */
        get type(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group.html aws_lb_target_group}.
     *
     * @stability stable
     */
    class DataAwsLbTargetGroup extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/lb_target_group.html aws_lb_target_group} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsLbTargetGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get arnSuffix(): string;
        /**
         * @stability stable
         */
        get deregistrationDelay(): number;
        /**
         * @stability stable
         */
        healthCheck(index: string): DataAwsLbTargetGroupHealthCheck;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lambdaMultiValueHeadersEnabled(): any;
        /**
         * @stability stable
         */
        get loadBalancingAlgorithmType(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get preserveClientIp(): string;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        get protocolVersion(): string;
        /**
         * @stability stable
         */
        get proxyProtocolV2(): any;
        /**
         * @stability stable
         */
        get slowStart(): number;
        /**
         * @stability stable
         */
        stickiness(index: string): DataAwsLbTargetGroupStickiness;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get targetType(): string;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
