import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Glue
*/
export declare namespace Glue {
    /**
     * @stability stable
     */
    interface GlueCatalogDatabaseConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#catalog_id GlueCatalogDatabase#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#description GlueCatalogDatabase#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#location_uri GlueCatalogDatabase#location_uri}.
         *
         * @stability stable
         */
        readonly locationUri?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#name GlueCatalogDatabase#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#parameters GlueCatalogDatabase#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * target_database block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#target_database GlueCatalogDatabase#target_database}
         *
         * @stability stable
         */
        readonly targetDatabase?: GlueCatalogDatabaseTargetDatabase;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogDatabaseTargetDatabase {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#catalog_id GlueCatalogDatabase#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html#database_name GlueCatalogDatabase#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
    }
    /**
     * @stability stable
     */
    class GlueCatalogDatabaseTargetDatabaseOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string;
        /**
         * @stability stable
         */
        set catalogId(value: string);
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html aws_glue_catalog_database}.
     *
     * @stability stable
     */
    class GlueCatalogDatabase extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_database.html aws_glue_catalog_database} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueCatalogDatabaseConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _locationUri?;
        /**
         * @stability stable
         */
        get locationUri(): string | undefined;
        /**
         * @stability stable
         */
        set locationUri(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocationUri(): void;
        /**
         * @stability stable
         */
        get locationUriInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetDatabase?;
        private __targetDatabaseOutput;
        /**
         * @stability stable
         */
        get targetDatabase(): GlueCatalogDatabaseTargetDatabaseOutputReference;
        /**
         * @stability stable
         */
        putTargetDatabase(value: GlueCatalogDatabaseTargetDatabase | undefined): void;
        /**
         * @stability stable
         */
        resetTargetDatabase(): void;
        /**
         * @stability stable
         */
        get targetDatabaseInput(): GlueCatalogDatabaseTargetDatabase | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#catalog_id GlueCatalogTable#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#database_name GlueCatalogTable#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#description GlueCatalogTable#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#name GlueCatalogTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#owner GlueCatalogTable#owner}.
         *
         * @stability stable
         */
        readonly owner?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#parameters GlueCatalogTable#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#retention GlueCatalogTable#retention}.
         *
         * @stability stable
         */
        readonly retention?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#table_type GlueCatalogTable#table_type}.
         *
         * @stability stable
         */
        readonly tableType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#view_expanded_text GlueCatalogTable#view_expanded_text}.
         *
         * @stability stable
         */
        readonly viewExpandedText?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#view_original_text GlueCatalogTable#view_original_text}.
         *
         * @stability stable
         */
        readonly viewOriginalText?: string;
        /**
         * partition_index block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#partition_index GlueCatalogTable#partition_index}
         *
         * @stability stable
         */
        readonly partitionIndex?: GlueCatalogTablePartitionIndex[];
        /**
         * partition_keys block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#partition_keys GlueCatalogTable#partition_keys}
         *
         * @stability stable
         */
        readonly partitionKeys?: GlueCatalogTablePartitionKeys[];
        /**
         * storage_descriptor block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#storage_descriptor GlueCatalogTable#storage_descriptor}
         *
         * @stability stable
         */
        readonly storageDescriptor?: GlueCatalogTableStorageDescriptor;
        /**
         * target_table block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#target_table GlueCatalogTable#target_table}
         *
         * @stability stable
         */
        readonly targetTable?: GlueCatalogTableTargetTable;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTablePartitionIndex {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#index_name GlueCatalogTable#index_name}.
         *
         * @stability stable
         */
        readonly indexName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#keys GlueCatalogTable#keys}.
         *
         * @stability stable
         */
        readonly keys: string[];
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTablePartitionKeys {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#comment GlueCatalogTable#comment}.
         *
         * @stability stable
         */
        readonly comment?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#name GlueCatalogTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#type GlueCatalogTable#type}.
         *
         * @stability stable
         */
        readonly type?: string;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableStorageDescriptorColumns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#comment GlueCatalogTable#comment}.
         *
         * @stability stable
         */
        readonly comment?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#name GlueCatalogTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#parameters GlueCatalogTable#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#type GlueCatalogTable#type}.
         *
         * @stability stable
         */
        readonly type?: string;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableStorageDescriptorSchemaReferenceSchemaId {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#registry_name GlueCatalogTable#registry_name}.
         *
         * @stability stable
         */
        readonly registryName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#schema_arn GlueCatalogTable#schema_arn}.
         *
         * @stability stable
         */
        readonly schemaArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#schema_name GlueCatalogTable#schema_name}.
         *
         * @stability stable
         */
        readonly schemaName?: string;
    }
    /**
     * @stability stable
     */
    class GlueCatalogTableStorageDescriptorSchemaReferenceSchemaIdOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _registryName?;
        /**
         * @stability stable
         */
        get registryName(): string | undefined;
        /**
         * @stability stable
         */
        set registryName(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegistryName(): void;
        /**
         * @stability stable
         */
        get registryNameInput(): string | undefined;
        private _schemaArn?;
        /**
         * @stability stable
         */
        get schemaArn(): string | undefined;
        /**
         * @stability stable
         */
        set schemaArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchemaArn(): void;
        /**
         * @stability stable
         */
        get schemaArnInput(): string | undefined;
        private _schemaName?;
        /**
         * @stability stable
         */
        get schemaName(): string | undefined;
        /**
         * @stability stable
         */
        set schemaName(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchemaName(): void;
        /**
         * @stability stable
         */
        get schemaNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableStorageDescriptorSchemaReference {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#schema_version_id GlueCatalogTable#schema_version_id}.
         *
         * @stability stable
         */
        readonly schemaVersionId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#schema_version_number GlueCatalogTable#schema_version_number}.
         *
         * @stability stable
         */
        readonly schemaVersionNumber: number;
        /**
         * schema_id block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#schema_id GlueCatalogTable#schema_id}
         *
         * @stability stable
         */
        readonly schemaId?: GlueCatalogTableStorageDescriptorSchemaReferenceSchemaId;
    }
    /**
     * @stability stable
     */
    class GlueCatalogTableStorageDescriptorSchemaReferenceOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _schemaVersionId?;
        /**
         * @stability stable
         */
        get schemaVersionId(): string | undefined;
        /**
         * @stability stable
         */
        set schemaVersionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchemaVersionId(): void;
        /**
         * @stability stable
         */
        get schemaVersionIdInput(): string | undefined;
        private _schemaVersionNumber?;
        /**
         * @stability stable
         */
        get schemaVersionNumber(): number;
        /**
         * @stability stable
         */
        set schemaVersionNumber(value: number);
        /**
         * @stability stable
         */
        get schemaVersionNumberInput(): number | undefined;
        private _schemaId?;
        private __schemaIdOutput;
        /**
         * @stability stable
         */
        get schemaId(): GlueCatalogTableStorageDescriptorSchemaReferenceSchemaIdOutputReference;
        /**
         * @stability stable
         */
        putSchemaId(value: GlueCatalogTableStorageDescriptorSchemaReferenceSchemaId | undefined): void;
        /**
         * @stability stable
         */
        resetSchemaId(): void;
        /**
         * @stability stable
         */
        get schemaIdInput(): GlueCatalogTableStorageDescriptorSchemaReferenceSchemaId | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableStorageDescriptorSerDeInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#name GlueCatalogTable#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#parameters GlueCatalogTable#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#serialization_library GlueCatalogTable#serialization_library}.
         *
         * @stability stable
         */
        readonly serializationLibrary?: string;
    }
    /**
     * @stability stable
     */
    class GlueCatalogTableStorageDescriptorSerDeInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _serializationLibrary?;
        /**
         * @stability stable
         */
        get serializationLibrary(): string | undefined;
        /**
         * @stability stable
         */
        set serializationLibrary(value: string | undefined);
        /**
         * @stability stable
         */
        resetSerializationLibrary(): void;
        /**
         * @stability stable
         */
        get serializationLibraryInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableStorageDescriptorSkewedInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#skewed_column_names GlueCatalogTable#skewed_column_names}.
         *
         * @stability stable
         */
        readonly skewedColumnNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#skewed_column_value_location_maps GlueCatalogTable#skewed_column_value_location_maps}.
         *
         * @stability stable
         */
        readonly skewedColumnValueLocationMaps?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#skewed_column_values GlueCatalogTable#skewed_column_values}.
         *
         * @stability stable
         */
        readonly skewedColumnValues?: string[];
    }
    /**
     * @stability stable
     */
    class GlueCatalogTableStorageDescriptorSkewedInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _skewedColumnNames?;
        /**
         * @stability stable
         */
        get skewedColumnNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set skewedColumnNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSkewedColumnNames(): void;
        /**
         * @stability stable
         */
        get skewedColumnNamesInput(): string[] | undefined;
        private _skewedColumnValueLocationMaps?;
        /**
         * @stability stable
         */
        get skewedColumnValueLocationMaps(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set skewedColumnValueLocationMaps(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSkewedColumnValueLocationMaps(): void;
        /**
         * @stability stable
         */
        get skewedColumnValueLocationMapsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _skewedColumnValues?;
        /**
         * @stability stable
         */
        get skewedColumnValues(): string[] | undefined;
        /**
         * @stability stable
         */
        set skewedColumnValues(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSkewedColumnValues(): void;
        /**
         * @stability stable
         */
        get skewedColumnValuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableStorageDescriptorSortColumns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#column GlueCatalogTable#column}.
         *
         * @stability stable
         */
        readonly column: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#sort_order GlueCatalogTable#sort_order}.
         *
         * @stability stable
         */
        readonly sortOrder: number;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableStorageDescriptor {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#bucket_columns GlueCatalogTable#bucket_columns}.
         *
         * @stability stable
         */
        readonly bucketColumns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#compressed GlueCatalogTable#compressed}.
         *
         * @stability stable
         */
        readonly compressed?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#input_format GlueCatalogTable#input_format}.
         *
         * @stability stable
         */
        readonly inputFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#location GlueCatalogTable#location}.
         *
         * @stability stable
         */
        readonly location?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#number_of_buckets GlueCatalogTable#number_of_buckets}.
         *
         * @stability stable
         */
        readonly numberOfBuckets?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#output_format GlueCatalogTable#output_format}.
         *
         * @stability stable
         */
        readonly outputFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#parameters GlueCatalogTable#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#stored_as_sub_directories GlueCatalogTable#stored_as_sub_directories}.
         *
         * @stability stable
         */
        readonly storedAsSubDirectories?: boolean | cdktf.IResolvable;
        /**
         * columns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#columns GlueCatalogTable#columns}
         *
         * @stability stable
         */
        readonly columns?: GlueCatalogTableStorageDescriptorColumns[];
        /**
         * schema_reference block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#schema_reference GlueCatalogTable#schema_reference}
         *
         * @stability stable
         */
        readonly schemaReference?: GlueCatalogTableStorageDescriptorSchemaReference;
        /**
         * ser_de_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#ser_de_info GlueCatalogTable#ser_de_info}
         *
         * @stability stable
         */
        readonly serDeInfo?: GlueCatalogTableStorageDescriptorSerDeInfo;
        /**
         * skewed_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#skewed_info GlueCatalogTable#skewed_info}
         *
         * @stability stable
         */
        readonly skewedInfo?: GlueCatalogTableStorageDescriptorSkewedInfo;
        /**
         * sort_columns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#sort_columns GlueCatalogTable#sort_columns}
         *
         * @stability stable
         */
        readonly sortColumns?: GlueCatalogTableStorageDescriptorSortColumns[];
    }
    /**
     * @stability stable
     */
    class GlueCatalogTableStorageDescriptorOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketColumns?;
        /**
         * @stability stable
         */
        get bucketColumns(): string[] | undefined;
        /**
         * @stability stable
         */
        set bucketColumns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetBucketColumns(): void;
        /**
         * @stability stable
         */
        get bucketColumnsInput(): string[] | undefined;
        private _compressed?;
        /**
         * @stability stable
         */
        get compressed(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set compressed(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCompressed(): void;
        /**
         * @stability stable
         */
        get compressedInput(): boolean | cdktf.IResolvable | undefined;
        private _inputFormat?;
        /**
         * @stability stable
         */
        get inputFormat(): string | undefined;
        /**
         * @stability stable
         */
        set inputFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetInputFormat(): void;
        /**
         * @stability stable
         */
        get inputFormatInput(): string | undefined;
        private _location?;
        /**
         * @stability stable
         */
        get location(): string | undefined;
        /**
         * @stability stable
         */
        set location(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocation(): void;
        /**
         * @stability stable
         */
        get locationInput(): string | undefined;
        private _numberOfBuckets?;
        /**
         * @stability stable
         */
        get numberOfBuckets(): number | undefined;
        /**
         * @stability stable
         */
        set numberOfBuckets(value: number | undefined);
        /**
         * @stability stable
         */
        resetNumberOfBuckets(): void;
        /**
         * @stability stable
         */
        get numberOfBucketsInput(): number | undefined;
        private _outputFormat?;
        /**
         * @stability stable
         */
        get outputFormat(): string | undefined;
        /**
         * @stability stable
         */
        set outputFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutputFormat(): void;
        /**
         * @stability stable
         */
        get outputFormatInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _storedAsSubDirectories?;
        /**
         * @stability stable
         */
        get storedAsSubDirectories(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set storedAsSubDirectories(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetStoredAsSubDirectories(): void;
        /**
         * @stability stable
         */
        get storedAsSubDirectoriesInput(): boolean | cdktf.IResolvable | undefined;
        private _columns?;
        /**
         * @stability stable
         */
        get columns(): GlueCatalogTableStorageDescriptorColumns[] | undefined;
        /**
         * @stability stable
         */
        set columns(value: GlueCatalogTableStorageDescriptorColumns[] | undefined);
        /**
         * @stability stable
         */
        resetColumns(): void;
        /**
         * @stability stable
         */
        get columnsInput(): GlueCatalogTableStorageDescriptorColumns[] | undefined;
        private _schemaReference?;
        private __schemaReferenceOutput;
        /**
         * @stability stable
         */
        get schemaReference(): GlueCatalogTableStorageDescriptorSchemaReferenceOutputReference;
        /**
         * @stability stable
         */
        putSchemaReference(value: GlueCatalogTableStorageDescriptorSchemaReference | undefined): void;
        /**
         * @stability stable
         */
        resetSchemaReference(): void;
        /**
         * @stability stable
         */
        get schemaReferenceInput(): GlueCatalogTableStorageDescriptorSchemaReference | undefined;
        private _serDeInfo?;
        private __serDeInfoOutput;
        /**
         * @stability stable
         */
        get serDeInfo(): GlueCatalogTableStorageDescriptorSerDeInfoOutputReference;
        /**
         * @stability stable
         */
        putSerDeInfo(value: GlueCatalogTableStorageDescriptorSerDeInfo | undefined): void;
        /**
         * @stability stable
         */
        resetSerDeInfo(): void;
        /**
         * @stability stable
         */
        get serDeInfoInput(): GlueCatalogTableStorageDescriptorSerDeInfo | undefined;
        private _skewedInfo?;
        private __skewedInfoOutput;
        /**
         * @stability stable
         */
        get skewedInfo(): GlueCatalogTableStorageDescriptorSkewedInfoOutputReference;
        /**
         * @stability stable
         */
        putSkewedInfo(value: GlueCatalogTableStorageDescriptorSkewedInfo | undefined): void;
        /**
         * @stability stable
         */
        resetSkewedInfo(): void;
        /**
         * @stability stable
         */
        get skewedInfoInput(): GlueCatalogTableStorageDescriptorSkewedInfo | undefined;
        private _sortColumns?;
        /**
         * @stability stable
         */
        get sortColumns(): GlueCatalogTableStorageDescriptorSortColumns[] | undefined;
        /**
         * @stability stable
         */
        set sortColumns(value: GlueCatalogTableStorageDescriptorSortColumns[] | undefined);
        /**
         * @stability stable
         */
        resetSortColumns(): void;
        /**
         * @stability stable
         */
        get sortColumnsInput(): GlueCatalogTableStorageDescriptorSortColumns[] | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueCatalogTableTargetTable {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#catalog_id GlueCatalogTable#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#database_name GlueCatalogTable#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html#name GlueCatalogTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    class GlueCatalogTableTargetTableOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string;
        /**
         * @stability stable
         */
        set catalogId(value: string);
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html aws_glue_catalog_table}.
     *
     * @stability stable
     */
    class GlueCatalogTable extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_catalog_table.html aws_glue_catalog_table} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueCatalogTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _owner?;
        /**
         * @stability stable
         */
        get owner(): string | undefined;
        /**
         * @stability stable
         */
        set owner(value: string | undefined);
        /**
         * @stability stable
         */
        resetOwner(): void;
        /**
         * @stability stable
         */
        get ownerInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _retention?;
        /**
         * @stability stable
         */
        get retention(): number | undefined;
        /**
         * @stability stable
         */
        set retention(value: number | undefined);
        /**
         * @stability stable
         */
        resetRetention(): void;
        /**
         * @stability stable
         */
        get retentionInput(): number | undefined;
        private _tableType?;
        /**
         * @stability stable
         */
        get tableType(): string | undefined;
        /**
         * @stability stable
         */
        set tableType(value: string | undefined);
        /**
         * @stability stable
         */
        resetTableType(): void;
        /**
         * @stability stable
         */
        get tableTypeInput(): string | undefined;
        private _viewExpandedText?;
        /**
         * @stability stable
         */
        get viewExpandedText(): string | undefined;
        /**
         * @stability stable
         */
        set viewExpandedText(value: string | undefined);
        /**
         * @stability stable
         */
        resetViewExpandedText(): void;
        /**
         * @stability stable
         */
        get viewExpandedTextInput(): string | undefined;
        private _viewOriginalText?;
        /**
         * @stability stable
         */
        get viewOriginalText(): string | undefined;
        /**
         * @stability stable
         */
        set viewOriginalText(value: string | undefined);
        /**
         * @stability stable
         */
        resetViewOriginalText(): void;
        /**
         * @stability stable
         */
        get viewOriginalTextInput(): string | undefined;
        private _partitionIndex?;
        /**
         * @stability stable
         */
        get partitionIndex(): GlueCatalogTablePartitionIndex[] | undefined;
        /**
         * @stability stable
         */
        set partitionIndex(value: GlueCatalogTablePartitionIndex[] | undefined);
        /**
         * @stability stable
         */
        resetPartitionIndex(): void;
        /**
         * @stability stable
         */
        get partitionIndexInput(): GlueCatalogTablePartitionIndex[] | undefined;
        private _partitionKeys?;
        /**
         * @stability stable
         */
        get partitionKeys(): GlueCatalogTablePartitionKeys[] | undefined;
        /**
         * @stability stable
         */
        set partitionKeys(value: GlueCatalogTablePartitionKeys[] | undefined);
        /**
         * @stability stable
         */
        resetPartitionKeys(): void;
        /**
         * @stability stable
         */
        get partitionKeysInput(): GlueCatalogTablePartitionKeys[] | undefined;
        private _storageDescriptor?;
        private __storageDescriptorOutput;
        /**
         * @stability stable
         */
        get storageDescriptor(): GlueCatalogTableStorageDescriptorOutputReference;
        /**
         * @stability stable
         */
        putStorageDescriptor(value: GlueCatalogTableStorageDescriptor | undefined): void;
        /**
         * @stability stable
         */
        resetStorageDescriptor(): void;
        /**
         * @stability stable
         */
        get storageDescriptorInput(): GlueCatalogTableStorageDescriptor | undefined;
        private _targetTable?;
        private __targetTableOutput;
        /**
         * @stability stable
         */
        get targetTable(): GlueCatalogTableTargetTableOutputReference;
        /**
         * @stability stable
         */
        putTargetTable(value: GlueCatalogTableTargetTable | undefined): void;
        /**
         * @stability stable
         */
        resetTargetTable(): void;
        /**
         * @stability stable
         */
        get targetTableInput(): GlueCatalogTableTargetTable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueClassifierConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#name GlueClassifier#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * csv_classifier block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#csv_classifier GlueClassifier#csv_classifier}
         *
         * @stability stable
         */
        readonly csvClassifier?: GlueClassifierCsvClassifier;
        /**
         * grok_classifier block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#grok_classifier GlueClassifier#grok_classifier}
         *
         * @stability stable
         */
        readonly grokClassifier?: GlueClassifierGrokClassifier;
        /**
         * json_classifier block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#json_classifier GlueClassifier#json_classifier}
         *
         * @stability stable
         */
        readonly jsonClassifier?: GlueClassifierJsonClassifier;
        /**
         * xml_classifier block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#xml_classifier GlueClassifier#xml_classifier}
         *
         * @stability stable
         */
        readonly xmlClassifier?: GlueClassifierXmlClassifier;
    }
    /**
     * @stability stable
     */
    interface GlueClassifierCsvClassifier {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#allow_single_column GlueClassifier#allow_single_column}.
         *
         * @stability stable
         */
        readonly allowSingleColumn?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#contains_header GlueClassifier#contains_header}.
         *
         * @stability stable
         */
        readonly containsHeader?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#delimiter GlueClassifier#delimiter}.
         *
         * @stability stable
         */
        readonly delimiter?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#disable_value_trimming GlueClassifier#disable_value_trimming}.
         *
         * @stability stable
         */
        readonly disableValueTrimming?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#header GlueClassifier#header}.
         *
         * @stability stable
         */
        readonly header?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#quote_symbol GlueClassifier#quote_symbol}.
         *
         * @stability stable
         */
        readonly quoteSymbol?: string;
    }
    /**
     * @stability stable
     */
    class GlueClassifierCsvClassifierOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowSingleColumn?;
        /**
         * @stability stable
         */
        get allowSingleColumn(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowSingleColumn(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowSingleColumn(): void;
        /**
         * @stability stable
         */
        get allowSingleColumnInput(): boolean | cdktf.IResolvable | undefined;
        private _containsHeader?;
        /**
         * @stability stable
         */
        get containsHeader(): string | undefined;
        /**
         * @stability stable
         */
        set containsHeader(value: string | undefined);
        /**
         * @stability stable
         */
        resetContainsHeader(): void;
        /**
         * @stability stable
         */
        get containsHeaderInput(): string | undefined;
        private _delimiter?;
        /**
         * @stability stable
         */
        get delimiter(): string | undefined;
        /**
         * @stability stable
         */
        set delimiter(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelimiter(): void;
        /**
         * @stability stable
         */
        get delimiterInput(): string | undefined;
        private _disableValueTrimming?;
        /**
         * @stability stable
         */
        get disableValueTrimming(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set disableValueTrimming(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDisableValueTrimming(): void;
        /**
         * @stability stable
         */
        get disableValueTrimmingInput(): boolean | cdktf.IResolvable | undefined;
        private _header?;
        /**
         * @stability stable
         */
        get header(): string[] | undefined;
        /**
         * @stability stable
         */
        set header(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetHeader(): void;
        /**
         * @stability stable
         */
        get headerInput(): string[] | undefined;
        private _quoteSymbol?;
        /**
         * @stability stable
         */
        get quoteSymbol(): string | undefined;
        /**
         * @stability stable
         */
        set quoteSymbol(value: string | undefined);
        /**
         * @stability stable
         */
        resetQuoteSymbol(): void;
        /**
         * @stability stable
         */
        get quoteSymbolInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueClassifierGrokClassifier {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#classification GlueClassifier#classification}.
         *
         * @stability stable
         */
        readonly classification: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#custom_patterns GlueClassifier#custom_patterns}.
         *
         * @stability stable
         */
        readonly customPatterns?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#grok_pattern GlueClassifier#grok_pattern}.
         *
         * @stability stable
         */
        readonly grokPattern: string;
    }
    /**
     * @stability stable
     */
    class GlueClassifierGrokClassifierOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _classification?;
        /**
         * @stability stable
         */
        get classification(): string;
        /**
         * @stability stable
         */
        set classification(value: string);
        /**
         * @stability stable
         */
        get classificationInput(): string | undefined;
        private _customPatterns?;
        /**
         * @stability stable
         */
        get customPatterns(): string | undefined;
        /**
         * @stability stable
         */
        set customPatterns(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomPatterns(): void;
        /**
         * @stability stable
         */
        get customPatternsInput(): string | undefined;
        private _grokPattern?;
        /**
         * @stability stable
         */
        get grokPattern(): string;
        /**
         * @stability stable
         */
        set grokPattern(value: string);
        /**
         * @stability stable
         */
        get grokPatternInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueClassifierJsonClassifier {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#json_path GlueClassifier#json_path}.
         *
         * @stability stable
         */
        readonly jsonPath: string;
    }
    /**
     * @stability stable
     */
    class GlueClassifierJsonClassifierOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _jsonPath?;
        /**
         * @stability stable
         */
        get jsonPath(): string;
        /**
         * @stability stable
         */
        set jsonPath(value: string);
        /**
         * @stability stable
         */
        get jsonPathInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueClassifierXmlClassifier {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#classification GlueClassifier#classification}.
         *
         * @stability stable
         */
        readonly classification: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#row_tag GlueClassifier#row_tag}.
         *
         * @stability stable
         */
        readonly rowTag: string;
    }
    /**
     * @stability stable
     */
    class GlueClassifierXmlClassifierOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _classification?;
        /**
         * @stability stable
         */
        get classification(): string;
        /**
         * @stability stable
         */
        set classification(value: string);
        /**
         * @stability stable
         */
        get classificationInput(): string | undefined;
        private _rowTag?;
        /**
         * @stability stable
         */
        get rowTag(): string;
        /**
         * @stability stable
         */
        set rowTag(value: string);
        /**
         * @stability stable
         */
        get rowTagInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html aws_glue_classifier}.
     *
     * @stability stable
     */
    class GlueClassifier extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html aws_glue_classifier} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueClassifierConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _csvClassifier?;
        private __csvClassifierOutput;
        /**
         * @stability stable
         */
        get csvClassifier(): GlueClassifierCsvClassifierOutputReference;
        /**
         * @stability stable
         */
        putCsvClassifier(value: GlueClassifierCsvClassifier | undefined): void;
        /**
         * @stability stable
         */
        resetCsvClassifier(): void;
        /**
         * @stability stable
         */
        get csvClassifierInput(): GlueClassifierCsvClassifier | undefined;
        private _grokClassifier?;
        private __grokClassifierOutput;
        /**
         * @stability stable
         */
        get grokClassifier(): GlueClassifierGrokClassifierOutputReference;
        /**
         * @stability stable
         */
        putGrokClassifier(value: GlueClassifierGrokClassifier | undefined): void;
        /**
         * @stability stable
         */
        resetGrokClassifier(): void;
        /**
         * @stability stable
         */
        get grokClassifierInput(): GlueClassifierGrokClassifier | undefined;
        private _jsonClassifier?;
        private __jsonClassifierOutput;
        /**
         * @stability stable
         */
        get jsonClassifier(): GlueClassifierJsonClassifierOutputReference;
        /**
         * @stability stable
         */
        putJsonClassifier(value: GlueClassifierJsonClassifier | undefined): void;
        /**
         * @stability stable
         */
        resetJsonClassifier(): void;
        /**
         * @stability stable
         */
        get jsonClassifierInput(): GlueClassifierJsonClassifier | undefined;
        private _xmlClassifier?;
        private __xmlClassifierOutput;
        /**
         * @stability stable
         */
        get xmlClassifier(): GlueClassifierXmlClassifierOutputReference;
        /**
         * @stability stable
         */
        putXmlClassifier(value: GlueClassifierXmlClassifier | undefined): void;
        /**
         * @stability stable
         */
        resetXmlClassifier(): void;
        /**
         * @stability stable
         */
        get xmlClassifierInput(): GlueClassifierXmlClassifier | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#catalog_id GlueConnection#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#connection_properties GlueConnection#connection_properties}.
         *
         * @stability stable
         */
        readonly connectionProperties?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#connection_type GlueConnection#connection_type}.
         *
         * @stability stable
         */
        readonly connectionType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#description GlueConnection#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#match_criteria GlueConnection#match_criteria}.
         *
         * @stability stable
         */
        readonly matchCriteria?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#name GlueConnection#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#tags GlueConnection#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#tags_all GlueConnection#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * physical_connection_requirements block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#physical_connection_requirements GlueConnection#physical_connection_requirements}
         *
         * @stability stable
         */
        readonly physicalConnectionRequirements?: GlueConnectionPhysicalConnectionRequirements;
    }
    /**
     * @stability stable
     */
    interface GlueConnectionPhysicalConnectionRequirements {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#availability_zone GlueConnection#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#security_group_id_list GlueConnection#security_group_id_list}.
         *
         * @stability stable
         */
        readonly securityGroupIdList?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html#subnet_id GlueConnection#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
    }
    /**
     * @stability stable
     */
    class GlueConnectionPhysicalConnectionRequirementsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _securityGroupIdList?;
        /**
         * @stability stable
         */
        get securityGroupIdList(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIdList(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIdList(): void;
        /**
         * @stability stable
         */
        get securityGroupIdListInput(): string[] | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html aws_glue_connection}.
     *
     * @stability stable
     */
    class GlueConnection extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_connection.html aws_glue_connection} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueConnectionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _connectionProperties?;
        /**
         * @stability stable
         */
        get connectionProperties(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set connectionProperties(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetConnectionProperties(): void;
        /**
         * @stability stable
         */
        get connectionPropertiesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _connectionType?;
        /**
         * @stability stable
         */
        get connectionType(): string | undefined;
        /**
         * @stability stable
         */
        set connectionType(value: string | undefined);
        /**
         * @stability stable
         */
        resetConnectionType(): void;
        /**
         * @stability stable
         */
        get connectionTypeInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _matchCriteria?;
        /**
         * @stability stable
         */
        get matchCriteria(): string[] | undefined;
        /**
         * @stability stable
         */
        set matchCriteria(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetMatchCriteria(): void;
        /**
         * @stability stable
         */
        get matchCriteriaInput(): string[] | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _physicalConnectionRequirements?;
        private __physicalConnectionRequirementsOutput;
        /**
         * @stability stable
         */
        get physicalConnectionRequirements(): GlueConnectionPhysicalConnectionRequirementsOutputReference;
        /**
         * @stability stable
         */
        putPhysicalConnectionRequirements(value: GlueConnectionPhysicalConnectionRequirements | undefined): void;
        /**
         * @stability stable
         */
        resetPhysicalConnectionRequirements(): void;
        /**
         * @stability stable
         */
        get physicalConnectionRequirementsInput(): GlueConnectionPhysicalConnectionRequirements | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#classifiers GlueCrawler#classifiers}.
         *
         * @stability stable
         */
        readonly classifiers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#configuration GlueCrawler#configuration}.
         *
         * @stability stable
         */
        readonly configuration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#database_name GlueCrawler#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#description GlueCrawler#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#name GlueCrawler#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#role GlueCrawler#role}.
         *
         * @stability stable
         */
        readonly role: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#schedule GlueCrawler#schedule}.
         *
         * @stability stable
         */
        readonly schedule?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#security_configuration GlueCrawler#security_configuration}.
         *
         * @stability stable
         */
        readonly securityConfiguration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#table_prefix GlueCrawler#table_prefix}.
         *
         * @stability stable
         */
        readonly tablePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#tags GlueCrawler#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#tags_all GlueCrawler#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * catalog_target block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#catalog_target GlueCrawler#catalog_target}
         *
         * @stability stable
         */
        readonly catalogTarget?: GlueCrawlerCatalogTarget[];
        /**
         * dynamodb_target block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#dynamodb_target GlueCrawler#dynamodb_target}
         *
         * @stability stable
         */
        readonly dynamodbTarget?: GlueCrawlerDynamodbTarget[];
        /**
         * jdbc_target block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#jdbc_target GlueCrawler#jdbc_target}
         *
         * @stability stable
         */
        readonly jdbcTarget?: GlueCrawlerJdbcTarget[];
        /**
         * lineage_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#lineage_configuration GlueCrawler#lineage_configuration}
         *
         * @stability stable
         */
        readonly lineageConfiguration?: GlueCrawlerLineageConfiguration;
        /**
         * mongodb_target block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#mongodb_target GlueCrawler#mongodb_target}
         *
         * @stability stable
         */
        readonly mongodbTarget?: GlueCrawlerMongodbTarget[];
        /**
         * recrawl_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#recrawl_policy GlueCrawler#recrawl_policy}
         *
         * @stability stable
         */
        readonly recrawlPolicy?: GlueCrawlerRecrawlPolicy;
        /**
         * s3_target block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#s3_target GlueCrawler#s3_target}
         *
         * @stability stable
         */
        readonly s3Target?: GlueCrawlerS3Target[];
        /**
         * schema_change_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#schema_change_policy GlueCrawler#schema_change_policy}
         *
         * @stability stable
         */
        readonly schemaChangePolicy?: GlueCrawlerSchemaChangePolicy;
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerCatalogTarget {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#database_name GlueCrawler#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#tables GlueCrawler#tables}.
         *
         * @stability stable
         */
        readonly tables: string[];
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerDynamodbTarget {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#path GlueCrawler#path}.
         *
         * @stability stable
         */
        readonly path: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#scan_all GlueCrawler#scan_all}.
         *
         * @stability stable
         */
        readonly scanAll?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#scan_rate GlueCrawler#scan_rate}.
         *
         * @stability stable
         */
        readonly scanRate?: number;
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerJdbcTarget {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#connection_name GlueCrawler#connection_name}.
         *
         * @stability stable
         */
        readonly connectionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#exclusions GlueCrawler#exclusions}.
         *
         * @stability stable
         */
        readonly exclusions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#path GlueCrawler#path}.
         *
         * @stability stable
         */
        readonly path: string;
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerLineageConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#crawler_lineage_settings GlueCrawler#crawler_lineage_settings}.
         *
         * @stability stable
         */
        readonly crawlerLineageSettings?: string;
    }
    /**
     * @stability stable
     */
    class GlueCrawlerLineageConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _crawlerLineageSettings?;
        /**
         * @stability stable
         */
        get crawlerLineageSettings(): string | undefined;
        /**
         * @stability stable
         */
        set crawlerLineageSettings(value: string | undefined);
        /**
         * @stability stable
         */
        resetCrawlerLineageSettings(): void;
        /**
         * @stability stable
         */
        get crawlerLineageSettingsInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerMongodbTarget {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#connection_name GlueCrawler#connection_name}.
         *
         * @stability stable
         */
        readonly connectionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#path GlueCrawler#path}.
         *
         * @stability stable
         */
        readonly path: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#scan_all GlueCrawler#scan_all}.
         *
         * @stability stable
         */
        readonly scanAll?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerRecrawlPolicy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#recrawl_behavior GlueCrawler#recrawl_behavior}.
         *
         * @stability stable
         */
        readonly recrawlBehavior?: string;
    }
    /**
     * @stability stable
     */
    class GlueCrawlerRecrawlPolicyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _recrawlBehavior?;
        /**
         * @stability stable
         */
        get recrawlBehavior(): string | undefined;
        /**
         * @stability stable
         */
        set recrawlBehavior(value: string | undefined);
        /**
         * @stability stable
         */
        resetRecrawlBehavior(): void;
        /**
         * @stability stable
         */
        get recrawlBehaviorInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerS3Target {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#connection_name GlueCrawler#connection_name}.
         *
         * @stability stable
         */
        readonly connectionName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#exclusions GlueCrawler#exclusions}.
         *
         * @stability stable
         */
        readonly exclusions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#path GlueCrawler#path}.
         *
         * @stability stable
         */
        readonly path: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#sample_size GlueCrawler#sample_size}.
         *
         * @stability stable
         */
        readonly sampleSize?: number;
    }
    /**
     * @stability stable
     */
    interface GlueCrawlerSchemaChangePolicy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#delete_behavior GlueCrawler#delete_behavior}.
         *
         * @stability stable
         */
        readonly deleteBehavior?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html#update_behavior GlueCrawler#update_behavior}.
         *
         * @stability stable
         */
        readonly updateBehavior?: string;
    }
    /**
     * @stability stable
     */
    class GlueCrawlerSchemaChangePolicyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _deleteBehavior?;
        /**
         * @stability stable
         */
        get deleteBehavior(): string | undefined;
        /**
         * @stability stable
         */
        set deleteBehavior(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeleteBehavior(): void;
        /**
         * @stability stable
         */
        get deleteBehaviorInput(): string | undefined;
        private _updateBehavior?;
        /**
         * @stability stable
         */
        get updateBehavior(): string | undefined;
        /**
         * @stability stable
         */
        set updateBehavior(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdateBehavior(): void;
        /**
         * @stability stable
         */
        get updateBehaviorInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html aws_glue_crawler}.
     *
     * @stability stable
     */
    class GlueCrawler extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_crawler.html aws_glue_crawler} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueCrawlerConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _classifiers?;
        /**
         * @stability stable
         */
        get classifiers(): string[] | undefined;
        /**
         * @stability stable
         */
        set classifiers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetClassifiers(): void;
        /**
         * @stability stable
         */
        get classifiersInput(): string[] | undefined;
        private _configuration?;
        /**
         * @stability stable
         */
        get configuration(): string | undefined;
        /**
         * @stability stable
         */
        set configuration(value: string | undefined);
        /**
         * @stability stable
         */
        resetConfiguration(): void;
        /**
         * @stability stable
         */
        get configurationInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _role?;
        /**
         * @stability stable
         */
        get role(): string;
        /**
         * @stability stable
         */
        set role(value: string);
        /**
         * @stability stable
         */
        get roleInput(): string | undefined;
        private _schedule?;
        /**
         * @stability stable
         */
        get schedule(): string | undefined;
        /**
         * @stability stable
         */
        set schedule(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchedule(): void;
        /**
         * @stability stable
         */
        get scheduleInput(): string | undefined;
        private _securityConfiguration?;
        /**
         * @stability stable
         */
        get securityConfiguration(): string | undefined;
        /**
         * @stability stable
         */
        set securityConfiguration(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecurityConfiguration(): void;
        /**
         * @stability stable
         */
        get securityConfigurationInput(): string | undefined;
        private _tablePrefix?;
        /**
         * @stability stable
         */
        get tablePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set tablePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetTablePrefix(): void;
        /**
         * @stability stable
         */
        get tablePrefixInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _catalogTarget?;
        /**
         * @stability stable
         */
        get catalogTarget(): GlueCrawlerCatalogTarget[] | undefined;
        /**
         * @stability stable
         */
        set catalogTarget(value: GlueCrawlerCatalogTarget[] | undefined);
        /**
         * @stability stable
         */
        resetCatalogTarget(): void;
        /**
         * @stability stable
         */
        get catalogTargetInput(): GlueCrawlerCatalogTarget[] | undefined;
        private _dynamodbTarget?;
        /**
         * @stability stable
         */
        get dynamodbTarget(): GlueCrawlerDynamodbTarget[] | undefined;
        /**
         * @stability stable
         */
        set dynamodbTarget(value: GlueCrawlerDynamodbTarget[] | undefined);
        /**
         * @stability stable
         */
        resetDynamodbTarget(): void;
        /**
         * @stability stable
         */
        get dynamodbTargetInput(): GlueCrawlerDynamodbTarget[] | undefined;
        private _jdbcTarget?;
        /**
         * @stability stable
         */
        get jdbcTarget(): GlueCrawlerJdbcTarget[] | undefined;
        /**
         * @stability stable
         */
        set jdbcTarget(value: GlueCrawlerJdbcTarget[] | undefined);
        /**
         * @stability stable
         */
        resetJdbcTarget(): void;
        /**
         * @stability stable
         */
        get jdbcTargetInput(): GlueCrawlerJdbcTarget[] | undefined;
        private _lineageConfiguration?;
        private __lineageConfigurationOutput;
        /**
         * @stability stable
         */
        get lineageConfiguration(): GlueCrawlerLineageConfigurationOutputReference;
        /**
         * @stability stable
         */
        putLineageConfiguration(value: GlueCrawlerLineageConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetLineageConfiguration(): void;
        /**
         * @stability stable
         */
        get lineageConfigurationInput(): GlueCrawlerLineageConfiguration | undefined;
        private _mongodbTarget?;
        /**
         * @stability stable
         */
        get mongodbTarget(): GlueCrawlerMongodbTarget[] | undefined;
        /**
         * @stability stable
         */
        set mongodbTarget(value: GlueCrawlerMongodbTarget[] | undefined);
        /**
         * @stability stable
         */
        resetMongodbTarget(): void;
        /**
         * @stability stable
         */
        get mongodbTargetInput(): GlueCrawlerMongodbTarget[] | undefined;
        private _recrawlPolicy?;
        private __recrawlPolicyOutput;
        /**
         * @stability stable
         */
        get recrawlPolicy(): GlueCrawlerRecrawlPolicyOutputReference;
        /**
         * @stability stable
         */
        putRecrawlPolicy(value: GlueCrawlerRecrawlPolicy | undefined): void;
        /**
         * @stability stable
         */
        resetRecrawlPolicy(): void;
        /**
         * @stability stable
         */
        get recrawlPolicyInput(): GlueCrawlerRecrawlPolicy | undefined;
        private _s3Target?;
        /**
         * @stability stable
         */
        get s3Target(): GlueCrawlerS3Target[] | undefined;
        /**
         * @stability stable
         */
        set s3Target(value: GlueCrawlerS3Target[] | undefined);
        /**
         * @stability stable
         */
        resetS3Target(): void;
        /**
         * @stability stable
         */
        get s3TargetInput(): GlueCrawlerS3Target[] | undefined;
        private _schemaChangePolicy?;
        private __schemaChangePolicyOutput;
        /**
         * @stability stable
         */
        get schemaChangePolicy(): GlueCrawlerSchemaChangePolicyOutputReference;
        /**
         * @stability stable
         */
        putSchemaChangePolicy(value: GlueCrawlerSchemaChangePolicy | undefined): void;
        /**
         * @stability stable
         */
        resetSchemaChangePolicy(): void;
        /**
         * @stability stable
         */
        get schemaChangePolicyInput(): GlueCrawlerSchemaChangePolicy | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueDataCatalogEncryptionSettingsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#catalog_id GlueDataCatalogEncryptionSettings#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * data_catalog_encryption_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#data_catalog_encryption_settings GlueDataCatalogEncryptionSettings#data_catalog_encryption_settings}
         *
         * @stability stable
         */
        readonly dataCatalogEncryptionSettings: GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettings;
    }
    /**
     * @stability stable
     */
    interface GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsConnectionPasswordEncryption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#aws_kms_key_id GlueDataCatalogEncryptionSettings#aws_kms_key_id}.
         *
         * @stability stable
         */
        readonly awsKmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#return_connection_password_encrypted GlueDataCatalogEncryptionSettings#return_connection_password_encrypted}.
         *
         * @stability stable
         */
        readonly returnConnectionPasswordEncrypted: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsConnectionPasswordEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _awsKmsKeyId?;
        /**
         * @stability stable
         */
        get awsKmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set awsKmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAwsKmsKeyId(): void;
        /**
         * @stability stable
         */
        get awsKmsKeyIdInput(): string | undefined;
        private _returnConnectionPasswordEncrypted?;
        /**
         * @stability stable
         */
        get returnConnectionPasswordEncrypted(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set returnConnectionPasswordEncrypted(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get returnConnectionPasswordEncryptedInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsEncryptionAtRest {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#catalog_encryption_mode GlueDataCatalogEncryptionSettings#catalog_encryption_mode}.
         *
         * @stability stable
         */
        readonly catalogEncryptionMode: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#sse_aws_kms_key_id GlueDataCatalogEncryptionSettings#sse_aws_kms_key_id}.
         *
         * @stability stable
         */
        readonly sseAwsKmsKeyId?: string;
    }
    /**
     * @stability stable
     */
    class GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsEncryptionAtRestOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalogEncryptionMode?;
        /**
         * @stability stable
         */
        get catalogEncryptionMode(): string;
        /**
         * @stability stable
         */
        set catalogEncryptionMode(value: string);
        /**
         * @stability stable
         */
        get catalogEncryptionModeInput(): string | undefined;
        private _sseAwsKmsKeyId?;
        /**
         * @stability stable
         */
        get sseAwsKmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set sseAwsKmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSseAwsKmsKeyId(): void;
        /**
         * @stability stable
         */
        get sseAwsKmsKeyIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettings {
        /**
         * connection_password_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#connection_password_encryption GlueDataCatalogEncryptionSettings#connection_password_encryption}
         *
         * @stability stable
         */
        readonly connectionPasswordEncryption: GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsConnectionPasswordEncryption;
        /**
         * encryption_at_rest block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html#encryption_at_rest GlueDataCatalogEncryptionSettings#encryption_at_rest}
         *
         * @stability stable
         */
        readonly encryptionAtRest: GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsEncryptionAtRest;
    }
    /**
     * @stability stable
     */
    class GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _connectionPasswordEncryption?;
        private __connectionPasswordEncryptionOutput;
        /**
         * @stability stable
         */
        get connectionPasswordEncryption(): GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsConnectionPasswordEncryptionOutputReference;
        /**
         * @stability stable
         */
        putConnectionPasswordEncryption(value: GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsConnectionPasswordEncryption): void;
        /**
         * @stability stable
         */
        get connectionPasswordEncryptionInput(): GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsConnectionPasswordEncryption | undefined;
        private _encryptionAtRest?;
        private __encryptionAtRestOutput;
        /**
         * @stability stable
         */
        get encryptionAtRest(): GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsEncryptionAtRestOutputReference;
        /**
         * @stability stable
         */
        putEncryptionAtRest(value: GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsEncryptionAtRest): void;
        /**
         * @stability stable
         */
        get encryptionAtRestInput(): GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsEncryptionAtRest | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html aws_glue_data_catalog_encryption_settings}.
     *
     * @stability stable
     */
    class GlueDataCatalogEncryptionSettings extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_data_catalog_encryption_settings.html aws_glue_data_catalog_encryption_settings} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueDataCatalogEncryptionSettingsConfig);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _dataCatalogEncryptionSettings?;
        private __dataCatalogEncryptionSettingsOutput;
        /**
         * @stability stable
         */
        get dataCatalogEncryptionSettings(): GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsOutputReference;
        /**
         * @stability stable
         */
        putDataCatalogEncryptionSettings(value: GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettings): void;
        /**
         * @stability stable
         */
        get dataCatalogEncryptionSettingsInput(): GlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettings | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueDevEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#arguments GlueDevEndpoint#arguments}.
         *
         * @stability stable
         */
        readonly arguments?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#extra_jars_s3_path GlueDevEndpoint#extra_jars_s3_path}.
         *
         * @stability stable
         */
        readonly extraJarsS3Path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#extra_python_libs_s3_path GlueDevEndpoint#extra_python_libs_s3_path}.
         *
         * @stability stable
         */
        readonly extraPythonLibsS3Path?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#glue_version GlueDevEndpoint#glue_version}.
         *
         * @stability stable
         */
        readonly glueVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#name GlueDevEndpoint#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#number_of_nodes GlueDevEndpoint#number_of_nodes}.
         *
         * @stability stable
         */
        readonly numberOfNodes?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#number_of_workers GlueDevEndpoint#number_of_workers}.
         *
         * @stability stable
         */
        readonly numberOfWorkers?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#public_key GlueDevEndpoint#public_key}.
         *
         * @stability stable
         */
        readonly publicKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#public_keys GlueDevEndpoint#public_keys}.
         *
         * @stability stable
         */
        readonly publicKeys?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#role_arn GlueDevEndpoint#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#security_configuration GlueDevEndpoint#security_configuration}.
         *
         * @stability stable
         */
        readonly securityConfiguration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#security_group_ids GlueDevEndpoint#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#subnet_id GlueDevEndpoint#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#tags GlueDevEndpoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#tags_all GlueDevEndpoint#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html#worker_type GlueDevEndpoint#worker_type}.
         *
         * @stability stable
         */
        readonly workerType?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html aws_glue_dev_endpoint}.
     *
     * @stability stable
     */
    class GlueDevEndpoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_dev_endpoint.html aws_glue_dev_endpoint} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueDevEndpointConfig);
        private _arguments?;
        /**
         * @stability stable
         */
        get arguments(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set arguments(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetArguments(): void;
        /**
         * @stability stable
         */
        get argumentsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        private _extraJarsS3Path?;
        /**
         * @stability stable
         */
        get extraJarsS3Path(): string | undefined;
        /**
         * @stability stable
         */
        set extraJarsS3Path(value: string | undefined);
        /**
         * @stability stable
         */
        resetExtraJarsS3Path(): void;
        /**
         * @stability stable
         */
        get extraJarsS3PathInput(): string | undefined;
        private _extraPythonLibsS3Path?;
        /**
         * @stability stable
         */
        get extraPythonLibsS3Path(): string | undefined;
        /**
         * @stability stable
         */
        set extraPythonLibsS3Path(value: string | undefined);
        /**
         * @stability stable
         */
        resetExtraPythonLibsS3Path(): void;
        /**
         * @stability stable
         */
        get extraPythonLibsS3PathInput(): string | undefined;
        /**
         * @stability stable
         */
        get failureReason(): string;
        private _glueVersion?;
        /**
         * @stability stable
         */
        get glueVersion(): string | undefined;
        /**
         * @stability stable
         */
        set glueVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetGlueVersion(): void;
        /**
         * @stability stable
         */
        get glueVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _numberOfNodes?;
        /**
         * @stability stable
         */
        get numberOfNodes(): number | undefined;
        /**
         * @stability stable
         */
        set numberOfNodes(value: number | undefined);
        /**
         * @stability stable
         */
        resetNumberOfNodes(): void;
        /**
         * @stability stable
         */
        get numberOfNodesInput(): number | undefined;
        private _numberOfWorkers?;
        /**
         * @stability stable
         */
        get numberOfWorkers(): number | undefined;
        /**
         * @stability stable
         */
        set numberOfWorkers(value: number | undefined);
        /**
         * @stability stable
         */
        resetNumberOfWorkers(): void;
        /**
         * @stability stable
         */
        get numberOfWorkersInput(): number | undefined;
        /**
         * @stability stable
         */
        get privateAddress(): string;
        /**
         * @stability stable
         */
        get publicAddress(): string;
        private _publicKey?;
        /**
         * @stability stable
         */
        get publicKey(): string | undefined;
        /**
         * @stability stable
         */
        set publicKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetPublicKey(): void;
        /**
         * @stability stable
         */
        get publicKeyInput(): string | undefined;
        private _publicKeys?;
        /**
         * @stability stable
         */
        get publicKeys(): string[] | undefined;
        /**
         * @stability stable
         */
        set publicKeys(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPublicKeys(): void;
        /**
         * @stability stable
         */
        get publicKeysInput(): string[] | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _securityConfiguration?;
        /**
         * @stability stable
         */
        get securityConfiguration(): string | undefined;
        /**
         * @stability stable
         */
        set securityConfiguration(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecurityConfiguration(): void;
        /**
         * @stability stable
         */
        get securityConfigurationInput(): string | undefined;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _workerType?;
        /**
         * @stability stable
         */
        get workerType(): string | undefined;
        /**
         * @stability stable
         */
        set workerType(value: string | undefined);
        /**
         * @stability stable
         */
        resetWorkerType(): void;
        /**
         * @stability stable
         */
        get workerTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get yarnEndpointAddress(): string;
        /**
         * @stability stable
         */
        get zeppelinRemoteSparkInterpreterPort(): number;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueJobConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#connections GlueJob#connections}.
         *
         * @stability stable
         */
        readonly connections?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#default_arguments GlueJob#default_arguments}.
         *
         * @stability stable
         */
        readonly defaultArguments?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#description GlueJob#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#glue_version GlueJob#glue_version}.
         *
         * @stability stable
         */
        readonly glueVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#max_capacity GlueJob#max_capacity}.
         *
         * @stability stable
         */
        readonly maxCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#max_retries GlueJob#max_retries}.
         *
         * @stability stable
         */
        readonly maxRetries?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#name GlueJob#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#non_overridable_arguments GlueJob#non_overridable_arguments}.
         *
         * @stability stable
         */
        readonly nonOverridableArguments?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#number_of_workers GlueJob#number_of_workers}.
         *
         * @stability stable
         */
        readonly numberOfWorkers?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#role_arn GlueJob#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#security_configuration GlueJob#security_configuration}.
         *
         * @stability stable
         */
        readonly securityConfiguration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#tags GlueJob#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#tags_all GlueJob#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#timeout GlueJob#timeout}.
         *
         * @stability stable
         */
        readonly timeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#worker_type GlueJob#worker_type}.
         *
         * @stability stable
         */
        readonly workerType?: string;
        /**
         * command block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#command GlueJob#command}
         *
         * @stability stable
         */
        readonly command: GlueJobCommand;
        /**
         * execution_property block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#execution_property GlueJob#execution_property}
         *
         * @stability stable
         */
        readonly executionProperty?: GlueJobExecutionProperty;
        /**
         * notification_property block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#notification_property GlueJob#notification_property}
         *
         * @stability stable
         */
        readonly notificationProperty?: GlueJobNotificationProperty;
    }
    /**
     * @stability stable
     */
    interface GlueJobCommand {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#name GlueJob#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#python_version GlueJob#python_version}.
         *
         * @stability stable
         */
        readonly pythonVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#script_location GlueJob#script_location}.
         *
         * @stability stable
         */
        readonly scriptLocation: string;
    }
    /**
     * @stability stable
     */
    class GlueJobCommandOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _pythonVersion?;
        /**
         * @stability stable
         */
        get pythonVersion(): string | undefined;
        /**
         * @stability stable
         */
        set pythonVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetPythonVersion(): void;
        /**
         * @stability stable
         */
        get pythonVersionInput(): string | undefined;
        private _scriptLocation?;
        /**
         * @stability stable
         */
        get scriptLocation(): string;
        /**
         * @stability stable
         */
        set scriptLocation(value: string);
        /**
         * @stability stable
         */
        get scriptLocationInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueJobExecutionProperty {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#max_concurrent_runs GlueJob#max_concurrent_runs}.
         *
         * @stability stable
         */
        readonly maxConcurrentRuns?: number;
    }
    /**
     * @stability stable
     */
    class GlueJobExecutionPropertyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _maxConcurrentRuns?;
        /**
         * @stability stable
         */
        get maxConcurrentRuns(): number | undefined;
        /**
         * @stability stable
         */
        set maxConcurrentRuns(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxConcurrentRuns(): void;
        /**
         * @stability stable
         */
        get maxConcurrentRunsInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueJobNotificationProperty {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html#notify_delay_after GlueJob#notify_delay_after}.
         *
         * @stability stable
         */
        readonly notifyDelayAfter?: number;
    }
    /**
     * @stability stable
     */
    class GlueJobNotificationPropertyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _notifyDelayAfter?;
        /**
         * @stability stable
         */
        get notifyDelayAfter(): number | undefined;
        /**
         * @stability stable
         */
        set notifyDelayAfter(value: number | undefined);
        /**
         * @stability stable
         */
        resetNotifyDelayAfter(): void;
        /**
         * @stability stable
         */
        get notifyDelayAfterInput(): number | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html aws_glue_job}.
     *
     * @stability stable
     */
    class GlueJob extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_job.html aws_glue_job} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueJobConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _connections?;
        /**
         * @stability stable
         */
        get connections(): string[] | undefined;
        /**
         * @stability stable
         */
        set connections(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetConnections(): void;
        /**
         * @stability stable
         */
        get connectionsInput(): string[] | undefined;
        private _defaultArguments?;
        /**
         * @stability stable
         */
        get defaultArguments(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set defaultArguments(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDefaultArguments(): void;
        /**
         * @stability stable
         */
        get defaultArgumentsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _glueVersion?;
        /**
         * @stability stable
         */
        get glueVersion(): string | undefined;
        /**
         * @stability stable
         */
        set glueVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetGlueVersion(): void;
        /**
         * @stability stable
         */
        get glueVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _maxCapacity?;
        /**
         * @stability stable
         */
        get maxCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set maxCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxCapacity(): void;
        /**
         * @stability stable
         */
        get maxCapacityInput(): number | undefined;
        private _maxRetries?;
        /**
         * @stability stable
         */
        get maxRetries(): number | undefined;
        /**
         * @stability stable
         */
        set maxRetries(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxRetries(): void;
        /**
         * @stability stable
         */
        get maxRetriesInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _nonOverridableArguments?;
        /**
         * @stability stable
         */
        get nonOverridableArguments(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set nonOverridableArguments(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetNonOverridableArguments(): void;
        /**
         * @stability stable
         */
        get nonOverridableArgumentsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _numberOfWorkers?;
        /**
         * @stability stable
         */
        get numberOfWorkers(): number | undefined;
        /**
         * @stability stable
         */
        set numberOfWorkers(value: number | undefined);
        /**
         * @stability stable
         */
        resetNumberOfWorkers(): void;
        /**
         * @stability stable
         */
        get numberOfWorkersInput(): number | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _securityConfiguration?;
        /**
         * @stability stable
         */
        get securityConfiguration(): string | undefined;
        /**
         * @stability stable
         */
        set securityConfiguration(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecurityConfiguration(): void;
        /**
         * @stability stable
         */
        get securityConfigurationInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _timeout?;
        /**
         * @stability stable
         */
        get timeout(): number | undefined;
        /**
         * @stability stable
         */
        set timeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeout(): void;
        /**
         * @stability stable
         */
        get timeoutInput(): number | undefined;
        private _workerType?;
        /**
         * @stability stable
         */
        get workerType(): string | undefined;
        /**
         * @stability stable
         */
        set workerType(value: string | undefined);
        /**
         * @stability stable
         */
        resetWorkerType(): void;
        /**
         * @stability stable
         */
        get workerTypeInput(): string | undefined;
        private _command?;
        private __commandOutput;
        /**
         * @stability stable
         */
        get command(): GlueJobCommandOutputReference;
        /**
         * @stability stable
         */
        putCommand(value: GlueJobCommand): void;
        /**
         * @stability stable
         */
        get commandInput(): GlueJobCommand | undefined;
        private _executionProperty?;
        private __executionPropertyOutput;
        /**
         * @stability stable
         */
        get executionProperty(): GlueJobExecutionPropertyOutputReference;
        /**
         * @stability stable
         */
        putExecutionProperty(value: GlueJobExecutionProperty | undefined): void;
        /**
         * @stability stable
         */
        resetExecutionProperty(): void;
        /**
         * @stability stable
         */
        get executionPropertyInput(): GlueJobExecutionProperty | undefined;
        private _notificationProperty?;
        private __notificationPropertyOutput;
        /**
         * @stability stable
         */
        get notificationProperty(): GlueJobNotificationPropertyOutputReference;
        /**
         * @stability stable
         */
        putNotificationProperty(value: GlueJobNotificationProperty | undefined): void;
        /**
         * @stability stable
         */
        resetNotificationProperty(): void;
        /**
         * @stability stable
         */
        get notificationPropertyInput(): GlueJobNotificationProperty | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueMlTransformConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#description GlueMlTransform#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#glue_version GlueMlTransform#glue_version}.
         *
         * @stability stable
         */
        readonly glueVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#max_capacity GlueMlTransform#max_capacity}.
         *
         * @stability stable
         */
        readonly maxCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#max_retries GlueMlTransform#max_retries}.
         *
         * @stability stable
         */
        readonly maxRetries?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#name GlueMlTransform#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#number_of_workers GlueMlTransform#number_of_workers}.
         *
         * @stability stable
         */
        readonly numberOfWorkers?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#role_arn GlueMlTransform#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#tags GlueMlTransform#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#tags_all GlueMlTransform#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#timeout GlueMlTransform#timeout}.
         *
         * @stability stable
         */
        readonly timeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#worker_type GlueMlTransform#worker_type}.
         *
         * @stability stable
         */
        readonly workerType?: string;
        /**
         * input_record_tables block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#input_record_tables GlueMlTransform#input_record_tables}
         *
         * @stability stable
         */
        readonly inputRecordTables: GlueMlTransformInputRecordTables[];
        /**
         * parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#parameters GlueMlTransform#parameters}
         *
         * @stability stable
         */
        readonly parameters: GlueMlTransformParameters;
    }
    /**
     * @stability stable
     */
    class GlueMlTransformSchema extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get dataType(): string;
        /**
         * @stability stable
         */
        get name(): string;
    }
    /**
     * @stability stable
     */
    interface GlueMlTransformInputRecordTables {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#catalog_id GlueMlTransform#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#connection_name GlueMlTransform#connection_name}.
         *
         * @stability stable
         */
        readonly connectionName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#database_name GlueMlTransform#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#table_name GlueMlTransform#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
    }
    /**
     * @stability stable
     */
    interface GlueMlTransformParametersFindMatchesParameters {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#accuracy_cost_trade_off GlueMlTransform#accuracy_cost_trade_off}.
         *
         * @stability stable
         */
        readonly accuracyCostTradeOff?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#enforce_provided_labels GlueMlTransform#enforce_provided_labels}.
         *
         * @stability stable
         */
        readonly enforceProvidedLabels?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#precision_recall_trade_off GlueMlTransform#precision_recall_trade_off}.
         *
         * @stability stable
         */
        readonly precisionRecallTradeOff?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#primary_key_column_name GlueMlTransform#primary_key_column_name}.
         *
         * @stability stable
         */
        readonly primaryKeyColumnName?: string;
    }
    /**
     * @stability stable
     */
    class GlueMlTransformParametersFindMatchesParametersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _accuracyCostTradeOff?;
        /**
         * @stability stable
         */
        get accuracyCostTradeOff(): number | undefined;
        /**
         * @stability stable
         */
        set accuracyCostTradeOff(value: number | undefined);
        /**
         * @stability stable
         */
        resetAccuracyCostTradeOff(): void;
        /**
         * @stability stable
         */
        get accuracyCostTradeOffInput(): number | undefined;
        private _enforceProvidedLabels?;
        /**
         * @stability stable
         */
        get enforceProvidedLabels(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enforceProvidedLabels(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnforceProvidedLabels(): void;
        /**
         * @stability stable
         */
        get enforceProvidedLabelsInput(): boolean | cdktf.IResolvable | undefined;
        private _precisionRecallTradeOff?;
        /**
         * @stability stable
         */
        get precisionRecallTradeOff(): number | undefined;
        /**
         * @stability stable
         */
        set precisionRecallTradeOff(value: number | undefined);
        /**
         * @stability stable
         */
        resetPrecisionRecallTradeOff(): void;
        /**
         * @stability stable
         */
        get precisionRecallTradeOffInput(): number | undefined;
        private _primaryKeyColumnName?;
        /**
         * @stability stable
         */
        get primaryKeyColumnName(): string | undefined;
        /**
         * @stability stable
         */
        set primaryKeyColumnName(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrimaryKeyColumnName(): void;
        /**
         * @stability stable
         */
        get primaryKeyColumnNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueMlTransformParameters {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#transform_type GlueMlTransform#transform_type}.
         *
         * @stability stable
         */
        readonly transformType: string;
        /**
         * find_matches_parameters block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html#find_matches_parameters GlueMlTransform#find_matches_parameters}
         *
         * @stability stable
         */
        readonly findMatchesParameters: GlueMlTransformParametersFindMatchesParameters;
    }
    /**
     * @stability stable
     */
    class GlueMlTransformParametersOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _transformType?;
        /**
         * @stability stable
         */
        get transformType(): string;
        /**
         * @stability stable
         */
        set transformType(value: string);
        /**
         * @stability stable
         */
        get transformTypeInput(): string | undefined;
        private _findMatchesParameters?;
        private __findMatchesParametersOutput;
        /**
         * @stability stable
         */
        get findMatchesParameters(): GlueMlTransformParametersFindMatchesParametersOutputReference;
        /**
         * @stability stable
         */
        putFindMatchesParameters(value: GlueMlTransformParametersFindMatchesParameters): void;
        /**
         * @stability stable
         */
        get findMatchesParametersInput(): GlueMlTransformParametersFindMatchesParameters | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html aws_glue_ml_transform}.
     *
     * @stability stable
     */
    class GlueMlTransform extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_ml_transform.html aws_glue_ml_transform} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueMlTransformConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _glueVersion?;
        /**
         * @stability stable
         */
        get glueVersion(): string | undefined;
        /**
         * @stability stable
         */
        set glueVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetGlueVersion(): void;
        /**
         * @stability stable
         */
        get glueVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get labelCount(): number;
        private _maxCapacity?;
        /**
         * @stability stable
         */
        get maxCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set maxCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxCapacity(): void;
        /**
         * @stability stable
         */
        get maxCapacityInput(): number | undefined;
        private _maxRetries?;
        /**
         * @stability stable
         */
        get maxRetries(): number | undefined;
        /**
         * @stability stable
         */
        set maxRetries(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxRetries(): void;
        /**
         * @stability stable
         */
        get maxRetriesInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _numberOfWorkers?;
        /**
         * @stability stable
         */
        get numberOfWorkers(): number | undefined;
        /**
         * @stability stable
         */
        set numberOfWorkers(value: number | undefined);
        /**
         * @stability stable
         */
        resetNumberOfWorkers(): void;
        /**
         * @stability stable
         */
        get numberOfWorkersInput(): number | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        schema(index: string): GlueMlTransformSchema;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _timeout?;
        /**
         * @stability stable
         */
        get timeout(): number | undefined;
        /**
         * @stability stable
         */
        set timeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetTimeout(): void;
        /**
         * @stability stable
         */
        get timeoutInput(): number | undefined;
        private _workerType?;
        /**
         * @stability stable
         */
        get workerType(): string | undefined;
        /**
         * @stability stable
         */
        set workerType(value: string | undefined);
        /**
         * @stability stable
         */
        resetWorkerType(): void;
        /**
         * @stability stable
         */
        get workerTypeInput(): string | undefined;
        private _inputRecordTables?;
        /**
         * @stability stable
         */
        get inputRecordTables(): GlueMlTransformInputRecordTables[];
        /**
         * @stability stable
         */
        set inputRecordTables(value: GlueMlTransformInputRecordTables[]);
        /**
         * @stability stable
         */
        get inputRecordTablesInput(): GlueMlTransformInputRecordTables[] | undefined;
        private _parameters?;
        private __parametersOutput;
        /**
         * @stability stable
         */
        get parameters(): GlueMlTransformParametersOutputReference;
        /**
         * @stability stable
         */
        putParameters(value: GlueMlTransformParameters): void;
        /**
         * @stability stable
         */
        get parametersInput(): GlueMlTransformParameters | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GluePartitionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#catalog_id GluePartition#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#database_name GluePartition#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#parameters GluePartition#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#partition_values GluePartition#partition_values}.
         *
         * @stability stable
         */
        readonly partitionValues: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#table_name GluePartition#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
        /**
         * storage_descriptor block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#storage_descriptor GluePartition#storage_descriptor}
         *
         * @stability stable
         */
        readonly storageDescriptor?: GluePartitionStorageDescriptor;
    }
    /**
     * @stability stable
     */
    interface GluePartitionStorageDescriptorColumns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#comment GluePartition#comment}.
         *
         * @stability stable
         */
        readonly comment?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#name GluePartition#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#type GluePartition#type}.
         *
         * @stability stable
         */
        readonly type?: string;
    }
    /**
     * @stability stable
     */
    interface GluePartitionStorageDescriptorSerDeInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#name GluePartition#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#parameters GluePartition#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#serialization_library GluePartition#serialization_library}.
         *
         * @stability stable
         */
        readonly serializationLibrary?: string;
    }
    /**
     * @stability stable
     */
    class GluePartitionStorageDescriptorSerDeInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _serializationLibrary?;
        /**
         * @stability stable
         */
        get serializationLibrary(): string | undefined;
        /**
         * @stability stable
         */
        set serializationLibrary(value: string | undefined);
        /**
         * @stability stable
         */
        resetSerializationLibrary(): void;
        /**
         * @stability stable
         */
        get serializationLibraryInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GluePartitionStorageDescriptorSkewedInfo {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#skewed_column_names GluePartition#skewed_column_names}.
         *
         * @stability stable
         */
        readonly skewedColumnNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#skewed_column_value_location_maps GluePartition#skewed_column_value_location_maps}.
         *
         * @stability stable
         */
        readonly skewedColumnValueLocationMaps?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#skewed_column_values GluePartition#skewed_column_values}.
         *
         * @stability stable
         */
        readonly skewedColumnValues?: string[];
    }
    /**
     * @stability stable
     */
    class GluePartitionStorageDescriptorSkewedInfoOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _skewedColumnNames?;
        /**
         * @stability stable
         */
        get skewedColumnNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set skewedColumnNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSkewedColumnNames(): void;
        /**
         * @stability stable
         */
        get skewedColumnNamesInput(): string[] | undefined;
        private _skewedColumnValueLocationMaps?;
        /**
         * @stability stable
         */
        get skewedColumnValueLocationMaps(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set skewedColumnValueLocationMaps(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSkewedColumnValueLocationMaps(): void;
        /**
         * @stability stable
         */
        get skewedColumnValueLocationMapsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _skewedColumnValues?;
        /**
         * @stability stable
         */
        get skewedColumnValues(): string[] | undefined;
        /**
         * @stability stable
         */
        set skewedColumnValues(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSkewedColumnValues(): void;
        /**
         * @stability stable
         */
        get skewedColumnValuesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface GluePartitionStorageDescriptorSortColumns {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#column GluePartition#column}.
         *
         * @stability stable
         */
        readonly column: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#sort_order GluePartition#sort_order}.
         *
         * @stability stable
         */
        readonly sortOrder: number;
    }
    /**
     * @stability stable
     */
    interface GluePartitionStorageDescriptor {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#bucket_columns GluePartition#bucket_columns}.
         *
         * @stability stable
         */
        readonly bucketColumns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#compressed GluePartition#compressed}.
         *
         * @stability stable
         */
        readonly compressed?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#input_format GluePartition#input_format}.
         *
         * @stability stable
         */
        readonly inputFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#location GluePartition#location}.
         *
         * @stability stable
         */
        readonly location?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#number_of_buckets GluePartition#number_of_buckets}.
         *
         * @stability stable
         */
        readonly numberOfBuckets?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#output_format GluePartition#output_format}.
         *
         * @stability stable
         */
        readonly outputFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#parameters GluePartition#parameters}.
         *
         * @stability stable
         */
        readonly parameters?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#stored_as_sub_directories GluePartition#stored_as_sub_directories}.
         *
         * @stability stable
         */
        readonly storedAsSubDirectories?: boolean | cdktf.IResolvable;
        /**
         * columns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#columns GluePartition#columns}
         *
         * @stability stable
         */
        readonly columns?: GluePartitionStorageDescriptorColumns[];
        /**
         * ser_de_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#ser_de_info GluePartition#ser_de_info}
         *
         * @stability stable
         */
        readonly serDeInfo?: GluePartitionStorageDescriptorSerDeInfo;
        /**
         * skewed_info block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#skewed_info GluePartition#skewed_info}
         *
         * @stability stable
         */
        readonly skewedInfo?: GluePartitionStorageDescriptorSkewedInfo;
        /**
         * sort_columns block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html#sort_columns GluePartition#sort_columns}
         *
         * @stability stable
         */
        readonly sortColumns?: GluePartitionStorageDescriptorSortColumns[];
    }
    /**
     * @stability stable
     */
    class GluePartitionStorageDescriptorOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketColumns?;
        /**
         * @stability stable
         */
        get bucketColumns(): string[] | undefined;
        /**
         * @stability stable
         */
        set bucketColumns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetBucketColumns(): void;
        /**
         * @stability stable
         */
        get bucketColumnsInput(): string[] | undefined;
        private _compressed?;
        /**
         * @stability stable
         */
        get compressed(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set compressed(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCompressed(): void;
        /**
         * @stability stable
         */
        get compressedInput(): boolean | cdktf.IResolvable | undefined;
        private _inputFormat?;
        /**
         * @stability stable
         */
        get inputFormat(): string | undefined;
        /**
         * @stability stable
         */
        set inputFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetInputFormat(): void;
        /**
         * @stability stable
         */
        get inputFormatInput(): string | undefined;
        private _location?;
        /**
         * @stability stable
         */
        get location(): string | undefined;
        /**
         * @stability stable
         */
        set location(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocation(): void;
        /**
         * @stability stable
         */
        get locationInput(): string | undefined;
        private _numberOfBuckets?;
        /**
         * @stability stable
         */
        get numberOfBuckets(): number | undefined;
        /**
         * @stability stable
         */
        set numberOfBuckets(value: number | undefined);
        /**
         * @stability stable
         */
        resetNumberOfBuckets(): void;
        /**
         * @stability stable
         */
        get numberOfBucketsInput(): number | undefined;
        private _outputFormat?;
        /**
         * @stability stable
         */
        get outputFormat(): string | undefined;
        /**
         * @stability stable
         */
        set outputFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutputFormat(): void;
        /**
         * @stability stable
         */
        get outputFormatInput(): string | undefined;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _storedAsSubDirectories?;
        /**
         * @stability stable
         */
        get storedAsSubDirectories(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set storedAsSubDirectories(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetStoredAsSubDirectories(): void;
        /**
         * @stability stable
         */
        get storedAsSubDirectoriesInput(): boolean | cdktf.IResolvable | undefined;
        private _columns?;
        /**
         * @stability stable
         */
        get columns(): GluePartitionStorageDescriptorColumns[] | undefined;
        /**
         * @stability stable
         */
        set columns(value: GluePartitionStorageDescriptorColumns[] | undefined);
        /**
         * @stability stable
         */
        resetColumns(): void;
        /**
         * @stability stable
         */
        get columnsInput(): GluePartitionStorageDescriptorColumns[] | undefined;
        private _serDeInfo?;
        private __serDeInfoOutput;
        /**
         * @stability stable
         */
        get serDeInfo(): GluePartitionStorageDescriptorSerDeInfoOutputReference;
        /**
         * @stability stable
         */
        putSerDeInfo(value: GluePartitionStorageDescriptorSerDeInfo | undefined): void;
        /**
         * @stability stable
         */
        resetSerDeInfo(): void;
        /**
         * @stability stable
         */
        get serDeInfoInput(): GluePartitionStorageDescriptorSerDeInfo | undefined;
        private _skewedInfo?;
        private __skewedInfoOutput;
        /**
         * @stability stable
         */
        get skewedInfo(): GluePartitionStorageDescriptorSkewedInfoOutputReference;
        /**
         * @stability stable
         */
        putSkewedInfo(value: GluePartitionStorageDescriptorSkewedInfo | undefined): void;
        /**
         * @stability stable
         */
        resetSkewedInfo(): void;
        /**
         * @stability stable
         */
        get skewedInfoInput(): GluePartitionStorageDescriptorSkewedInfo | undefined;
        private _sortColumns?;
        /**
         * @stability stable
         */
        get sortColumns(): GluePartitionStorageDescriptorSortColumns[] | undefined;
        /**
         * @stability stable
         */
        set sortColumns(value: GluePartitionStorageDescriptorSortColumns[] | undefined);
        /**
         * @stability stable
         */
        resetSortColumns(): void;
        /**
         * @stability stable
         */
        get sortColumnsInput(): GluePartitionStorageDescriptorSortColumns[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html aws_glue_partition}.
     *
     * @stability stable
     */
    class GluePartition extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_partition.html aws_glue_partition} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GluePartitionConfig);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get creationTime(): string;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get lastAccessedTime(): string;
        /**
         * @stability stable
         */
        get lastAnalyzedTime(): string;
        private _parameters?;
        /**
         * @stability stable
         */
        get parameters(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set parameters(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetParameters(): void;
        /**
         * @stability stable
         */
        get parametersInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _partitionValues?;
        /**
         * @stability stable
         */
        get partitionValues(): string[];
        /**
         * @stability stable
         */
        set partitionValues(value: string[]);
        /**
         * @stability stable
         */
        get partitionValuesInput(): string[] | undefined;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
        private _storageDescriptor?;
        private __storageDescriptorOutput;
        /**
         * @stability stable
         */
        get storageDescriptor(): GluePartitionStorageDescriptorOutputReference;
        /**
         * @stability stable
         */
        putStorageDescriptor(value: GluePartitionStorageDescriptor | undefined): void;
        /**
         * @stability stable
         */
        resetStorageDescriptor(): void;
        /**
         * @stability stable
         */
        get storageDescriptorInput(): GluePartitionStorageDescriptor | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GluePartitionIndexConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html#catalog_id GluePartitionIndex#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html#database_name GluePartitionIndex#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html#table_name GluePartitionIndex#table_name}.
         *
         * @stability stable
         */
        readonly tableName: string;
        /**
         * partition_index block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html#partition_index GluePartitionIndex#partition_index}
         *
         * @stability stable
         */
        readonly partitionIndex: GluePartitionIndexPartitionIndex;
    }
    /**
     * @stability stable
     */
    interface GluePartitionIndexPartitionIndex {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html#index_name GluePartitionIndex#index_name}.
         *
         * @stability stable
         */
        readonly indexName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html#keys GluePartitionIndex#keys}.
         *
         * @stability stable
         */
        readonly keys?: string[];
    }
    /**
     * @stability stable
     */
    class GluePartitionIndexPartitionIndexOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _indexName?;
        /**
         * @stability stable
         */
        get indexName(): string | undefined;
        /**
         * @stability stable
         */
        set indexName(value: string | undefined);
        /**
         * @stability stable
         */
        resetIndexName(): void;
        /**
         * @stability stable
         */
        get indexNameInput(): string | undefined;
        private _keys?;
        /**
         * @stability stable
         */
        get keys(): string[] | undefined;
        /**
         * @stability stable
         */
        set keys(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetKeys(): void;
        /**
         * @stability stable
         */
        get keysInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html aws_glue_partition_index}.
     *
     * @stability stable
     */
    class GluePartitionIndex extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_partition_index.html aws_glue_partition_index} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GluePartitionIndexConfig);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string;
        /**
         * @stability stable
         */
        set tableName(value: string);
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
        private _partitionIndex?;
        private __partitionIndexOutput;
        /**
         * @stability stable
         */
        get partitionIndex(): GluePartitionIndexPartitionIndexOutputReference;
        /**
         * @stability stable
         */
        putPartitionIndex(value: GluePartitionIndexPartitionIndex): void;
        /**
         * @stability stable
         */
        get partitionIndexInput(): GluePartitionIndexPartitionIndex | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueRegistryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_registry.html#description GlueRegistry#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_registry.html#registry_name GlueRegistry#registry_name}.
         *
         * @stability stable
         */
        readonly registryName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_registry.html#tags GlueRegistry#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_registry.html#tags_all GlueRegistry#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_registry.html aws_glue_registry}.
     *
     * @stability stable
     */
    class GlueRegistry extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_registry.html aws_glue_registry} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueRegistryConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _registryName?;
        /**
         * @stability stable
         */
        get registryName(): string;
        /**
         * @stability stable
         */
        set registryName(value: string);
        /**
         * @stability stable
         */
        get registryNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueResourcePolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_resource_policy.html#enable_hybrid GlueResourcePolicy#enable_hybrid}.
         *
         * @stability stable
         */
        readonly enableHybrid?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_resource_policy.html#policy GlueResourcePolicy#policy}.
         *
         * @stability stable
         */
        readonly policy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_resource_policy.html aws_glue_resource_policy}.
     *
     * @stability stable
     */
    class GlueResourcePolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_resource_policy.html aws_glue_resource_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueResourcePolicyConfig);
        private _enableHybrid?;
        /**
         * @stability stable
         */
        get enableHybrid(): string | undefined;
        /**
         * @stability stable
         */
        set enableHybrid(value: string | undefined);
        /**
         * @stability stable
         */
        resetEnableHybrid(): void;
        /**
         * @stability stable
         */
        get enableHybridInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        set policy(value: string);
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueSchemaConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#compatibility GlueSchema#compatibility}.
         *
         * @stability stable
         */
        readonly compatibility: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#data_format GlueSchema#data_format}.
         *
         * @stability stable
         */
        readonly dataFormat: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#description GlueSchema#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#registry_arn GlueSchema#registry_arn}.
         *
         * @stability stable
         */
        readonly registryArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#schema_definition GlueSchema#schema_definition}.
         *
         * @stability stable
         */
        readonly schemaDefinition: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#schema_name GlueSchema#schema_name}.
         *
         * @stability stable
         */
        readonly schemaName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#tags GlueSchema#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html#tags_all GlueSchema#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html aws_glue_schema}.
     *
     * @stability stable
     */
    class GlueSchema extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_schema.html aws_glue_schema} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueSchemaConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _compatibility?;
        /**
         * @stability stable
         */
        get compatibility(): string;
        /**
         * @stability stable
         */
        set compatibility(value: string);
        /**
         * @stability stable
         */
        get compatibilityInput(): string | undefined;
        private _dataFormat?;
        /**
         * @stability stable
         */
        get dataFormat(): string;
        /**
         * @stability stable
         */
        set dataFormat(value: string);
        /**
         * @stability stable
         */
        get dataFormatInput(): string | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get latestSchemaVersion(): number;
        /**
         * @stability stable
         */
        get nextSchemaVersion(): number;
        private _registryArn?;
        /**
         * @stability stable
         */
        get registryArn(): string | undefined;
        /**
         * @stability stable
         */
        set registryArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegistryArn(): void;
        /**
         * @stability stable
         */
        get registryArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get registryName(): string;
        /**
         * @stability stable
         */
        get schemaCheckpoint(): number;
        private _schemaDefinition?;
        /**
         * @stability stable
         */
        get schemaDefinition(): string;
        /**
         * @stability stable
         */
        set schemaDefinition(value: string);
        /**
         * @stability stable
         */
        get schemaDefinitionInput(): string | undefined;
        private _schemaName?;
        /**
         * @stability stable
         */
        get schemaName(): string;
        /**
         * @stability stable
         */
        set schemaName(value: string);
        /**
         * @stability stable
         */
        get schemaNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueSecurityConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#name GlueSecurityConfiguration#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * encryption_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#encryption_configuration GlueSecurityConfiguration#encryption_configuration}
         *
         * @stability stable
         */
        readonly encryptionConfiguration: GlueSecurityConfigurationEncryptionConfiguration;
    }
    /**
     * @stability stable
     */
    interface GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#cloudwatch_encryption_mode GlueSecurityConfiguration#cloudwatch_encryption_mode}.
         *
         * @stability stable
         */
        readonly cloudwatchEncryptionMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#kms_key_arn GlueSecurityConfiguration#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
    }
    /**
     * @stability stable
     */
    class GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cloudwatchEncryptionMode?;
        /**
         * @stability stable
         */
        get cloudwatchEncryptionMode(): string | undefined;
        /**
         * @stability stable
         */
        set cloudwatchEncryptionMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetCloudwatchEncryptionMode(): void;
        /**
         * @stability stable
         */
        get cloudwatchEncryptionModeInput(): string | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#job_bookmarks_encryption_mode GlueSecurityConfiguration#job_bookmarks_encryption_mode}.
         *
         * @stability stable
         */
        readonly jobBookmarksEncryptionMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#kms_key_arn GlueSecurityConfiguration#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
    }
    /**
     * @stability stable
     */
    class GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _jobBookmarksEncryptionMode?;
        /**
         * @stability stable
         */
        get jobBookmarksEncryptionMode(): string | undefined;
        /**
         * @stability stable
         */
        set jobBookmarksEncryptionMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetJobBookmarksEncryptionMode(): void;
        /**
         * @stability stable
         */
        get jobBookmarksEncryptionModeInput(): string | undefined;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueSecurityConfigurationEncryptionConfigurationS3Encryption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#kms_key_arn GlueSecurityConfiguration#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#s3_encryption_mode GlueSecurityConfiguration#s3_encryption_mode}.
         *
         * @stability stable
         */
        readonly s3EncryptionMode?: string;
    }
    /**
     * @stability stable
     */
    class GlueSecurityConfigurationEncryptionConfigurationS3EncryptionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _s3EncryptionMode?;
        /**
         * @stability stable
         */
        get s3EncryptionMode(): string | undefined;
        /**
         * @stability stable
         */
        set s3EncryptionMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3EncryptionMode(): void;
        /**
         * @stability stable
         */
        get s3EncryptionModeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueSecurityConfigurationEncryptionConfiguration {
        /**
         * cloudwatch_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#cloudwatch_encryption GlueSecurityConfiguration#cloudwatch_encryption}
         *
         * @stability stable
         */
        readonly cloudwatchEncryption: GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption;
        /**
         * job_bookmarks_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#job_bookmarks_encryption GlueSecurityConfiguration#job_bookmarks_encryption}
         *
         * @stability stable
         */
        readonly jobBookmarksEncryption: GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption;
        /**
         * s3_encryption block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html#s3_encryption GlueSecurityConfiguration#s3_encryption}
         *
         * @stability stable
         */
        readonly s3Encryption: GlueSecurityConfigurationEncryptionConfigurationS3Encryption;
    }
    /**
     * @stability stable
     */
    class GlueSecurityConfigurationEncryptionConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cloudwatchEncryption?;
        private __cloudwatchEncryptionOutput;
        /**
         * @stability stable
         */
        get cloudwatchEncryption(): GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryptionOutputReference;
        /**
         * @stability stable
         */
        putCloudwatchEncryption(value: GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption): void;
        /**
         * @stability stable
         */
        get cloudwatchEncryptionInput(): GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption | undefined;
        private _jobBookmarksEncryption?;
        private __jobBookmarksEncryptionOutput;
        /**
         * @stability stable
         */
        get jobBookmarksEncryption(): GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryptionOutputReference;
        /**
         * @stability stable
         */
        putJobBookmarksEncryption(value: GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption): void;
        /**
         * @stability stable
         */
        get jobBookmarksEncryptionInput(): GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption | undefined;
        private _s3Encryption?;
        private __s3EncryptionOutput;
        /**
         * @stability stable
         */
        get s3Encryption(): GlueSecurityConfigurationEncryptionConfigurationS3EncryptionOutputReference;
        /**
         * @stability stable
         */
        putS3Encryption(value: GlueSecurityConfigurationEncryptionConfigurationS3Encryption): void;
        /**
         * @stability stable
         */
        get s3EncryptionInput(): GlueSecurityConfigurationEncryptionConfigurationS3Encryption | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html aws_glue_security_configuration}.
     *
     * @stability stable
     */
    class GlueSecurityConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_security_configuration.html aws_glue_security_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueSecurityConfigurationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _encryptionConfiguration?;
        private __encryptionConfigurationOutput;
        /**
         * @stability stable
         */
        get encryptionConfiguration(): GlueSecurityConfigurationEncryptionConfigurationOutputReference;
        /**
         * @stability stable
         */
        putEncryptionConfiguration(value: GlueSecurityConfigurationEncryptionConfiguration): void;
        /**
         * @stability stable
         */
        get encryptionConfigurationInput(): GlueSecurityConfigurationEncryptionConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueTriggerConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#description GlueTrigger#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#enabled GlueTrigger#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#name GlueTrigger#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#schedule GlueTrigger#schedule}.
         *
         * @stability stable
         */
        readonly schedule?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#tags GlueTrigger#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#tags_all GlueTrigger#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#type GlueTrigger#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#workflow_name GlueTrigger#workflow_name}.
         *
         * @stability stable
         */
        readonly workflowName?: string;
        /**
         * actions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#actions GlueTrigger#actions}
         *
         * @stability stable
         */
        readonly actions: GlueTriggerActions[];
        /**
         * predicate block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#predicate GlueTrigger#predicate}
         *
         * @stability stable
         */
        readonly predicate?: GlueTriggerPredicate;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#timeouts GlueTrigger#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: GlueTriggerTimeouts;
    }
    /**
     * @stability stable
     */
    interface GlueTriggerActionsNotificationProperty {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#notify_delay_after GlueTrigger#notify_delay_after}.
         *
         * @stability stable
         */
        readonly notifyDelayAfter?: number;
    }
    /**
     * @stability stable
     */
    class GlueTriggerActionsNotificationPropertyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _notifyDelayAfter?;
        /**
         * @stability stable
         */
        get notifyDelayAfter(): number | undefined;
        /**
         * @stability stable
         */
        set notifyDelayAfter(value: number | undefined);
        /**
         * @stability stable
         */
        resetNotifyDelayAfter(): void;
        /**
         * @stability stable
         */
        get notifyDelayAfterInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueTriggerActions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#arguments GlueTrigger#arguments}.
         *
         * @stability stable
         */
        readonly arguments?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#crawler_name GlueTrigger#crawler_name}.
         *
         * @stability stable
         */
        readonly crawlerName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#job_name GlueTrigger#job_name}.
         *
         * @stability stable
         */
        readonly jobName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#security_configuration GlueTrigger#security_configuration}.
         *
         * @stability stable
         */
        readonly securityConfiguration?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#timeout GlueTrigger#timeout}.
         *
         * @stability stable
         */
        readonly timeout?: number;
        /**
         * notification_property block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#notification_property GlueTrigger#notification_property}
         *
         * @stability stable
         */
        readonly notificationProperty?: GlueTriggerActionsNotificationProperty;
    }
    /**
     * @stability stable
     */
    interface GlueTriggerPredicateConditions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#crawl_state GlueTrigger#crawl_state}.
         *
         * @stability stable
         */
        readonly crawlState?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#crawler_name GlueTrigger#crawler_name}.
         *
         * @stability stable
         */
        readonly crawlerName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#job_name GlueTrigger#job_name}.
         *
         * @stability stable
         */
        readonly jobName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#logical_operator GlueTrigger#logical_operator}.
         *
         * @stability stable
         */
        readonly logicalOperator?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#state GlueTrigger#state}.
         *
         * @stability stable
         */
        readonly state?: string;
    }
    /**
     * @stability stable
     */
    interface GlueTriggerPredicate {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#logical GlueTrigger#logical}.
         *
         * @stability stable
         */
        readonly logical?: string;
        /**
         * conditions block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#conditions GlueTrigger#conditions}
         *
         * @stability stable
         */
        readonly conditions: GlueTriggerPredicateConditions[];
    }
    /**
     * @stability stable
     */
    class GlueTriggerPredicateOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _logical?;
        /**
         * @stability stable
         */
        get logical(): string | undefined;
        /**
         * @stability stable
         */
        set logical(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogical(): void;
        /**
         * @stability stable
         */
        get logicalInput(): string | undefined;
        private _conditions?;
        /**
         * @stability stable
         */
        get conditions(): GlueTriggerPredicateConditions[];
        /**
         * @stability stable
         */
        set conditions(value: GlueTriggerPredicateConditions[]);
        /**
         * @stability stable
         */
        get conditionsInput(): GlueTriggerPredicateConditions[] | undefined;
    }
    /**
     * @stability stable
     */
    interface GlueTriggerTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#create GlueTrigger#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html#delete GlueTrigger#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class GlueTriggerTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html aws_glue_trigger}.
     *
     * @stability stable
     */
    class GlueTrigger extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_trigger.html aws_glue_trigger} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueTriggerConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _schedule?;
        /**
         * @stability stable
         */
        get schedule(): string | undefined;
        /**
         * @stability stable
         */
        set schedule(value: string | undefined);
        /**
         * @stability stable
         */
        resetSchedule(): void;
        /**
         * @stability stable
         */
        get scheduleInput(): string | undefined;
        /**
         * @stability stable
         */
        get state(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        private _workflowName?;
        /**
         * @stability stable
         */
        get workflowName(): string | undefined;
        /**
         * @stability stable
         */
        set workflowName(value: string | undefined);
        /**
         * @stability stable
         */
        resetWorkflowName(): void;
        /**
         * @stability stable
         */
        get workflowNameInput(): string | undefined;
        private _actions?;
        /**
         * @stability stable
         */
        get actions(): GlueTriggerActions[];
        /**
         * @stability stable
         */
        set actions(value: GlueTriggerActions[]);
        /**
         * @stability stable
         */
        get actionsInput(): GlueTriggerActions[] | undefined;
        private _predicate?;
        private __predicateOutput;
        /**
         * @stability stable
         */
        get predicate(): GlueTriggerPredicateOutputReference;
        /**
         * @stability stable
         */
        putPredicate(value: GlueTriggerPredicate | undefined): void;
        /**
         * @stability stable
         */
        resetPredicate(): void;
        /**
         * @stability stable
         */
        get predicateInput(): GlueTriggerPredicate | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): GlueTriggerTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: GlueTriggerTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): GlueTriggerTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueUserDefinedFunctionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#catalog_id GlueUserDefinedFunction#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#class_name GlueUserDefinedFunction#class_name}.
         *
         * @stability stable
         */
        readonly className: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#database_name GlueUserDefinedFunction#database_name}.
         *
         * @stability stable
         */
        readonly databaseName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#name GlueUserDefinedFunction#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#owner_name GlueUserDefinedFunction#owner_name}.
         *
         * @stability stable
         */
        readonly ownerName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#owner_type GlueUserDefinedFunction#owner_type}.
         *
         * @stability stable
         */
        readonly ownerType: string;
        /**
         * resource_uris block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#resource_uris GlueUserDefinedFunction#resource_uris}
         *
         * @stability stable
         */
        readonly resourceUris?: GlueUserDefinedFunctionResourceUris[];
    }
    /**
     * @stability stable
     */
    interface GlueUserDefinedFunctionResourceUris {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#resource_type GlueUserDefinedFunction#resource_type}.
         *
         * @stability stable
         */
        readonly resourceType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html#uri GlueUserDefinedFunction#uri}.
         *
         * @stability stable
         */
        readonly uri: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html aws_glue_user_defined_function}.
     *
     * @stability stable
     */
    class GlueUserDefinedFunction extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_user_defined_function.html aws_glue_user_defined_function} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: GlueUserDefinedFunctionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string | undefined;
        /**
         * @stability stable
         */
        set catalogId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalogId(): void;
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        private _className?;
        /**
         * @stability stable
         */
        get className(): string;
        /**
         * @stability stable
         */
        set className(value: string);
        /**
         * @stability stable
         */
        get classNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get createTime(): string;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        set databaseName(value: string);
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _ownerName?;
        /**
         * @stability stable
         */
        get ownerName(): string;
        /**
         * @stability stable
         */
        set ownerName(value: string);
        /**
         * @stability stable
         */
        get ownerNameInput(): string | undefined;
        private _ownerType?;
        /**
         * @stability stable
         */
        get ownerType(): string;
        /**
         * @stability stable
         */
        set ownerType(value: string);
        /**
         * @stability stable
         */
        get ownerTypeInput(): string | undefined;
        private _resourceUris?;
        /**
         * @stability stable
         */
        get resourceUris(): GlueUserDefinedFunctionResourceUris[] | undefined;
        /**
         * @stability stable
         */
        set resourceUris(value: GlueUserDefinedFunctionResourceUris[] | undefined);
        /**
         * @stability stable
         */
        resetResourceUris(): void;
        /**
         * @stability stable
         */
        get resourceUrisInput(): GlueUserDefinedFunctionResourceUris[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface GlueWorkflowConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html#default_run_properties GlueWorkflow#default_run_properties}.
         *
         * @stability stable
         */
        readonly defaultRunProperties?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html#description GlueWorkflow#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html#max_concurrent_runs GlueWorkflow#max_concurrent_runs}.
         *
         * @stability stable
         */
        readonly maxConcurrentRuns?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html#name GlueWorkflow#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html#tags GlueWorkflow#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html#tags_all GlueWorkflow#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html aws_glue_workflow}.
     *
     * @stability stable
     */
    class GlueWorkflow extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_workflow.html aws_glue_workflow} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: GlueWorkflowConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _defaultRunProperties?;
        /**
         * @stability stable
         */
        get defaultRunProperties(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set defaultRunProperties(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDefaultRunProperties(): void;
        /**
         * @stability stable
         */
        get defaultRunPropertiesInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _maxConcurrentRuns?;
        /**
         * @stability stable
         */
        get maxConcurrentRuns(): number | undefined;
        /**
         * @stability stable
         */
        set maxConcurrentRuns(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxConcurrentRuns(): void;
        /**
         * @stability stable
         */
        get maxConcurrentRunsInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsGlueConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_connection.html#id DataAwsGlueConnection#id}.
         *
         * @stability stable
         */
        readonly id: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_connection.html#tags DataAwsGlueConnection#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DataAwsGlueConnectionPhysicalConnectionRequirements extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        /**
         * @stability stable
         */
        get securityGroupIdList(): string[];
        /**
         * @stability stable
         */
        get subnetId(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/glue_connection.html aws_glue_connection}.
     *
     * @stability stable
     */
    class DataAwsGlueConnection extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/glue_connection.html aws_glue_connection} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsGlueConnectionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get catalogId(): string;
        /**
         * @stability stable
         */
        connectionProperties(key: string): string;
        /**
         * @stability stable
         */
        get connectionType(): string;
        /**
         * @stability stable
         */
        get description(): string;
        private _id?;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        set id(value: string);
        /**
         * @stability stable
         */
        get idInput(): string | undefined;
        /**
         * @stability stable
         */
        get matchCriteria(): string[];
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        physicalConnectionRequirements(index: string): DataAwsGlueConnectionPhysicalConnectionRequirements;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsGlueDataCatalogEncryptionSettingsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_data_catalog_encryption_settings.html#catalog_id DataAwsGlueDataCatalogEncryptionSettings#catalog_id}.
         *
         * @stability stable
         */
        readonly catalogId: string;
    }
    /**
     * @stability stable
     */
    class DataAwsGlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsConnectionPasswordEncryption extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get awsKmsKeyId(): string;
        /**
         * @stability stable
         */
        get returnConnectionPasswordEncrypted(): any;
    }
    /**
     * @stability stable
     */
    class DataAwsGlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettingsEncryptionAtRest extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get catalogEncryptionMode(): string;
        /**
         * @stability stable
         */
        get sseAwsKmsKeyId(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsGlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettings extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get connectionPasswordEncryption(): any;
        /**
         * @stability stable
         */
        get encryptionAtRest(): any;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/glue_data_catalog_encryption_settings.html aws_glue_data_catalog_encryption_settings}.
     *
     * @stability stable
     */
    class DataAwsGlueDataCatalogEncryptionSettings extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/glue_data_catalog_encryption_settings.html aws_glue_data_catalog_encryption_settings} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsGlueDataCatalogEncryptionSettingsConfig);
        private _catalogId?;
        /**
         * @stability stable
         */
        get catalogId(): string;
        /**
         * @stability stable
         */
        set catalogId(value: string);
        /**
         * @stability stable
         */
        get catalogIdInput(): string | undefined;
        /**
         * @stability stable
         */
        dataCatalogEncryptionSettings(index: string): DataAwsGlueDataCatalogEncryptionSettingsDataCatalogEncryptionSettings;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsGlueScriptConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#language DataAwsGlueScript#language}.
         *
         * @stability stable
         */
        readonly language?: string;
        /**
         * dag_edge block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#dag_edge DataAwsGlueScript#dag_edge}
         *
         * @stability stable
         */
        readonly dagEdge: DataAwsGlueScriptDagEdge[];
        /**
         * dag_node block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#dag_node DataAwsGlueScript#dag_node}
         *
         * @stability stable
         */
        readonly dagNode: DataAwsGlueScriptDagNode[];
    }
    /**
     * @stability stable
     */
    interface DataAwsGlueScriptDagEdge {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#source DataAwsGlueScript#source}.
         *
         * @stability stable
         */
        readonly source: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#target DataAwsGlueScript#target}.
         *
         * @stability stable
         */
        readonly target: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#target_parameter DataAwsGlueScript#target_parameter}.
         *
         * @stability stable
         */
        readonly targetParameter?: string;
    }
    /**
     * @stability stable
     */
    interface DataAwsGlueScriptDagNodeArgs {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#name DataAwsGlueScript#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#param DataAwsGlueScript#param}.
         *
         * @stability stable
         */
        readonly param?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#value DataAwsGlueScript#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface DataAwsGlueScriptDagNode {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#id DataAwsGlueScript#id}.
         *
         * @stability stable
         */
        readonly id: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#line_number DataAwsGlueScript#line_number}.
         *
         * @stability stable
         */
        readonly lineNumber?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#node_type DataAwsGlueScript#node_type}.
         *
         * @stability stable
         */
        readonly nodeType: string;
        /**
         * args block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html#args DataAwsGlueScript#args}
         *
         * @stability stable
         */
        readonly args: DataAwsGlueScriptDagNodeArgs[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html aws_glue_script}.
     *
     * @stability stable
     */
    class DataAwsGlueScript extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/glue_script.html aws_glue_script} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsGlueScriptConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _language?;
        /**
         * @stability stable
         */
        get language(): string | undefined;
        /**
         * @stability stable
         */
        set language(value: string | undefined);
        /**
         * @stability stable
         */
        resetLanguage(): void;
        /**
         * @stability stable
         */
        get languageInput(): string | undefined;
        /**
         * @stability stable
         */
        get pythonScript(): string;
        /**
         * @stability stable
         */
        get scalaCode(): string;
        private _dagEdge?;
        /**
         * @stability stable
         */
        get dagEdge(): DataAwsGlueScriptDagEdge[];
        /**
         * @stability stable
         */
        set dagEdge(value: DataAwsGlueScriptDagEdge[]);
        /**
         * @stability stable
         */
        get dagEdgeInput(): DataAwsGlueScriptDagEdge[] | undefined;
        private _dagNode?;
        /**
         * @stability stable
         */
        get dagNode(): DataAwsGlueScriptDagNode[];
        /**
         * @stability stable
         */
        set dagNode(value: DataAwsGlueScriptDagNode[]);
        /**
         * @stability stable
         */
        get dagNodeInput(): DataAwsGlueScriptDagNode[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
