import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS Relational Database Service
*/
export declare namespace RDS {
    /**
     * @stability stable
     */
    interface DbClusterSnapshotConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html#db_cluster_identifier DbClusterSnapshot#db_cluster_identifier}.
         *
         * @stability stable
         */
        readonly dbClusterIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html#db_cluster_snapshot_identifier DbClusterSnapshot#db_cluster_snapshot_identifier}.
         *
         * @stability stable
         */
        readonly dbClusterSnapshotIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html#tags DbClusterSnapshot#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html#tags_all DbClusterSnapshot#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html#timeouts DbClusterSnapshot#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbClusterSnapshotTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbClusterSnapshotTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html#create DbClusterSnapshot#create}.
         *
         * @stability stable
         */
        readonly create?: string;
    }
    /**
     * @stability stable
     */
    class DbClusterSnapshotTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html aws_db_cluster_snapshot}.
     *
     * @stability stable
     */
    class DbClusterSnapshot extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_cluster_snapshot.html aws_db_cluster_snapshot} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbClusterSnapshotConfig);
        /**
         * @stability stable
         */
        get allocatedStorage(): number;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        private _dbClusterIdentifier?;
        /**
         * @stability stable
         */
        get dbClusterIdentifier(): string;
        /**
         * @stability stable
         */
        set dbClusterIdentifier(value: string);
        /**
         * @stability stable
         */
        get dbClusterIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get dbClusterSnapshotArn(): string;
        private _dbClusterSnapshotIdentifier?;
        /**
         * @stability stable
         */
        get dbClusterSnapshotIdentifier(): string;
        /**
         * @stability stable
         */
        set dbClusterSnapshotIdentifier(value: string);
        /**
         * @stability stable
         */
        get dbClusterSnapshotIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        get engineVersion(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        get licenseModel(): string;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get snapshotType(): string;
        /**
         * @stability stable
         */
        get sourceDbClusterSnapshotArn(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get storageEncrypted(): any;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbClusterSnapshotTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbClusterSnapshotTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbClusterSnapshotTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbEventSubscriptionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#enabled DbEventSubscription#enabled}.
         *
         * @stability stable
         */
        readonly enabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#event_categories DbEventSubscription#event_categories}.
         *
         * @stability stable
         */
        readonly eventCategories?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#name DbEventSubscription#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#name_prefix DbEventSubscription#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#sns_topic DbEventSubscription#sns_topic}.
         *
         * @stability stable
         */
        readonly snsTopic: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#source_ids DbEventSubscription#source_ids}.
         *
         * @stability stable
         */
        readonly sourceIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#source_type DbEventSubscription#source_type}.
         *
         * @stability stable
         */
        readonly sourceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#tags DbEventSubscription#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#tags_all DbEventSubscription#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#timeouts DbEventSubscription#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbEventSubscriptionTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbEventSubscriptionTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#create DbEventSubscription#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#delete DbEventSubscription#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html#update DbEventSubscription#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DbEventSubscriptionTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html aws_db_event_subscription}.
     *
     * @stability stable
     */
    class DbEventSubscription extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_event_subscription.html aws_db_event_subscription} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbEventSubscriptionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get customerAwsId(): string;
        private _enabled?;
        /**
         * @stability stable
         */
        get enabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnabled(): void;
        /**
         * @stability stable
         */
        get enabledInput(): boolean | cdktf.IResolvable | undefined;
        private _eventCategories?;
        /**
         * @stability stable
         */
        get eventCategories(): string[] | undefined;
        /**
         * @stability stable
         */
        set eventCategories(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEventCategories(): void;
        /**
         * @stability stable
         */
        get eventCategoriesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _snsTopic?;
        /**
         * @stability stable
         */
        get snsTopic(): string;
        /**
         * @stability stable
         */
        set snsTopic(value: string);
        /**
         * @stability stable
         */
        get snsTopicInput(): string | undefined;
        private _sourceIds?;
        /**
         * @stability stable
         */
        get sourceIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set sourceIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSourceIds(): void;
        /**
         * @stability stable
         */
        get sourceIdsInput(): string[] | undefined;
        private _sourceType?;
        /**
         * @stability stable
         */
        get sourceType(): string | undefined;
        /**
         * @stability stable
         */
        set sourceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceType(): void;
        /**
         * @stability stable
         */
        get sourceTypeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbEventSubscriptionTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbEventSubscriptionTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbEventSubscriptionTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#allocated_storage DbInstance#allocated_storage}.
         *
         * @stability stable
         */
        readonly allocatedStorage?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#allow_major_version_upgrade DbInstance#allow_major_version_upgrade}.
         *
         * @stability stable
         */
        readonly allowMajorVersionUpgrade?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#apply_immediately DbInstance#apply_immediately}.
         *
         * @stability stable
         */
        readonly applyImmediately?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#auto_minor_version_upgrade DbInstance#auto_minor_version_upgrade}.
         *
         * @stability stable
         */
        readonly autoMinorVersionUpgrade?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#availability_zone DbInstance#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#backup_retention_period DbInstance#backup_retention_period}.
         *
         * @stability stable
         */
        readonly backupRetentionPeriod?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#backup_window DbInstance#backup_window}.
         *
         * @stability stable
         */
        readonly backupWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#ca_cert_identifier DbInstance#ca_cert_identifier}.
         *
         * @stability stable
         */
        readonly caCertIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#character_set_name DbInstance#character_set_name}.
         *
         * @stability stable
         */
        readonly characterSetName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#copy_tags_to_snapshot DbInstance#copy_tags_to_snapshot}.
         *
         * @stability stable
         */
        readonly copyTagsToSnapshot?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#customer_owned_ip_enabled DbInstance#customer_owned_ip_enabled}.
         *
         * @stability stable
         */
        readonly customerOwnedIpEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#db_subnet_group_name DbInstance#db_subnet_group_name}.
         *
         * @stability stable
         */
        readonly dbSubnetGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#delete_automated_backups DbInstance#delete_automated_backups}.
         *
         * @stability stable
         */
        readonly deleteAutomatedBackups?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#deletion_protection DbInstance#deletion_protection}.
         *
         * @stability stable
         */
        readonly deletionProtection?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#domain DbInstance#domain}.
         *
         * @stability stable
         */
        readonly domain?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#domain_iam_role_name DbInstance#domain_iam_role_name}.
         *
         * @stability stable
         */
        readonly domainIamRoleName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#enabled_cloudwatch_logs_exports DbInstance#enabled_cloudwatch_logs_exports}.
         *
         * @stability stable
         */
        readonly enabledCloudwatchLogsExports?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#engine DbInstance#engine}.
         *
         * @stability stable
         */
        readonly engine?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#engine_version DbInstance#engine_version}.
         *
         * @stability stable
         */
        readonly engineVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#final_snapshot_identifier DbInstance#final_snapshot_identifier}.
         *
         * @stability stable
         */
        readonly finalSnapshotIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#iam_database_authentication_enabled DbInstance#iam_database_authentication_enabled}.
         *
         * @stability stable
         */
        readonly iamDatabaseAuthenticationEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#identifier DbInstance#identifier}.
         *
         * @stability stable
         */
        readonly identifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#identifier_prefix DbInstance#identifier_prefix}.
         *
         * @stability stable
         */
        readonly identifierPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#instance_class DbInstance#instance_class}.
         *
         * @stability stable
         */
        readonly instanceClass: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#iops DbInstance#iops}.
         *
         * @stability stable
         */
        readonly iops?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#kms_key_id DbInstance#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#license_model DbInstance#license_model}.
         *
         * @stability stable
         */
        readonly licenseModel?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#maintenance_window DbInstance#maintenance_window}.
         *
         * @stability stable
         */
        readonly maintenanceWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#max_allocated_storage DbInstance#max_allocated_storage}.
         *
         * @stability stable
         */
        readonly maxAllocatedStorage?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#monitoring_interval DbInstance#monitoring_interval}.
         *
         * @stability stable
         */
        readonly monitoringInterval?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#monitoring_role_arn DbInstance#monitoring_role_arn}.
         *
         * @stability stable
         */
        readonly monitoringRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#multi_az DbInstance#multi_az}.
         *
         * @stability stable
         */
        readonly multiAz?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#name DbInstance#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#nchar_character_set_name DbInstance#nchar_character_set_name}.
         *
         * @stability stable
         */
        readonly ncharCharacterSetName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#option_group_name DbInstance#option_group_name}.
         *
         * @stability stable
         */
        readonly optionGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#parameter_group_name DbInstance#parameter_group_name}.
         *
         * @stability stable
         */
        readonly parameterGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#password DbInstance#password}.
         *
         * @stability stable
         */
        readonly password?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#performance_insights_enabled DbInstance#performance_insights_enabled}.
         *
         * @stability stable
         */
        readonly performanceInsightsEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#performance_insights_kms_key_id DbInstance#performance_insights_kms_key_id}.
         *
         * @stability stable
         */
        readonly performanceInsightsKmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#performance_insights_retention_period DbInstance#performance_insights_retention_period}.
         *
         * @stability stable
         */
        readonly performanceInsightsRetentionPeriod?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#port DbInstance#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#publicly_accessible DbInstance#publicly_accessible}.
         *
         * @stability stable
         */
        readonly publiclyAccessible?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#replica_mode DbInstance#replica_mode}.
         *
         * @stability stable
         */
        readonly replicaMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#replicate_source_db DbInstance#replicate_source_db}.
         *
         * @stability stable
         */
        readonly replicateSourceDb?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#security_group_names DbInstance#security_group_names}.
         *
         * @stability stable
         */
        readonly securityGroupNames?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#skip_final_snapshot DbInstance#skip_final_snapshot}.
         *
         * @stability stable
         */
        readonly skipFinalSnapshot?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#snapshot_identifier DbInstance#snapshot_identifier}.
         *
         * @stability stable
         */
        readonly snapshotIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#storage_encrypted DbInstance#storage_encrypted}.
         *
         * @stability stable
         */
        readonly storageEncrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#storage_type DbInstance#storage_type}.
         *
         * @stability stable
         */
        readonly storageType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#tags DbInstance#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#tags_all DbInstance#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#timezone DbInstance#timezone}.
         *
         * @stability stable
         */
        readonly timezone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#username DbInstance#username}.
         *
         * @stability stable
         */
        readonly username?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#vpc_security_group_ids DbInstance#vpc_security_group_ids}.
         *
         * @stability stable
         */
        readonly vpcSecurityGroupIds?: string[];
        /**
         * restore_to_point_in_time block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#restore_to_point_in_time DbInstance#restore_to_point_in_time}
         *
         * @stability stable
         */
        readonly restoreToPointInTime?: DbInstanceRestoreToPointInTime;
        /**
         * s3_import block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#s3_import DbInstance#s3_import}
         *
         * @stability stable
         */
        readonly s3Import?: DbInstanceS3Import;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#timeouts DbInstance#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbInstanceTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbInstanceRestoreToPointInTime {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#restore_time DbInstance#restore_time}.
         *
         * @stability stable
         */
        readonly restoreTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#source_db_instance_identifier DbInstance#source_db_instance_identifier}.
         *
         * @stability stable
         */
        readonly sourceDbInstanceIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#source_dbi_resource_id DbInstance#source_dbi_resource_id}.
         *
         * @stability stable
         */
        readonly sourceDbiResourceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#use_latest_restorable_time DbInstance#use_latest_restorable_time}.
         *
         * @stability stable
         */
        readonly useLatestRestorableTime?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class DbInstanceRestoreToPointInTimeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _restoreTime?;
        /**
         * @stability stable
         */
        get restoreTime(): string | undefined;
        /**
         * @stability stable
         */
        set restoreTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetRestoreTime(): void;
        /**
         * @stability stable
         */
        get restoreTimeInput(): string | undefined;
        private _sourceDbInstanceIdentifier?;
        /**
         * @stability stable
         */
        get sourceDbInstanceIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set sourceDbInstanceIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceDbInstanceIdentifier(): void;
        /**
         * @stability stable
         */
        get sourceDbInstanceIdentifierInput(): string | undefined;
        private _sourceDbiResourceId?;
        /**
         * @stability stable
         */
        get sourceDbiResourceId(): string | undefined;
        /**
         * @stability stable
         */
        set sourceDbiResourceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceDbiResourceId(): void;
        /**
         * @stability stable
         */
        get sourceDbiResourceIdInput(): string | undefined;
        private _useLatestRestorableTime?;
        /**
         * @stability stable
         */
        get useLatestRestorableTime(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set useLatestRestorableTime(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetUseLatestRestorableTime(): void;
        /**
         * @stability stable
         */
        get useLatestRestorableTimeInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface DbInstanceS3Import {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#bucket_name DbInstance#bucket_name}.
         *
         * @stability stable
         */
        readonly bucketName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#bucket_prefix DbInstance#bucket_prefix}.
         *
         * @stability stable
         */
        readonly bucketPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#ingestion_role DbInstance#ingestion_role}.
         *
         * @stability stable
         */
        readonly ingestionRole: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#source_engine DbInstance#source_engine}.
         *
         * @stability stable
         */
        readonly sourceEngine: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#source_engine_version DbInstance#source_engine_version}.
         *
         * @stability stable
         */
        readonly sourceEngineVersion: string;
    }
    /**
     * @stability stable
     */
    class DbInstanceS3ImportOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketName?;
        /**
         * @stability stable
         */
        get bucketName(): string;
        /**
         * @stability stable
         */
        set bucketName(value: string);
        /**
         * @stability stable
         */
        get bucketNameInput(): string | undefined;
        private _bucketPrefix?;
        /**
         * @stability stable
         */
        get bucketPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set bucketPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketPrefix(): void;
        /**
         * @stability stable
         */
        get bucketPrefixInput(): string | undefined;
        private _ingestionRole?;
        /**
         * @stability stable
         */
        get ingestionRole(): string;
        /**
         * @stability stable
         */
        set ingestionRole(value: string);
        /**
         * @stability stable
         */
        get ingestionRoleInput(): string | undefined;
        private _sourceEngine?;
        /**
         * @stability stable
         */
        get sourceEngine(): string;
        /**
         * @stability stable
         */
        set sourceEngine(value: string);
        /**
         * @stability stable
         */
        get sourceEngineInput(): string | undefined;
        private _sourceEngineVersion?;
        /**
         * @stability stable
         */
        get sourceEngineVersion(): string;
        /**
         * @stability stable
         */
        set sourceEngineVersion(value: string);
        /**
         * @stability stable
         */
        get sourceEngineVersionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface DbInstanceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#create DbInstance#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#delete DbInstance#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html#update DbInstance#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DbInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html aws_db_instance}.
     *
     * @stability stable
     */
    class DbInstance extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_instance.html aws_db_instance} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbInstanceConfig);
        /**
         * @stability stable
         */
        get address(): string;
        private _allocatedStorage?;
        /**
         * @stability stable
         */
        get allocatedStorage(): number | undefined;
        /**
         * @stability stable
         */
        set allocatedStorage(value: number | undefined);
        /**
         * @stability stable
         */
        resetAllocatedStorage(): void;
        /**
         * @stability stable
         */
        get allocatedStorageInput(): number | undefined;
        private _allowMajorVersionUpgrade?;
        /**
         * @stability stable
         */
        get allowMajorVersionUpgrade(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowMajorVersionUpgrade(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowMajorVersionUpgrade(): void;
        /**
         * @stability stable
         */
        get allowMajorVersionUpgradeInput(): boolean | cdktf.IResolvable | undefined;
        private _applyImmediately?;
        /**
         * @stability stable
         */
        get applyImmediately(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set applyImmediately(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetApplyImmediately(): void;
        /**
         * @stability stable
         */
        get applyImmediatelyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoMinorVersionUpgrade?;
        /**
         * @stability stable
         */
        get autoMinorVersionUpgrade(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoMinorVersionUpgrade(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoMinorVersionUpgrade(): void;
        /**
         * @stability stable
         */
        get autoMinorVersionUpgradeInput(): boolean | cdktf.IResolvable | undefined;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _backupRetentionPeriod?;
        /**
         * @stability stable
         */
        get backupRetentionPeriod(): number | undefined;
        /**
         * @stability stable
         */
        set backupRetentionPeriod(value: number | undefined);
        /**
         * @stability stable
         */
        resetBackupRetentionPeriod(): void;
        /**
         * @stability stable
         */
        get backupRetentionPeriodInput(): number | undefined;
        private _backupWindow?;
        /**
         * @stability stable
         */
        get backupWindow(): string | undefined;
        /**
         * @stability stable
         */
        set backupWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetBackupWindow(): void;
        /**
         * @stability stable
         */
        get backupWindowInput(): string | undefined;
        private _caCertIdentifier?;
        /**
         * @stability stable
         */
        get caCertIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set caCertIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetCaCertIdentifier(): void;
        /**
         * @stability stable
         */
        get caCertIdentifierInput(): string | undefined;
        private _characterSetName?;
        /**
         * @stability stable
         */
        get characterSetName(): string | undefined;
        /**
         * @stability stable
         */
        set characterSetName(value: string | undefined);
        /**
         * @stability stable
         */
        resetCharacterSetName(): void;
        /**
         * @stability stable
         */
        get characterSetNameInput(): string | undefined;
        private _copyTagsToSnapshot?;
        /**
         * @stability stable
         */
        get copyTagsToSnapshot(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set copyTagsToSnapshot(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCopyTagsToSnapshot(): void;
        /**
         * @stability stable
         */
        get copyTagsToSnapshotInput(): boolean | cdktf.IResolvable | undefined;
        private _customerOwnedIpEnabled?;
        /**
         * @stability stable
         */
        get customerOwnedIpEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set customerOwnedIpEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCustomerOwnedIpEnabled(): void;
        /**
         * @stability stable
         */
        get customerOwnedIpEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _dbSubnetGroupName?;
        /**
         * @stability stable
         */
        get dbSubnetGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set dbSubnetGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbSubnetGroupName(): void;
        /**
         * @stability stable
         */
        get dbSubnetGroupNameInput(): string | undefined;
        private _deleteAutomatedBackups?;
        /**
         * @stability stable
         */
        get deleteAutomatedBackups(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deleteAutomatedBackups(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeleteAutomatedBackups(): void;
        /**
         * @stability stable
         */
        get deleteAutomatedBackupsInput(): boolean | cdktf.IResolvable | undefined;
        private _deletionProtection?;
        /**
         * @stability stable
         */
        get deletionProtection(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deletionProtection(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeletionProtection(): void;
        /**
         * @stability stable
         */
        get deletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
        private _domain?;
        /**
         * @stability stable
         */
        get domain(): string | undefined;
        /**
         * @stability stable
         */
        set domain(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomain(): void;
        /**
         * @stability stable
         */
        get domainInput(): string | undefined;
        private _domainIamRoleName?;
        /**
         * @stability stable
         */
        get domainIamRoleName(): string | undefined;
        /**
         * @stability stable
         */
        set domainIamRoleName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainIamRoleName(): void;
        /**
         * @stability stable
         */
        get domainIamRoleNameInput(): string | undefined;
        private _enabledCloudwatchLogsExports?;
        /**
         * @stability stable
         */
        get enabledCloudwatchLogsExports(): string[] | undefined;
        /**
         * @stability stable
         */
        set enabledCloudwatchLogsExports(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEnabledCloudwatchLogsExports(): void;
        /**
         * @stability stable
         */
        get enabledCloudwatchLogsExportsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        private _engine?;
        /**
         * @stability stable
         */
        get engine(): string | undefined;
        /**
         * @stability stable
         */
        set engine(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngine(): void;
        /**
         * @stability stable
         */
        get engineInput(): string | undefined;
        private _engineVersion?;
        /**
         * @stability stable
         */
        get engineVersion(): string | undefined;
        /**
         * @stability stable
         */
        set engineVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngineVersion(): void;
        /**
         * @stability stable
         */
        get engineVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get engineVersionActual(): string;
        private _finalSnapshotIdentifier?;
        /**
         * @stability stable
         */
        get finalSnapshotIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set finalSnapshotIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetFinalSnapshotIdentifier(): void;
        /**
         * @stability stable
         */
        get finalSnapshotIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get hostedZoneId(): string;
        private _iamDatabaseAuthenticationEnabled?;
        /**
         * @stability stable
         */
        get iamDatabaseAuthenticationEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set iamDatabaseAuthenticationEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIamDatabaseAuthenticationEnabled(): void;
        /**
         * @stability stable
         */
        get iamDatabaseAuthenticationEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _identifier?;
        /**
         * @stability stable
         */
        get identifier(): string | undefined;
        /**
         * @stability stable
         */
        set identifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdentifier(): void;
        /**
         * @stability stable
         */
        get identifierInput(): string | undefined;
        private _identifierPrefix?;
        /**
         * @stability stable
         */
        get identifierPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set identifierPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdentifierPrefix(): void;
        /**
         * @stability stable
         */
        get identifierPrefixInput(): string | undefined;
        private _instanceClass?;
        /**
         * @stability stable
         */
        get instanceClass(): string;
        /**
         * @stability stable
         */
        set instanceClass(value: string);
        /**
         * @stability stable
         */
        get instanceClassInput(): string | undefined;
        private _iops?;
        /**
         * @stability stable
         */
        get iops(): number | undefined;
        /**
         * @stability stable
         */
        set iops(value: number | undefined);
        /**
         * @stability stable
         */
        resetIops(): void;
        /**
         * @stability stable
         */
        get iopsInput(): number | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get latestRestorableTime(): string;
        private _licenseModel?;
        /**
         * @stability stable
         */
        get licenseModel(): string | undefined;
        /**
         * @stability stable
         */
        set licenseModel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLicenseModel(): void;
        /**
         * @stability stable
         */
        get licenseModelInput(): string | undefined;
        private _maintenanceWindow?;
        /**
         * @stability stable
         */
        get maintenanceWindow(): string | undefined;
        /**
         * @stability stable
         */
        set maintenanceWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetMaintenanceWindow(): void;
        /**
         * @stability stable
         */
        get maintenanceWindowInput(): string | undefined;
        private _maxAllocatedStorage?;
        /**
         * @stability stable
         */
        get maxAllocatedStorage(): number | undefined;
        /**
         * @stability stable
         */
        set maxAllocatedStorage(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxAllocatedStorage(): void;
        /**
         * @stability stable
         */
        get maxAllocatedStorageInput(): number | undefined;
        private _monitoringInterval?;
        /**
         * @stability stable
         */
        get monitoringInterval(): number | undefined;
        /**
         * @stability stable
         */
        set monitoringInterval(value: number | undefined);
        /**
         * @stability stable
         */
        resetMonitoringInterval(): void;
        /**
         * @stability stable
         */
        get monitoringIntervalInput(): number | undefined;
        private _monitoringRoleArn?;
        /**
         * @stability stable
         */
        get monitoringRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set monitoringRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetMonitoringRoleArn(): void;
        /**
         * @stability stable
         */
        get monitoringRoleArnInput(): string | undefined;
        private _multiAz?;
        /**
         * @stability stable
         */
        get multiAz(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set multiAz(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMultiAz(): void;
        /**
         * @stability stable
         */
        get multiAzInput(): boolean | cdktf.IResolvable | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _ncharCharacterSetName?;
        /**
         * @stability stable
         */
        get ncharCharacterSetName(): string | undefined;
        /**
         * @stability stable
         */
        set ncharCharacterSetName(value: string | undefined);
        /**
         * @stability stable
         */
        resetNcharCharacterSetName(): void;
        /**
         * @stability stable
         */
        get ncharCharacterSetNameInput(): string | undefined;
        private _optionGroupName?;
        /**
         * @stability stable
         */
        get optionGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set optionGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetOptionGroupName(): void;
        /**
         * @stability stable
         */
        get optionGroupNameInput(): string | undefined;
        private _parameterGroupName?;
        /**
         * @stability stable
         */
        get parameterGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set parameterGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetParameterGroupName(): void;
        /**
         * @stability stable
         */
        get parameterGroupNameInput(): string | undefined;
        private _password?;
        /**
         * @stability stable
         */
        get password(): string | undefined;
        /**
         * @stability stable
         */
        set password(value: string | undefined);
        /**
         * @stability stable
         */
        resetPassword(): void;
        /**
         * @stability stable
         */
        get passwordInput(): string | undefined;
        private _performanceInsightsEnabled?;
        /**
         * @stability stable
         */
        get performanceInsightsEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set performanceInsightsEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPerformanceInsightsEnabled(): void;
        /**
         * @stability stable
         */
        get performanceInsightsEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _performanceInsightsKmsKeyId?;
        /**
         * @stability stable
         */
        get performanceInsightsKmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set performanceInsightsKmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPerformanceInsightsKmsKeyId(): void;
        /**
         * @stability stable
         */
        get performanceInsightsKmsKeyIdInput(): string | undefined;
        private _performanceInsightsRetentionPeriod?;
        /**
         * @stability stable
         */
        get performanceInsightsRetentionPeriod(): number | undefined;
        /**
         * @stability stable
         */
        set performanceInsightsRetentionPeriod(value: number | undefined);
        /**
         * @stability stable
         */
        resetPerformanceInsightsRetentionPeriod(): void;
        /**
         * @stability stable
         */
        get performanceInsightsRetentionPeriodInput(): number | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _publiclyAccessible?;
        /**
         * @stability stable
         */
        get publiclyAccessible(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set publiclyAccessible(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPubliclyAccessible(): void;
        /**
         * @stability stable
         */
        get publiclyAccessibleInput(): boolean | cdktf.IResolvable | undefined;
        private _replicaMode?;
        /**
         * @stability stable
         */
        get replicaMode(): string | undefined;
        /**
         * @stability stable
         */
        set replicaMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetReplicaMode(): void;
        /**
         * @stability stable
         */
        get replicaModeInput(): string | undefined;
        /**
         * @stability stable
         */
        get replicas(): string[];
        private _replicateSourceDb?;
        /**
         * @stability stable
         */
        get replicateSourceDb(): string | undefined;
        /**
         * @stability stable
         */
        set replicateSourceDb(value: string | undefined);
        /**
         * @stability stable
         */
        resetReplicateSourceDb(): void;
        /**
         * @stability stable
         */
        get replicateSourceDbInput(): string | undefined;
        /**
         * @stability stable
         */
        get resourceId(): string;
        private _securityGroupNames?;
        /**
         * @stability stable
         */
        get securityGroupNames(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupNames(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupNames(): void;
        /**
         * @stability stable
         */
        get securityGroupNamesInput(): string[] | undefined;
        private _skipFinalSnapshot?;
        /**
         * @stability stable
         */
        get skipFinalSnapshot(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set skipFinalSnapshot(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSkipFinalSnapshot(): void;
        /**
         * @stability stable
         */
        get skipFinalSnapshotInput(): boolean | cdktf.IResolvable | undefined;
        private _snapshotIdentifier?;
        /**
         * @stability stable
         */
        get snapshotIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set snapshotIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetSnapshotIdentifier(): void;
        /**
         * @stability stable
         */
        get snapshotIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        private _storageEncrypted?;
        /**
         * @stability stable
         */
        get storageEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set storageEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetStorageEncrypted(): void;
        /**
         * @stability stable
         */
        get storageEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _storageType?;
        /**
         * @stability stable
         */
        get storageType(): string | undefined;
        /**
         * @stability stable
         */
        set storageType(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageType(): void;
        /**
         * @stability stable
         */
        get storageTypeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _timezone?;
        /**
         * @stability stable
         */
        get timezone(): string | undefined;
        /**
         * @stability stable
         */
        set timezone(value: string | undefined);
        /**
         * @stability stable
         */
        resetTimezone(): void;
        /**
         * @stability stable
         */
        get timezoneInput(): string | undefined;
        private _username?;
        /**
         * @stability stable
         */
        get username(): string | undefined;
        /**
         * @stability stable
         */
        set username(value: string | undefined);
        /**
         * @stability stable
         */
        resetUsername(): void;
        /**
         * @stability stable
         */
        get usernameInput(): string | undefined;
        private _vpcSecurityGroupIds?;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcSecurityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIdsInput(): string[] | undefined;
        private _restoreToPointInTime?;
        private __restoreToPointInTimeOutput;
        /**
         * @stability stable
         */
        get restoreToPointInTime(): DbInstanceRestoreToPointInTimeOutputReference;
        /**
         * @stability stable
         */
        putRestoreToPointInTime(value: DbInstanceRestoreToPointInTime | undefined): void;
        /**
         * @stability stable
         */
        resetRestoreToPointInTime(): void;
        /**
         * @stability stable
         */
        get restoreToPointInTimeInput(): DbInstanceRestoreToPointInTime | undefined;
        private _s3Import?;
        private __s3ImportOutput;
        /**
         * @stability stable
         */
        get s3Import(): DbInstanceS3ImportOutputReference;
        /**
         * @stability stable
         */
        putS3Import(value: DbInstanceS3Import | undefined): void;
        /**
         * @stability stable
         */
        resetS3Import(): void;
        /**
         * @stability stable
         */
        get s3ImportInput(): DbInstanceS3Import | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbInstanceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbInstanceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbInstanceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbInstanceRoleAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance_role_association.html#db_instance_identifier DbInstanceRoleAssociation#db_instance_identifier}.
         *
         * @stability stable
         */
        readonly dbInstanceIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance_role_association.html#feature_name DbInstanceRoleAssociation#feature_name}.
         *
         * @stability stable
         */
        readonly featureName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_instance_role_association.html#role_arn DbInstanceRoleAssociation#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_instance_role_association.html aws_db_instance_role_association}.
     *
     * @stability stable
     */
    class DbInstanceRoleAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_instance_role_association.html aws_db_instance_role_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbInstanceRoleAssociationConfig);
        private _dbInstanceIdentifier?;
        /**
         * @stability stable
         */
        get dbInstanceIdentifier(): string;
        /**
         * @stability stable
         */
        set dbInstanceIdentifier(value: string);
        /**
         * @stability stable
         */
        get dbInstanceIdentifierInput(): string | undefined;
        private _featureName?;
        /**
         * @stability stable
         */
        get featureName(): string;
        /**
         * @stability stable
         */
        set featureName(value: string);
        /**
         * @stability stable
         */
        get featureNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbOptionGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#engine_name DbOptionGroup#engine_name}.
         *
         * @stability stable
         */
        readonly engineName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#major_engine_version DbOptionGroup#major_engine_version}.
         *
         * @stability stable
         */
        readonly majorEngineVersion: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#name DbOptionGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#name_prefix DbOptionGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#option_group_description DbOptionGroup#option_group_description}.
         *
         * @stability stable
         */
        readonly optionGroupDescription?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#tags DbOptionGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#tags_all DbOptionGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * option block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#option DbOptionGroup#option}
         *
         * @stability stable
         */
        readonly option?: DbOptionGroupOption[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#timeouts DbOptionGroup#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbOptionGroupTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbOptionGroupOptionOptionSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#name DbOptionGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#value DbOptionGroup#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * @stability stable
     */
    interface DbOptionGroupOption {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#db_security_group_memberships DbOptionGroup#db_security_group_memberships}.
         *
         * @stability stable
         */
        readonly dbSecurityGroupMemberships?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#option_name DbOptionGroup#option_name}.
         *
         * @stability stable
         */
        readonly optionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#port DbOptionGroup#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#version DbOptionGroup#version}.
         *
         * @stability stable
         */
        readonly version?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#vpc_security_group_memberships DbOptionGroup#vpc_security_group_memberships}.
         *
         * @stability stable
         */
        readonly vpcSecurityGroupMemberships?: string[];
        /**
         * option_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#option_settings DbOptionGroup#option_settings}
         *
         * @stability stable
         */
        readonly optionSettings?: DbOptionGroupOptionOptionSettings[];
    }
    /**
     * @stability stable
     */
    interface DbOptionGroupTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html#delete DbOptionGroup#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DbOptionGroupTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html aws_db_option_group}.
     *
     * @stability stable
     */
    class DbOptionGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_option_group.html aws_db_option_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbOptionGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _engineName?;
        /**
         * @stability stable
         */
        get engineName(): string;
        /**
         * @stability stable
         */
        set engineName(value: string);
        /**
         * @stability stable
         */
        get engineNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _majorEngineVersion?;
        /**
         * @stability stable
         */
        get majorEngineVersion(): string;
        /**
         * @stability stable
         */
        set majorEngineVersion(value: string);
        /**
         * @stability stable
         */
        get majorEngineVersionInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _optionGroupDescription?;
        /**
         * @stability stable
         */
        get optionGroupDescription(): string | undefined;
        /**
         * @stability stable
         */
        set optionGroupDescription(value: string | undefined);
        /**
         * @stability stable
         */
        resetOptionGroupDescription(): void;
        /**
         * @stability stable
         */
        get optionGroupDescriptionInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _option?;
        /**
         * @stability stable
         */
        get option(): DbOptionGroupOption[] | undefined;
        /**
         * @stability stable
         */
        set option(value: DbOptionGroupOption[] | undefined);
        /**
         * @stability stable
         */
        resetOption(): void;
        /**
         * @stability stable
         */
        get optionInput(): DbOptionGroupOption[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbOptionGroupTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbOptionGroupTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbOptionGroupTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbParameterGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#description DbParameterGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#family DbParameterGroup#family}.
         *
         * @stability stable
         */
        readonly family: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#name DbParameterGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#name_prefix DbParameterGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#tags DbParameterGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#tags_all DbParameterGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * parameter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#parameter DbParameterGroup#parameter}
         *
         * @stability stable
         */
        readonly parameter?: DbParameterGroupParameter[];
    }
    /**
     * @stability stable
     */
    interface DbParameterGroupParameter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#apply_method DbParameterGroup#apply_method}.
         *
         * @stability stable
         */
        readonly applyMethod?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#name DbParameterGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html#value DbParameterGroup#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html aws_db_parameter_group}.
     *
     * @stability stable
     */
    class DbParameterGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_parameter_group.html aws_db_parameter_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbParameterGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _family?;
        /**
         * @stability stable
         */
        get family(): string;
        /**
         * @stability stable
         */
        set family(value: string);
        /**
         * @stability stable
         */
        get familyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _parameter?;
        /**
         * @stability stable
         */
        get parameter(): DbParameterGroupParameter[] | undefined;
        /**
         * @stability stable
         */
        set parameter(value: DbParameterGroupParameter[] | undefined);
        /**
         * @stability stable
         */
        resetParameter(): void;
        /**
         * @stability stable
         */
        get parameterInput(): DbParameterGroupParameter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbProxyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#debug_logging DbProxy#debug_logging}.
         *
         * @stability stable
         */
        readonly debugLogging?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#engine_family DbProxy#engine_family}.
         *
         * @stability stable
         */
        readonly engineFamily: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#idle_client_timeout DbProxy#idle_client_timeout}.
         *
         * @stability stable
         */
        readonly idleClientTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#name DbProxy#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#require_tls DbProxy#require_tls}.
         *
         * @stability stable
         */
        readonly requireTls?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#role_arn DbProxy#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#tags DbProxy#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#tags_all DbProxy#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#vpc_security_group_ids DbProxy#vpc_security_group_ids}.
         *
         * @stability stable
         */
        readonly vpcSecurityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#vpc_subnet_ids DbProxy#vpc_subnet_ids}.
         *
         * @stability stable
         */
        readonly vpcSubnetIds: string[];
        /**
         * auth block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#auth DbProxy#auth}
         *
         * @stability stable
         */
        readonly auth: DbProxyAuth[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#timeouts DbProxy#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbProxyTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbProxyAuth {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#auth_scheme DbProxy#auth_scheme}.
         *
         * @stability stable
         */
        readonly authScheme?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#description DbProxy#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#iam_auth DbProxy#iam_auth}.
         *
         * @stability stable
         */
        readonly iamAuth?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#secret_arn DbProxy#secret_arn}.
         *
         * @stability stable
         */
        readonly secretArn?: string;
    }
    /**
     * @stability stable
     */
    interface DbProxyTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#create DbProxy#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#delete DbProxy#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html#update DbProxy#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DbProxyTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html aws_db_proxy}.
     *
     * @stability stable
     */
    class DbProxy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_proxy.html aws_db_proxy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbProxyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _debugLogging?;
        /**
         * @stability stable
         */
        get debugLogging(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set debugLogging(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDebugLogging(): void;
        /**
         * @stability stable
         */
        get debugLoggingInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        private _engineFamily?;
        /**
         * @stability stable
         */
        get engineFamily(): string;
        /**
         * @stability stable
         */
        set engineFamily(value: string);
        /**
         * @stability stable
         */
        get engineFamilyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _idleClientTimeout?;
        /**
         * @stability stable
         */
        get idleClientTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set idleClientTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetIdleClientTimeout(): void;
        /**
         * @stability stable
         */
        get idleClientTimeoutInput(): number | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _requireTls?;
        /**
         * @stability stable
         */
        get requireTls(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set requireTls(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRequireTls(): void;
        /**
         * @stability stable
         */
        get requireTlsInput(): boolean | cdktf.IResolvable | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcSecurityGroupIds?;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcSecurityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIdsInput(): string[] | undefined;
        private _vpcSubnetIds?;
        /**
         * @stability stable
         */
        get vpcSubnetIds(): string[];
        /**
         * @stability stable
         */
        set vpcSubnetIds(value: string[]);
        /**
         * @stability stable
         */
        get vpcSubnetIdsInput(): string[] | undefined;
        private _auth?;
        /**
         * @stability stable
         */
        get auth(): DbProxyAuth[];
        /**
         * @stability stable
         */
        set auth(value: DbProxyAuth[]);
        /**
         * @stability stable
         */
        get authInput(): DbProxyAuth[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbProxyTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbProxyTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbProxyTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbProxyDefaultTargetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#db_proxy_name DbProxyDefaultTargetGroup#db_proxy_name}.
         *
         * @stability stable
         */
        readonly dbProxyName: string;
        /**
         * connection_pool_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#connection_pool_config DbProxyDefaultTargetGroup#connection_pool_config}
         *
         * @stability stable
         */
        readonly connectionPoolConfig?: DbProxyDefaultTargetGroupConnectionPoolConfig;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#timeouts DbProxyDefaultTargetGroup#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbProxyDefaultTargetGroupTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbProxyDefaultTargetGroupConnectionPoolConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#connection_borrow_timeout DbProxyDefaultTargetGroup#connection_borrow_timeout}.
         *
         * @stability stable
         */
        readonly connectionBorrowTimeout?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#init_query DbProxyDefaultTargetGroup#init_query}.
         *
         * @stability stable
         */
        readonly initQuery?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#max_connections_percent DbProxyDefaultTargetGroup#max_connections_percent}.
         *
         * @stability stable
         */
        readonly maxConnectionsPercent?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#max_idle_connections_percent DbProxyDefaultTargetGroup#max_idle_connections_percent}.
         *
         * @stability stable
         */
        readonly maxIdleConnectionsPercent?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#session_pinning_filters DbProxyDefaultTargetGroup#session_pinning_filters}.
         *
         * @stability stable
         */
        readonly sessionPinningFilters?: string[];
    }
    /**
     * @stability stable
     */
    class DbProxyDefaultTargetGroupConnectionPoolConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _connectionBorrowTimeout?;
        /**
         * @stability stable
         */
        get connectionBorrowTimeout(): number | undefined;
        /**
         * @stability stable
         */
        set connectionBorrowTimeout(value: number | undefined);
        /**
         * @stability stable
         */
        resetConnectionBorrowTimeout(): void;
        /**
         * @stability stable
         */
        get connectionBorrowTimeoutInput(): number | undefined;
        private _initQuery?;
        /**
         * @stability stable
         */
        get initQuery(): string | undefined;
        /**
         * @stability stable
         */
        set initQuery(value: string | undefined);
        /**
         * @stability stable
         */
        resetInitQuery(): void;
        /**
         * @stability stable
         */
        get initQueryInput(): string | undefined;
        private _maxConnectionsPercent?;
        /**
         * @stability stable
         */
        get maxConnectionsPercent(): number | undefined;
        /**
         * @stability stable
         */
        set maxConnectionsPercent(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxConnectionsPercent(): void;
        /**
         * @stability stable
         */
        get maxConnectionsPercentInput(): number | undefined;
        private _maxIdleConnectionsPercent?;
        /**
         * @stability stable
         */
        get maxIdleConnectionsPercent(): number | undefined;
        /**
         * @stability stable
         */
        set maxIdleConnectionsPercent(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxIdleConnectionsPercent(): void;
        /**
         * @stability stable
         */
        get maxIdleConnectionsPercentInput(): number | undefined;
        private _sessionPinningFilters?;
        /**
         * @stability stable
         */
        get sessionPinningFilters(): string[] | undefined;
        /**
         * @stability stable
         */
        set sessionPinningFilters(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSessionPinningFilters(): void;
        /**
         * @stability stable
         */
        get sessionPinningFiltersInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface DbProxyDefaultTargetGroupTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#create DbProxyDefaultTargetGroup#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html#update DbProxyDefaultTargetGroup#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DbProxyDefaultTargetGroupTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html aws_db_proxy_default_target_group}.
     *
     * @stability stable
     */
    class DbProxyDefaultTargetGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_default_target_group.html aws_db_proxy_default_target_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbProxyDefaultTargetGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _dbProxyName?;
        /**
         * @stability stable
         */
        get dbProxyName(): string;
        /**
         * @stability stable
         */
        set dbProxyName(value: string);
        /**
         * @stability stable
         */
        get dbProxyNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get name(): string;
        private _connectionPoolConfig?;
        private __connectionPoolConfigOutput;
        /**
         * @stability stable
         */
        get connectionPoolConfig(): DbProxyDefaultTargetGroupConnectionPoolConfigOutputReference;
        /**
         * @stability stable
         */
        putConnectionPoolConfig(value: DbProxyDefaultTargetGroupConnectionPoolConfig | undefined): void;
        /**
         * @stability stable
         */
        resetConnectionPoolConfig(): void;
        /**
         * @stability stable
         */
        get connectionPoolConfigInput(): DbProxyDefaultTargetGroupConnectionPoolConfig | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbProxyDefaultTargetGroupTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbProxyDefaultTargetGroupTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbProxyDefaultTargetGroupTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbProxyEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#db_proxy_endpoint_name DbProxyEndpoint#db_proxy_endpoint_name}.
         *
         * @stability stable
         */
        readonly dbProxyEndpointName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#db_proxy_name DbProxyEndpoint#db_proxy_name}.
         *
         * @stability stable
         */
        readonly dbProxyName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#tags DbProxyEndpoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#tags_all DbProxyEndpoint#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#target_role DbProxyEndpoint#target_role}.
         *
         * @stability stable
         */
        readonly targetRole?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#vpc_security_group_ids DbProxyEndpoint#vpc_security_group_ids}.
         *
         * @stability stable
         */
        readonly vpcSecurityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#vpc_subnet_ids DbProxyEndpoint#vpc_subnet_ids}.
         *
         * @stability stable
         */
        readonly vpcSubnetIds: string[];
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#timeouts DbProxyEndpoint#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbProxyEndpointTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbProxyEndpointTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#create DbProxyEndpoint#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#delete DbProxyEndpoint#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html#update DbProxyEndpoint#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DbProxyEndpointTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html aws_db_proxy_endpoint}.
     *
     * @stability stable
     */
    class DbProxyEndpoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_endpoint.html aws_db_proxy_endpoint} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbProxyEndpointConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _dbProxyEndpointName?;
        /**
         * @stability stable
         */
        get dbProxyEndpointName(): string;
        /**
         * @stability stable
         */
        set dbProxyEndpointName(value: string);
        /**
         * @stability stable
         */
        get dbProxyEndpointNameInput(): string | undefined;
        private _dbProxyName?;
        /**
         * @stability stable
         */
        get dbProxyName(): string;
        /**
         * @stability stable
         */
        set dbProxyName(value: string);
        /**
         * @stability stable
         */
        get dbProxyNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get isDefault(): any;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _targetRole?;
        /**
         * @stability stable
         */
        get targetRole(): string | undefined;
        /**
         * @stability stable
         */
        set targetRole(value: string | undefined);
        /**
         * @stability stable
         */
        resetTargetRole(): void;
        /**
         * @stability stable
         */
        get targetRoleInput(): string | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _vpcSecurityGroupIds?;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcSecurityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIdsInput(): string[] | undefined;
        private _vpcSubnetIds?;
        /**
         * @stability stable
         */
        get vpcSubnetIds(): string[];
        /**
         * @stability stable
         */
        set vpcSubnetIds(value: string[]);
        /**
         * @stability stable
         */
        get vpcSubnetIdsInput(): string[] | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbProxyEndpointTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbProxyEndpointTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbProxyEndpointTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbProxyTargetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_target.html#db_cluster_identifier DbProxyTarget#db_cluster_identifier}.
         *
         * @stability stable
         */
        readonly dbClusterIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_target.html#db_instance_identifier DbProxyTarget#db_instance_identifier}.
         *
         * @stability stable
         */
        readonly dbInstanceIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_target.html#db_proxy_name DbProxyTarget#db_proxy_name}.
         *
         * @stability stable
         */
        readonly dbProxyName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_target.html#target_group_name DbProxyTarget#target_group_name}.
         *
         * @stability stable
         */
        readonly targetGroupName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_target.html aws_db_proxy_target}.
     *
     * @stability stable
     */
    class DbProxyTarget extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_proxy_target.html aws_db_proxy_target} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbProxyTargetConfig);
        private _dbClusterIdentifier?;
        /**
         * @stability stable
         */
        get dbClusterIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set dbClusterIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbClusterIdentifier(): void;
        /**
         * @stability stable
         */
        get dbClusterIdentifierInput(): string | undefined;
        private _dbInstanceIdentifier?;
        /**
         * @stability stable
         */
        get dbInstanceIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set dbInstanceIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbInstanceIdentifier(): void;
        /**
         * @stability stable
         */
        get dbInstanceIdentifierInput(): string | undefined;
        private _dbProxyName?;
        /**
         * @stability stable
         */
        get dbProxyName(): string;
        /**
         * @stability stable
         */
        set dbProxyName(value: string);
        /**
         * @stability stable
         */
        get dbProxyNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get rdsResourceId(): string;
        /**
         * @stability stable
         */
        get targetArn(): string;
        private _targetGroupName?;
        /**
         * @stability stable
         */
        get targetGroupName(): string;
        /**
         * @stability stable
         */
        set targetGroupName(value: string);
        /**
         * @stability stable
         */
        get targetGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get trackedClusterId(): string;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbSecurityGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#description DbSecurityGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#name DbSecurityGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#tags DbSecurityGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#tags_all DbSecurityGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * ingress block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#ingress DbSecurityGroup#ingress}
         *
         * @stability stable
         */
        readonly ingress: DbSecurityGroupIngress[];
    }
    /**
     * @stability stable
     */
    interface DbSecurityGroupIngress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#cidr DbSecurityGroup#cidr}.
         *
         * @stability stable
         */
        readonly cidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#security_group_id DbSecurityGroup#security_group_id}.
         *
         * @stability stable
         */
        readonly securityGroupId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#security_group_name DbSecurityGroup#security_group_name}.
         *
         * @stability stable
         */
        readonly securityGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html#security_group_owner_id DbSecurityGroup#security_group_owner_id}.
         *
         * @stability stable
         */
        readonly securityGroupOwnerId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html aws_db_security_group}.
     *
     * @stability stable
     */
    class DbSecurityGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_security_group.html aws_db_security_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbSecurityGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _ingress?;
        /**
         * @stability stable
         */
        get ingress(): DbSecurityGroupIngress[];
        /**
         * @stability stable
         */
        set ingress(value: DbSecurityGroupIngress[]);
        /**
         * @stability stable
         */
        get ingressInput(): DbSecurityGroupIngress[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbSnapshotConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#db_instance_identifier DbSnapshot#db_instance_identifier}.
         *
         * @stability stable
         */
        readonly dbInstanceIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#db_snapshot_identifier DbSnapshot#db_snapshot_identifier}.
         *
         * @stability stable
         */
        readonly dbSnapshotIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#tags DbSnapshot#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#tags_all DbSnapshot#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#timeouts DbSnapshot#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DbSnapshotTimeouts;
    }
    /**
     * @stability stable
     */
    interface DbSnapshotTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html#read DbSnapshot#read}.
         *
         * @stability stable
         */
        readonly read?: string;
    }
    /**
     * @stability stable
     */
    class DbSnapshotTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _read?;
        /**
         * @stability stable
         */
        get read(): string | undefined;
        /**
         * @stability stable
         */
        set read(value: string | undefined);
        /**
         * @stability stable
         */
        resetRead(): void;
        /**
         * @stability stable
         */
        get readInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html aws_db_snapshot}.
     *
     * @stability stable
     */
    class DbSnapshot extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_snapshot.html aws_db_snapshot} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbSnapshotConfig);
        /**
         * @stability stable
         */
        get allocatedStorage(): number;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        private _dbInstanceIdentifier?;
        /**
         * @stability stable
         */
        get dbInstanceIdentifier(): string;
        /**
         * @stability stable
         */
        set dbInstanceIdentifier(value: string);
        /**
         * @stability stable
         */
        get dbInstanceIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get dbSnapshotArn(): string;
        private _dbSnapshotIdentifier?;
        /**
         * @stability stable
         */
        get dbSnapshotIdentifier(): string;
        /**
         * @stability stable
         */
        set dbSnapshotIdentifier(value: string);
        /**
         * @stability stable
         */
        get dbSnapshotIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get encrypted(): any;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        get engineVersion(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get iops(): number;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        get licenseModel(): string;
        /**
         * @stability stable
         */
        get optionGroupName(): string;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get snapshotType(): string;
        /**
         * @stability stable
         */
        get sourceDbSnapshotIdentifier(): string;
        /**
         * @stability stable
         */
        get sourceRegion(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get storageType(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DbSnapshotTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DbSnapshotTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DbSnapshotTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DbSubnetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html#description DbSubnetGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html#name DbSubnetGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html#name_prefix DbSubnetGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html#subnet_ids DbSubnetGroup#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html#tags DbSubnetGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html#tags_all DbSubnetGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html aws_db_subnet_group}.
     *
     * @stability stable
     */
    class DbSubnetGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/db_subnet_group.html aws_db_subnet_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DbSubnetGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RdsClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#allow_major_version_upgrade RdsCluster#allow_major_version_upgrade}.
         *
         * @stability stable
         */
        readonly allowMajorVersionUpgrade?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#apply_immediately RdsCluster#apply_immediately}.
         *
         * @stability stable
         */
        readonly applyImmediately?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#availability_zones RdsCluster#availability_zones}.
         *
         * @stability stable
         */
        readonly availabilityZones?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#backtrack_window RdsCluster#backtrack_window}.
         *
         * @stability stable
         */
        readonly backtrackWindow?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#backup_retention_period RdsCluster#backup_retention_period}.
         *
         * @stability stable
         */
        readonly backupRetentionPeriod?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#cluster_identifier RdsCluster#cluster_identifier}.
         *
         * @stability stable
         */
        readonly clusterIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#cluster_identifier_prefix RdsCluster#cluster_identifier_prefix}.
         *
         * @stability stable
         */
        readonly clusterIdentifierPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#cluster_members RdsCluster#cluster_members}.
         *
         * @stability stable
         */
        readonly clusterMembers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#copy_tags_to_snapshot RdsCluster#copy_tags_to_snapshot}.
         *
         * @stability stable
         */
        readonly copyTagsToSnapshot?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#database_name RdsCluster#database_name}.
         *
         * @stability stable
         */
        readonly databaseName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#db_cluster_parameter_group_name RdsCluster#db_cluster_parameter_group_name}.
         *
         * @stability stable
         */
        readonly dbClusterParameterGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#db_instance_parameter_group_name RdsCluster#db_instance_parameter_group_name}.
         *
         * @stability stable
         */
        readonly dbInstanceParameterGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#db_subnet_group_name RdsCluster#db_subnet_group_name}.
         *
         * @stability stable
         */
        readonly dbSubnetGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#deletion_protection RdsCluster#deletion_protection}.
         *
         * @stability stable
         */
        readonly deletionProtection?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#enable_global_write_forwarding RdsCluster#enable_global_write_forwarding}.
         *
         * @stability stable
         */
        readonly enableGlobalWriteForwarding?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#enable_http_endpoint RdsCluster#enable_http_endpoint}.
         *
         * @stability stable
         */
        readonly enableHttpEndpoint?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#enabled_cloudwatch_logs_exports RdsCluster#enabled_cloudwatch_logs_exports}.
         *
         * @stability stable
         */
        readonly enabledCloudwatchLogsExports?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#engine RdsCluster#engine}.
         *
         * @stability stable
         */
        readonly engine?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#engine_mode RdsCluster#engine_mode}.
         *
         * @stability stable
         */
        readonly engineMode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#engine_version RdsCluster#engine_version}.
         *
         * @stability stable
         */
        readonly engineVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#final_snapshot_identifier RdsCluster#final_snapshot_identifier}.
         *
         * @stability stable
         */
        readonly finalSnapshotIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#global_cluster_identifier RdsCluster#global_cluster_identifier}.
         *
         * @stability stable
         */
        readonly globalClusterIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#iam_database_authentication_enabled RdsCluster#iam_database_authentication_enabled}.
         *
         * @stability stable
         */
        readonly iamDatabaseAuthenticationEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#iam_roles RdsCluster#iam_roles}.
         *
         * @stability stable
         */
        readonly iamRoles?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#kms_key_id RdsCluster#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#master_password RdsCluster#master_password}.
         *
         * @stability stable
         */
        readonly masterPassword?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#master_username RdsCluster#master_username}.
         *
         * @stability stable
         */
        readonly masterUsername?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#port RdsCluster#port}.
         *
         * @stability stable
         */
        readonly port?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#preferred_backup_window RdsCluster#preferred_backup_window}.
         *
         * @stability stable
         */
        readonly preferredBackupWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#preferred_maintenance_window RdsCluster#preferred_maintenance_window}.
         *
         * @stability stable
         */
        readonly preferredMaintenanceWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#replication_source_identifier RdsCluster#replication_source_identifier}.
         *
         * @stability stable
         */
        readonly replicationSourceIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#skip_final_snapshot RdsCluster#skip_final_snapshot}.
         *
         * @stability stable
         */
        readonly skipFinalSnapshot?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#snapshot_identifier RdsCluster#snapshot_identifier}.
         *
         * @stability stable
         */
        readonly snapshotIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#source_region RdsCluster#source_region}.
         *
         * @stability stable
         */
        readonly sourceRegion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#storage_encrypted RdsCluster#storage_encrypted}.
         *
         * @stability stable
         */
        readonly storageEncrypted?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#tags RdsCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#tags_all RdsCluster#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#vpc_security_group_ids RdsCluster#vpc_security_group_ids}.
         *
         * @stability stable
         */
        readonly vpcSecurityGroupIds?: string[];
        /**
         * restore_to_point_in_time block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#restore_to_point_in_time RdsCluster#restore_to_point_in_time}
         *
         * @stability stable
         */
        readonly restoreToPointInTime?: RdsClusterRestoreToPointInTime;
        /**
         * s3_import block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#s3_import RdsCluster#s3_import}
         *
         * @stability stable
         */
        readonly s3Import?: RdsClusterS3Import;
        /**
         * scaling_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#scaling_configuration RdsCluster#scaling_configuration}
         *
         * @stability stable
         */
        readonly scalingConfiguration?: RdsClusterScalingConfiguration;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#timeouts RdsCluster#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: RdsClusterTimeouts;
    }
    /**
     * @stability stable
     */
    interface RdsClusterRestoreToPointInTime {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#restore_to_time RdsCluster#restore_to_time}.
         *
         * @stability stable
         */
        readonly restoreToTime?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#restore_type RdsCluster#restore_type}.
         *
         * @stability stable
         */
        readonly restoreType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#source_cluster_identifier RdsCluster#source_cluster_identifier}.
         *
         * @stability stable
         */
        readonly sourceClusterIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#use_latest_restorable_time RdsCluster#use_latest_restorable_time}.
         *
         * @stability stable
         */
        readonly useLatestRestorableTime?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class RdsClusterRestoreToPointInTimeOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _restoreToTime?;
        /**
         * @stability stable
         */
        get restoreToTime(): string | undefined;
        /**
         * @stability stable
         */
        set restoreToTime(value: string | undefined);
        /**
         * @stability stable
         */
        resetRestoreToTime(): void;
        /**
         * @stability stable
         */
        get restoreToTimeInput(): string | undefined;
        private _restoreType?;
        /**
         * @stability stable
         */
        get restoreType(): string | undefined;
        /**
         * @stability stable
         */
        set restoreType(value: string | undefined);
        /**
         * @stability stable
         */
        resetRestoreType(): void;
        /**
         * @stability stable
         */
        get restoreTypeInput(): string | undefined;
        private _sourceClusterIdentifier?;
        /**
         * @stability stable
         */
        get sourceClusterIdentifier(): string;
        /**
         * @stability stable
         */
        set sourceClusterIdentifier(value: string);
        /**
         * @stability stable
         */
        get sourceClusterIdentifierInput(): string | undefined;
        private _useLatestRestorableTime?;
        /**
         * @stability stable
         */
        get useLatestRestorableTime(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set useLatestRestorableTime(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetUseLatestRestorableTime(): void;
        /**
         * @stability stable
         */
        get useLatestRestorableTimeInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface RdsClusterS3Import {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#bucket_name RdsCluster#bucket_name}.
         *
         * @stability stable
         */
        readonly bucketName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#bucket_prefix RdsCluster#bucket_prefix}.
         *
         * @stability stable
         */
        readonly bucketPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#ingestion_role RdsCluster#ingestion_role}.
         *
         * @stability stable
         */
        readonly ingestionRole: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#source_engine RdsCluster#source_engine}.
         *
         * @stability stable
         */
        readonly sourceEngine: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#source_engine_version RdsCluster#source_engine_version}.
         *
         * @stability stable
         */
        readonly sourceEngineVersion: string;
    }
    /**
     * @stability stable
     */
    class RdsClusterS3ImportOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _bucketName?;
        /**
         * @stability stable
         */
        get bucketName(): string;
        /**
         * @stability stable
         */
        set bucketName(value: string);
        /**
         * @stability stable
         */
        get bucketNameInput(): string | undefined;
        private _bucketPrefix?;
        /**
         * @stability stable
         */
        get bucketPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set bucketPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetBucketPrefix(): void;
        /**
         * @stability stable
         */
        get bucketPrefixInput(): string | undefined;
        private _ingestionRole?;
        /**
         * @stability stable
         */
        get ingestionRole(): string;
        /**
         * @stability stable
         */
        set ingestionRole(value: string);
        /**
         * @stability stable
         */
        get ingestionRoleInput(): string | undefined;
        private _sourceEngine?;
        /**
         * @stability stable
         */
        get sourceEngine(): string;
        /**
         * @stability stable
         */
        set sourceEngine(value: string);
        /**
         * @stability stable
         */
        get sourceEngineInput(): string | undefined;
        private _sourceEngineVersion?;
        /**
         * @stability stable
         */
        get sourceEngineVersion(): string;
        /**
         * @stability stable
         */
        set sourceEngineVersion(value: string);
        /**
         * @stability stable
         */
        get sourceEngineVersionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface RdsClusterScalingConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#auto_pause RdsCluster#auto_pause}.
         *
         * @stability stable
         */
        readonly autoPause?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#max_capacity RdsCluster#max_capacity}.
         *
         * @stability stable
         */
        readonly maxCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#min_capacity RdsCluster#min_capacity}.
         *
         * @stability stable
         */
        readonly minCapacity?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#seconds_until_auto_pause RdsCluster#seconds_until_auto_pause}.
         *
         * @stability stable
         */
        readonly secondsUntilAutoPause?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#timeout_action RdsCluster#timeout_action}.
         *
         * @stability stable
         */
        readonly timeoutAction?: string;
    }
    /**
     * @stability stable
     */
    class RdsClusterScalingConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _autoPause?;
        /**
         * @stability stable
         */
        get autoPause(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoPause(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoPause(): void;
        /**
         * @stability stable
         */
        get autoPauseInput(): boolean | cdktf.IResolvable | undefined;
        private _maxCapacity?;
        /**
         * @stability stable
         */
        get maxCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set maxCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxCapacity(): void;
        /**
         * @stability stable
         */
        get maxCapacityInput(): number | undefined;
        private _minCapacity?;
        /**
         * @stability stable
         */
        get minCapacity(): number | undefined;
        /**
         * @stability stable
         */
        set minCapacity(value: number | undefined);
        /**
         * @stability stable
         */
        resetMinCapacity(): void;
        /**
         * @stability stable
         */
        get minCapacityInput(): number | undefined;
        private _secondsUntilAutoPause?;
        /**
         * @stability stable
         */
        get secondsUntilAutoPause(): number | undefined;
        /**
         * @stability stable
         */
        set secondsUntilAutoPause(value: number | undefined);
        /**
         * @stability stable
         */
        resetSecondsUntilAutoPause(): void;
        /**
         * @stability stable
         */
        get secondsUntilAutoPauseInput(): number | undefined;
        private _timeoutAction?;
        /**
         * @stability stable
         */
        get timeoutAction(): string | undefined;
        /**
         * @stability stable
         */
        set timeoutAction(value: string | undefined);
        /**
         * @stability stable
         */
        resetTimeoutAction(): void;
        /**
         * @stability stable
         */
        get timeoutActionInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface RdsClusterTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#create RdsCluster#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#delete RdsCluster#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html#update RdsCluster#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class RdsClusterTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html aws_rds_cluster}.
     *
     * @stability stable
     */
    class RdsCluster extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster.html aws_rds_cluster} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: RdsClusterConfig);
        private _allowMajorVersionUpgrade?;
        /**
         * @stability stable
         */
        get allowMajorVersionUpgrade(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowMajorVersionUpgrade(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowMajorVersionUpgrade(): void;
        /**
         * @stability stable
         */
        get allowMajorVersionUpgradeInput(): boolean | cdktf.IResolvable | undefined;
        private _applyImmediately?;
        /**
         * @stability stable
         */
        get applyImmediately(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set applyImmediately(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetApplyImmediately(): void;
        /**
         * @stability stable
         */
        get applyImmediatelyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _availabilityZones?;
        /**
         * @stability stable
         */
        get availabilityZones(): string[] | undefined;
        /**
         * @stability stable
         */
        set availabilityZones(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZones(): void;
        /**
         * @stability stable
         */
        get availabilityZonesInput(): string[] | undefined;
        private _backtrackWindow?;
        /**
         * @stability stable
         */
        get backtrackWindow(): number | undefined;
        /**
         * @stability stable
         */
        set backtrackWindow(value: number | undefined);
        /**
         * @stability stable
         */
        resetBacktrackWindow(): void;
        /**
         * @stability stable
         */
        get backtrackWindowInput(): number | undefined;
        private _backupRetentionPeriod?;
        /**
         * @stability stable
         */
        get backupRetentionPeriod(): number | undefined;
        /**
         * @stability stable
         */
        set backupRetentionPeriod(value: number | undefined);
        /**
         * @stability stable
         */
        resetBackupRetentionPeriod(): void;
        /**
         * @stability stable
         */
        get backupRetentionPeriodInput(): number | undefined;
        private _clusterIdentifier?;
        /**
         * @stability stable
         */
        get clusterIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set clusterIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetClusterIdentifier(): void;
        /**
         * @stability stable
         */
        get clusterIdentifierInput(): string | undefined;
        private _clusterIdentifierPrefix?;
        /**
         * @stability stable
         */
        get clusterIdentifierPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set clusterIdentifierPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetClusterIdentifierPrefix(): void;
        /**
         * @stability stable
         */
        get clusterIdentifierPrefixInput(): string | undefined;
        private _clusterMembers?;
        /**
         * @stability stable
         */
        get clusterMembers(): string[] | undefined;
        /**
         * @stability stable
         */
        set clusterMembers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetClusterMembers(): void;
        /**
         * @stability stable
         */
        get clusterMembersInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get clusterResourceId(): string;
        private _copyTagsToSnapshot?;
        /**
         * @stability stable
         */
        get copyTagsToSnapshot(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set copyTagsToSnapshot(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCopyTagsToSnapshot(): void;
        /**
         * @stability stable
         */
        get copyTagsToSnapshotInput(): boolean | cdktf.IResolvable | undefined;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string | undefined;
        /**
         * @stability stable
         */
        set databaseName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDatabaseName(): void;
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _dbClusterParameterGroupName?;
        /**
         * @stability stable
         */
        get dbClusterParameterGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set dbClusterParameterGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbClusterParameterGroupName(): void;
        /**
         * @stability stable
         */
        get dbClusterParameterGroupNameInput(): string | undefined;
        private _dbInstanceParameterGroupName?;
        /**
         * @stability stable
         */
        get dbInstanceParameterGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set dbInstanceParameterGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbInstanceParameterGroupName(): void;
        /**
         * @stability stable
         */
        get dbInstanceParameterGroupNameInput(): string | undefined;
        private _dbSubnetGroupName?;
        /**
         * @stability stable
         */
        get dbSubnetGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set dbSubnetGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbSubnetGroupName(): void;
        /**
         * @stability stable
         */
        get dbSubnetGroupNameInput(): string | undefined;
        private _deletionProtection?;
        /**
         * @stability stable
         */
        get deletionProtection(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deletionProtection(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeletionProtection(): void;
        /**
         * @stability stable
         */
        get deletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
        private _enableGlobalWriteForwarding?;
        /**
         * @stability stable
         */
        get enableGlobalWriteForwarding(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableGlobalWriteForwarding(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableGlobalWriteForwarding(): void;
        /**
         * @stability stable
         */
        get enableGlobalWriteForwardingInput(): boolean | cdktf.IResolvable | undefined;
        private _enableHttpEndpoint?;
        /**
         * @stability stable
         */
        get enableHttpEndpoint(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableHttpEndpoint(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableHttpEndpoint(): void;
        /**
         * @stability stable
         */
        get enableHttpEndpointInput(): boolean | cdktf.IResolvable | undefined;
        private _enabledCloudwatchLogsExports?;
        /**
         * @stability stable
         */
        get enabledCloudwatchLogsExports(): string[] | undefined;
        /**
         * @stability stable
         */
        set enabledCloudwatchLogsExports(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetEnabledCloudwatchLogsExports(): void;
        /**
         * @stability stable
         */
        get enabledCloudwatchLogsExportsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        private _engine?;
        /**
         * @stability stable
         */
        get engine(): string | undefined;
        /**
         * @stability stable
         */
        set engine(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngine(): void;
        /**
         * @stability stable
         */
        get engineInput(): string | undefined;
        private _engineMode?;
        /**
         * @stability stable
         */
        get engineMode(): string | undefined;
        /**
         * @stability stable
         */
        set engineMode(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngineMode(): void;
        /**
         * @stability stable
         */
        get engineModeInput(): string | undefined;
        private _engineVersion?;
        /**
         * @stability stable
         */
        get engineVersion(): string | undefined;
        /**
         * @stability stable
         */
        set engineVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngineVersion(): void;
        /**
         * @stability stable
         */
        get engineVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get engineVersionActual(): string;
        private _finalSnapshotIdentifier?;
        /**
         * @stability stable
         */
        get finalSnapshotIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set finalSnapshotIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetFinalSnapshotIdentifier(): void;
        /**
         * @stability stable
         */
        get finalSnapshotIdentifierInput(): string | undefined;
        private _globalClusterIdentifier?;
        /**
         * @stability stable
         */
        get globalClusterIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set globalClusterIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetGlobalClusterIdentifier(): void;
        /**
         * @stability stable
         */
        get globalClusterIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get hostedZoneId(): string;
        private _iamDatabaseAuthenticationEnabled?;
        /**
         * @stability stable
         */
        get iamDatabaseAuthenticationEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set iamDatabaseAuthenticationEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIamDatabaseAuthenticationEnabled(): void;
        /**
         * @stability stable
         */
        get iamDatabaseAuthenticationEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _iamRoles?;
        /**
         * @stability stable
         */
        get iamRoles(): string[] | undefined;
        /**
         * @stability stable
         */
        set iamRoles(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetIamRoles(): void;
        /**
         * @stability stable
         */
        get iamRolesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _masterPassword?;
        /**
         * @stability stable
         */
        get masterPassword(): string | undefined;
        /**
         * @stability stable
         */
        set masterPassword(value: string | undefined);
        /**
         * @stability stable
         */
        resetMasterPassword(): void;
        /**
         * @stability stable
         */
        get masterPasswordInput(): string | undefined;
        private _masterUsername?;
        /**
         * @stability stable
         */
        get masterUsername(): string | undefined;
        /**
         * @stability stable
         */
        set masterUsername(value: string | undefined);
        /**
         * @stability stable
         */
        resetMasterUsername(): void;
        /**
         * @stability stable
         */
        get masterUsernameInput(): string | undefined;
        private _port?;
        /**
         * @stability stable
         */
        get port(): number | undefined;
        /**
         * @stability stable
         */
        set port(value: number | undefined);
        /**
         * @stability stable
         */
        resetPort(): void;
        /**
         * @stability stable
         */
        get portInput(): number | undefined;
        private _preferredBackupWindow?;
        /**
         * @stability stable
         */
        get preferredBackupWindow(): string | undefined;
        /**
         * @stability stable
         */
        set preferredBackupWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreferredBackupWindow(): void;
        /**
         * @stability stable
         */
        get preferredBackupWindowInput(): string | undefined;
        private _preferredMaintenanceWindow?;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindow(): string | undefined;
        /**
         * @stability stable
         */
        set preferredMaintenanceWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreferredMaintenanceWindow(): void;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindowInput(): string | undefined;
        /**
         * @stability stable
         */
        get readerEndpoint(): string;
        private _replicationSourceIdentifier?;
        /**
         * @stability stable
         */
        get replicationSourceIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set replicationSourceIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetReplicationSourceIdentifier(): void;
        /**
         * @stability stable
         */
        get replicationSourceIdentifierInput(): string | undefined;
        private _skipFinalSnapshot?;
        /**
         * @stability stable
         */
        get skipFinalSnapshot(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set skipFinalSnapshot(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSkipFinalSnapshot(): void;
        /**
         * @stability stable
         */
        get skipFinalSnapshotInput(): boolean | cdktf.IResolvable | undefined;
        private _snapshotIdentifier?;
        /**
         * @stability stable
         */
        get snapshotIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set snapshotIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetSnapshotIdentifier(): void;
        /**
         * @stability stable
         */
        get snapshotIdentifierInput(): string | undefined;
        private _sourceRegion?;
        /**
         * @stability stable
         */
        get sourceRegion(): string | undefined;
        /**
         * @stability stable
         */
        set sourceRegion(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceRegion(): void;
        /**
         * @stability stable
         */
        get sourceRegionInput(): string | undefined;
        private _storageEncrypted?;
        /**
         * @stability stable
         */
        get storageEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set storageEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetStorageEncrypted(): void;
        /**
         * @stability stable
         */
        get storageEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcSecurityGroupIds?;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set vpcSecurityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetVpcSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIdsInput(): string[] | undefined;
        private _restoreToPointInTime?;
        private __restoreToPointInTimeOutput;
        /**
         * @stability stable
         */
        get restoreToPointInTime(): RdsClusterRestoreToPointInTimeOutputReference;
        /**
         * @stability stable
         */
        putRestoreToPointInTime(value: RdsClusterRestoreToPointInTime | undefined): void;
        /**
         * @stability stable
         */
        resetRestoreToPointInTime(): void;
        /**
         * @stability stable
         */
        get restoreToPointInTimeInput(): RdsClusterRestoreToPointInTime | undefined;
        private _s3Import?;
        private __s3ImportOutput;
        /**
         * @stability stable
         */
        get s3Import(): RdsClusterS3ImportOutputReference;
        /**
         * @stability stable
         */
        putS3Import(value: RdsClusterS3Import | undefined): void;
        /**
         * @stability stable
         */
        resetS3Import(): void;
        /**
         * @stability stable
         */
        get s3ImportInput(): RdsClusterS3Import | undefined;
        private _scalingConfiguration?;
        private __scalingConfigurationOutput;
        /**
         * @stability stable
         */
        get scalingConfiguration(): RdsClusterScalingConfigurationOutputReference;
        /**
         * @stability stable
         */
        putScalingConfiguration(value: RdsClusterScalingConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetScalingConfiguration(): void;
        /**
         * @stability stable
         */
        get scalingConfigurationInput(): RdsClusterScalingConfiguration | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): RdsClusterTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: RdsClusterTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): RdsClusterTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RdsClusterEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html#cluster_endpoint_identifier RdsClusterEndpoint#cluster_endpoint_identifier}.
         *
         * @stability stable
         */
        readonly clusterEndpointIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html#cluster_identifier RdsClusterEndpoint#cluster_identifier}.
         *
         * @stability stable
         */
        readonly clusterIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html#custom_endpoint_type RdsClusterEndpoint#custom_endpoint_type}.
         *
         * @stability stable
         */
        readonly customEndpointType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html#excluded_members RdsClusterEndpoint#excluded_members}.
         *
         * @stability stable
         */
        readonly excludedMembers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html#static_members RdsClusterEndpoint#static_members}.
         *
         * @stability stable
         */
        readonly staticMembers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html#tags RdsClusterEndpoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html#tags_all RdsClusterEndpoint#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html aws_rds_cluster_endpoint}.
     *
     * @stability stable
     */
    class RdsClusterEndpoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_endpoint.html aws_rds_cluster_endpoint} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RdsClusterEndpointConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _clusterEndpointIdentifier?;
        /**
         * @stability stable
         */
        get clusterEndpointIdentifier(): string;
        /**
         * @stability stable
         */
        set clusterEndpointIdentifier(value: string);
        /**
         * @stability stable
         */
        get clusterEndpointIdentifierInput(): string | undefined;
        private _clusterIdentifier?;
        /**
         * @stability stable
         */
        get clusterIdentifier(): string;
        /**
         * @stability stable
         */
        set clusterIdentifier(value: string);
        /**
         * @stability stable
         */
        get clusterIdentifierInput(): string | undefined;
        private _customEndpointType?;
        /**
         * @stability stable
         */
        get customEndpointType(): string;
        /**
         * @stability stable
         */
        set customEndpointType(value: string);
        /**
         * @stability stable
         */
        get customEndpointTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get endpoint(): string;
        private _excludedMembers?;
        /**
         * @stability stable
         */
        get excludedMembers(): string[] | undefined;
        /**
         * @stability stable
         */
        set excludedMembers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetExcludedMembers(): void;
        /**
         * @stability stable
         */
        get excludedMembersInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _staticMembers?;
        /**
         * @stability stable
         */
        get staticMembers(): string[] | undefined;
        /**
         * @stability stable
         */
        set staticMembers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetStaticMembers(): void;
        /**
         * @stability stable
         */
        get staticMembersInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RdsClusterInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#apply_immediately RdsClusterInstance#apply_immediately}.
         *
         * @stability stable
         */
        readonly applyImmediately?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#auto_minor_version_upgrade RdsClusterInstance#auto_minor_version_upgrade}.
         *
         * @stability stable
         */
        readonly autoMinorVersionUpgrade?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#availability_zone RdsClusterInstance#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#ca_cert_identifier RdsClusterInstance#ca_cert_identifier}.
         *
         * @stability stable
         */
        readonly caCertIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#cluster_identifier RdsClusterInstance#cluster_identifier}.
         *
         * @stability stable
         */
        readonly clusterIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#copy_tags_to_snapshot RdsClusterInstance#copy_tags_to_snapshot}.
         *
         * @stability stable
         */
        readonly copyTagsToSnapshot?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#db_parameter_group_name RdsClusterInstance#db_parameter_group_name}.
         *
         * @stability stable
         */
        readonly dbParameterGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#db_subnet_group_name RdsClusterInstance#db_subnet_group_name}.
         *
         * @stability stable
         */
        readonly dbSubnetGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#engine RdsClusterInstance#engine}.
         *
         * @stability stable
         */
        readonly engine?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#engine_version RdsClusterInstance#engine_version}.
         *
         * @stability stable
         */
        readonly engineVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#identifier RdsClusterInstance#identifier}.
         *
         * @stability stable
         */
        readonly identifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#identifier_prefix RdsClusterInstance#identifier_prefix}.
         *
         * @stability stable
         */
        readonly identifierPrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#instance_class RdsClusterInstance#instance_class}.
         *
         * @stability stable
         */
        readonly instanceClass: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#monitoring_interval RdsClusterInstance#monitoring_interval}.
         *
         * @stability stable
         */
        readonly monitoringInterval?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#monitoring_role_arn RdsClusterInstance#monitoring_role_arn}.
         *
         * @stability stable
         */
        readonly monitoringRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#performance_insights_enabled RdsClusterInstance#performance_insights_enabled}.
         *
         * @stability stable
         */
        readonly performanceInsightsEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#performance_insights_kms_key_id RdsClusterInstance#performance_insights_kms_key_id}.
         *
         * @stability stable
         */
        readonly performanceInsightsKmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#performance_insights_retention_period RdsClusterInstance#performance_insights_retention_period}.
         *
         * @stability stable
         */
        readonly performanceInsightsRetentionPeriod?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#preferred_backup_window RdsClusterInstance#preferred_backup_window}.
         *
         * @stability stable
         */
        readonly preferredBackupWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#preferred_maintenance_window RdsClusterInstance#preferred_maintenance_window}.
         *
         * @stability stable
         */
        readonly preferredMaintenanceWindow?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#promotion_tier RdsClusterInstance#promotion_tier}.
         *
         * @stability stable
         */
        readonly promotionTier?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#publicly_accessible RdsClusterInstance#publicly_accessible}.
         *
         * @stability stable
         */
        readonly publiclyAccessible?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#tags RdsClusterInstance#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#tags_all RdsClusterInstance#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#timeouts RdsClusterInstance#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: RdsClusterInstanceTimeouts;
    }
    /**
     * @stability stable
     */
    interface RdsClusterInstanceTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#create RdsClusterInstance#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#delete RdsClusterInstance#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html#update RdsClusterInstance#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class RdsClusterInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html aws_rds_cluster_instance}.
     *
     * @stability stable
     */
    class RdsClusterInstance extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_instance.html aws_rds_cluster_instance} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RdsClusterInstanceConfig);
        private _applyImmediately?;
        /**
         * @stability stable
         */
        get applyImmediately(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set applyImmediately(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetApplyImmediately(): void;
        /**
         * @stability stable
         */
        get applyImmediatelyInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoMinorVersionUpgrade?;
        /**
         * @stability stable
         */
        get autoMinorVersionUpgrade(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoMinorVersionUpgrade(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoMinorVersionUpgrade(): void;
        /**
         * @stability stable
         */
        get autoMinorVersionUpgradeInput(): boolean | cdktf.IResolvable | undefined;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _caCertIdentifier?;
        /**
         * @stability stable
         */
        get caCertIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set caCertIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetCaCertIdentifier(): void;
        /**
         * @stability stable
         */
        get caCertIdentifierInput(): string | undefined;
        private _clusterIdentifier?;
        /**
         * @stability stable
         */
        get clusterIdentifier(): string;
        /**
         * @stability stable
         */
        set clusterIdentifier(value: string);
        /**
         * @stability stable
         */
        get clusterIdentifierInput(): string | undefined;
        private _copyTagsToSnapshot?;
        /**
         * @stability stable
         */
        get copyTagsToSnapshot(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set copyTagsToSnapshot(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetCopyTagsToSnapshot(): void;
        /**
         * @stability stable
         */
        get copyTagsToSnapshotInput(): boolean | cdktf.IResolvable | undefined;
        private _dbParameterGroupName?;
        /**
         * @stability stable
         */
        get dbParameterGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set dbParameterGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbParameterGroupName(): void;
        /**
         * @stability stable
         */
        get dbParameterGroupNameInput(): string | undefined;
        private _dbSubnetGroupName?;
        /**
         * @stability stable
         */
        get dbSubnetGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set dbSubnetGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbSubnetGroupName(): void;
        /**
         * @stability stable
         */
        get dbSubnetGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get dbiResourceId(): string;
        /**
         * @stability stable
         */
        get endpoint(): string;
        private _engine?;
        /**
         * @stability stable
         */
        get engine(): string | undefined;
        /**
         * @stability stable
         */
        set engine(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngine(): void;
        /**
         * @stability stable
         */
        get engineInput(): string | undefined;
        private _engineVersion?;
        /**
         * @stability stable
         */
        get engineVersion(): string | undefined;
        /**
         * @stability stable
         */
        set engineVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngineVersion(): void;
        /**
         * @stability stable
         */
        get engineVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get engineVersionActual(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _identifier?;
        /**
         * @stability stable
         */
        get identifier(): string | undefined;
        /**
         * @stability stable
         */
        set identifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdentifier(): void;
        /**
         * @stability stable
         */
        get identifierInput(): string | undefined;
        private _identifierPrefix?;
        /**
         * @stability stable
         */
        get identifierPrefix(): string | undefined;
        /**
         * @stability stable
         */
        set identifierPrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetIdentifierPrefix(): void;
        /**
         * @stability stable
         */
        get identifierPrefixInput(): string | undefined;
        private _instanceClass?;
        /**
         * @stability stable
         */
        get instanceClass(): string;
        /**
         * @stability stable
         */
        set instanceClass(value: string);
        /**
         * @stability stable
         */
        get instanceClassInput(): string | undefined;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        private _monitoringInterval?;
        /**
         * @stability stable
         */
        get monitoringInterval(): number | undefined;
        /**
         * @stability stable
         */
        set monitoringInterval(value: number | undefined);
        /**
         * @stability stable
         */
        resetMonitoringInterval(): void;
        /**
         * @stability stable
         */
        get monitoringIntervalInput(): number | undefined;
        private _monitoringRoleArn?;
        /**
         * @stability stable
         */
        get monitoringRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set monitoringRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetMonitoringRoleArn(): void;
        /**
         * @stability stable
         */
        get monitoringRoleArnInput(): string | undefined;
        private _performanceInsightsEnabled?;
        /**
         * @stability stable
         */
        get performanceInsightsEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set performanceInsightsEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPerformanceInsightsEnabled(): void;
        /**
         * @stability stable
         */
        get performanceInsightsEnabledInput(): boolean | cdktf.IResolvable | undefined;
        private _performanceInsightsKmsKeyId?;
        /**
         * @stability stable
         */
        get performanceInsightsKmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set performanceInsightsKmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPerformanceInsightsKmsKeyId(): void;
        /**
         * @stability stable
         */
        get performanceInsightsKmsKeyIdInput(): string | undefined;
        private _performanceInsightsRetentionPeriod?;
        /**
         * @stability stable
         */
        get performanceInsightsRetentionPeriod(): number | undefined;
        /**
         * @stability stable
         */
        set performanceInsightsRetentionPeriod(value: number | undefined);
        /**
         * @stability stable
         */
        resetPerformanceInsightsRetentionPeriod(): void;
        /**
         * @stability stable
         */
        get performanceInsightsRetentionPeriodInput(): number | undefined;
        /**
         * @stability stable
         */
        get port(): number;
        private _preferredBackupWindow?;
        /**
         * @stability stable
         */
        get preferredBackupWindow(): string | undefined;
        /**
         * @stability stable
         */
        set preferredBackupWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreferredBackupWindow(): void;
        /**
         * @stability stable
         */
        get preferredBackupWindowInput(): string | undefined;
        private _preferredMaintenanceWindow?;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindow(): string | undefined;
        /**
         * @stability stable
         */
        set preferredMaintenanceWindow(value: string | undefined);
        /**
         * @stability stable
         */
        resetPreferredMaintenanceWindow(): void;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindowInput(): string | undefined;
        private _promotionTier?;
        /**
         * @stability stable
         */
        get promotionTier(): number | undefined;
        /**
         * @stability stable
         */
        set promotionTier(value: number | undefined);
        /**
         * @stability stable
         */
        resetPromotionTier(): void;
        /**
         * @stability stable
         */
        get promotionTierInput(): number | undefined;
        private _publiclyAccessible?;
        /**
         * @stability stable
         */
        get publiclyAccessible(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set publiclyAccessible(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPubliclyAccessible(): void;
        /**
         * @stability stable
         */
        get publiclyAccessibleInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get storageEncrypted(): any;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get writer(): any;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): RdsClusterInstanceTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: RdsClusterInstanceTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): RdsClusterInstanceTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RdsClusterParameterGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#description RdsClusterParameterGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#family RdsClusterParameterGroup#family}.
         *
         * @stability stable
         */
        readonly family: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#name RdsClusterParameterGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#name_prefix RdsClusterParameterGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#tags RdsClusterParameterGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#tags_all RdsClusterParameterGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * parameter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#parameter RdsClusterParameterGroup#parameter}
         *
         * @stability stable
         */
        readonly parameter?: RdsClusterParameterGroupParameter[];
    }
    /**
     * @stability stable
     */
    interface RdsClusterParameterGroupParameter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#apply_method RdsClusterParameterGroup#apply_method}.
         *
         * @stability stable
         */
        readonly applyMethod?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#name RdsClusterParameterGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html#value RdsClusterParameterGroup#value}.
         *
         * @stability stable
         */
        readonly value: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html aws_rds_cluster_parameter_group}.
     *
     * @stability stable
     */
    class RdsClusterParameterGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_parameter_group.html aws_rds_cluster_parameter_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RdsClusterParameterGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _family?;
        /**
         * @stability stable
         */
        get family(): string;
        /**
         * @stability stable
         */
        set family(value: string);
        /**
         * @stability stable
         */
        get familyInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _parameter?;
        /**
         * @stability stable
         */
        get parameter(): RdsClusterParameterGroupParameter[] | undefined;
        /**
         * @stability stable
         */
        set parameter(value: RdsClusterParameterGroupParameter[] | undefined);
        /**
         * @stability stable
         */
        resetParameter(): void;
        /**
         * @stability stable
         */
        get parameterInput(): RdsClusterParameterGroupParameter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RdsClusterRoleAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_role_association.html#db_cluster_identifier RdsClusterRoleAssociation#db_cluster_identifier}.
         *
         * @stability stable
         */
        readonly dbClusterIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_role_association.html#feature_name RdsClusterRoleAssociation#feature_name}.
         *
         * @stability stable
         */
        readonly featureName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_role_association.html#role_arn RdsClusterRoleAssociation#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_role_association.html aws_rds_cluster_role_association}.
     *
     * @stability stable
     */
    class RdsClusterRoleAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_cluster_role_association.html aws_rds_cluster_role_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RdsClusterRoleAssociationConfig);
        private _dbClusterIdentifier?;
        /**
         * @stability stable
         */
        get dbClusterIdentifier(): string;
        /**
         * @stability stable
         */
        set dbClusterIdentifier(value: string);
        /**
         * @stability stable
         */
        get dbClusterIdentifierInput(): string | undefined;
        private _featureName?;
        /**
         * @stability stable
         */
        get featureName(): string;
        /**
         * @stability stable
         */
        set featureName(value: string);
        /**
         * @stability stable
         */
        get featureNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RdsGlobalClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#database_name RdsGlobalCluster#database_name}.
         *
         * @stability stable
         */
        readonly databaseName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#deletion_protection RdsGlobalCluster#deletion_protection}.
         *
         * @stability stable
         */
        readonly deletionProtection?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#engine RdsGlobalCluster#engine}.
         *
         * @stability stable
         */
        readonly engine?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#engine_version RdsGlobalCluster#engine_version}.
         *
         * @stability stable
         */
        readonly engineVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#force_destroy RdsGlobalCluster#force_destroy}.
         *
         * @stability stable
         */
        readonly forceDestroy?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#global_cluster_identifier RdsGlobalCluster#global_cluster_identifier}.
         *
         * @stability stable
         */
        readonly globalClusterIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#source_db_cluster_identifier RdsGlobalCluster#source_db_cluster_identifier}.
         *
         * @stability stable
         */
        readonly sourceDbClusterIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html#storage_encrypted RdsGlobalCluster#storage_encrypted}.
         *
         * @stability stable
         */
        readonly storageEncrypted?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class RdsGlobalClusterGlobalClusterMembers extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get dbClusterArn(): string;
        /**
         * @stability stable
         */
        get isWriter(): any;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html aws_rds_global_cluster}.
     *
     * @stability stable
     */
    class RdsGlobalCluster extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/rds_global_cluster.html aws_rds_global_cluster} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RdsGlobalClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _databaseName?;
        /**
         * @stability stable
         */
        get databaseName(): string | undefined;
        /**
         * @stability stable
         */
        set databaseName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDatabaseName(): void;
        /**
         * @stability stable
         */
        get databaseNameInput(): string | undefined;
        private _deletionProtection?;
        /**
         * @stability stable
         */
        get deletionProtection(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set deletionProtection(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDeletionProtection(): void;
        /**
         * @stability stable
         */
        get deletionProtectionInput(): boolean | cdktf.IResolvable | undefined;
        private _engine?;
        /**
         * @stability stable
         */
        get engine(): string | undefined;
        /**
         * @stability stable
         */
        set engine(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngine(): void;
        /**
         * @stability stable
         */
        get engineInput(): string | undefined;
        private _engineVersion?;
        /**
         * @stability stable
         */
        get engineVersion(): string | undefined;
        /**
         * @stability stable
         */
        set engineVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngineVersion(): void;
        /**
         * @stability stable
         */
        get engineVersionInput(): string | undefined;
        private _forceDestroy?;
        /**
         * @stability stable
         */
        get forceDestroy(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set forceDestroy(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetForceDestroy(): void;
        /**
         * @stability stable
         */
        get forceDestroyInput(): boolean | cdktf.IResolvable | undefined;
        private _globalClusterIdentifier?;
        /**
         * @stability stable
         */
        get globalClusterIdentifier(): string;
        /**
         * @stability stable
         */
        set globalClusterIdentifier(value: string);
        /**
         * @stability stable
         */
        get globalClusterIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        globalClusterMembers(index: string): RdsGlobalClusterGlobalClusterMembers;
        /**
         * @stability stable
         */
        get globalClusterResourceId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _sourceDbClusterIdentifier?;
        /**
         * @stability stable
         */
        get sourceDbClusterIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set sourceDbClusterIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceDbClusterIdentifier(): void;
        /**
         * @stability stable
         */
        get sourceDbClusterIdentifierInput(): string | undefined;
        private _storageEncrypted?;
        /**
         * @stability stable
         */
        get storageEncrypted(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set storageEncrypted(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetStorageEncrypted(): void;
        /**
         * @stability stable
         */
        get storageEncryptedInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDbClusterSnapshotConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html#db_cluster_identifier DataAwsDbClusterSnapshot#db_cluster_identifier}.
         *
         * @stability stable
         */
        readonly dbClusterIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html#db_cluster_snapshot_identifier DataAwsDbClusterSnapshot#db_cluster_snapshot_identifier}.
         *
         * @stability stable
         */
        readonly dbClusterSnapshotIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html#include_public DataAwsDbClusterSnapshot#include_public}.
         *
         * @stability stable
         */
        readonly includePublic?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html#include_shared DataAwsDbClusterSnapshot#include_shared}.
         *
         * @stability stable
         */
        readonly includeShared?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html#most_recent DataAwsDbClusterSnapshot#most_recent}.
         *
         * @stability stable
         */
        readonly mostRecent?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html#snapshot_type DataAwsDbClusterSnapshot#snapshot_type}.
         *
         * @stability stable
         */
        readonly snapshotType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html#tags DataAwsDbClusterSnapshot#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html aws_db_cluster_snapshot}.
     *
     * @stability stable
     */
    class DataAwsDbClusterSnapshot extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_cluster_snapshot.html aws_db_cluster_snapshot} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsDbClusterSnapshotConfig);
        /**
         * @stability stable
         */
        get allocatedStorage(): number;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        private _dbClusterIdentifier?;
        /**
         * @stability stable
         */
        get dbClusterIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set dbClusterIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbClusterIdentifier(): void;
        /**
         * @stability stable
         */
        get dbClusterIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get dbClusterSnapshotArn(): string;
        private _dbClusterSnapshotIdentifier?;
        /**
         * @stability stable
         */
        get dbClusterSnapshotIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set dbClusterSnapshotIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbClusterSnapshotIdentifier(): void;
        /**
         * @stability stable
         */
        get dbClusterSnapshotIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        get engineVersion(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _includePublic?;
        /**
         * @stability stable
         */
        get includePublic(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includePublic(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludePublic(): void;
        /**
         * @stability stable
         */
        get includePublicInput(): boolean | cdktf.IResolvable | undefined;
        private _includeShared?;
        /**
         * @stability stable
         */
        get includeShared(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeShared(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeShared(): void;
        /**
         * @stability stable
         */
        get includeSharedInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        get licenseModel(): string;
        private _mostRecent?;
        /**
         * @stability stable
         */
        get mostRecent(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mostRecent(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMostRecent(): void;
        /**
         * @stability stable
         */
        get mostRecentInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get snapshotCreateTime(): string;
        private _snapshotType?;
        /**
         * @stability stable
         */
        get snapshotType(): string | undefined;
        /**
         * @stability stable
         */
        set snapshotType(value: string | undefined);
        /**
         * @stability stable
         */
        resetSnapshotType(): void;
        /**
         * @stability stable
         */
        get snapshotTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get sourceDbClusterSnapshotArn(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get storageEncrypted(): any;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDbEventCategoriesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_event_categories.html#source_type DataAwsDbEventCategories#source_type}.
         *
         * @stability stable
         */
        readonly sourceType?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/db_event_categories.html aws_db_event_categories}.
     *
     * @stability stable
     */
    class DataAwsDbEventCategories extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_event_categories.html aws_db_event_categories} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsDbEventCategoriesConfig);
        /**
         * @stability stable
         */
        get eventCategories(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        private _sourceType?;
        /**
         * @stability stable
         */
        get sourceType(): string | undefined;
        /**
         * @stability stable
         */
        set sourceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceType(): void;
        /**
         * @stability stable
         */
        get sourceTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDbInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_instance.html#db_instance_identifier DataAwsDbInstance#db_instance_identifier}.
         *
         * @stability stable
         */
        readonly dbInstanceIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_instance.html#tags DataAwsDbInstance#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/db_instance.html aws_db_instance}.
     *
     * @stability stable
     */
    class DataAwsDbInstance extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_instance.html aws_db_instance} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDbInstanceConfig);
        /**
         * @stability stable
         */
        get address(): string;
        /**
         * @stability stable
         */
        get allocatedStorage(): number;
        /**
         * @stability stable
         */
        get autoMinorVersionUpgrade(): any;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        /**
         * @stability stable
         */
        get backupRetentionPeriod(): number;
        /**
         * @stability stable
         */
        get caCertIdentifier(): string;
        /**
         * @stability stable
         */
        get dbClusterIdentifier(): string;
        /**
         * @stability stable
         */
        get dbInstanceArn(): string;
        /**
         * @stability stable
         */
        get dbInstanceClass(): string;
        private _dbInstanceIdentifier?;
        /**
         * @stability stable
         */
        get dbInstanceIdentifier(): string;
        /**
         * @stability stable
         */
        set dbInstanceIdentifier(value: string);
        /**
         * @stability stable
         */
        get dbInstanceIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get dbInstancePort(): number;
        /**
         * @stability stable
         */
        get dbName(): string;
        /**
         * @stability stable
         */
        get dbParameterGroups(): string[];
        /**
         * @stability stable
         */
        get dbSecurityGroups(): string[];
        /**
         * @stability stable
         */
        get dbSubnetGroup(): string;
        /**
         * @stability stable
         */
        get enabledCloudwatchLogsExports(): string[];
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        get engineVersion(): string;
        /**
         * @stability stable
         */
        get hostedZoneId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get iops(): number;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        get licenseModel(): string;
        /**
         * @stability stable
         */
        get masterUsername(): string;
        /**
         * @stability stable
         */
        get monitoringInterval(): number;
        /**
         * @stability stable
         */
        get monitoringRoleArn(): string;
        /**
         * @stability stable
         */
        get multiAz(): any;
        /**
         * @stability stable
         */
        get optionGroupMemberships(): string[];
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get preferredBackupWindow(): string;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindow(): string;
        /**
         * @stability stable
         */
        get publiclyAccessible(): any;
        /**
         * @stability stable
         */
        get replicateSourceDb(): string;
        /**
         * @stability stable
         */
        get resourceId(): string;
        /**
         * @stability stable
         */
        get storageEncrypted(): any;
        /**
         * @stability stable
         */
        get storageType(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get timezone(): string;
        /**
         * @stability stable
         */
        get vpcSecurityGroups(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDbProxyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_proxy.html#name DataAwsDbProxy#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    class DataAwsDbProxyAuth extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get authScheme(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get iamAuth(): string;
        /**
         * @stability stable
         */
        get secretArn(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/db_proxy.html aws_db_proxy}.
     *
     * @stability stable
     */
    class DataAwsDbProxy extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_proxy.html aws_db_proxy} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDbProxyConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        auth(index: string): DataAwsDbProxyAuth;
        /**
         * @stability stable
         */
        get debugLogging(): any;
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get engineFamily(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get idleClientTimeout(): number;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get requireTls(): any;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIds(): string[];
        /**
         * @stability stable
         */
        get vpcSubnetIds(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDbSnapshotConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html#db_instance_identifier DataAwsDbSnapshot#db_instance_identifier}.
         *
         * @stability stable
         */
        readonly dbInstanceIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html#db_snapshot_identifier DataAwsDbSnapshot#db_snapshot_identifier}.
         *
         * @stability stable
         */
        readonly dbSnapshotIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html#include_public DataAwsDbSnapshot#include_public}.
         *
         * @stability stable
         */
        readonly includePublic?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html#include_shared DataAwsDbSnapshot#include_shared}.
         *
         * @stability stable
         */
        readonly includeShared?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html#most_recent DataAwsDbSnapshot#most_recent}.
         *
         * @stability stable
         */
        readonly mostRecent?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html#snapshot_type DataAwsDbSnapshot#snapshot_type}.
         *
         * @stability stable
         */
        readonly snapshotType?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html aws_db_snapshot}.
     *
     * @stability stable
     */
    class DataAwsDbSnapshot extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_snapshot.html aws_db_snapshot} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsDbSnapshotConfig);
        /**
         * @stability stable
         */
        get allocatedStorage(): number;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        private _dbInstanceIdentifier?;
        /**
         * @stability stable
         */
        get dbInstanceIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set dbInstanceIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbInstanceIdentifier(): void;
        /**
         * @stability stable
         */
        get dbInstanceIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get dbSnapshotArn(): string;
        private _dbSnapshotIdentifier?;
        /**
         * @stability stable
         */
        get dbSnapshotIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set dbSnapshotIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetDbSnapshotIdentifier(): void;
        /**
         * @stability stable
         */
        get dbSnapshotIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get encrypted(): any;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        get engineVersion(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _includePublic?;
        /**
         * @stability stable
         */
        get includePublic(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includePublic(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludePublic(): void;
        /**
         * @stability stable
         */
        get includePublicInput(): boolean | cdktf.IResolvable | undefined;
        private _includeShared?;
        /**
         * @stability stable
         */
        get includeShared(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set includeShared(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetIncludeShared(): void;
        /**
         * @stability stable
         */
        get includeSharedInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get iops(): number;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        get licenseModel(): string;
        private _mostRecent?;
        /**
         * @stability stable
         */
        get mostRecent(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mostRecent(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMostRecent(): void;
        /**
         * @stability stable
         */
        get mostRecentInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get optionGroupName(): string;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get snapshotCreateTime(): string;
        private _snapshotType?;
        /**
         * @stability stable
         */
        get snapshotType(): string | undefined;
        /**
         * @stability stable
         */
        set snapshotType(value: string | undefined);
        /**
         * @stability stable
         */
        resetSnapshotType(): void;
        /**
         * @stability stable
         */
        get snapshotTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get sourceDbSnapshotIdentifier(): string;
        /**
         * @stability stable
         */
        get sourceRegion(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get storageType(): string;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsDbSubnetGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/db_subnet_group.html#name DataAwsDbSubnetGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/db_subnet_group.html aws_db_subnet_group}.
     *
     * @stability stable
     */
    class DataAwsDbSubnetGroup extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/db_subnet_group.html aws_db_subnet_group} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsDbSubnetGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRdsCertificateConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_certificate.html#latest_valid_till DataAwsRdsCertificate#latest_valid_till}.
         *
         * @stability stable
         */
        readonly latestValidTill?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/rds_certificate.html aws_rds_certificate}.
     *
     * @stability stable
     */
    class DataAwsRdsCertificate extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/rds_certificate.html aws_rds_certificate} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsRdsCertificateConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get certificateType(): string;
        /**
         * @stability stable
         */
        get customerOverride(): any;
        /**
         * @stability stable
         */
        get customerOverrideValidTill(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _latestValidTill?;
        /**
         * @stability stable
         */
        get latestValidTill(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set latestValidTill(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetLatestValidTill(): void;
        /**
         * @stability stable
         */
        get latestValidTillInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get thumbprint(): string;
        /**
         * @stability stable
         */
        get validFrom(): string;
        /**
         * @stability stable
         */
        get validTill(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRdsClusterConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster.html#cluster_identifier DataAwsRdsCluster#cluster_identifier}.
         *
         * @stability stable
         */
        readonly clusterIdentifier: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster.html#tags DataAwsRdsCluster#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster.html aws_rds_cluster}.
     *
     * @stability stable
     */
    class DataAwsRdsCluster extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/rds_cluster.html aws_rds_cluster} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsRdsClusterConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get backtrackWindow(): number;
        /**
         * @stability stable
         */
        get backupRetentionPeriod(): number;
        private _clusterIdentifier?;
        /**
         * @stability stable
         */
        get clusterIdentifier(): string;
        /**
         * @stability stable
         */
        set clusterIdentifier(value: string);
        /**
         * @stability stable
         */
        get clusterIdentifierInput(): string | undefined;
        /**
         * @stability stable
         */
        get clusterMembers(): string[];
        /**
         * @stability stable
         */
        get clusterResourceId(): string;
        /**
         * @stability stable
         */
        get databaseName(): string;
        /**
         * @stability stable
         */
        get dbClusterParameterGroupName(): string;
        /**
         * @stability stable
         */
        get dbSubnetGroupName(): string;
        /**
         * @stability stable
         */
        get enabledCloudwatchLogsExports(): string[];
        /**
         * @stability stable
         */
        get endpoint(): string;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        get engineVersion(): string;
        /**
         * @stability stable
         */
        get finalSnapshotIdentifier(): string;
        /**
         * @stability stable
         */
        get hostedZoneId(): string;
        /**
         * @stability stable
         */
        get iamDatabaseAuthenticationEnabled(): any;
        /**
         * @stability stable
         */
        get iamRoles(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get kmsKeyId(): string;
        /**
         * @stability stable
         */
        get masterUsername(): string;
        /**
         * @stability stable
         */
        get port(): number;
        /**
         * @stability stable
         */
        get preferredBackupWindow(): string;
        /**
         * @stability stable
         */
        get preferredMaintenanceWindow(): string;
        /**
         * @stability stable
         */
        get readerEndpoint(): string;
        /**
         * @stability stable
         */
        get replicationSourceIdentifier(): string;
        /**
         * @stability stable
         */
        get storageEncrypted(): any;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcSecurityGroupIds(): string[];
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRdsEngineVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_engine_version.html#engine DataAwsRdsEngineVersion#engine}.
         *
         * @stability stable
         */
        readonly engine: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_engine_version.html#parameter_group_family DataAwsRdsEngineVersion#parameter_group_family}.
         *
         * @stability stable
         */
        readonly parameterGroupFamily?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_engine_version.html#preferred_versions DataAwsRdsEngineVersion#preferred_versions}.
         *
         * @stability stable
         */
        readonly preferredVersions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_engine_version.html#version DataAwsRdsEngineVersion#version}.
         *
         * @stability stable
         */
        readonly version?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/rds_engine_version.html aws_rds_engine_version}.
     *
     * @stability stable
     */
    class DataAwsRdsEngineVersion extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/rds_engine_version.html aws_rds_engine_version} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsRdsEngineVersionConfig);
        /**
         * @stability stable
         */
        get defaultCharacterSet(): string;
        private _engine?;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        set engine(value: string);
        /**
         * @stability stable
         */
        get engineInput(): string | undefined;
        /**
         * @stability stable
         */
        get engineDescription(): string;
        /**
         * @stability stable
         */
        get exportableLogTypes(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        private _parameterGroupFamily?;
        /**
         * @stability stable
         */
        get parameterGroupFamily(): string | undefined;
        /**
         * @stability stable
         */
        set parameterGroupFamily(value: string | undefined);
        /**
         * @stability stable
         */
        resetParameterGroupFamily(): void;
        /**
         * @stability stable
         */
        get parameterGroupFamilyInput(): string | undefined;
        private _preferredVersions?;
        /**
         * @stability stable
         */
        get preferredVersions(): string[] | undefined;
        /**
         * @stability stable
         */
        set preferredVersions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPreferredVersions(): void;
        /**
         * @stability stable
         */
        get preferredVersionsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get supportedCharacterSets(): string[];
        /**
         * @stability stable
         */
        get supportedFeatureNames(): string[];
        /**
         * @stability stable
         */
        get supportedModes(): string[];
        /**
         * @stability stable
         */
        get supportedTimezones(): string[];
        /**
         * @stability stable
         */
        get supportsGlobalDatabases(): any;
        /**
         * @stability stable
         */
        get supportsLogExportsToCloudwatch(): any;
        /**
         * @stability stable
         */
        get supportsParallelQuery(): any;
        /**
         * @stability stable
         */
        get supportsReadReplica(): any;
        /**
         * @stability stable
         */
        get validUpgradeTargets(): string[];
        private _version?;
        /**
         * @stability stable
         */
        get version(): string | undefined;
        /**
         * @stability stable
         */
        set version(value: string | undefined);
        /**
         * @stability stable
         */
        resetVersion(): void;
        /**
         * @stability stable
         */
        get versionInput(): string | undefined;
        /**
         * @stability stable
         */
        get versionDescription(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRdsOrderableDbInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#availability_zone_group DataAwsRdsOrderableDbInstance#availability_zone_group}.
         *
         * @stability stable
         */
        readonly availabilityZoneGroup?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#engine DataAwsRdsOrderableDbInstance#engine}.
         *
         * @stability stable
         */
        readonly engine: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#engine_version DataAwsRdsOrderableDbInstance#engine_version}.
         *
         * @stability stable
         */
        readonly engineVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#instance_class DataAwsRdsOrderableDbInstance#instance_class}.
         *
         * @stability stable
         */
        readonly instanceClass?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#license_model DataAwsRdsOrderableDbInstance#license_model}.
         *
         * @stability stable
         */
        readonly licenseModel?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#preferred_engine_versions DataAwsRdsOrderableDbInstance#preferred_engine_versions}.
         *
         * @stability stable
         */
        readonly preferredEngineVersions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#preferred_instance_classes DataAwsRdsOrderableDbInstance#preferred_instance_classes}.
         *
         * @stability stable
         */
        readonly preferredInstanceClasses?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#storage_type DataAwsRdsOrderableDbInstance#storage_type}.
         *
         * @stability stable
         */
        readonly storageType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_enhanced_monitoring DataAwsRdsOrderableDbInstance#supports_enhanced_monitoring}.
         *
         * @stability stable
         */
        readonly supportsEnhancedMonitoring?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_global_databases DataAwsRdsOrderableDbInstance#supports_global_databases}.
         *
         * @stability stable
         */
        readonly supportsGlobalDatabases?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_iam_database_authentication DataAwsRdsOrderableDbInstance#supports_iam_database_authentication}.
         *
         * @stability stable
         */
        readonly supportsIamDatabaseAuthentication?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_iops DataAwsRdsOrderableDbInstance#supports_iops}.
         *
         * @stability stable
         */
        readonly supportsIops?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_kerberos_authentication DataAwsRdsOrderableDbInstance#supports_kerberos_authentication}.
         *
         * @stability stable
         */
        readonly supportsKerberosAuthentication?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_performance_insights DataAwsRdsOrderableDbInstance#supports_performance_insights}.
         *
         * @stability stable
         */
        readonly supportsPerformanceInsights?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_storage_autoscaling DataAwsRdsOrderableDbInstance#supports_storage_autoscaling}.
         *
         * @stability stable
         */
        readonly supportsStorageAutoscaling?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#supports_storage_encryption DataAwsRdsOrderableDbInstance#supports_storage_encryption}.
         *
         * @stability stable
         */
        readonly supportsStorageEncryption?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html#vpc DataAwsRdsOrderableDbInstance#vpc}.
         *
         * @stability stable
         */
        readonly vpc?: boolean | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html aws_rds_orderable_db_instance}.
     *
     * @stability stable
     */
    class DataAwsRdsOrderableDbInstance extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/rds_orderable_db_instance.html aws_rds_orderable_db_instance} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsRdsOrderableDbInstanceConfig);
        private _availabilityZoneGroup?;
        /**
         * @stability stable
         */
        get availabilityZoneGroup(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZoneGroup(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZoneGroup(): void;
        /**
         * @stability stable
         */
        get availabilityZoneGroupInput(): string | undefined;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        private _engine?;
        /**
         * @stability stable
         */
        get engine(): string;
        /**
         * @stability stable
         */
        set engine(value: string);
        /**
         * @stability stable
         */
        get engineInput(): string | undefined;
        private _engineVersion?;
        /**
         * @stability stable
         */
        get engineVersion(): string | undefined;
        /**
         * @stability stable
         */
        set engineVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetEngineVersion(): void;
        /**
         * @stability stable
         */
        get engineVersionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceClass?;
        /**
         * @stability stable
         */
        get instanceClass(): string | undefined;
        /**
         * @stability stable
         */
        set instanceClass(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceClass(): void;
        /**
         * @stability stable
         */
        get instanceClassInput(): string | undefined;
        private _licenseModel?;
        /**
         * @stability stable
         */
        get licenseModel(): string | undefined;
        /**
         * @stability stable
         */
        set licenseModel(value: string | undefined);
        /**
         * @stability stable
         */
        resetLicenseModel(): void;
        /**
         * @stability stable
         */
        get licenseModelInput(): string | undefined;
        /**
         * @stability stable
         */
        get maxIopsPerDbInstance(): number;
        /**
         * @stability stable
         */
        get maxIopsPerGib(): number;
        /**
         * @stability stable
         */
        get maxStorageSize(): number;
        /**
         * @stability stable
         */
        get minIopsPerDbInstance(): number;
        /**
         * @stability stable
         */
        get minIopsPerGib(): number;
        /**
         * @stability stable
         */
        get minStorageSize(): number;
        /**
         * @stability stable
         */
        get multiAzCapable(): any;
        /**
         * @stability stable
         */
        get outpostCapable(): any;
        private _preferredEngineVersions?;
        /**
         * @stability stable
         */
        get preferredEngineVersions(): string[] | undefined;
        /**
         * @stability stable
         */
        set preferredEngineVersions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPreferredEngineVersions(): void;
        /**
         * @stability stable
         */
        get preferredEngineVersionsInput(): string[] | undefined;
        private _preferredInstanceClasses?;
        /**
         * @stability stable
         */
        get preferredInstanceClasses(): string[] | undefined;
        /**
         * @stability stable
         */
        set preferredInstanceClasses(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPreferredInstanceClasses(): void;
        /**
         * @stability stable
         */
        get preferredInstanceClassesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get readReplicaCapable(): any;
        private _storageType?;
        /**
         * @stability stable
         */
        get storageType(): string | undefined;
        /**
         * @stability stable
         */
        set storageType(value: string | undefined);
        /**
         * @stability stable
         */
        resetStorageType(): void;
        /**
         * @stability stable
         */
        get storageTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get supportedEngineModes(): string[];
        private _supportsEnhancedMonitoring?;
        /**
         * @stability stable
         */
        get supportsEnhancedMonitoring(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsEnhancedMonitoring(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsEnhancedMonitoring(): void;
        /**
         * @stability stable
         */
        get supportsEnhancedMonitoringInput(): boolean | cdktf.IResolvable | undefined;
        private _supportsGlobalDatabases?;
        /**
         * @stability stable
         */
        get supportsGlobalDatabases(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsGlobalDatabases(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsGlobalDatabases(): void;
        /**
         * @stability stable
         */
        get supportsGlobalDatabasesInput(): boolean | cdktf.IResolvable | undefined;
        private _supportsIamDatabaseAuthentication?;
        /**
         * @stability stable
         */
        get supportsIamDatabaseAuthentication(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsIamDatabaseAuthentication(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsIamDatabaseAuthentication(): void;
        /**
         * @stability stable
         */
        get supportsIamDatabaseAuthenticationInput(): boolean | cdktf.IResolvable | undefined;
        private _supportsIops?;
        /**
         * @stability stable
         */
        get supportsIops(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsIops(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsIops(): void;
        /**
         * @stability stable
         */
        get supportsIopsInput(): boolean | cdktf.IResolvable | undefined;
        private _supportsKerberosAuthentication?;
        /**
         * @stability stable
         */
        get supportsKerberosAuthentication(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsKerberosAuthentication(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsKerberosAuthentication(): void;
        /**
         * @stability stable
         */
        get supportsKerberosAuthenticationInput(): boolean | cdktf.IResolvable | undefined;
        private _supportsPerformanceInsights?;
        /**
         * @stability stable
         */
        get supportsPerformanceInsights(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsPerformanceInsights(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsPerformanceInsights(): void;
        /**
         * @stability stable
         */
        get supportsPerformanceInsightsInput(): boolean | cdktf.IResolvable | undefined;
        private _supportsStorageAutoscaling?;
        /**
         * @stability stable
         */
        get supportsStorageAutoscaling(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsStorageAutoscaling(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsStorageAutoscaling(): void;
        /**
         * @stability stable
         */
        get supportsStorageAutoscalingInput(): boolean | cdktf.IResolvable | undefined;
        private _supportsStorageEncryption?;
        /**
         * @stability stable
         */
        get supportsStorageEncryption(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set supportsStorageEncryption(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSupportsStorageEncryption(): void;
        /**
         * @stability stable
         */
        get supportsStorageEncryptionInput(): boolean | cdktf.IResolvable | undefined;
        private _vpc?;
        /**
         * @stability stable
         */
        get vpc(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set vpc(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetVpc(): void;
        /**
         * @stability stable
         */
        get vpcInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
