import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS SageMaker
*/
export declare namespace SageMaker {
    /**
     * @stability stable
     */
    interface SagemakerAppConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#app_name SagemakerApp#app_name}.
         *
         * @stability stable
         */
        readonly appName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#app_type SagemakerApp#app_type}.
         *
         * @stability stable
         */
        readonly appType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#domain_id SagemakerApp#domain_id}.
         *
         * @stability stable
         */
        readonly domainId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#tags SagemakerApp#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#tags_all SagemakerApp#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#user_profile_name SagemakerApp#user_profile_name}.
         *
         * @stability stable
         */
        readonly userProfileName: string;
        /**
         * resource_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#resource_spec SagemakerApp#resource_spec}
         *
         * @stability stable
         */
        readonly resourceSpec?: SagemakerAppResourceSpec;
    }
    /**
     * @stability stable
     */
    interface SagemakerAppResourceSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#instance_type SagemakerApp#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html#sagemaker_image_arn SagemakerApp#sagemaker_image_arn}.
         *
         * @stability stable
         */
        readonly sagemakerImageArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerAppResourceSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _sagemakerImageArn?;
        /**
         * @stability stable
         */
        get sagemakerImageArn(): string | undefined;
        /**
         * @stability stable
         */
        set sagemakerImageArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSagemakerImageArn(): void;
        /**
         * @stability stable
         */
        get sagemakerImageArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html aws_sagemaker_app}.
     *
     * @stability stable
     */
    class SagemakerApp extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app.html aws_sagemaker_app} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerAppConfig);
        private _appName?;
        /**
         * @stability stable
         */
        get appName(): string;
        /**
         * @stability stable
         */
        set appName(value: string);
        /**
         * @stability stable
         */
        get appNameInput(): string | undefined;
        private _appType?;
        /**
         * @stability stable
         */
        get appType(): string;
        /**
         * @stability stable
         */
        set appType(value: string);
        /**
         * @stability stable
         */
        get appTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _domainId?;
        /**
         * @stability stable
         */
        get domainId(): string;
        /**
         * @stability stable
         */
        set domainId(value: string);
        /**
         * @stability stable
         */
        get domainIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _userProfileName?;
        /**
         * @stability stable
         */
        get userProfileName(): string;
        /**
         * @stability stable
         */
        set userProfileName(value: string);
        /**
         * @stability stable
         */
        get userProfileNameInput(): string | undefined;
        private _resourceSpec?;
        private __resourceSpecOutput;
        /**
         * @stability stable
         */
        get resourceSpec(): SagemakerAppResourceSpecOutputReference;
        /**
         * @stability stable
         */
        putResourceSpec(value: SagemakerAppResourceSpec | undefined): void;
        /**
         * @stability stable
         */
        resetResourceSpec(): void;
        /**
         * @stability stable
         */
        get resourceSpecInput(): SagemakerAppResourceSpec | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerAppImageConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#app_image_config_name SagemakerAppImageConfig#app_image_config_name}.
         *
         * @stability stable
         */
        readonly appImageConfigName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#tags SagemakerAppImageConfig#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#tags_all SagemakerAppImageConfig#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * kernel_gateway_image_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#kernel_gateway_image_config SagemakerAppImageConfig#kernel_gateway_image_config}
         *
         * @stability stable
         */
        readonly kernelGatewayImageConfig?: SagemakerAppImageConfigKernelGatewayImageConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#default_gid SagemakerAppImageConfig#default_gid}.
         *
         * @stability stable
         */
        readonly defaultGid?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#default_uid SagemakerAppImageConfig#default_uid}.
         *
         * @stability stable
         */
        readonly defaultUid?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#mount_path SagemakerAppImageConfig#mount_path}.
         *
         * @stability stable
         */
        readonly mountPath?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _defaultGid?;
        /**
         * @stability stable
         */
        get defaultGid(): number | undefined;
        /**
         * @stability stable
         */
        set defaultGid(value: number | undefined);
        /**
         * @stability stable
         */
        resetDefaultGid(): void;
        /**
         * @stability stable
         */
        get defaultGidInput(): number | undefined;
        private _defaultUid?;
        /**
         * @stability stable
         */
        get defaultUid(): number | undefined;
        /**
         * @stability stable
         */
        set defaultUid(value: number | undefined);
        /**
         * @stability stable
         */
        resetDefaultUid(): void;
        /**
         * @stability stable
         */
        get defaultUidInput(): number | undefined;
        private _mountPath?;
        /**
         * @stability stable
         */
        get mountPath(): string | undefined;
        /**
         * @stability stable
         */
        set mountPath(value: string | undefined);
        /**
         * @stability stable
         */
        resetMountPath(): void;
        /**
         * @stability stable
         */
        get mountPathInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#display_name SagemakerAppImageConfig#display_name}.
         *
         * @stability stable
         */
        readonly displayName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#name SagemakerAppImageConfig#name}.
         *
         * @stability stable
         */
        readonly name: string;
    }
    /**
     * @stability stable
     */
    class SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _displayName?;
        /**
         * @stability stable
         */
        get displayName(): string | undefined;
        /**
         * @stability stable
         */
        set displayName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDisplayName(): void;
        /**
         * @stability stable
         */
        get displayNameInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerAppImageConfigKernelGatewayImageConfig {
        /**
         * file_system_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#file_system_config SagemakerAppImageConfig#file_system_config}
         *
         * @stability stable
         */
        readonly fileSystemConfig?: SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig;
        /**
         * kernel_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html#kernel_spec SagemakerAppImageConfig#kernel_spec}
         *
         * @stability stable
         */
        readonly kernelSpec: SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec;
    }
    /**
     * @stability stable
     */
    class SagemakerAppImageConfigKernelGatewayImageConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _fileSystemConfig?;
        private __fileSystemConfigOutput;
        /**
         * @stability stable
         */
        get fileSystemConfig(): SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfigOutputReference;
        /**
         * @stability stable
         */
        putFileSystemConfig(value: SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig | undefined): void;
        /**
         * @stability stable
         */
        resetFileSystemConfig(): void;
        /**
         * @stability stable
         */
        get fileSystemConfigInput(): SagemakerAppImageConfigKernelGatewayImageConfigFileSystemConfig | undefined;
        private _kernelSpec?;
        private __kernelSpecOutput;
        /**
         * @stability stable
         */
        get kernelSpec(): SagemakerAppImageConfigKernelGatewayImageConfigKernelSpecOutputReference;
        /**
         * @stability stable
         */
        putKernelSpec(value: SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec): void;
        /**
         * @stability stable
         */
        get kernelSpecInput(): SagemakerAppImageConfigKernelGatewayImageConfigKernelSpec | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html aws_sagemaker_app_image_config}.
     *
     * @stability stable
     */
    class SagemakerAppImageConfig extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_app_image_config.html aws_sagemaker_app_image_config} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerAppImageConfigConfig);
        private _appImageConfigName?;
        /**
         * @stability stable
         */
        get appImageConfigName(): string;
        /**
         * @stability stable
         */
        set appImageConfigName(value: string);
        /**
         * @stability stable
         */
        get appImageConfigNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _kernelGatewayImageConfig?;
        private __kernelGatewayImageConfigOutput;
        /**
         * @stability stable
         */
        get kernelGatewayImageConfig(): SagemakerAppImageConfigKernelGatewayImageConfigOutputReference;
        /**
         * @stability stable
         */
        putKernelGatewayImageConfig(value: SagemakerAppImageConfigKernelGatewayImageConfig | undefined): void;
        /**
         * @stability stable
         */
        resetKernelGatewayImageConfig(): void;
        /**
         * @stability stable
         */
        get kernelGatewayImageConfigInput(): SagemakerAppImageConfigKernelGatewayImageConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerCodeRepositoryConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository.html#code_repository_name SagemakerCodeRepository#code_repository_name}.
         *
         * @stability stable
         */
        readonly codeRepositoryName: string;
        /**
         * git_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository.html#git_config SagemakerCodeRepository#git_config}
         *
         * @stability stable
         */
        readonly gitConfig: SagemakerCodeRepositoryGitConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerCodeRepositoryGitConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository.html#branch SagemakerCodeRepository#branch}.
         *
         * @stability stable
         */
        readonly branch?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository.html#repository_url SagemakerCodeRepository#repository_url}.
         *
         * @stability stable
         */
        readonly repositoryUrl: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository.html#secret_arn SagemakerCodeRepository#secret_arn}.
         *
         * @stability stable
         */
        readonly secretArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerCodeRepositoryGitConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _branch?;
        /**
         * @stability stable
         */
        get branch(): string | undefined;
        /**
         * @stability stable
         */
        set branch(value: string | undefined);
        /**
         * @stability stable
         */
        resetBranch(): void;
        /**
         * @stability stable
         */
        get branchInput(): string | undefined;
        private _repositoryUrl?;
        /**
         * @stability stable
         */
        get repositoryUrl(): string;
        /**
         * @stability stable
         */
        set repositoryUrl(value: string);
        /**
         * @stability stable
         */
        get repositoryUrlInput(): string | undefined;
        private _secretArn?;
        /**
         * @stability stable
         */
        get secretArn(): string | undefined;
        /**
         * @stability stable
         */
        set secretArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSecretArn(): void;
        /**
         * @stability stable
         */
        get secretArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository.html aws_sagemaker_code_repository}.
     *
     * @stability stable
     */
    class SagemakerCodeRepository extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_code_repository.html aws_sagemaker_code_repository} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerCodeRepositoryConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _codeRepositoryName?;
        /**
         * @stability stable
         */
        get codeRepositoryName(): string;
        /**
         * @stability stable
         */
        set codeRepositoryName(value: string);
        /**
         * @stability stable
         */
        get codeRepositoryNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _gitConfig?;
        private __gitConfigOutput;
        /**
         * @stability stable
         */
        get gitConfig(): SagemakerCodeRepositoryGitConfigOutputReference;
        /**
         * @stability stable
         */
        putGitConfig(value: SagemakerCodeRepositoryGitConfig): void;
        /**
         * @stability stable
         */
        get gitConfigInput(): SagemakerCodeRepositoryGitConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerDeviceFleetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#description SagemakerDeviceFleet#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#device_fleet_name SagemakerDeviceFleet#device_fleet_name}.
         *
         * @stability stable
         */
        readonly deviceFleetName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#enable_iot_role_alias SagemakerDeviceFleet#enable_iot_role_alias}.
         *
         * @stability stable
         */
        readonly enableIotRoleAlias?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#role_arn SagemakerDeviceFleet#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#tags SagemakerDeviceFleet#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#tags_all SagemakerDeviceFleet#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * output_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#output_config SagemakerDeviceFleet#output_config}
         *
         * @stability stable
         */
        readonly outputConfig: SagemakerDeviceFleetOutputConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerDeviceFleetOutputConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#kms_key_id SagemakerDeviceFleet#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html#s3_output_location SagemakerDeviceFleet#s3_output_location}.
         *
         * @stability stable
         */
        readonly s3OutputLocation: string;
    }
    /**
     * @stability stable
     */
    class SagemakerDeviceFleetOutputConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _s3OutputLocation?;
        /**
         * @stability stable
         */
        get s3OutputLocation(): string;
        /**
         * @stability stable
         */
        set s3OutputLocation(value: string);
        /**
         * @stability stable
         */
        get s3OutputLocationInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html aws_sagemaker_device_fleet}.
     *
     * @stability stable
     */
    class SagemakerDeviceFleet extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_device_fleet.html aws_sagemaker_device_fleet} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerDeviceFleetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _deviceFleetName?;
        /**
         * @stability stable
         */
        get deviceFleetName(): string;
        /**
         * @stability stable
         */
        set deviceFleetName(value: string);
        /**
         * @stability stable
         */
        get deviceFleetNameInput(): string | undefined;
        private _enableIotRoleAlias?;
        /**
         * @stability stable
         */
        get enableIotRoleAlias(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableIotRoleAlias(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableIotRoleAlias(): void;
        /**
         * @stability stable
         */
        get enableIotRoleAliasInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get iotRoleAlias(): string;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _outputConfig?;
        private __outputConfigOutput;
        /**
         * @stability stable
         */
        get outputConfig(): SagemakerDeviceFleetOutputConfigOutputReference;
        /**
         * @stability stable
         */
        putOutputConfig(value: SagemakerDeviceFleetOutputConfig): void;
        /**
         * @stability stable
         */
        get outputConfigInput(): SagemakerDeviceFleetOutputConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#app_network_access_type SagemakerDomain#app_network_access_type}.
         *
         * @stability stable
         */
        readonly appNetworkAccessType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#auth_mode SagemakerDomain#auth_mode}.
         *
         * @stability stable
         */
        readonly authMode: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#domain_name SagemakerDomain#domain_name}.
         *
         * @stability stable
         */
        readonly domainName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#kms_key_id SagemakerDomain#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#subnet_ids SagemakerDomain#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#tags SagemakerDomain#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#tags_all SagemakerDomain#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#vpc_id SagemakerDomain#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * default_user_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#default_user_settings SagemakerDomain#default_user_settings}
         *
         * @stability stable
         */
        readonly defaultUserSettings: SagemakerDomainDefaultUserSettings;
        /**
         * retention_policy block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#retention_policy SagemakerDomain#retention_policy}
         *
         * @stability stable
         */
        readonly retentionPolicy?: SagemakerDomainRetentionPolicy;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsDefaultResourceSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#instance_type SagemakerDomain#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#sagemaker_image_arn SagemakerDomain#sagemaker_image_arn}.
         *
         * @stability stable
         */
        readonly sagemakerImageArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsDefaultResourceSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _sagemakerImageArn?;
        /**
         * @stability stable
         */
        get sagemakerImageArn(): string | undefined;
        /**
         * @stability stable
         */
        set sagemakerImageArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSagemakerImageArn(): void;
        /**
         * @stability stable
         */
        get sagemakerImageArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsJupyterServerAppSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#lifecycle_config_arns SagemakerDomain#lifecycle_config_arns}.
         *
         * @stability stable
         */
        readonly lifecycleConfigArns?: string[];
        /**
         * default_resource_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#default_resource_spec SagemakerDomain#default_resource_spec}
         *
         * @stability stable
         */
        readonly defaultResourceSpec?: SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsDefaultResourceSpec;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _lifecycleConfigArns?;
        /**
         * @stability stable
         */
        get lifecycleConfigArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set lifecycleConfigArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetLifecycleConfigArns(): void;
        /**
         * @stability stable
         */
        get lifecycleConfigArnsInput(): string[] | undefined;
        private _defaultResourceSpec?;
        private __defaultResourceSpecOutput;
        /**
         * @stability stable
         */
        get defaultResourceSpec(): SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsDefaultResourceSpecOutputReference;
        /**
         * @stability stable
         */
        putDefaultResourceSpec(value: SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsDefaultResourceSpec | undefined): void;
        /**
         * @stability stable
         */
        resetDefaultResourceSpec(): void;
        /**
         * @stability stable
         */
        get defaultResourceSpecInput(): SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsDefaultResourceSpec | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsCustomImage {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#app_image_config_name SagemakerDomain#app_image_config_name}.
         *
         * @stability stable
         */
        readonly appImageConfigName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#image_name SagemakerDomain#image_name}.
         *
         * @stability stable
         */
        readonly imageName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#image_version_number SagemakerDomain#image_version_number}.
         *
         * @stability stable
         */
        readonly imageVersionNumber?: number;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsDefaultResourceSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#instance_type SagemakerDomain#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#sagemaker_image_arn SagemakerDomain#sagemaker_image_arn}.
         *
         * @stability stable
         */
        readonly sagemakerImageArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsDefaultResourceSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _sagemakerImageArn?;
        /**
         * @stability stable
         */
        get sagemakerImageArn(): string | undefined;
        /**
         * @stability stable
         */
        set sagemakerImageArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSagemakerImageArn(): void;
        /**
         * @stability stable
         */
        get sagemakerImageArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsKernelGatewayAppSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#lifecycle_config_arns SagemakerDomain#lifecycle_config_arns}.
         *
         * @stability stable
         */
        readonly lifecycleConfigArns?: string[];
        /**
         * custom_image block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#custom_image SagemakerDomain#custom_image}
         *
         * @stability stable
         */
        readonly customImage?: SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsCustomImage[];
        /**
         * default_resource_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#default_resource_spec SagemakerDomain#default_resource_spec}
         *
         * @stability stable
         */
        readonly defaultResourceSpec?: SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsDefaultResourceSpec;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _lifecycleConfigArns?;
        /**
         * @stability stable
         */
        get lifecycleConfigArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set lifecycleConfigArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetLifecycleConfigArns(): void;
        /**
         * @stability stable
         */
        get lifecycleConfigArnsInput(): string[] | undefined;
        private _customImage?;
        /**
         * @stability stable
         */
        get customImage(): SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsCustomImage[] | undefined;
        /**
         * @stability stable
         */
        set customImage(value: SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsCustomImage[] | undefined);
        /**
         * @stability stable
         */
        resetCustomImage(): void;
        /**
         * @stability stable
         */
        get customImageInput(): SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsCustomImage[] | undefined;
        private _defaultResourceSpec?;
        private __defaultResourceSpecOutput;
        /**
         * @stability stable
         */
        get defaultResourceSpec(): SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsDefaultResourceSpecOutputReference;
        /**
         * @stability stable
         */
        putDefaultResourceSpec(value: SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsDefaultResourceSpec | undefined): void;
        /**
         * @stability stable
         */
        resetDefaultResourceSpec(): void;
        /**
         * @stability stable
         */
        get defaultResourceSpecInput(): SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsDefaultResourceSpec | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsSharingSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#notebook_output_option SagemakerDomain#notebook_output_option}.
         *
         * @stability stable
         */
        readonly notebookOutputOption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#s3_kms_key_id SagemakerDomain#s3_kms_key_id}.
         *
         * @stability stable
         */
        readonly s3KmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#s3_output_path SagemakerDomain#s3_output_path}.
         *
         * @stability stable
         */
        readonly s3OutputPath?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsSharingSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _notebookOutputOption?;
        /**
         * @stability stable
         */
        get notebookOutputOption(): string | undefined;
        /**
         * @stability stable
         */
        set notebookOutputOption(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotebookOutputOption(): void;
        /**
         * @stability stable
         */
        get notebookOutputOptionInput(): string | undefined;
        private _s3KmsKeyId?;
        /**
         * @stability stable
         */
        get s3KmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set s3KmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3KmsKeyId(): void;
        /**
         * @stability stable
         */
        get s3KmsKeyIdInput(): string | undefined;
        private _s3OutputPath?;
        /**
         * @stability stable
         */
        get s3OutputPath(): string | undefined;
        /**
         * @stability stable
         */
        set s3OutputPath(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3OutputPath(): void;
        /**
         * @stability stable
         */
        get s3OutputPathInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsDefaultResourceSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#instance_type SagemakerDomain#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#sagemaker_image_arn SagemakerDomain#sagemaker_image_arn}.
         *
         * @stability stable
         */
        readonly sagemakerImageArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsDefaultResourceSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _sagemakerImageArn?;
        /**
         * @stability stable
         */
        get sagemakerImageArn(): string | undefined;
        /**
         * @stability stable
         */
        set sagemakerImageArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSagemakerImageArn(): void;
        /**
         * @stability stable
         */
        get sagemakerImageArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettingsTensorBoardAppSettings {
        /**
         * default_resource_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#default_resource_spec SagemakerDomain#default_resource_spec}
         *
         * @stability stable
         */
        readonly defaultResourceSpec?: SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsDefaultResourceSpec;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _defaultResourceSpec?;
        private __defaultResourceSpecOutput;
        /**
         * @stability stable
         */
        get defaultResourceSpec(): SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsDefaultResourceSpecOutputReference;
        /**
         * @stability stable
         */
        putDefaultResourceSpec(value: SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsDefaultResourceSpec | undefined): void;
        /**
         * @stability stable
         */
        resetDefaultResourceSpec(): void;
        /**
         * @stability stable
         */
        get defaultResourceSpecInput(): SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsDefaultResourceSpec | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainDefaultUserSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#execution_role SagemakerDomain#execution_role}.
         *
         * @stability stable
         */
        readonly executionRole: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#security_groups SagemakerDomain#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * jupyter_server_app_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#jupyter_server_app_settings SagemakerDomain#jupyter_server_app_settings}
         *
         * @stability stable
         */
        readonly jupyterServerAppSettings?: SagemakerDomainDefaultUserSettingsJupyterServerAppSettings;
        /**
         * kernel_gateway_app_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#kernel_gateway_app_settings SagemakerDomain#kernel_gateway_app_settings}
         *
         * @stability stable
         */
        readonly kernelGatewayAppSettings?: SagemakerDomainDefaultUserSettingsKernelGatewayAppSettings;
        /**
         * sharing_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#sharing_settings SagemakerDomain#sharing_settings}
         *
         * @stability stable
         */
        readonly sharingSettings?: SagemakerDomainDefaultUserSettingsSharingSettings;
        /**
         * tensor_board_app_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#tensor_board_app_settings SagemakerDomain#tensor_board_app_settings}
         *
         * @stability stable
         */
        readonly tensorBoardAppSettings?: SagemakerDomainDefaultUserSettingsTensorBoardAppSettings;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainDefaultUserSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _executionRole?;
        /**
         * @stability stable
         */
        get executionRole(): string;
        /**
         * @stability stable
         */
        set executionRole(value: string);
        /**
         * @stability stable
         */
        get executionRoleInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _jupyterServerAppSettings?;
        private __jupyterServerAppSettingsOutput;
        /**
         * @stability stable
         */
        get jupyterServerAppSettings(): SagemakerDomainDefaultUserSettingsJupyterServerAppSettingsOutputReference;
        /**
         * @stability stable
         */
        putJupyterServerAppSettings(value: SagemakerDomainDefaultUserSettingsJupyterServerAppSettings | undefined): void;
        /**
         * @stability stable
         */
        resetJupyterServerAppSettings(): void;
        /**
         * @stability stable
         */
        get jupyterServerAppSettingsInput(): SagemakerDomainDefaultUserSettingsJupyterServerAppSettings | undefined;
        private _kernelGatewayAppSettings?;
        private __kernelGatewayAppSettingsOutput;
        /**
         * @stability stable
         */
        get kernelGatewayAppSettings(): SagemakerDomainDefaultUserSettingsKernelGatewayAppSettingsOutputReference;
        /**
         * @stability stable
         */
        putKernelGatewayAppSettings(value: SagemakerDomainDefaultUserSettingsKernelGatewayAppSettings | undefined): void;
        /**
         * @stability stable
         */
        resetKernelGatewayAppSettings(): void;
        /**
         * @stability stable
         */
        get kernelGatewayAppSettingsInput(): SagemakerDomainDefaultUserSettingsKernelGatewayAppSettings | undefined;
        private _sharingSettings?;
        private __sharingSettingsOutput;
        /**
         * @stability stable
         */
        get sharingSettings(): SagemakerDomainDefaultUserSettingsSharingSettingsOutputReference;
        /**
         * @stability stable
         */
        putSharingSettings(value: SagemakerDomainDefaultUserSettingsSharingSettings | undefined): void;
        /**
         * @stability stable
         */
        resetSharingSettings(): void;
        /**
         * @stability stable
         */
        get sharingSettingsInput(): SagemakerDomainDefaultUserSettingsSharingSettings | undefined;
        private _tensorBoardAppSettings?;
        private __tensorBoardAppSettingsOutput;
        /**
         * @stability stable
         */
        get tensorBoardAppSettings(): SagemakerDomainDefaultUserSettingsTensorBoardAppSettingsOutputReference;
        /**
         * @stability stable
         */
        putTensorBoardAppSettings(value: SagemakerDomainDefaultUserSettingsTensorBoardAppSettings | undefined): void;
        /**
         * @stability stable
         */
        resetTensorBoardAppSettings(): void;
        /**
         * @stability stable
         */
        get tensorBoardAppSettingsInput(): SagemakerDomainDefaultUserSettingsTensorBoardAppSettings | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerDomainRetentionPolicy {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html#home_efs_file_system SagemakerDomain#home_efs_file_system}.
         *
         * @stability stable
         */
        readonly homeEfsFileSystem?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerDomainRetentionPolicyOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _homeEfsFileSystem?;
        /**
         * @stability stable
         */
        get homeEfsFileSystem(): string | undefined;
        /**
         * @stability stable
         */
        set homeEfsFileSystem(value: string | undefined);
        /**
         * @stability stable
         */
        resetHomeEfsFileSystem(): void;
        /**
         * @stability stable
         */
        get homeEfsFileSystemInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html aws_sagemaker_domain}.
     *
     * @stability stable
     */
    class SagemakerDomain extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_domain.html aws_sagemaker_domain} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerDomainConfig);
        private _appNetworkAccessType?;
        /**
         * @stability stable
         */
        get appNetworkAccessType(): string | undefined;
        /**
         * @stability stable
         */
        set appNetworkAccessType(value: string | undefined);
        /**
         * @stability stable
         */
        resetAppNetworkAccessType(): void;
        /**
         * @stability stable
         */
        get appNetworkAccessTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _authMode?;
        /**
         * @stability stable
         */
        get authMode(): string;
        /**
         * @stability stable
         */
        set authMode(value: string);
        /**
         * @stability stable
         */
        get authModeInput(): string | undefined;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        set domainName(value: string);
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get homeEfsFileSystemId(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get singleSignOnManagedApplicationInstanceId(): string;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        /**
         * @stability stable
         */
        set subnetIds(value: string[]);
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get url(): string;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _defaultUserSettings?;
        private __defaultUserSettingsOutput;
        /**
         * @stability stable
         */
        get defaultUserSettings(): SagemakerDomainDefaultUserSettingsOutputReference;
        /**
         * @stability stable
         */
        putDefaultUserSettings(value: SagemakerDomainDefaultUserSettings): void;
        /**
         * @stability stable
         */
        get defaultUserSettingsInput(): SagemakerDomainDefaultUserSettings | undefined;
        private _retentionPolicy?;
        private __retentionPolicyOutput;
        /**
         * @stability stable
         */
        get retentionPolicy(): SagemakerDomainRetentionPolicyOutputReference;
        /**
         * @stability stable
         */
        putRetentionPolicy(value: SagemakerDomainRetentionPolicy | undefined): void;
        /**
         * @stability stable
         */
        resetRetentionPolicy(): void;
        /**
         * @stability stable
         */
        get retentionPolicyInput(): SagemakerDomainRetentionPolicy | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint.html#endpoint_config_name SagemakerEndpoint#endpoint_config_name}.
         *
         * @stability stable
         */
        readonly endpointConfigName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint.html#name SagemakerEndpoint#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint.html#tags SagemakerEndpoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint.html#tags_all SagemakerEndpoint#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint.html aws_sagemaker_endpoint}.
     *
     * @stability stable
     */
    class SagemakerEndpoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint.html aws_sagemaker_endpoint} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerEndpointConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _endpointConfigName?;
        /**
         * @stability stable
         */
        get endpointConfigName(): string;
        /**
         * @stability stable
         */
        set endpointConfigName(value: string);
        /**
         * @stability stable
         */
        get endpointConfigNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#kms_key_arn SagemakerEndpointConfiguration#kms_key_arn}.
         *
         * @stability stable
         */
        readonly kmsKeyArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#name SagemakerEndpointConfiguration#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#tags SagemakerEndpointConfiguration#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#tags_all SagemakerEndpointConfiguration#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * async_inference_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#async_inference_config SagemakerEndpointConfiguration#async_inference_config}
         *
         * @stability stable
         */
        readonly asyncInferenceConfig?: SagemakerEndpointConfigurationAsyncInferenceConfig;
        /**
         * data_capture_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#data_capture_config SagemakerEndpointConfiguration#data_capture_config}
         *
         * @stability stable
         */
        readonly dataCaptureConfig?: SagemakerEndpointConfigurationDataCaptureConfig;
        /**
         * production_variants block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#production_variants SagemakerEndpointConfiguration#production_variants}
         *
         * @stability stable
         */
        readonly productionVariants: SagemakerEndpointConfigurationProductionVariants[];
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationAsyncInferenceConfigClientConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#max_concurrent_invocations_per_instance SagemakerEndpointConfiguration#max_concurrent_invocations_per_instance}.
         *
         * @stability stable
         */
        readonly maxConcurrentInvocationsPerInstance?: number;
    }
    /**
     * @stability stable
     */
    class SagemakerEndpointConfigurationAsyncInferenceConfigClientConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _maxConcurrentInvocationsPerInstance?;
        /**
         * @stability stable
         */
        get maxConcurrentInvocationsPerInstance(): number | undefined;
        /**
         * @stability stable
         */
        set maxConcurrentInvocationsPerInstance(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxConcurrentInvocationsPerInstance(): void;
        /**
         * @stability stable
         */
        get maxConcurrentInvocationsPerInstanceInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigNotificationConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#error_topic SagemakerEndpointConfiguration#error_topic}.
         *
         * @stability stable
         */
        readonly errorTopic?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#success_topic SagemakerEndpointConfiguration#success_topic}.
         *
         * @stability stable
         */
        readonly successTopic?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigNotificationConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _errorTopic?;
        /**
         * @stability stable
         */
        get errorTopic(): string | undefined;
        /**
         * @stability stable
         */
        set errorTopic(value: string | undefined);
        /**
         * @stability stable
         */
        resetErrorTopic(): void;
        /**
         * @stability stable
         */
        get errorTopicInput(): string | undefined;
        private _successTopic?;
        /**
         * @stability stable
         */
        get successTopic(): string | undefined;
        /**
         * @stability stable
         */
        set successTopic(value: string | undefined);
        /**
         * @stability stable
         */
        resetSuccessTopic(): void;
        /**
         * @stability stable
         */
        get successTopicInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#kms_key_id SagemakerEndpointConfiguration#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#s3_output_path SagemakerEndpointConfiguration#s3_output_path}.
         *
         * @stability stable
         */
        readonly s3OutputPath: string;
        /**
         * notification_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#notification_config SagemakerEndpointConfiguration#notification_config}
         *
         * @stability stable
         */
        readonly notificationConfig?: SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigNotificationConfig;
    }
    /**
     * @stability stable
     */
    class SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _s3OutputPath?;
        /**
         * @stability stable
         */
        get s3OutputPath(): string;
        /**
         * @stability stable
         */
        set s3OutputPath(value: string);
        /**
         * @stability stable
         */
        get s3OutputPathInput(): string | undefined;
        private _notificationConfig?;
        private __notificationConfigOutput;
        /**
         * @stability stable
         */
        get notificationConfig(): SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigNotificationConfigOutputReference;
        /**
         * @stability stable
         */
        putNotificationConfig(value: SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigNotificationConfig | undefined): void;
        /**
         * @stability stable
         */
        resetNotificationConfig(): void;
        /**
         * @stability stable
         */
        get notificationConfigInput(): SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigNotificationConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationAsyncInferenceConfig {
        /**
         * client_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#client_config SagemakerEndpointConfiguration#client_config}
         *
         * @stability stable
         */
        readonly clientConfig?: SagemakerEndpointConfigurationAsyncInferenceConfigClientConfig;
        /**
         * output_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#output_config SagemakerEndpointConfiguration#output_config}
         *
         * @stability stable
         */
        readonly outputConfig: SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfig;
    }
    /**
     * @stability stable
     */
    class SagemakerEndpointConfigurationAsyncInferenceConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _clientConfig?;
        private __clientConfigOutput;
        /**
         * @stability stable
         */
        get clientConfig(): SagemakerEndpointConfigurationAsyncInferenceConfigClientConfigOutputReference;
        /**
         * @stability stable
         */
        putClientConfig(value: SagemakerEndpointConfigurationAsyncInferenceConfigClientConfig | undefined): void;
        /**
         * @stability stable
         */
        resetClientConfig(): void;
        /**
         * @stability stable
         */
        get clientConfigInput(): SagemakerEndpointConfigurationAsyncInferenceConfigClientConfig | undefined;
        private _outputConfig?;
        private __outputConfigOutput;
        /**
         * @stability stable
         */
        get outputConfig(): SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfigOutputReference;
        /**
         * @stability stable
         */
        putOutputConfig(value: SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfig): void;
        /**
         * @stability stable
         */
        get outputConfigInput(): SagemakerEndpointConfigurationAsyncInferenceConfigOutputConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationDataCaptureConfigCaptureContentTypeHeader {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#csv_content_types SagemakerEndpointConfiguration#csv_content_types}.
         *
         * @stability stable
         */
        readonly csvContentTypes?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#json_content_types SagemakerEndpointConfiguration#json_content_types}.
         *
         * @stability stable
         */
        readonly jsonContentTypes?: string[];
    }
    /**
     * @stability stable
     */
    class SagemakerEndpointConfigurationDataCaptureConfigCaptureContentTypeHeaderOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _csvContentTypes?;
        /**
         * @stability stable
         */
        get csvContentTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set csvContentTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCsvContentTypes(): void;
        /**
         * @stability stable
         */
        get csvContentTypesInput(): string[] | undefined;
        private _jsonContentTypes?;
        /**
         * @stability stable
         */
        get jsonContentTypes(): string[] | undefined;
        /**
         * @stability stable
         */
        set jsonContentTypes(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetJsonContentTypes(): void;
        /**
         * @stability stable
         */
        get jsonContentTypesInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationDataCaptureConfigCaptureOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#capture_mode SagemakerEndpointConfiguration#capture_mode}.
         *
         * @stability stable
         */
        readonly captureMode: string;
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationDataCaptureConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#destination_s3_uri SagemakerEndpointConfiguration#destination_s3_uri}.
         *
         * @stability stable
         */
        readonly destinationS3Uri: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#enable_capture SagemakerEndpointConfiguration#enable_capture}.
         *
         * @stability stable
         */
        readonly enableCapture?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#initial_sampling_percentage SagemakerEndpointConfiguration#initial_sampling_percentage}.
         *
         * @stability stable
         */
        readonly initialSamplingPercentage: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#kms_key_id SagemakerEndpointConfiguration#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * capture_content_type_header block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#capture_content_type_header SagemakerEndpointConfiguration#capture_content_type_header}
         *
         * @stability stable
         */
        readonly captureContentTypeHeader?: SagemakerEndpointConfigurationDataCaptureConfigCaptureContentTypeHeader;
        /**
         * capture_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#capture_options SagemakerEndpointConfiguration#capture_options}
         *
         * @stability stable
         */
        readonly captureOptions: SagemakerEndpointConfigurationDataCaptureConfigCaptureOptions[];
    }
    /**
     * @stability stable
     */
    class SagemakerEndpointConfigurationDataCaptureConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _destinationS3Uri?;
        /**
         * @stability stable
         */
        get destinationS3Uri(): string;
        /**
         * @stability stable
         */
        set destinationS3Uri(value: string);
        /**
         * @stability stable
         */
        get destinationS3UriInput(): string | undefined;
        private _enableCapture?;
        /**
         * @stability stable
         */
        get enableCapture(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableCapture(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableCapture(): void;
        /**
         * @stability stable
         */
        get enableCaptureInput(): boolean | cdktf.IResolvable | undefined;
        private _initialSamplingPercentage?;
        /**
         * @stability stable
         */
        get initialSamplingPercentage(): number;
        /**
         * @stability stable
         */
        set initialSamplingPercentage(value: number);
        /**
         * @stability stable
         */
        get initialSamplingPercentageInput(): number | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _captureContentTypeHeader?;
        private __captureContentTypeHeaderOutput;
        /**
         * @stability stable
         */
        get captureContentTypeHeader(): SagemakerEndpointConfigurationDataCaptureConfigCaptureContentTypeHeaderOutputReference;
        /**
         * @stability stable
         */
        putCaptureContentTypeHeader(value: SagemakerEndpointConfigurationDataCaptureConfigCaptureContentTypeHeader | undefined): void;
        /**
         * @stability stable
         */
        resetCaptureContentTypeHeader(): void;
        /**
         * @stability stable
         */
        get captureContentTypeHeaderInput(): SagemakerEndpointConfigurationDataCaptureConfigCaptureContentTypeHeader | undefined;
        private _captureOptions?;
        /**
         * @stability stable
         */
        get captureOptions(): SagemakerEndpointConfigurationDataCaptureConfigCaptureOptions[];
        /**
         * @stability stable
         */
        set captureOptions(value: SagemakerEndpointConfigurationDataCaptureConfigCaptureOptions[]);
        /**
         * @stability stable
         */
        get captureOptionsInput(): SagemakerEndpointConfigurationDataCaptureConfigCaptureOptions[] | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerEndpointConfigurationProductionVariants {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#accelerator_type SagemakerEndpointConfiguration#accelerator_type}.
         *
         * @stability stable
         */
        readonly acceleratorType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#initial_instance_count SagemakerEndpointConfiguration#initial_instance_count}.
         *
         * @stability stable
         */
        readonly initialInstanceCount: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#initial_variant_weight SagemakerEndpointConfiguration#initial_variant_weight}.
         *
         * @stability stable
         */
        readonly initialVariantWeight?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#instance_type SagemakerEndpointConfiguration#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#model_name SagemakerEndpointConfiguration#model_name}.
         *
         * @stability stable
         */
        readonly modelName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html#variant_name SagemakerEndpointConfiguration#variant_name}.
         *
         * @stability stable
         */
        readonly variantName?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html aws_sagemaker_endpoint_configuration}.
     *
     * @stability stable
     */
    class SagemakerEndpointConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_endpoint_configuration.html aws_sagemaker_endpoint_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerEndpointConfigurationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _kmsKeyArn?;
        /**
         * @stability stable
         */
        get kmsKeyArn(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyArn(): void;
        /**
         * @stability stable
         */
        get kmsKeyArnInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _asyncInferenceConfig?;
        private __asyncInferenceConfigOutput;
        /**
         * @stability stable
         */
        get asyncInferenceConfig(): SagemakerEndpointConfigurationAsyncInferenceConfigOutputReference;
        /**
         * @stability stable
         */
        putAsyncInferenceConfig(value: SagemakerEndpointConfigurationAsyncInferenceConfig | undefined): void;
        /**
         * @stability stable
         */
        resetAsyncInferenceConfig(): void;
        /**
         * @stability stable
         */
        get asyncInferenceConfigInput(): SagemakerEndpointConfigurationAsyncInferenceConfig | undefined;
        private _dataCaptureConfig?;
        private __dataCaptureConfigOutput;
        /**
         * @stability stable
         */
        get dataCaptureConfig(): SagemakerEndpointConfigurationDataCaptureConfigOutputReference;
        /**
         * @stability stable
         */
        putDataCaptureConfig(value: SagemakerEndpointConfigurationDataCaptureConfig | undefined): void;
        /**
         * @stability stable
         */
        resetDataCaptureConfig(): void;
        /**
         * @stability stable
         */
        get dataCaptureConfigInput(): SagemakerEndpointConfigurationDataCaptureConfig | undefined;
        private _productionVariants?;
        /**
         * @stability stable
         */
        get productionVariants(): SagemakerEndpointConfigurationProductionVariants[];
        /**
         * @stability stable
         */
        set productionVariants(value: SagemakerEndpointConfigurationProductionVariants[]);
        /**
         * @stability stable
         */
        get productionVariantsInput(): SagemakerEndpointConfigurationProductionVariants[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerFeatureGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#description SagemakerFeatureGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#event_time_feature_name SagemakerFeatureGroup#event_time_feature_name}.
         *
         * @stability stable
         */
        readonly eventTimeFeatureName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#feature_group_name SagemakerFeatureGroup#feature_group_name}.
         *
         * @stability stable
         */
        readonly featureGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#record_identifier_feature_name SagemakerFeatureGroup#record_identifier_feature_name}.
         *
         * @stability stable
         */
        readonly recordIdentifierFeatureName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#role_arn SagemakerFeatureGroup#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#tags SagemakerFeatureGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#tags_all SagemakerFeatureGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * feature_definition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#feature_definition SagemakerFeatureGroup#feature_definition}
         *
         * @stability stable
         */
        readonly featureDefinition: SagemakerFeatureGroupFeatureDefinition[];
        /**
         * offline_store_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#offline_store_config SagemakerFeatureGroup#offline_store_config}
         *
         * @stability stable
         */
        readonly offlineStoreConfig?: SagemakerFeatureGroupOfflineStoreConfig;
        /**
         * online_store_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#online_store_config SagemakerFeatureGroup#online_store_config}
         *
         * @stability stable
         */
        readonly onlineStoreConfig?: SagemakerFeatureGroupOnlineStoreConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerFeatureGroupFeatureDefinition {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#feature_name SagemakerFeatureGroup#feature_name}.
         *
         * @stability stable
         */
        readonly featureName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#feature_type SagemakerFeatureGroup#feature_type}.
         *
         * @stability stable
         */
        readonly featureType?: string;
    }
    /**
     * @stability stable
     */
    interface SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#catalog SagemakerFeatureGroup#catalog}.
         *
         * @stability stable
         */
        readonly catalog?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#database SagemakerFeatureGroup#database}.
         *
         * @stability stable
         */
        readonly database?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#table_name SagemakerFeatureGroup#table_name}.
         *
         * @stability stable
         */
        readonly tableName?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _catalog?;
        /**
         * @stability stable
         */
        get catalog(): string | undefined;
        /**
         * @stability stable
         */
        set catalog(value: string | undefined);
        /**
         * @stability stable
         */
        resetCatalog(): void;
        /**
         * @stability stable
         */
        get catalogInput(): string | undefined;
        private _database?;
        /**
         * @stability stable
         */
        get database(): string | undefined;
        /**
         * @stability stable
         */
        set database(value: string | undefined);
        /**
         * @stability stable
         */
        resetDatabase(): void;
        /**
         * @stability stable
         */
        get databaseInput(): string | undefined;
        private _tableName?;
        /**
         * @stability stable
         */
        get tableName(): string | undefined;
        /**
         * @stability stable
         */
        set tableName(value: string | undefined);
        /**
         * @stability stable
         */
        resetTableName(): void;
        /**
         * @stability stable
         */
        get tableNameInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#kms_key_id SagemakerFeatureGroup#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#s3_uri SagemakerFeatureGroup#s3_uri}.
         *
         * @stability stable
         */
        readonly s3Uri: string;
    }
    /**
     * @stability stable
     */
    class SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _s3Uri?;
        /**
         * @stability stable
         */
        get s3Uri(): string;
        /**
         * @stability stable
         */
        set s3Uri(value: string);
        /**
         * @stability stable
         */
        get s3UriInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFeatureGroupOfflineStoreConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#disable_glue_table_creation SagemakerFeatureGroup#disable_glue_table_creation}.
         *
         * @stability stable
         */
        readonly disableGlueTableCreation?: boolean | cdktf.IResolvable;
        /**
         * data_catalog_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#data_catalog_config SagemakerFeatureGroup#data_catalog_config}
         *
         * @stability stable
         */
        readonly dataCatalogConfig?: SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig;
        /**
         * s3_storage_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#s3_storage_config SagemakerFeatureGroup#s3_storage_config}
         *
         * @stability stable
         */
        readonly s3StorageConfig: SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig;
    }
    /**
     * @stability stable
     */
    class SagemakerFeatureGroupOfflineStoreConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _disableGlueTableCreation?;
        /**
         * @stability stable
         */
        get disableGlueTableCreation(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set disableGlueTableCreation(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDisableGlueTableCreation(): void;
        /**
         * @stability stable
         */
        get disableGlueTableCreationInput(): boolean | cdktf.IResolvable | undefined;
        private _dataCatalogConfig?;
        private __dataCatalogConfigOutput;
        /**
         * @stability stable
         */
        get dataCatalogConfig(): SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfigOutputReference;
        /**
         * @stability stable
         */
        putDataCatalogConfig(value: SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig | undefined): void;
        /**
         * @stability stable
         */
        resetDataCatalogConfig(): void;
        /**
         * @stability stable
         */
        get dataCatalogConfigInput(): SagemakerFeatureGroupOfflineStoreConfigDataCatalogConfig | undefined;
        private _s3StorageConfig?;
        private __s3StorageConfigOutput;
        /**
         * @stability stable
         */
        get s3StorageConfig(): SagemakerFeatureGroupOfflineStoreConfigS3StorageConfigOutputReference;
        /**
         * @stability stable
         */
        putS3StorageConfig(value: SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig): void;
        /**
         * @stability stable
         */
        get s3StorageConfigInput(): SagemakerFeatureGroupOfflineStoreConfigS3StorageConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFeatureGroupOnlineStoreConfigSecurityConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#kms_key_id SagemakerFeatureGroup#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFeatureGroupOnlineStoreConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#enable_online_store SagemakerFeatureGroup#enable_online_store}.
         *
         * @stability stable
         */
        readonly enableOnlineStore?: boolean | cdktf.IResolvable;
        /**
         * security_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html#security_config SagemakerFeatureGroup#security_config}
         *
         * @stability stable
         */
        readonly securityConfig?: SagemakerFeatureGroupOnlineStoreConfigSecurityConfig;
    }
    /**
     * @stability stable
     */
    class SagemakerFeatureGroupOnlineStoreConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _enableOnlineStore?;
        /**
         * @stability stable
         */
        get enableOnlineStore(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableOnlineStore(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableOnlineStore(): void;
        /**
         * @stability stable
         */
        get enableOnlineStoreInput(): boolean | cdktf.IResolvable | undefined;
        private _securityConfig?;
        private __securityConfigOutput;
        /**
         * @stability stable
         */
        get securityConfig(): SagemakerFeatureGroupOnlineStoreConfigSecurityConfigOutputReference;
        /**
         * @stability stable
         */
        putSecurityConfig(value: SagemakerFeatureGroupOnlineStoreConfigSecurityConfig | undefined): void;
        /**
         * @stability stable
         */
        resetSecurityConfig(): void;
        /**
         * @stability stable
         */
        get securityConfigInput(): SagemakerFeatureGroupOnlineStoreConfigSecurityConfig | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html aws_sagemaker_feature_group}.
     *
     * @stability stable
     */
    class SagemakerFeatureGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_feature_group.html aws_sagemaker_feature_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerFeatureGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _eventTimeFeatureName?;
        /**
         * @stability stable
         */
        get eventTimeFeatureName(): string;
        /**
         * @stability stable
         */
        set eventTimeFeatureName(value: string);
        /**
         * @stability stable
         */
        get eventTimeFeatureNameInput(): string | undefined;
        private _featureGroupName?;
        /**
         * @stability stable
         */
        get featureGroupName(): string;
        /**
         * @stability stable
         */
        set featureGroupName(value: string);
        /**
         * @stability stable
         */
        get featureGroupNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _recordIdentifierFeatureName?;
        /**
         * @stability stable
         */
        get recordIdentifierFeatureName(): string;
        /**
         * @stability stable
         */
        set recordIdentifierFeatureName(value: string);
        /**
         * @stability stable
         */
        get recordIdentifierFeatureNameInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _featureDefinition?;
        /**
         * @stability stable
         */
        get featureDefinition(): SagemakerFeatureGroupFeatureDefinition[];
        /**
         * @stability stable
         */
        set featureDefinition(value: SagemakerFeatureGroupFeatureDefinition[]);
        /**
         * @stability stable
         */
        get featureDefinitionInput(): SagemakerFeatureGroupFeatureDefinition[] | undefined;
        private _offlineStoreConfig?;
        private __offlineStoreConfigOutput;
        /**
         * @stability stable
         */
        get offlineStoreConfig(): SagemakerFeatureGroupOfflineStoreConfigOutputReference;
        /**
         * @stability stable
         */
        putOfflineStoreConfig(value: SagemakerFeatureGroupOfflineStoreConfig | undefined): void;
        /**
         * @stability stable
         */
        resetOfflineStoreConfig(): void;
        /**
         * @stability stable
         */
        get offlineStoreConfigInput(): SagemakerFeatureGroupOfflineStoreConfig | undefined;
        private _onlineStoreConfig?;
        private __onlineStoreConfigOutput;
        /**
         * @stability stable
         */
        get onlineStoreConfig(): SagemakerFeatureGroupOnlineStoreConfigOutputReference;
        /**
         * @stability stable
         */
        putOnlineStoreConfig(value: SagemakerFeatureGroupOnlineStoreConfig | undefined): void;
        /**
         * @stability stable
         */
        resetOnlineStoreConfig(): void;
        /**
         * @stability stable
         */
        get onlineStoreConfigInput(): SagemakerFeatureGroupOnlineStoreConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#flow_definition_name SagemakerFlowDefinition#flow_definition_name}.
         *
         * @stability stable
         */
        readonly flowDefinitionName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#role_arn SagemakerFlowDefinition#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#tags SagemakerFlowDefinition#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#tags_all SagemakerFlowDefinition#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * human_loop_activation_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#human_loop_activation_config SagemakerFlowDefinition#human_loop_activation_config}
         *
         * @stability stable
         */
        readonly humanLoopActivationConfig?: SagemakerFlowDefinitionHumanLoopActivationConfig;
        /**
         * human_loop_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#human_loop_config SagemakerFlowDefinition#human_loop_config}
         *
         * @stability stable
         */
        readonly humanLoopConfig: SagemakerFlowDefinitionHumanLoopConfig;
        /**
         * human_loop_request_source block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#human_loop_request_source SagemakerFlowDefinition#human_loop_request_source}
         *
         * @stability stable
         */
        readonly humanLoopRequestSource?: SagemakerFlowDefinitionHumanLoopRequestSource;
        /**
         * output_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#output_config SagemakerFlowDefinition#output_config}
         *
         * @stability stable
         */
        readonly outputConfig: SagemakerFlowDefinitionOutputConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#human_loop_activation_conditions SagemakerFlowDefinition#human_loop_activation_conditions}.
         *
         * @stability stable
         */
        readonly humanLoopActivationConditions: string;
    }
    /**
     * @stability stable
     */
    class SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _humanLoopActivationConditions?;
        /**
         * @stability stable
         */
        get humanLoopActivationConditions(): string;
        /**
         * @stability stable
         */
        set humanLoopActivationConditions(value: string);
        /**
         * @stability stable
         */
        get humanLoopActivationConditionsInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionHumanLoopActivationConfig {
        /**
         * human_loop_activation_conditions_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#human_loop_activation_conditions_config SagemakerFlowDefinition#human_loop_activation_conditions_config}
         *
         * @stability stable
         */
        readonly humanLoopActivationConditionsConfig?: SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig;
    }
    /**
     * @stability stable
     */
    class SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _humanLoopActivationConditionsConfig?;
        private __humanLoopActivationConditionsConfigOutput;
        /**
         * @stability stable
         */
        get humanLoopActivationConditionsConfig(): SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfigOutputReference;
        /**
         * @stability stable
         */
        putHumanLoopActivationConditionsConfig(value: SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig | undefined): void;
        /**
         * @stability stable
         */
        resetHumanLoopActivationConditionsConfig(): void;
        /**
         * @stability stable
         */
        get humanLoopActivationConditionsConfigInput(): SagemakerFlowDefinitionHumanLoopActivationConfigHumanLoopActivationConditionsConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#cents SagemakerFlowDefinition#cents}.
         *
         * @stability stable
         */
        readonly cents?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#dollars SagemakerFlowDefinition#dollars}.
         *
         * @stability stable
         */
        readonly dollars?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#tenth_fractions_of_a_cent SagemakerFlowDefinition#tenth_fractions_of_a_cent}.
         *
         * @stability stable
         */
        readonly tenthFractionsOfACent?: number;
    }
    /**
     * @stability stable
     */
    class SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cents?;
        /**
         * @stability stable
         */
        get cents(): number | undefined;
        /**
         * @stability stable
         */
        set cents(value: number | undefined);
        /**
         * @stability stable
         */
        resetCents(): void;
        /**
         * @stability stable
         */
        get centsInput(): number | undefined;
        private _dollars?;
        /**
         * @stability stable
         */
        get dollars(): number | undefined;
        /**
         * @stability stable
         */
        set dollars(value: number | undefined);
        /**
         * @stability stable
         */
        resetDollars(): void;
        /**
         * @stability stable
         */
        get dollarsInput(): number | undefined;
        private _tenthFractionsOfACent?;
        /**
         * @stability stable
         */
        get tenthFractionsOfACent(): number | undefined;
        /**
         * @stability stable
         */
        set tenthFractionsOfACent(value: number | undefined);
        /**
         * @stability stable
         */
        resetTenthFractionsOfACent(): void;
        /**
         * @stability stable
         */
        get tenthFractionsOfACentInput(): number | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice {
        /**
         * amount_in_usd block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#amount_in_usd SagemakerFlowDefinition#amount_in_usd}
         *
         * @stability stable
         */
        readonly amountInUsd?: SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd;
    }
    /**
     * @stability stable
     */
    class SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _amountInUsd?;
        private __amountInUsdOutput;
        /**
         * @stability stable
         */
        get amountInUsd(): SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsdOutputReference;
        /**
         * @stability stable
         */
        putAmountInUsd(value: SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd | undefined): void;
        /**
         * @stability stable
         */
        resetAmountInUsd(): void;
        /**
         * @stability stable
         */
        get amountInUsdInput(): SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceAmountInUsd | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionHumanLoopConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#human_task_ui_arn SagemakerFlowDefinition#human_task_ui_arn}.
         *
         * @stability stable
         */
        readonly humanTaskUiArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#task_availability_lifetime_in_seconds SagemakerFlowDefinition#task_availability_lifetime_in_seconds}.
         *
         * @stability stable
         */
        readonly taskAvailabilityLifetimeInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#task_count SagemakerFlowDefinition#task_count}.
         *
         * @stability stable
         */
        readonly taskCount: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#task_description SagemakerFlowDefinition#task_description}.
         *
         * @stability stable
         */
        readonly taskDescription: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#task_keywords SagemakerFlowDefinition#task_keywords}.
         *
         * @stability stable
         */
        readonly taskKeywords?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#task_time_limit_in_seconds SagemakerFlowDefinition#task_time_limit_in_seconds}.
         *
         * @stability stable
         */
        readonly taskTimeLimitInSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#task_title SagemakerFlowDefinition#task_title}.
         *
         * @stability stable
         */
        readonly taskTitle: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#workteam_arn SagemakerFlowDefinition#workteam_arn}.
         *
         * @stability stable
         */
        readonly workteamArn: string;
        /**
         * public_workforce_task_price block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#public_workforce_task_price SagemakerFlowDefinition#public_workforce_task_price}
         *
         * @stability stable
         */
        readonly publicWorkforceTaskPrice?: SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice;
    }
    /**
     * @stability stable
     */
    class SagemakerFlowDefinitionHumanLoopConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _humanTaskUiArn?;
        /**
         * @stability stable
         */
        get humanTaskUiArn(): string;
        /**
         * @stability stable
         */
        set humanTaskUiArn(value: string);
        /**
         * @stability stable
         */
        get humanTaskUiArnInput(): string | undefined;
        private _taskAvailabilityLifetimeInSeconds?;
        /**
         * @stability stable
         */
        get taskAvailabilityLifetimeInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set taskAvailabilityLifetimeInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTaskAvailabilityLifetimeInSeconds(): void;
        /**
         * @stability stable
         */
        get taskAvailabilityLifetimeInSecondsInput(): number | undefined;
        private _taskCount?;
        /**
         * @stability stable
         */
        get taskCount(): number;
        /**
         * @stability stable
         */
        set taskCount(value: number);
        /**
         * @stability stable
         */
        get taskCountInput(): number | undefined;
        private _taskDescription?;
        /**
         * @stability stable
         */
        get taskDescription(): string;
        /**
         * @stability stable
         */
        set taskDescription(value: string);
        /**
         * @stability stable
         */
        get taskDescriptionInput(): string | undefined;
        private _taskKeywords?;
        /**
         * @stability stable
         */
        get taskKeywords(): string[] | undefined;
        /**
         * @stability stable
         */
        set taskKeywords(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTaskKeywords(): void;
        /**
         * @stability stable
         */
        get taskKeywordsInput(): string[] | undefined;
        private _taskTimeLimitInSeconds?;
        /**
         * @stability stable
         */
        get taskTimeLimitInSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set taskTimeLimitInSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTaskTimeLimitInSeconds(): void;
        /**
         * @stability stable
         */
        get taskTimeLimitInSecondsInput(): number | undefined;
        private _taskTitle?;
        /**
         * @stability stable
         */
        get taskTitle(): string;
        /**
         * @stability stable
         */
        set taskTitle(value: string);
        /**
         * @stability stable
         */
        get taskTitleInput(): string | undefined;
        private _workteamArn?;
        /**
         * @stability stable
         */
        get workteamArn(): string;
        /**
         * @stability stable
         */
        set workteamArn(value: string);
        /**
         * @stability stable
         */
        get workteamArnInput(): string | undefined;
        private _publicWorkforceTaskPrice?;
        private __publicWorkforceTaskPriceOutput;
        /**
         * @stability stable
         */
        get publicWorkforceTaskPrice(): SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPriceOutputReference;
        /**
         * @stability stable
         */
        putPublicWorkforceTaskPrice(value: SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice | undefined): void;
        /**
         * @stability stable
         */
        resetPublicWorkforceTaskPrice(): void;
        /**
         * @stability stable
         */
        get publicWorkforceTaskPriceInput(): SagemakerFlowDefinitionHumanLoopConfigPublicWorkforceTaskPrice | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionHumanLoopRequestSource {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#aws_managed_human_loop_request_source SagemakerFlowDefinition#aws_managed_human_loop_request_source}.
         *
         * @stability stable
         */
        readonly awsManagedHumanLoopRequestSource: string;
    }
    /**
     * @stability stable
     */
    class SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _awsManagedHumanLoopRequestSource?;
        /**
         * @stability stable
         */
        get awsManagedHumanLoopRequestSource(): string;
        /**
         * @stability stable
         */
        set awsManagedHumanLoopRequestSource(value: string);
        /**
         * @stability stable
         */
        get awsManagedHumanLoopRequestSourceInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerFlowDefinitionOutputConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#kms_key_id SagemakerFlowDefinition#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html#s3_output_path SagemakerFlowDefinition#s3_output_path}.
         *
         * @stability stable
         */
        readonly s3OutputPath: string;
    }
    /**
     * @stability stable
     */
    class SagemakerFlowDefinitionOutputConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _s3OutputPath?;
        /**
         * @stability stable
         */
        get s3OutputPath(): string;
        /**
         * @stability stable
         */
        set s3OutputPath(value: string);
        /**
         * @stability stable
         */
        get s3OutputPathInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html aws_sagemaker_flow_definition}.
     *
     * @stability stable
     */
    class SagemakerFlowDefinition extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_flow_definition.html aws_sagemaker_flow_definition} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerFlowDefinitionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _flowDefinitionName?;
        /**
         * @stability stable
         */
        get flowDefinitionName(): string;
        /**
         * @stability stable
         */
        set flowDefinitionName(value: string);
        /**
         * @stability stable
         */
        get flowDefinitionNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _humanLoopActivationConfig?;
        private __humanLoopActivationConfigOutput;
        /**
         * @stability stable
         */
        get humanLoopActivationConfig(): SagemakerFlowDefinitionHumanLoopActivationConfigOutputReference;
        /**
         * @stability stable
         */
        putHumanLoopActivationConfig(value: SagemakerFlowDefinitionHumanLoopActivationConfig | undefined): void;
        /**
         * @stability stable
         */
        resetHumanLoopActivationConfig(): void;
        /**
         * @stability stable
         */
        get humanLoopActivationConfigInput(): SagemakerFlowDefinitionHumanLoopActivationConfig | undefined;
        private _humanLoopConfig?;
        private __humanLoopConfigOutput;
        /**
         * @stability stable
         */
        get humanLoopConfig(): SagemakerFlowDefinitionHumanLoopConfigOutputReference;
        /**
         * @stability stable
         */
        putHumanLoopConfig(value: SagemakerFlowDefinitionHumanLoopConfig): void;
        /**
         * @stability stable
         */
        get humanLoopConfigInput(): SagemakerFlowDefinitionHumanLoopConfig | undefined;
        private _humanLoopRequestSource?;
        private __humanLoopRequestSourceOutput;
        /**
         * @stability stable
         */
        get humanLoopRequestSource(): SagemakerFlowDefinitionHumanLoopRequestSourceOutputReference;
        /**
         * @stability stable
         */
        putHumanLoopRequestSource(value: SagemakerFlowDefinitionHumanLoopRequestSource | undefined): void;
        /**
         * @stability stable
         */
        resetHumanLoopRequestSource(): void;
        /**
         * @stability stable
         */
        get humanLoopRequestSourceInput(): SagemakerFlowDefinitionHumanLoopRequestSource | undefined;
        private _outputConfig?;
        private __outputConfigOutput;
        /**
         * @stability stable
         */
        get outputConfig(): SagemakerFlowDefinitionOutputConfigOutputReference;
        /**
         * @stability stable
         */
        putOutputConfig(value: SagemakerFlowDefinitionOutputConfig): void;
        /**
         * @stability stable
         */
        get outputConfigInput(): SagemakerFlowDefinitionOutputConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerHumanTaskUiConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_human_task_ui.html#human_task_ui_name SagemakerHumanTaskUi#human_task_ui_name}.
         *
         * @stability stable
         */
        readonly humanTaskUiName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_human_task_ui.html#tags SagemakerHumanTaskUi#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_human_task_ui.html#tags_all SagemakerHumanTaskUi#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * ui_template block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_human_task_ui.html#ui_template SagemakerHumanTaskUi#ui_template}
         *
         * @stability stable
         */
        readonly uiTemplate: SagemakerHumanTaskUiUiTemplate;
    }
    /**
     * @stability stable
     */
    interface SagemakerHumanTaskUiUiTemplate {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_human_task_ui.html#content SagemakerHumanTaskUi#content}.
         *
         * @stability stable
         */
        readonly content?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerHumanTaskUiUiTemplateOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _content?;
        /**
         * @stability stable
         */
        get content(): string | undefined;
        /**
         * @stability stable
         */
        set content(value: string | undefined);
        /**
         * @stability stable
         */
        resetContent(): void;
        /**
         * @stability stable
         */
        get contentInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_human_task_ui.html aws_sagemaker_human_task_ui}.
     *
     * @stability stable
     */
    class SagemakerHumanTaskUi extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_human_task_ui.html aws_sagemaker_human_task_ui} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerHumanTaskUiConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _humanTaskUiName?;
        /**
         * @stability stable
         */
        get humanTaskUiName(): string;
        /**
         * @stability stable
         */
        set humanTaskUiName(value: string);
        /**
         * @stability stable
         */
        get humanTaskUiNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _uiTemplate?;
        private __uiTemplateOutput;
        /**
         * @stability stable
         */
        get uiTemplate(): SagemakerHumanTaskUiUiTemplateOutputReference;
        /**
         * @stability stable
         */
        putUiTemplate(value: SagemakerHumanTaskUiUiTemplate): void;
        /**
         * @stability stable
         */
        get uiTemplateInput(): SagemakerHumanTaskUiUiTemplate | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerImageConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html#description SagemakerImage#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html#display_name SagemakerImage#display_name}.
         *
         * @stability stable
         */
        readonly displayName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html#image_name SagemakerImage#image_name}.
         *
         * @stability stable
         */
        readonly imageName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html#role_arn SagemakerImage#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html#tags SagemakerImage#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html#tags_all SagemakerImage#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html aws_sagemaker_image}.
     *
     * @stability stable
     */
    class SagemakerImage extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image.html aws_sagemaker_image} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerImageConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _displayName?;
        /**
         * @stability stable
         */
        get displayName(): string | undefined;
        /**
         * @stability stable
         */
        set displayName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDisplayName(): void;
        /**
         * @stability stable
         */
        get displayNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _imageName?;
        /**
         * @stability stable
         */
        get imageName(): string;
        /**
         * @stability stable
         */
        set imageName(value: string);
        /**
         * @stability stable
         */
        get imageNameInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerImageVersionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image_version.html#base_image SagemakerImageVersion#base_image}.
         *
         * @stability stable
         */
        readonly baseImage: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image_version.html#image_name SagemakerImageVersion#image_name}.
         *
         * @stability stable
         */
        readonly imageName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image_version.html aws_sagemaker_image_version}.
     *
     * @stability stable
     */
    class SagemakerImageVersion extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_image_version.html aws_sagemaker_image_version} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerImageVersionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _baseImage?;
        /**
         * @stability stable
         */
        get baseImage(): string;
        /**
         * @stability stable
         */
        set baseImage(value: string);
        /**
         * @stability stable
         */
        get baseImageInput(): string | undefined;
        /**
         * @stability stable
         */
        get containerImage(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get imageArn(): string;
        private _imageName?;
        /**
         * @stability stable
         */
        get imageName(): string;
        /**
         * @stability stable
         */
        set imageName(value: string);
        /**
         * @stability stable
         */
        get imageNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get version(): number;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerModelConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#enable_network_isolation SagemakerModel#enable_network_isolation}.
         *
         * @stability stable
         */
        readonly enableNetworkIsolation?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#execution_role_arn SagemakerModel#execution_role_arn}.
         *
         * @stability stable
         */
        readonly executionRoleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#name SagemakerModel#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#tags SagemakerModel#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#tags_all SagemakerModel#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * container block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#container SagemakerModel#container}
         *
         * @stability stable
         */
        readonly container?: SagemakerModelContainer[];
        /**
         * inference_execution_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#inference_execution_config SagemakerModel#inference_execution_config}
         *
         * @stability stable
         */
        readonly inferenceExecutionConfig?: SagemakerModelInferenceExecutionConfig;
        /**
         * primary_container block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#primary_container SagemakerModel#primary_container}
         *
         * @stability stable
         */
        readonly primaryContainer?: SagemakerModelPrimaryContainer;
        /**
         * vpc_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#vpc_config SagemakerModel#vpc_config}
         *
         * @stability stable
         */
        readonly vpcConfig?: SagemakerModelVpcConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerModelContainerImageConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#repository_access_mode SagemakerModel#repository_access_mode}.
         *
         * @stability stable
         */
        readonly repositoryAccessMode: string;
    }
    /**
     * @stability stable
     */
    class SagemakerModelContainerImageConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _repositoryAccessMode?;
        /**
         * @stability stable
         */
        get repositoryAccessMode(): string;
        /**
         * @stability stable
         */
        set repositoryAccessMode(value: string);
        /**
         * @stability stable
         */
        get repositoryAccessModeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerModelContainer {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#container_hostname SagemakerModel#container_hostname}.
         *
         * @stability stable
         */
        readonly containerHostname?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#environment SagemakerModel#environment}.
         *
         * @stability stable
         */
        readonly environment?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#image SagemakerModel#image}.
         *
         * @stability stable
         */
        readonly image: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#mode SagemakerModel#mode}.
         *
         * @stability stable
         */
        readonly mode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#model_data_url SagemakerModel#model_data_url}.
         *
         * @stability stable
         */
        readonly modelDataUrl?: string;
        /**
         * image_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#image_config SagemakerModel#image_config}
         *
         * @stability stable
         */
        readonly imageConfig?: SagemakerModelContainerImageConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerModelInferenceExecutionConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#mode SagemakerModel#mode}.
         *
         * @stability stable
         */
        readonly mode: string;
    }
    /**
     * @stability stable
     */
    class SagemakerModelInferenceExecutionConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _mode?;
        /**
         * @stability stable
         */
        get mode(): string;
        /**
         * @stability stable
         */
        set mode(value: string);
        /**
         * @stability stable
         */
        get modeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerModelPrimaryContainerImageConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#repository_access_mode SagemakerModel#repository_access_mode}.
         *
         * @stability stable
         */
        readonly repositoryAccessMode: string;
    }
    /**
     * @stability stable
     */
    class SagemakerModelPrimaryContainerImageConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _repositoryAccessMode?;
        /**
         * @stability stable
         */
        get repositoryAccessMode(): string;
        /**
         * @stability stable
         */
        set repositoryAccessMode(value: string);
        /**
         * @stability stable
         */
        get repositoryAccessModeInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerModelPrimaryContainer {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#container_hostname SagemakerModel#container_hostname}.
         *
         * @stability stable
         */
        readonly containerHostname?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#environment SagemakerModel#environment}.
         *
         * @stability stable
         */
        readonly environment?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#image SagemakerModel#image}.
         *
         * @stability stable
         */
        readonly image: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#mode SagemakerModel#mode}.
         *
         * @stability stable
         */
        readonly mode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#model_data_url SagemakerModel#model_data_url}.
         *
         * @stability stable
         */
        readonly modelDataUrl?: string;
        /**
         * image_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#image_config SagemakerModel#image_config}
         *
         * @stability stable
         */
        readonly imageConfig?: SagemakerModelPrimaryContainerImageConfig;
    }
    /**
     * @stability stable
     */
    class SagemakerModelPrimaryContainerOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _containerHostname?;
        /**
         * @stability stable
         */
        get containerHostname(): string | undefined;
        /**
         * @stability stable
         */
        set containerHostname(value: string | undefined);
        /**
         * @stability stable
         */
        resetContainerHostname(): void;
        /**
         * @stability stable
         */
        get containerHostnameInput(): string | undefined;
        private _environment?;
        /**
         * @stability stable
         */
        get environment(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set environment(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnvironment(): void;
        /**
         * @stability stable
         */
        get environmentInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _image?;
        /**
         * @stability stable
         */
        get image(): string;
        /**
         * @stability stable
         */
        set image(value: string);
        /**
         * @stability stable
         */
        get imageInput(): string | undefined;
        private _mode?;
        /**
         * @stability stable
         */
        get mode(): string | undefined;
        /**
         * @stability stable
         */
        set mode(value: string | undefined);
        /**
         * @stability stable
         */
        resetMode(): void;
        /**
         * @stability stable
         */
        get modeInput(): string | undefined;
        private _modelDataUrl?;
        /**
         * @stability stable
         */
        get modelDataUrl(): string | undefined;
        /**
         * @stability stable
         */
        set modelDataUrl(value: string | undefined);
        /**
         * @stability stable
         */
        resetModelDataUrl(): void;
        /**
         * @stability stable
         */
        get modelDataUrlInput(): string | undefined;
        private _imageConfig?;
        private __imageConfigOutput;
        /**
         * @stability stable
         */
        get imageConfig(): SagemakerModelPrimaryContainerImageConfigOutputReference;
        /**
         * @stability stable
         */
        putImageConfig(value: SagemakerModelPrimaryContainerImageConfig | undefined): void;
        /**
         * @stability stable
         */
        resetImageConfig(): void;
        /**
         * @stability stable
         */
        get imageConfigInput(): SagemakerModelPrimaryContainerImageConfig | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerModelVpcConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#security_group_ids SagemakerModel#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html#subnets SagemakerModel#subnets}.
         *
         * @stability stable
         */
        readonly subnets: string[];
    }
    /**
     * @stability stable
     */
    class SagemakerModelVpcConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[];
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[]);
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _subnets?;
        /**
         * @stability stable
         */
        get subnets(): string[];
        /**
         * @stability stable
         */
        set subnets(value: string[]);
        /**
         * @stability stable
         */
        get subnetsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html aws_sagemaker_model}.
     *
     * @stability stable
     */
    class SagemakerModel extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model.html aws_sagemaker_model} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerModelConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _enableNetworkIsolation?;
        /**
         * @stability stable
         */
        get enableNetworkIsolation(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableNetworkIsolation(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableNetworkIsolation(): void;
        /**
         * @stability stable
         */
        get enableNetworkIsolationInput(): boolean | cdktf.IResolvable | undefined;
        private _executionRoleArn?;
        /**
         * @stability stable
         */
        get executionRoleArn(): string;
        /**
         * @stability stable
         */
        set executionRoleArn(value: string);
        /**
         * @stability stable
         */
        get executionRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _container?;
        /**
         * @stability stable
         */
        get container(): SagemakerModelContainer[] | undefined;
        /**
         * @stability stable
         */
        set container(value: SagemakerModelContainer[] | undefined);
        /**
         * @stability stable
         */
        resetContainer(): void;
        /**
         * @stability stable
         */
        get containerInput(): SagemakerModelContainer[] | undefined;
        private _inferenceExecutionConfig?;
        private __inferenceExecutionConfigOutput;
        /**
         * @stability stable
         */
        get inferenceExecutionConfig(): SagemakerModelInferenceExecutionConfigOutputReference;
        /**
         * @stability stable
         */
        putInferenceExecutionConfig(value: SagemakerModelInferenceExecutionConfig | undefined): void;
        /**
         * @stability stable
         */
        resetInferenceExecutionConfig(): void;
        /**
         * @stability stable
         */
        get inferenceExecutionConfigInput(): SagemakerModelInferenceExecutionConfig | undefined;
        private _primaryContainer?;
        private __primaryContainerOutput;
        /**
         * @stability stable
         */
        get primaryContainer(): SagemakerModelPrimaryContainerOutputReference;
        /**
         * @stability stable
         */
        putPrimaryContainer(value: SagemakerModelPrimaryContainer | undefined): void;
        /**
         * @stability stable
         */
        resetPrimaryContainer(): void;
        /**
         * @stability stable
         */
        get primaryContainerInput(): SagemakerModelPrimaryContainer | undefined;
        private _vpcConfig?;
        private __vpcConfigOutput;
        /**
         * @stability stable
         */
        get vpcConfig(): SagemakerModelVpcConfigOutputReference;
        /**
         * @stability stable
         */
        putVpcConfig(value: SagemakerModelVpcConfig | undefined): void;
        /**
         * @stability stable
         */
        resetVpcConfig(): void;
        /**
         * @stability stable
         */
        get vpcConfigInput(): SagemakerModelVpcConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerModelPackageGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group.html#model_package_group_description SagemakerModelPackageGroup#model_package_group_description}.
         *
         * @stability stable
         */
        readonly modelPackageGroupDescription?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group.html#model_package_group_name SagemakerModelPackageGroup#model_package_group_name}.
         *
         * @stability stable
         */
        readonly modelPackageGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group.html#tags SagemakerModelPackageGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group.html#tags_all SagemakerModelPackageGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group.html aws_sagemaker_model_package_group}.
     *
     * @stability stable
     */
    class SagemakerModelPackageGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group.html aws_sagemaker_model_package_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerModelPackageGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _modelPackageGroupDescription?;
        /**
         * @stability stable
         */
        get modelPackageGroupDescription(): string | undefined;
        /**
         * @stability stable
         */
        set modelPackageGroupDescription(value: string | undefined);
        /**
         * @stability stable
         */
        resetModelPackageGroupDescription(): void;
        /**
         * @stability stable
         */
        get modelPackageGroupDescriptionInput(): string | undefined;
        private _modelPackageGroupName?;
        /**
         * @stability stable
         */
        get modelPackageGroupName(): string;
        /**
         * @stability stable
         */
        set modelPackageGroupName(value: string);
        /**
         * @stability stable
         */
        get modelPackageGroupNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerModelPackageGroupPolicyConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group_policy.html#model_package_group_name SagemakerModelPackageGroupPolicy#model_package_group_name}.
         *
         * @stability stable
         */
        readonly modelPackageGroupName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group_policy.html#resource_policy SagemakerModelPackageGroupPolicy#resource_policy}.
         *
         * @stability stable
         */
        readonly resourcePolicy: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group_policy.html aws_sagemaker_model_package_group_policy}.
     *
     * @stability stable
     */
    class SagemakerModelPackageGroupPolicy extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_model_package_group_policy.html aws_sagemaker_model_package_group_policy} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerModelPackageGroupPolicyConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _modelPackageGroupName?;
        /**
         * @stability stable
         */
        get modelPackageGroupName(): string;
        /**
         * @stability stable
         */
        set modelPackageGroupName(value: string);
        /**
         * @stability stable
         */
        get modelPackageGroupNameInput(): string | undefined;
        private _resourcePolicy?;
        /**
         * @stability stable
         */
        get resourcePolicy(): string;
        /**
         * @stability stable
         */
        set resourcePolicy(value: string);
        /**
         * @stability stable
         */
        get resourcePolicyInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerNotebookInstanceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#additional_code_repositories SagemakerNotebookInstance#additional_code_repositories}.
         *
         * @stability stable
         */
        readonly additionalCodeRepositories?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#default_code_repository SagemakerNotebookInstance#default_code_repository}.
         *
         * @stability stable
         */
        readonly defaultCodeRepository?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#direct_internet_access SagemakerNotebookInstance#direct_internet_access}.
         *
         * @stability stable
         */
        readonly directInternetAccess?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#instance_type SagemakerNotebookInstance#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#kms_key_id SagemakerNotebookInstance#kms_key_id}.
         *
         * @stability stable
         */
        readonly kmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#lifecycle_config_name SagemakerNotebookInstance#lifecycle_config_name}.
         *
         * @stability stable
         */
        readonly lifecycleConfigName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#name SagemakerNotebookInstance#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#platform_identifier SagemakerNotebookInstance#platform_identifier}.
         *
         * @stability stable
         */
        readonly platformIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#role_arn SagemakerNotebookInstance#role_arn}.
         *
         * @stability stable
         */
        readonly roleArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#root_access SagemakerNotebookInstance#root_access}.
         *
         * @stability stable
         */
        readonly rootAccess?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#security_groups SagemakerNotebookInstance#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#subnet_id SagemakerNotebookInstance#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#tags SagemakerNotebookInstance#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#tags_all SagemakerNotebookInstance#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html#volume_size SagemakerNotebookInstance#volume_size}.
         *
         * @stability stable
         */
        readonly volumeSize?: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html aws_sagemaker_notebook_instance}.
     *
     * @stability stable
     */
    class SagemakerNotebookInstance extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance.html aws_sagemaker_notebook_instance} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerNotebookInstanceConfig);
        private _additionalCodeRepositories?;
        /**
         * @stability stable
         */
        get additionalCodeRepositories(): string[] | undefined;
        /**
         * @stability stable
         */
        set additionalCodeRepositories(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAdditionalCodeRepositories(): void;
        /**
         * @stability stable
         */
        get additionalCodeRepositoriesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _defaultCodeRepository?;
        /**
         * @stability stable
         */
        get defaultCodeRepository(): string | undefined;
        /**
         * @stability stable
         */
        set defaultCodeRepository(value: string | undefined);
        /**
         * @stability stable
         */
        resetDefaultCodeRepository(): void;
        /**
         * @stability stable
         */
        get defaultCodeRepositoryInput(): string | undefined;
        private _directInternetAccess?;
        /**
         * @stability stable
         */
        get directInternetAccess(): string | undefined;
        /**
         * @stability stable
         */
        set directInternetAccess(value: string | undefined);
        /**
         * @stability stable
         */
        resetDirectInternetAccess(): void;
        /**
         * @stability stable
         */
        get directInternetAccessInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string;
        /**
         * @stability stable
         */
        set instanceType(value: string);
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _kmsKeyId?;
        /**
         * @stability stable
         */
        get kmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set kmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetKmsKeyId(): void;
        /**
         * @stability stable
         */
        get kmsKeyIdInput(): string | undefined;
        private _lifecycleConfigName?;
        /**
         * @stability stable
         */
        get lifecycleConfigName(): string | undefined;
        /**
         * @stability stable
         */
        set lifecycleConfigName(value: string | undefined);
        /**
         * @stability stable
         */
        resetLifecycleConfigName(): void;
        /**
         * @stability stable
         */
        get lifecycleConfigNameInput(): string | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        set name(value: string);
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        private _platformIdentifier?;
        /**
         * @stability stable
         */
        get platformIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set platformIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetPlatformIdentifier(): void;
        /**
         * @stability stable
         */
        get platformIdentifierInput(): string | undefined;
        private _roleArn?;
        /**
         * @stability stable
         */
        get roleArn(): string;
        /**
         * @stability stable
         */
        set roleArn(value: string);
        /**
         * @stability stable
         */
        get roleArnInput(): string | undefined;
        private _rootAccess?;
        /**
         * @stability stable
         */
        get rootAccess(): string | undefined;
        /**
         * @stability stable
         */
        set rootAccess(value: string | undefined);
        /**
         * @stability stable
         */
        resetRootAccess(): void;
        /**
         * @stability stable
         */
        get rootAccessInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get url(): string;
        private _volumeSize?;
        /**
         * @stability stable
         */
        get volumeSize(): number | undefined;
        /**
         * @stability stable
         */
        set volumeSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetVolumeSize(): void;
        /**
         * @stability stable
         */
        get volumeSizeInput(): number | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerNotebookInstanceLifecycleConfigurationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance_lifecycle_configuration.html#name SagemakerNotebookInstanceLifecycleConfiguration#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance_lifecycle_configuration.html#on_create SagemakerNotebookInstanceLifecycleConfiguration#on_create}.
         *
         * @stability stable
         */
        readonly onCreate?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance_lifecycle_configuration.html#on_start SagemakerNotebookInstanceLifecycleConfiguration#on_start}.
         *
         * @stability stable
         */
        readonly onStart?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance_lifecycle_configuration.html aws_sagemaker_notebook_instance_lifecycle_configuration}.
     *
     * @stability stable
     */
    class SagemakerNotebookInstanceLifecycleConfiguration extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_notebook_instance_lifecycle_configuration.html aws_sagemaker_notebook_instance_lifecycle_configuration} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: SagemakerNotebookInstanceLifecycleConfigurationConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _onCreate?;
        /**
         * @stability stable
         */
        get onCreate(): string | undefined;
        /**
         * @stability stable
         */
        set onCreate(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnCreate(): void;
        /**
         * @stability stable
         */
        get onCreateInput(): string | undefined;
        private _onStart?;
        /**
         * @stability stable
         */
        get onStart(): string | undefined;
        /**
         * @stability stable
         */
        set onStart(value: string | undefined);
        /**
         * @stability stable
         */
        resetOnStart(): void;
        /**
         * @stability stable
         */
        get onStartInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerStudioLifecycleConfigConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_studio_lifecycle_config.html#studio_lifecycle_config_app_type SagemakerStudioLifecycleConfig#studio_lifecycle_config_app_type}.
         *
         * @stability stable
         */
        readonly studioLifecycleConfigAppType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_studio_lifecycle_config.html#studio_lifecycle_config_content SagemakerStudioLifecycleConfig#studio_lifecycle_config_content}.
         *
         * @stability stable
         */
        readonly studioLifecycleConfigContent: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_studio_lifecycle_config.html#studio_lifecycle_config_name SagemakerStudioLifecycleConfig#studio_lifecycle_config_name}.
         *
         * @stability stable
         */
        readonly studioLifecycleConfigName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_studio_lifecycle_config.html#tags SagemakerStudioLifecycleConfig#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_studio_lifecycle_config.html#tags_all SagemakerStudioLifecycleConfig#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_studio_lifecycle_config.html aws_sagemaker_studio_lifecycle_config}.
     *
     * @stability stable
     */
    class SagemakerStudioLifecycleConfig extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_studio_lifecycle_config.html aws_sagemaker_studio_lifecycle_config} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerStudioLifecycleConfigConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _studioLifecycleConfigAppType?;
        /**
         * @stability stable
         */
        get studioLifecycleConfigAppType(): string;
        /**
         * @stability stable
         */
        set studioLifecycleConfigAppType(value: string);
        /**
         * @stability stable
         */
        get studioLifecycleConfigAppTypeInput(): string | undefined;
        private _studioLifecycleConfigContent?;
        /**
         * @stability stable
         */
        get studioLifecycleConfigContent(): string;
        /**
         * @stability stable
         */
        set studioLifecycleConfigContent(value: string);
        /**
         * @stability stable
         */
        get studioLifecycleConfigContentInput(): string | undefined;
        private _studioLifecycleConfigName?;
        /**
         * @stability stable
         */
        get studioLifecycleConfigName(): string;
        /**
         * @stability stable
         */
        set studioLifecycleConfigName(value: string);
        /**
         * @stability stable
         */
        get studioLifecycleConfigNameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#domain_id SagemakerUserProfile#domain_id}.
         *
         * @stability stable
         */
        readonly domainId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#single_sign_on_user_identifier SagemakerUserProfile#single_sign_on_user_identifier}.
         *
         * @stability stable
         */
        readonly singleSignOnUserIdentifier?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#single_sign_on_user_value SagemakerUserProfile#single_sign_on_user_value}.
         *
         * @stability stable
         */
        readonly singleSignOnUserValue?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#tags SagemakerUserProfile#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#tags_all SagemakerUserProfile#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#user_profile_name SagemakerUserProfile#user_profile_name}.
         *
         * @stability stable
         */
        readonly userProfileName: string;
        /**
         * user_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#user_settings SagemakerUserProfile#user_settings}
         *
         * @stability stable
         */
        readonly userSettings?: SagemakerUserProfileUserSettings;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsJupyterServerAppSettingsDefaultResourceSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#instance_type SagemakerUserProfile#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#sagemaker_image_arn SagemakerUserProfile#sagemaker_image_arn}.
         *
         * @stability stable
         */
        readonly sagemakerImageArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsJupyterServerAppSettingsDefaultResourceSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _sagemakerImageArn?;
        /**
         * @stability stable
         */
        get sagemakerImageArn(): string | undefined;
        /**
         * @stability stable
         */
        set sagemakerImageArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSagemakerImageArn(): void;
        /**
         * @stability stable
         */
        get sagemakerImageArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsJupyterServerAppSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#lifecycle_config_arns SagemakerUserProfile#lifecycle_config_arns}.
         *
         * @stability stable
         */
        readonly lifecycleConfigArns?: string[];
        /**
         * default_resource_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#default_resource_spec SagemakerUserProfile#default_resource_spec}
         *
         * @stability stable
         */
        readonly defaultResourceSpec: SagemakerUserProfileUserSettingsJupyterServerAppSettingsDefaultResourceSpec;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsJupyterServerAppSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _lifecycleConfigArns?;
        /**
         * @stability stable
         */
        get lifecycleConfigArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set lifecycleConfigArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetLifecycleConfigArns(): void;
        /**
         * @stability stable
         */
        get lifecycleConfigArnsInput(): string[] | undefined;
        private _defaultResourceSpec?;
        private __defaultResourceSpecOutput;
        /**
         * @stability stable
         */
        get defaultResourceSpec(): SagemakerUserProfileUserSettingsJupyterServerAppSettingsDefaultResourceSpecOutputReference;
        /**
         * @stability stable
         */
        putDefaultResourceSpec(value: SagemakerUserProfileUserSettingsJupyterServerAppSettingsDefaultResourceSpec): void;
        /**
         * @stability stable
         */
        get defaultResourceSpecInput(): SagemakerUserProfileUserSettingsJupyterServerAppSettingsDefaultResourceSpec | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsKernelGatewayAppSettingsCustomImage {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#app_image_config_name SagemakerUserProfile#app_image_config_name}.
         *
         * @stability stable
         */
        readonly appImageConfigName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#image_name SagemakerUserProfile#image_name}.
         *
         * @stability stable
         */
        readonly imageName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#image_version_number SagemakerUserProfile#image_version_number}.
         *
         * @stability stable
         */
        readonly imageVersionNumber?: number;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsKernelGatewayAppSettingsDefaultResourceSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#instance_type SagemakerUserProfile#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#sagemaker_image_arn SagemakerUserProfile#sagemaker_image_arn}.
         *
         * @stability stable
         */
        readonly sagemakerImageArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsKernelGatewayAppSettingsDefaultResourceSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _sagemakerImageArn?;
        /**
         * @stability stable
         */
        get sagemakerImageArn(): string | undefined;
        /**
         * @stability stable
         */
        set sagemakerImageArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSagemakerImageArn(): void;
        /**
         * @stability stable
         */
        get sagemakerImageArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsKernelGatewayAppSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#lifecycle_config_arns SagemakerUserProfile#lifecycle_config_arns}.
         *
         * @stability stable
         */
        readonly lifecycleConfigArns?: string[];
        /**
         * custom_image block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#custom_image SagemakerUserProfile#custom_image}
         *
         * @stability stable
         */
        readonly customImage?: SagemakerUserProfileUserSettingsKernelGatewayAppSettingsCustomImage[];
        /**
         * default_resource_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#default_resource_spec SagemakerUserProfile#default_resource_spec}
         *
         * @stability stable
         */
        readonly defaultResourceSpec: SagemakerUserProfileUserSettingsKernelGatewayAppSettingsDefaultResourceSpec;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsKernelGatewayAppSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _lifecycleConfigArns?;
        /**
         * @stability stable
         */
        get lifecycleConfigArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set lifecycleConfigArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetLifecycleConfigArns(): void;
        /**
         * @stability stable
         */
        get lifecycleConfigArnsInput(): string[] | undefined;
        private _customImage?;
        /**
         * @stability stable
         */
        get customImage(): SagemakerUserProfileUserSettingsKernelGatewayAppSettingsCustomImage[] | undefined;
        /**
         * @stability stable
         */
        set customImage(value: SagemakerUserProfileUserSettingsKernelGatewayAppSettingsCustomImage[] | undefined);
        /**
         * @stability stable
         */
        resetCustomImage(): void;
        /**
         * @stability stable
         */
        get customImageInput(): SagemakerUserProfileUserSettingsKernelGatewayAppSettingsCustomImage[] | undefined;
        private _defaultResourceSpec?;
        private __defaultResourceSpecOutput;
        /**
         * @stability stable
         */
        get defaultResourceSpec(): SagemakerUserProfileUserSettingsKernelGatewayAppSettingsDefaultResourceSpecOutputReference;
        /**
         * @stability stable
         */
        putDefaultResourceSpec(value: SagemakerUserProfileUserSettingsKernelGatewayAppSettingsDefaultResourceSpec): void;
        /**
         * @stability stable
         */
        get defaultResourceSpecInput(): SagemakerUserProfileUserSettingsKernelGatewayAppSettingsDefaultResourceSpec | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsSharingSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#notebook_output_option SagemakerUserProfile#notebook_output_option}.
         *
         * @stability stable
         */
        readonly notebookOutputOption?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#s3_kms_key_id SagemakerUserProfile#s3_kms_key_id}.
         *
         * @stability stable
         */
        readonly s3KmsKeyId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#s3_output_path SagemakerUserProfile#s3_output_path}.
         *
         * @stability stable
         */
        readonly s3OutputPath?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsSharingSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _notebookOutputOption?;
        /**
         * @stability stable
         */
        get notebookOutputOption(): string | undefined;
        /**
         * @stability stable
         */
        set notebookOutputOption(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotebookOutputOption(): void;
        /**
         * @stability stable
         */
        get notebookOutputOptionInput(): string | undefined;
        private _s3KmsKeyId?;
        /**
         * @stability stable
         */
        get s3KmsKeyId(): string | undefined;
        /**
         * @stability stable
         */
        set s3KmsKeyId(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3KmsKeyId(): void;
        /**
         * @stability stable
         */
        get s3KmsKeyIdInput(): string | undefined;
        private _s3OutputPath?;
        /**
         * @stability stable
         */
        get s3OutputPath(): string | undefined;
        /**
         * @stability stable
         */
        set s3OutputPath(value: string | undefined);
        /**
         * @stability stable
         */
        resetS3OutputPath(): void;
        /**
         * @stability stable
         */
        get s3OutputPathInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsTensorBoardAppSettingsDefaultResourceSpec {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#instance_type SagemakerUserProfile#instance_type}.
         *
         * @stability stable
         */
        readonly instanceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#sagemaker_image_arn SagemakerUserProfile#sagemaker_image_arn}.
         *
         * @stability stable
         */
        readonly sagemakerImageArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsTensorBoardAppSettingsDefaultResourceSpecOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _instanceType?;
        /**
         * @stability stable
         */
        get instanceType(): string | undefined;
        /**
         * @stability stable
         */
        set instanceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceType(): void;
        /**
         * @stability stable
         */
        get instanceTypeInput(): string | undefined;
        private _sagemakerImageArn?;
        /**
         * @stability stable
         */
        get sagemakerImageArn(): string | undefined;
        /**
         * @stability stable
         */
        set sagemakerImageArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetSagemakerImageArn(): void;
        /**
         * @stability stable
         */
        get sagemakerImageArnInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettingsTensorBoardAppSettings {
        /**
         * default_resource_spec block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#default_resource_spec SagemakerUserProfile#default_resource_spec}
         *
         * @stability stable
         */
        readonly defaultResourceSpec: SagemakerUserProfileUserSettingsTensorBoardAppSettingsDefaultResourceSpec;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsTensorBoardAppSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _defaultResourceSpec?;
        private __defaultResourceSpecOutput;
        /**
         * @stability stable
         */
        get defaultResourceSpec(): SagemakerUserProfileUserSettingsTensorBoardAppSettingsDefaultResourceSpecOutputReference;
        /**
         * @stability stable
         */
        putDefaultResourceSpec(value: SagemakerUserProfileUserSettingsTensorBoardAppSettingsDefaultResourceSpec): void;
        /**
         * @stability stable
         */
        get defaultResourceSpecInput(): SagemakerUserProfileUserSettingsTensorBoardAppSettingsDefaultResourceSpec | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerUserProfileUserSettings {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#execution_role SagemakerUserProfile#execution_role}.
         *
         * @stability stable
         */
        readonly executionRole: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#security_groups SagemakerUserProfile#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * jupyter_server_app_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#jupyter_server_app_settings SagemakerUserProfile#jupyter_server_app_settings}
         *
         * @stability stable
         */
        readonly jupyterServerAppSettings?: SagemakerUserProfileUserSettingsJupyterServerAppSettings;
        /**
         * kernel_gateway_app_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#kernel_gateway_app_settings SagemakerUserProfile#kernel_gateway_app_settings}
         *
         * @stability stable
         */
        readonly kernelGatewayAppSettings?: SagemakerUserProfileUserSettingsKernelGatewayAppSettings;
        /**
         * sharing_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#sharing_settings SagemakerUserProfile#sharing_settings}
         *
         * @stability stable
         */
        readonly sharingSettings?: SagemakerUserProfileUserSettingsSharingSettings;
        /**
         * tensor_board_app_settings block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html#tensor_board_app_settings SagemakerUserProfile#tensor_board_app_settings}
         *
         * @stability stable
         */
        readonly tensorBoardAppSettings?: SagemakerUserProfileUserSettingsTensorBoardAppSettings;
    }
    /**
     * @stability stable
     */
    class SagemakerUserProfileUserSettingsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _executionRole?;
        /**
         * @stability stable
         */
        get executionRole(): string;
        /**
         * @stability stable
         */
        set executionRole(value: string);
        /**
         * @stability stable
         */
        get executionRoleInput(): string | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _jupyterServerAppSettings?;
        private __jupyterServerAppSettingsOutput;
        /**
         * @stability stable
         */
        get jupyterServerAppSettings(): SagemakerUserProfileUserSettingsJupyterServerAppSettingsOutputReference;
        /**
         * @stability stable
         */
        putJupyterServerAppSettings(value: SagemakerUserProfileUserSettingsJupyterServerAppSettings | undefined): void;
        /**
         * @stability stable
         */
        resetJupyterServerAppSettings(): void;
        /**
         * @stability stable
         */
        get jupyterServerAppSettingsInput(): SagemakerUserProfileUserSettingsJupyterServerAppSettings | undefined;
        private _kernelGatewayAppSettings?;
        private __kernelGatewayAppSettingsOutput;
        /**
         * @stability stable
         */
        get kernelGatewayAppSettings(): SagemakerUserProfileUserSettingsKernelGatewayAppSettingsOutputReference;
        /**
         * @stability stable
         */
        putKernelGatewayAppSettings(value: SagemakerUserProfileUserSettingsKernelGatewayAppSettings | undefined): void;
        /**
         * @stability stable
         */
        resetKernelGatewayAppSettings(): void;
        /**
         * @stability stable
         */
        get kernelGatewayAppSettingsInput(): SagemakerUserProfileUserSettingsKernelGatewayAppSettings | undefined;
        private _sharingSettings?;
        private __sharingSettingsOutput;
        /**
         * @stability stable
         */
        get sharingSettings(): SagemakerUserProfileUserSettingsSharingSettingsOutputReference;
        /**
         * @stability stable
         */
        putSharingSettings(value: SagemakerUserProfileUserSettingsSharingSettings | undefined): void;
        /**
         * @stability stable
         */
        resetSharingSettings(): void;
        /**
         * @stability stable
         */
        get sharingSettingsInput(): SagemakerUserProfileUserSettingsSharingSettings | undefined;
        private _tensorBoardAppSettings?;
        private __tensorBoardAppSettingsOutput;
        /**
         * @stability stable
         */
        get tensorBoardAppSettings(): SagemakerUserProfileUserSettingsTensorBoardAppSettingsOutputReference;
        /**
         * @stability stable
         */
        putTensorBoardAppSettings(value: SagemakerUserProfileUserSettingsTensorBoardAppSettings | undefined): void;
        /**
         * @stability stable
         */
        resetTensorBoardAppSettings(): void;
        /**
         * @stability stable
         */
        get tensorBoardAppSettingsInput(): SagemakerUserProfileUserSettingsTensorBoardAppSettings | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html aws_sagemaker_user_profile}.
     *
     * @stability stable
     */
    class SagemakerUserProfile extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_user_profile.html aws_sagemaker_user_profile} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerUserProfileConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _domainId?;
        /**
         * @stability stable
         */
        get domainId(): string;
        /**
         * @stability stable
         */
        set domainId(value: string);
        /**
         * @stability stable
         */
        get domainIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get homeEfsFileSystemUid(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _singleSignOnUserIdentifier?;
        /**
         * @stability stable
         */
        get singleSignOnUserIdentifier(): string | undefined;
        /**
         * @stability stable
         */
        set singleSignOnUserIdentifier(value: string | undefined);
        /**
         * @stability stable
         */
        resetSingleSignOnUserIdentifier(): void;
        /**
         * @stability stable
         */
        get singleSignOnUserIdentifierInput(): string | undefined;
        private _singleSignOnUserValue?;
        /**
         * @stability stable
         */
        get singleSignOnUserValue(): string | undefined;
        /**
         * @stability stable
         */
        set singleSignOnUserValue(value: string | undefined);
        /**
         * @stability stable
         */
        resetSingleSignOnUserValue(): void;
        /**
         * @stability stable
         */
        get singleSignOnUserValueInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _userProfileName?;
        /**
         * @stability stable
         */
        get userProfileName(): string;
        /**
         * @stability stable
         */
        set userProfileName(value: string);
        /**
         * @stability stable
         */
        get userProfileNameInput(): string | undefined;
        private _userSettings?;
        private __userSettingsOutput;
        /**
         * @stability stable
         */
        get userSettings(): SagemakerUserProfileUserSettingsOutputReference;
        /**
         * @stability stable
         */
        putUserSettings(value: SagemakerUserProfileUserSettings | undefined): void;
        /**
         * @stability stable
         */
        resetUserSettings(): void;
        /**
         * @stability stable
         */
        get userSettingsInput(): SagemakerUserProfileUserSettings | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkforceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#workforce_name SagemakerWorkforce#workforce_name}.
         *
         * @stability stable
         */
        readonly workforceName: string;
        /**
         * cognito_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#cognito_config SagemakerWorkforce#cognito_config}
         *
         * @stability stable
         */
        readonly cognitoConfig?: SagemakerWorkforceCognitoConfig;
        /**
         * oidc_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#oidc_config SagemakerWorkforce#oidc_config}
         *
         * @stability stable
         */
        readonly oidcConfig?: SagemakerWorkforceOidcConfig;
        /**
         * source_ip_config block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#source_ip_config SagemakerWorkforce#source_ip_config}
         *
         * @stability stable
         */
        readonly sourceIpConfig?: SagemakerWorkforceSourceIpConfig;
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkforceCognitoConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#client_id SagemakerWorkforce#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#user_pool SagemakerWorkforce#user_pool}.
         *
         * @stability stable
         */
        readonly userPool: string;
    }
    /**
     * @stability stable
     */
    class SagemakerWorkforceCognitoConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _userPool?;
        /**
         * @stability stable
         */
        get userPool(): string;
        /**
         * @stability stable
         */
        set userPool(value: string);
        /**
         * @stability stable
         */
        get userPoolInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkforceOidcConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#authorization_endpoint SagemakerWorkforce#authorization_endpoint}.
         *
         * @stability stable
         */
        readonly authorizationEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#client_id SagemakerWorkforce#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#client_secret SagemakerWorkforce#client_secret}.
         *
         * @stability stable
         */
        readonly clientSecret: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#issuer SagemakerWorkforce#issuer}.
         *
         * @stability stable
         */
        readonly issuer: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#jwks_uri SagemakerWorkforce#jwks_uri}.
         *
         * @stability stable
         */
        readonly jwksUri: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#logout_endpoint SagemakerWorkforce#logout_endpoint}.
         *
         * @stability stable
         */
        readonly logoutEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#token_endpoint SagemakerWorkforce#token_endpoint}.
         *
         * @stability stable
         */
        readonly tokenEndpoint: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#user_info_endpoint SagemakerWorkforce#user_info_endpoint}.
         *
         * @stability stable
         */
        readonly userInfoEndpoint: string;
    }
    /**
     * @stability stable
     */
    class SagemakerWorkforceOidcConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _authorizationEndpoint?;
        /**
         * @stability stable
         */
        get authorizationEndpoint(): string;
        /**
         * @stability stable
         */
        set authorizationEndpoint(value: string);
        /**
         * @stability stable
         */
        get authorizationEndpointInput(): string | undefined;
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _clientSecret?;
        /**
         * @stability stable
         */
        get clientSecret(): string;
        /**
         * @stability stable
         */
        set clientSecret(value: string);
        /**
         * @stability stable
         */
        get clientSecretInput(): string | undefined;
        private _issuer?;
        /**
         * @stability stable
         */
        get issuer(): string;
        /**
         * @stability stable
         */
        set issuer(value: string);
        /**
         * @stability stable
         */
        get issuerInput(): string | undefined;
        private _jwksUri?;
        /**
         * @stability stable
         */
        get jwksUri(): string;
        /**
         * @stability stable
         */
        set jwksUri(value: string);
        /**
         * @stability stable
         */
        get jwksUriInput(): string | undefined;
        private _logoutEndpoint?;
        /**
         * @stability stable
         */
        get logoutEndpoint(): string;
        /**
         * @stability stable
         */
        set logoutEndpoint(value: string);
        /**
         * @stability stable
         */
        get logoutEndpointInput(): string | undefined;
        private _tokenEndpoint?;
        /**
         * @stability stable
         */
        get tokenEndpoint(): string;
        /**
         * @stability stable
         */
        set tokenEndpoint(value: string);
        /**
         * @stability stable
         */
        get tokenEndpointInput(): string | undefined;
        private _userInfoEndpoint?;
        /**
         * @stability stable
         */
        get userInfoEndpoint(): string;
        /**
         * @stability stable
         */
        set userInfoEndpoint(value: string);
        /**
         * @stability stable
         */
        get userInfoEndpointInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkforceSourceIpConfig {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html#cidrs SagemakerWorkforce#cidrs}.
         *
         * @stability stable
         */
        readonly cidrs: string[];
    }
    /**
     * @stability stable
     */
    class SagemakerWorkforceSourceIpConfigOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _cidrs?;
        /**
         * @stability stable
         */
        get cidrs(): string[];
        /**
         * @stability stable
         */
        set cidrs(value: string[]);
        /**
         * @stability stable
         */
        get cidrsInput(): string[] | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html aws_sagemaker_workforce}.
     *
     * @stability stable
     */
    class SagemakerWorkforce extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workforce.html aws_sagemaker_workforce} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerWorkforceConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get subdomain(): string;
        private _workforceName?;
        /**
         * @stability stable
         */
        get workforceName(): string;
        /**
         * @stability stable
         */
        set workforceName(value: string);
        /**
         * @stability stable
         */
        get workforceNameInput(): string | undefined;
        private _cognitoConfig?;
        private __cognitoConfigOutput;
        /**
         * @stability stable
         */
        get cognitoConfig(): SagemakerWorkforceCognitoConfigOutputReference;
        /**
         * @stability stable
         */
        putCognitoConfig(value: SagemakerWorkforceCognitoConfig | undefined): void;
        /**
         * @stability stable
         */
        resetCognitoConfig(): void;
        /**
         * @stability stable
         */
        get cognitoConfigInput(): SagemakerWorkforceCognitoConfig | undefined;
        private _oidcConfig?;
        private __oidcConfigOutput;
        /**
         * @stability stable
         */
        get oidcConfig(): SagemakerWorkforceOidcConfigOutputReference;
        /**
         * @stability stable
         */
        putOidcConfig(value: SagemakerWorkforceOidcConfig | undefined): void;
        /**
         * @stability stable
         */
        resetOidcConfig(): void;
        /**
         * @stability stable
         */
        get oidcConfigInput(): SagemakerWorkforceOidcConfig | undefined;
        private _sourceIpConfig?;
        private __sourceIpConfigOutput;
        /**
         * @stability stable
         */
        get sourceIpConfig(): SagemakerWorkforceSourceIpConfigOutputReference;
        /**
         * @stability stable
         */
        putSourceIpConfig(value: SagemakerWorkforceSourceIpConfig | undefined): void;
        /**
         * @stability stable
         */
        resetSourceIpConfig(): void;
        /**
         * @stability stable
         */
        get sourceIpConfigInput(): SagemakerWorkforceSourceIpConfig | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkteamConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#description SagemakerWorkteam#description}.
         *
         * @stability stable
         */
        readonly description: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#tags SagemakerWorkteam#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#tags_all SagemakerWorkteam#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#workforce_name SagemakerWorkteam#workforce_name}.
         *
         * @stability stable
         */
        readonly workforceName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#workteam_name SagemakerWorkteam#workteam_name}.
         *
         * @stability stable
         */
        readonly workteamName: string;
        /**
         * member_definition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#member_definition SagemakerWorkteam#member_definition}
         *
         * @stability stable
         */
        readonly memberDefinition: SagemakerWorkteamMemberDefinition[];
        /**
         * notification_configuration block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#notification_configuration SagemakerWorkteam#notification_configuration}
         *
         * @stability stable
         */
        readonly notificationConfiguration?: SagemakerWorkteamNotificationConfiguration;
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkteamMemberDefinitionCognitoMemberDefinition {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#client_id SagemakerWorkteam#client_id}.
         *
         * @stability stable
         */
        readonly clientId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#user_group SagemakerWorkteam#user_group}.
         *
         * @stability stable
         */
        readonly userGroup: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#user_pool SagemakerWorkteam#user_pool}.
         *
         * @stability stable
         */
        readonly userPool: string;
    }
    /**
     * @stability stable
     */
    class SagemakerWorkteamMemberDefinitionCognitoMemberDefinitionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _clientId?;
        /**
         * @stability stable
         */
        get clientId(): string;
        /**
         * @stability stable
         */
        set clientId(value: string);
        /**
         * @stability stable
         */
        get clientIdInput(): string | undefined;
        private _userGroup?;
        /**
         * @stability stable
         */
        get userGroup(): string;
        /**
         * @stability stable
         */
        set userGroup(value: string);
        /**
         * @stability stable
         */
        get userGroupInput(): string | undefined;
        private _userPool?;
        /**
         * @stability stable
         */
        get userPool(): string;
        /**
         * @stability stable
         */
        set userPool(value: string);
        /**
         * @stability stable
         */
        get userPoolInput(): string | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkteamMemberDefinitionOidcMemberDefinition {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#groups SagemakerWorkteam#groups}.
         *
         * @stability stable
         */
        readonly groups: string[];
    }
    /**
     * @stability stable
     */
    class SagemakerWorkteamMemberDefinitionOidcMemberDefinitionOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _groups?;
        /**
         * @stability stable
         */
        get groups(): string[];
        /**
         * @stability stable
         */
        set groups(value: string[]);
        /**
         * @stability stable
         */
        get groupsInput(): string[] | undefined;
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkteamMemberDefinition {
        /**
         * cognito_member_definition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#cognito_member_definition SagemakerWorkteam#cognito_member_definition}
         *
         * @stability stable
         */
        readonly cognitoMemberDefinition?: SagemakerWorkteamMemberDefinitionCognitoMemberDefinition;
        /**
         * oidc_member_definition block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#oidc_member_definition SagemakerWorkteam#oidc_member_definition}
         *
         * @stability stable
         */
        readonly oidcMemberDefinition?: SagemakerWorkteamMemberDefinitionOidcMemberDefinition;
    }
    /**
     * @stability stable
     */
    interface SagemakerWorkteamNotificationConfiguration {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html#notification_topic_arn SagemakerWorkteam#notification_topic_arn}.
         *
         * @stability stable
         */
        readonly notificationTopicArn?: string;
    }
    /**
     * @stability stable
     */
    class SagemakerWorkteamNotificationConfigurationOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _notificationTopicArn?;
        /**
         * @stability stable
         */
        get notificationTopicArn(): string | undefined;
        /**
         * @stability stable
         */
        set notificationTopicArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetNotificationTopicArn(): void;
        /**
         * @stability stable
         */
        get notificationTopicArnInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html aws_sagemaker_workteam}.
     *
     * @stability stable
     */
    class SagemakerWorkteam extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/sagemaker_workteam.html aws_sagemaker_workteam} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SagemakerWorkteamConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        set description(value: string);
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get subdomain(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _workforceName?;
        /**
         * @stability stable
         */
        get workforceName(): string;
        /**
         * @stability stable
         */
        set workforceName(value: string);
        /**
         * @stability stable
         */
        get workforceNameInput(): string | undefined;
        private _workteamName?;
        /**
         * @stability stable
         */
        get workteamName(): string;
        /**
         * @stability stable
         */
        set workteamName(value: string);
        /**
         * @stability stable
         */
        get workteamNameInput(): string | undefined;
        private _memberDefinition?;
        /**
         * @stability stable
         */
        get memberDefinition(): SagemakerWorkteamMemberDefinition[];
        /**
         * @stability stable
         */
        set memberDefinition(value: SagemakerWorkteamMemberDefinition[]);
        /**
         * @stability stable
         */
        get memberDefinitionInput(): SagemakerWorkteamMemberDefinition[] | undefined;
        private _notificationConfiguration?;
        private __notificationConfigurationOutput;
        /**
         * @stability stable
         */
        get notificationConfiguration(): SagemakerWorkteamNotificationConfigurationOutputReference;
        /**
         * @stability stable
         */
        putNotificationConfiguration(value: SagemakerWorkteamNotificationConfiguration | undefined): void;
        /**
         * @stability stable
         */
        resetNotificationConfiguration(): void;
        /**
         * @stability stable
         */
        get notificationConfigurationInput(): SagemakerWorkteamNotificationConfiguration | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSagemakerPrebuiltEcrImageConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sagemaker_prebuilt_ecr_image.html#dns_suffix DataAwsSagemakerPrebuiltEcrImage#dns_suffix}.
         *
         * @stability stable
         */
        readonly dnsSuffix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sagemaker_prebuilt_ecr_image.html#image_tag DataAwsSagemakerPrebuiltEcrImage#image_tag}.
         *
         * @stability stable
         */
        readonly imageTag?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sagemaker_prebuilt_ecr_image.html#region DataAwsSagemakerPrebuiltEcrImage#region}.
         *
         * @stability stable
         */
        readonly region?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/sagemaker_prebuilt_ecr_image.html#repository_name DataAwsSagemakerPrebuiltEcrImage#repository_name}.
         *
         * @stability stable
         */
        readonly repositoryName: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/sagemaker_prebuilt_ecr_image.html aws_sagemaker_prebuilt_ecr_image}.
     *
     * @stability stable
     */
    class DataAwsSagemakerPrebuiltEcrImage extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/sagemaker_prebuilt_ecr_image.html aws_sagemaker_prebuilt_ecr_image} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSagemakerPrebuiltEcrImageConfig);
        private _dnsSuffix?;
        /**
         * @stability stable
         */
        get dnsSuffix(): string | undefined;
        /**
         * @stability stable
         */
        set dnsSuffix(value: string | undefined);
        /**
         * @stability stable
         */
        resetDnsSuffix(): void;
        /**
         * @stability stable
         */
        get dnsSuffixInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _imageTag?;
        /**
         * @stability stable
         */
        get imageTag(): string | undefined;
        /**
         * @stability stable
         */
        set imageTag(value: string | undefined);
        /**
         * @stability stable
         */
        resetImageTag(): void;
        /**
         * @stability stable
         */
        get imageTagInput(): string | undefined;
        private _region?;
        /**
         * @stability stable
         */
        get region(): string | undefined;
        /**
         * @stability stable
         */
        set region(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegion(): void;
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
        /**
         * @stability stable
         */
        get registryId(): string;
        /**
         * @stability stable
         */
        get registryPath(): string;
        private _repositoryName?;
        /**
         * @stability stable
         */
        get repositoryName(): string;
        /**
         * @stability stable
         */
        set repositoryName(value: string);
        /**
         * @stability stable
         */
        get repositoryNameInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
