import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
* AWS VPC
*/
export declare namespace VPC {
    /**
     * @stability stable
     */
    interface CustomerGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html#bgp_asn CustomerGateway#bgp_asn}.
         *
         * @stability stable
         */
        readonly bgpAsn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html#device_name CustomerGateway#device_name}.
         *
         * @stability stable
         */
        readonly deviceName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html#ip_address CustomerGateway#ip_address}.
         *
         * @stability stable
         */
        readonly ipAddress: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html#tags CustomerGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html#tags_all CustomerGateway#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html#type CustomerGateway#type}.
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html aws_customer_gateway}.
     *
     * @stability stable
     */
    class CustomerGateway extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/customer_gateway.html aws_customer_gateway} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: CustomerGatewayConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _bgpAsn?;
        /**
         * @stability stable
         */
        get bgpAsn(): string;
        /**
         * @stability stable
         */
        set bgpAsn(value: string);
        /**
         * @stability stable
         */
        get bgpAsnInput(): string | undefined;
        private _deviceName?;
        /**
         * @stability stable
         */
        get deviceName(): string | undefined;
        /**
         * @stability stable
         */
        set deviceName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDeviceName(): void;
        /**
         * @stability stable
         */
        get deviceNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipAddress?;
        /**
         * @stability stable
         */
        get ipAddress(): string;
        /**
         * @stability stable
         */
        set ipAddress(value: string);
        /**
         * @stability stable
         */
        get ipAddressInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DefaultNetworkAclConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#default_network_acl_id DefaultNetworkAcl#default_network_acl_id}.
         *
         * @stability stable
         */
        readonly defaultNetworkAclId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#subnet_ids DefaultNetworkAcl#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#tags DefaultNetworkAcl#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#tags_all DefaultNetworkAcl#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * egress block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#egress DefaultNetworkAcl#egress}
         *
         * @stability stable
         */
        readonly egress?: DefaultNetworkAclEgress[];
        /**
         * ingress block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#ingress DefaultNetworkAcl#ingress}
         *
         * @stability stable
         */
        readonly ingress?: DefaultNetworkAclIngress[];
    }
    /**
     * @stability stable
     */
    interface DefaultNetworkAclEgress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#action DefaultNetworkAcl#action}.
         *
         * @stability stable
         */
        readonly action: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#cidr_block DefaultNetworkAcl#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#from_port DefaultNetworkAcl#from_port}.
         *
         * @stability stable
         */
        readonly fromPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#icmp_code DefaultNetworkAcl#icmp_code}.
         *
         * @stability stable
         */
        readonly icmpCode?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#icmp_type DefaultNetworkAcl#icmp_type}.
         *
         * @stability stable
         */
        readonly icmpType?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#ipv6_cidr_block DefaultNetworkAcl#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#protocol DefaultNetworkAcl#protocol}.
         *
         * @stability stable
         */
        readonly protocol: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#rule_no DefaultNetworkAcl#rule_no}.
         *
         * @stability stable
         */
        readonly ruleNo: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#to_port DefaultNetworkAcl#to_port}.
         *
         * @stability stable
         */
        readonly toPort: number;
    }
    /**
     * @stability stable
     */
    interface DefaultNetworkAclIngress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#action DefaultNetworkAcl#action}.
         *
         * @stability stable
         */
        readonly action: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#cidr_block DefaultNetworkAcl#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#from_port DefaultNetworkAcl#from_port}.
         *
         * @stability stable
         */
        readonly fromPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#icmp_code DefaultNetworkAcl#icmp_code}.
         *
         * @stability stable
         */
        readonly icmpCode?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#icmp_type DefaultNetworkAcl#icmp_type}.
         *
         * @stability stable
         */
        readonly icmpType?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#ipv6_cidr_block DefaultNetworkAcl#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#protocol DefaultNetworkAcl#protocol}.
         *
         * @stability stable
         */
        readonly protocol: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#rule_no DefaultNetworkAcl#rule_no}.
         *
         * @stability stable
         */
        readonly ruleNo: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html#to_port DefaultNetworkAcl#to_port}.
         *
         * @stability stable
         */
        readonly toPort: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html aws_default_network_acl}.
     *
     * @stability stable
     */
    class DefaultNetworkAcl extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_network_acl.html aws_default_network_acl} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DefaultNetworkAclConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _defaultNetworkAclId?;
        /**
         * @stability stable
         */
        get defaultNetworkAclId(): string;
        /**
         * @stability stable
         */
        set defaultNetworkAclId(value: string);
        /**
         * @stability stable
         */
        get defaultNetworkAclIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnetIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetIds(): void;
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _egress?;
        /**
         * @stability stable
         */
        get egress(): DefaultNetworkAclEgress[] | undefined;
        /**
         * @stability stable
         */
        set egress(value: DefaultNetworkAclEgress[] | undefined);
        /**
         * @stability stable
         */
        resetEgress(): void;
        /**
         * @stability stable
         */
        get egressInput(): DefaultNetworkAclEgress[] | undefined;
        private _ingress?;
        /**
         * @stability stable
         */
        get ingress(): DefaultNetworkAclIngress[] | undefined;
        /**
         * @stability stable
         */
        set ingress(value: DefaultNetworkAclIngress[] | undefined);
        /**
         * @stability stable
         */
        resetIngress(): void;
        /**
         * @stability stable
         */
        get ingressInput(): DefaultNetworkAclIngress[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DefaultRouteTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#default_route_table_id DefaultRouteTable#default_route_table_id}.
         *
         * @stability stable
         */
        readonly defaultRouteTableId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#propagating_vgws DefaultRouteTable#propagating_vgws}.
         *
         * @stability stable
         */
        readonly propagatingVgws?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#route DefaultRouteTable#route}.
         *
         * @stability stable
         */
        readonly route?: DefaultRouteTableRoute[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#tags DefaultRouteTable#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#tags_all DefaultRouteTable#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#timeouts DefaultRouteTable#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DefaultRouteTableTimeouts;
    }
    /**
     * @stability stable
     */
    interface DefaultRouteTableRoute {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#cidr_block DefaultRouteTable#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#destination_prefix_list_id DefaultRouteTable#destination_prefix_list_id}.
         *
         * @stability stable
         */
        readonly destinationPrefixListId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#egress_only_gateway_id DefaultRouteTable#egress_only_gateway_id}.
         *
         * @stability stable
         */
        readonly egressOnlyGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#gateway_id DefaultRouteTable#gateway_id}.
         *
         * @stability stable
         */
        readonly gatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#instance_id DefaultRouteTable#instance_id}.
         *
         * @stability stable
         */
        readonly instanceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#ipv6_cidr_block DefaultRouteTable#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#nat_gateway_id DefaultRouteTable#nat_gateway_id}.
         *
         * @stability stable
         */
        readonly natGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#network_interface_id DefaultRouteTable#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#transit_gateway_id DefaultRouteTable#transit_gateway_id}.
         *
         * @stability stable
         */
        readonly transitGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#vpc_endpoint_id DefaultRouteTable#vpc_endpoint_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#vpc_peering_connection_id DefaultRouteTable#vpc_peering_connection_id}.
         *
         * @stability stable
         */
        readonly vpcPeeringConnectionId?: string;
    }
    /**
     * @stability stable
     */
    interface DefaultRouteTableTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#create DefaultRouteTable#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html#update DefaultRouteTable#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class DefaultRouteTableTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html aws_default_route_table}.
     *
     * @stability stable
     */
    class DefaultRouteTable extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_route_table.html aws_default_route_table} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DefaultRouteTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _defaultRouteTableId?;
        /**
         * @stability stable
         */
        get defaultRouteTableId(): string;
        /**
         * @stability stable
         */
        set defaultRouteTableId(value: string);
        /**
         * @stability stable
         */
        get defaultRouteTableIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _propagatingVgws?;
        /**
         * @stability stable
         */
        get propagatingVgws(): string[] | undefined;
        /**
         * @stability stable
         */
        set propagatingVgws(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPropagatingVgws(): void;
        /**
         * @stability stable
         */
        get propagatingVgwsInput(): string[] | undefined;
        private _route?;
        /**
         * @stability stable
         */
        get route(): DefaultRouteTableRoute[] | undefined;
        /**
         * @stability stable
         */
        set route(value: DefaultRouteTableRoute[] | undefined);
        /**
         * @stability stable
         */
        resetRoute(): void;
        /**
         * @stability stable
         */
        get routeInput(): DefaultRouteTableRoute[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DefaultRouteTableTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DefaultRouteTableTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DefaultRouteTableTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DefaultSecurityGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#egress DefaultSecurityGroup#egress}.
         *
         * @stability stable
         */
        readonly egress?: DefaultSecurityGroupEgress[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#ingress DefaultSecurityGroup#ingress}.
         *
         * @stability stable
         */
        readonly ingress?: DefaultSecurityGroupIngress[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#revoke_rules_on_delete DefaultSecurityGroup#revoke_rules_on_delete}.
         *
         * @stability stable
         */
        readonly revokeRulesOnDelete?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#tags DefaultSecurityGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#tags_all DefaultSecurityGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#vpc_id DefaultSecurityGroup#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
    }
    /**
     * @stability stable
     */
    interface DefaultSecurityGroupEgress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#cidr_blocks DefaultSecurityGroup#cidr_blocks}.
         *
         * @stability stable
         */
        readonly cidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#description DefaultSecurityGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#from_port DefaultSecurityGroup#from_port}.
         *
         * @stability stable
         */
        readonly fromPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#ipv6_cidr_blocks DefaultSecurityGroup#ipv6_cidr_blocks}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#prefix_list_ids DefaultSecurityGroup#prefix_list_ids}.
         *
         * @stability stable
         */
        readonly prefixListIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#protocol DefaultSecurityGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#security_groups DefaultSecurityGroup#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#self DefaultSecurityGroup#self}.
         *
         * @stability stable
         */
        readonly selfAttribute?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#to_port DefaultSecurityGroup#to_port}.
         *
         * @stability stable
         */
        readonly toPort?: number;
    }
    /**
     * @stability stable
     */
    interface DefaultSecurityGroupIngress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#cidr_blocks DefaultSecurityGroup#cidr_blocks}.
         *
         * @stability stable
         */
        readonly cidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#description DefaultSecurityGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#from_port DefaultSecurityGroup#from_port}.
         *
         * @stability stable
         */
        readonly fromPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#ipv6_cidr_blocks DefaultSecurityGroup#ipv6_cidr_blocks}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#prefix_list_ids DefaultSecurityGroup#prefix_list_ids}.
         *
         * @stability stable
         */
        readonly prefixListIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#protocol DefaultSecurityGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#security_groups DefaultSecurityGroup#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#self DefaultSecurityGroup#self}.
         *
         * @stability stable
         */
        readonly selfAttribute?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html#to_port DefaultSecurityGroup#to_port}.
         *
         * @stability stable
         */
        readonly toPort?: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html aws_default_security_group}.
     *
     * @stability stable
     */
    class DefaultSecurityGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_security_group.html aws_default_security_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DefaultSecurityGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get description(): string;
        private _egress?;
        /**
         * @stability stable
         */
        get egress(): DefaultSecurityGroupEgress[] | undefined;
        /**
         * @stability stable
         */
        set egress(value: DefaultSecurityGroupEgress[] | undefined);
        /**
         * @stability stable
         */
        resetEgress(): void;
        /**
         * @stability stable
         */
        get egressInput(): DefaultSecurityGroupEgress[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ingress?;
        /**
         * @stability stable
         */
        get ingress(): DefaultSecurityGroupIngress[] | undefined;
        /**
         * @stability stable
         */
        set ingress(value: DefaultSecurityGroupIngress[] | undefined);
        /**
         * @stability stable
         */
        resetIngress(): void;
        /**
         * @stability stable
         */
        get ingressInput(): DefaultSecurityGroupIngress[] | undefined;
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _revokeRulesOnDelete?;
        /**
         * @stability stable
         */
        get revokeRulesOnDelete(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set revokeRulesOnDelete(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRevokeRulesOnDelete(): void;
        /**
         * @stability stable
         */
        get revokeRulesOnDeleteInput(): boolean | cdktf.IResolvable | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DefaultSubnetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#availability_zone DefaultSubnet#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#customer_owned_ipv4_pool DefaultSubnet#customer_owned_ipv4_pool}.
         *
         * @stability stable
         */
        readonly customerOwnedIpv4Pool?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#map_customer_owned_ip_on_launch DefaultSubnet#map_customer_owned_ip_on_launch}.
         *
         * @stability stable
         */
        readonly mapCustomerOwnedIpOnLaunch?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#map_public_ip_on_launch DefaultSubnet#map_public_ip_on_launch}.
         *
         * @stability stable
         */
        readonly mapPublicIpOnLaunch?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#outpost_arn DefaultSubnet#outpost_arn}.
         *
         * @stability stable
         */
        readonly outpostArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#tags DefaultSubnet#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#tags_all DefaultSubnet#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#timeouts DefaultSubnet#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: DefaultSubnetTimeouts;
    }
    /**
     * @stability stable
     */
    interface DefaultSubnetTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#create DefaultSubnet#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html#delete DefaultSubnet#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class DefaultSubnetTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html aws_default_subnet}.
     *
     * @stability stable
     */
    class DefaultSubnet extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_subnet.html aws_default_subnet} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DefaultSubnetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get assignIpv6AddressOnCreation(): any;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        /**
         * @stability stable
         */
        set availabilityZone(value: string);
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        /**
         * @stability stable
         */
        get availabilityZoneId(): string;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        private _customerOwnedIpv4Pool?;
        /**
         * @stability stable
         */
        get customerOwnedIpv4Pool(): string | undefined;
        /**
         * @stability stable
         */
        set customerOwnedIpv4Pool(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerOwnedIpv4Pool(): void;
        /**
         * @stability stable
         */
        get customerOwnedIpv4PoolInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string;
        /**
         * @stability stable
         */
        get ipv6CidrBlockAssociationId(): string;
        private _mapCustomerOwnedIpOnLaunch?;
        /**
         * @stability stable
         */
        get mapCustomerOwnedIpOnLaunch(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mapCustomerOwnedIpOnLaunch(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMapCustomerOwnedIpOnLaunch(): void;
        /**
         * @stability stable
         */
        get mapCustomerOwnedIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
        private _mapPublicIpOnLaunch?;
        /**
         * @stability stable
         */
        get mapPublicIpOnLaunch(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mapPublicIpOnLaunch(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMapPublicIpOnLaunch(): void;
        /**
         * @stability stable
         */
        get mapPublicIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
        private _outpostArn?;
        /**
         * @stability stable
         */
        get outpostArn(): string | undefined;
        /**
         * @stability stable
         */
        set outpostArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutpostArn(): void;
        /**
         * @stability stable
         */
        get outpostArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): DefaultSubnetTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: DefaultSubnetTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): DefaultSubnetTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DefaultVpcConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_classiclink DefaultVpc#enable_classiclink}.
         *
         * @stability stable
         */
        readonly enableClassiclink?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_classiclink_dns_support DefaultVpc#enable_classiclink_dns_support}.
         *
         * @stability stable
         */
        readonly enableClassiclinkDnsSupport?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_dns_hostnames DefaultVpc#enable_dns_hostnames}.
         *
         * @stability stable
         */
        readonly enableDnsHostnames?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#enable_dns_support DefaultVpc#enable_dns_support}.
         *
         * @stability stable
         */
        readonly enableDnsSupport?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#tags DefaultVpc#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html#tags_all DefaultVpc#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html aws_default_vpc}.
     *
     * @stability stable
     */
    class DefaultVpc extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_vpc.html aws_default_vpc} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DefaultVpcConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get assignGeneratedIpv6CidrBlock(): any;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        /**
         * @stability stable
         */
        get defaultNetworkAclId(): string;
        /**
         * @stability stable
         */
        get defaultRouteTableId(): string;
        /**
         * @stability stable
         */
        get defaultSecurityGroupId(): string;
        /**
         * @stability stable
         */
        get dhcpOptionsId(): string;
        private _enableClassiclink?;
        /**
         * @stability stable
         */
        get enableClassiclink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableClassiclink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableClassiclink(): void;
        /**
         * @stability stable
         */
        get enableClassiclinkInput(): boolean | cdktf.IResolvable | undefined;
        private _enableClassiclinkDnsSupport?;
        /**
         * @stability stable
         */
        get enableClassiclinkDnsSupport(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableClassiclinkDnsSupport(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableClassiclinkDnsSupport(): void;
        /**
         * @stability stable
         */
        get enableClassiclinkDnsSupportInput(): boolean | cdktf.IResolvable | undefined;
        private _enableDnsHostnames?;
        /**
         * @stability stable
         */
        get enableDnsHostnames(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableDnsHostnames(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableDnsHostnames(): void;
        /**
         * @stability stable
         */
        get enableDnsHostnamesInput(): boolean | cdktf.IResolvable | undefined;
        private _enableDnsSupport?;
        /**
         * @stability stable
         */
        get enableDnsSupport(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableDnsSupport(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableDnsSupport(): void;
        /**
         * @stability stable
         */
        get enableDnsSupportInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get instanceTenancy(): string;
        /**
         * @stability stable
         */
        get ipv6AssociationId(): string;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string;
        /**
         * @stability stable
         */
        get mainRouteTableId(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DefaultVpcDhcpOptionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc_dhcp_options.html#netbios_name_servers DefaultVpcDhcpOptions#netbios_name_servers}.
         *
         * @stability stable
         */
        readonly netbiosNameServers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc_dhcp_options.html#netbios_node_type DefaultVpcDhcpOptions#netbios_node_type}.
         *
         * @stability stable
         */
        readonly netbiosNodeType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc_dhcp_options.html#owner_id DefaultVpcDhcpOptions#owner_id}.
         *
         * @stability stable
         */
        readonly ownerId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc_dhcp_options.html#tags DefaultVpcDhcpOptions#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/default_vpc_dhcp_options.html#tags_all DefaultVpcDhcpOptions#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/default_vpc_dhcp_options.html aws_default_vpc_dhcp_options}.
     *
     * @stability stable
     */
    class DefaultVpcDhcpOptions extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/default_vpc_dhcp_options.html aws_default_vpc_dhcp_options} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DefaultVpcDhcpOptionsConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        get domainNameServers(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _netbiosNameServers?;
        /**
         * @stability stable
         */
        get netbiosNameServers(): string[] | undefined;
        /**
         * @stability stable
         */
        set netbiosNameServers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetNetbiosNameServers(): void;
        /**
         * @stability stable
         */
        get netbiosNameServersInput(): string[] | undefined;
        private _netbiosNodeType?;
        /**
         * @stability stable
         */
        get netbiosNodeType(): string | undefined;
        /**
         * @stability stable
         */
        set netbiosNodeType(value: string | undefined);
        /**
         * @stability stable
         */
        resetNetbiosNodeType(): void;
        /**
         * @stability stable
         */
        get netbiosNodeTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get ntpServers(): string;
        private _ownerId?;
        /**
         * @stability stable
         */
        get ownerId(): string | undefined;
        /**
         * @stability stable
         */
        set ownerId(value: string | undefined);
        /**
         * @stability stable
         */
        resetOwnerId(): void;
        /**
         * @stability stable
         */
        get ownerIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface EgressOnlyInternetGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/egress_only_internet_gateway.html#tags EgressOnlyInternetGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/egress_only_internet_gateway.html#tags_all EgressOnlyInternetGateway#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/egress_only_internet_gateway.html#vpc_id EgressOnlyInternetGateway#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/egress_only_internet_gateway.html aws_egress_only_internet_gateway}.
     *
     * @stability stable
     */
    class EgressOnlyInternetGateway extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/egress_only_internet_gateway.html aws_egress_only_internet_gateway} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: EgressOnlyInternetGatewayConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface FlowLogConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#eni_id FlowLog#eni_id}.
         *
         * @stability stable
         */
        readonly eniId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#iam_role_arn FlowLog#iam_role_arn}.
         *
         * @stability stable
         */
        readonly iamRoleArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#log_destination FlowLog#log_destination}.
         *
         * @stability stable
         */
        readonly logDestination?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#log_destination_type FlowLog#log_destination_type}.
         *
         * @stability stable
         */
        readonly logDestinationType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#log_format FlowLog#log_format}.
         *
         * @stability stable
         */
        readonly logFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#log_group_name FlowLog#log_group_name}.
         *
         * @stability stable
         */
        readonly logGroupName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#max_aggregation_interval FlowLog#max_aggregation_interval}.
         *
         * @stability stable
         */
        readonly maxAggregationInterval?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#subnet_id FlowLog#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#tags FlowLog#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#tags_all FlowLog#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#traffic_type FlowLog#traffic_type}.
         *
         * @stability stable
         */
        readonly trafficType: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#vpc_id FlowLog#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * destination_options block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#destination_options FlowLog#destination_options}
         *
         * @stability stable
         */
        readonly destinationOptions?: FlowLogDestinationOptions;
    }
    /**
     * @stability stable
     */
    interface FlowLogDestinationOptions {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#file_format FlowLog#file_format}.
         *
         * @stability stable
         */
        readonly fileFormat?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#hive_compatible_partitions FlowLog#hive_compatible_partitions}.
         *
         * @stability stable
         */
        readonly hiveCompatiblePartitions?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html#per_hour_partition FlowLog#per_hour_partition}.
         *
         * @stability stable
         */
        readonly perHourPartition?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class FlowLogDestinationOptionsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _fileFormat?;
        /**
         * @stability stable
         */
        get fileFormat(): string | undefined;
        /**
         * @stability stable
         */
        set fileFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetFileFormat(): void;
        /**
         * @stability stable
         */
        get fileFormatInput(): string | undefined;
        private _hiveCompatiblePartitions?;
        /**
         * @stability stable
         */
        get hiveCompatiblePartitions(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set hiveCompatiblePartitions(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetHiveCompatiblePartitions(): void;
        /**
         * @stability stable
         */
        get hiveCompatiblePartitionsInput(): boolean | cdktf.IResolvable | undefined;
        private _perHourPartition?;
        /**
         * @stability stable
         */
        get perHourPartition(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set perHourPartition(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPerHourPartition(): void;
        /**
         * @stability stable
         */
        get perHourPartitionInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html aws_flow_log}.
     *
     * @stability stable
     */
    class FlowLog extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/flow_log.html aws_flow_log} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: FlowLogConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _eniId?;
        /**
         * @stability stable
         */
        get eniId(): string | undefined;
        /**
         * @stability stable
         */
        set eniId(value: string | undefined);
        /**
         * @stability stable
         */
        resetEniId(): void;
        /**
         * @stability stable
         */
        get eniIdInput(): string | undefined;
        private _iamRoleArn?;
        /**
         * @stability stable
         */
        get iamRoleArn(): string | undefined;
        /**
         * @stability stable
         */
        set iamRoleArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetIamRoleArn(): void;
        /**
         * @stability stable
         */
        get iamRoleArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _logDestination?;
        /**
         * @stability stable
         */
        get logDestination(): string | undefined;
        /**
         * @stability stable
         */
        set logDestination(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogDestination(): void;
        /**
         * @stability stable
         */
        get logDestinationInput(): string | undefined;
        private _logDestinationType?;
        /**
         * @stability stable
         */
        get logDestinationType(): string | undefined;
        /**
         * @stability stable
         */
        set logDestinationType(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogDestinationType(): void;
        /**
         * @stability stable
         */
        get logDestinationTypeInput(): string | undefined;
        private _logFormat?;
        /**
         * @stability stable
         */
        get logFormat(): string | undefined;
        /**
         * @stability stable
         */
        set logFormat(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogFormat(): void;
        /**
         * @stability stable
         */
        get logFormatInput(): string | undefined;
        private _logGroupName?;
        /**
         * @stability stable
         */
        get logGroupName(): string | undefined;
        /**
         * @stability stable
         */
        set logGroupName(value: string | undefined);
        /**
         * @stability stable
         */
        resetLogGroupName(): void;
        /**
         * @stability stable
         */
        get logGroupNameInput(): string | undefined;
        private _maxAggregationInterval?;
        /**
         * @stability stable
         */
        get maxAggregationInterval(): number | undefined;
        /**
         * @stability stable
         */
        set maxAggregationInterval(value: number | undefined);
        /**
         * @stability stable
         */
        resetMaxAggregationInterval(): void;
        /**
         * @stability stable
         */
        get maxAggregationIntervalInput(): number | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _trafficType?;
        /**
         * @stability stable
         */
        get trafficType(): string;
        /**
         * @stability stable
         */
        set trafficType(value: string);
        /**
         * @stability stable
         */
        get trafficTypeInput(): string | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _destinationOptions?;
        private __destinationOptionsOutput;
        /**
         * @stability stable
         */
        get destinationOptions(): FlowLogDestinationOptionsOutputReference;
        /**
         * @stability stable
         */
        putDestinationOptions(value: FlowLogDestinationOptions | undefined): void;
        /**
         * @stability stable
         */
        resetDestinationOptions(): void;
        /**
         * @stability stable
         */
        get destinationOptionsInput(): FlowLogDestinationOptions | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface InternetGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/internet_gateway.html#tags InternetGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/internet_gateway.html#tags_all InternetGateway#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/internet_gateway.html#vpc_id InternetGateway#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/internet_gateway.html aws_internet_gateway}.
     *
     * @stability stable
     */
    class InternetGateway extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/internet_gateway.html aws_internet_gateway} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: InternetGatewayConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface MainRouteTableAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/main_route_table_association.html#route_table_id MainRouteTableAssociation#route_table_id}.
         *
         * @stability stable
         */
        readonly routeTableId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/main_route_table_association.html#vpc_id MainRouteTableAssociation#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/main_route_table_association.html aws_main_route_table_association}.
     *
     * @stability stable
     */
    class MainRouteTableAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/main_route_table_association.html aws_main_route_table_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: MainRouteTableAssociationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get originalRouteTableId(): string;
        private _routeTableId?;
        /**
         * @stability stable
         */
        get routeTableId(): string;
        /**
         * @stability stable
         */
        set routeTableId(value: string);
        /**
         * @stability stable
         */
        get routeTableIdInput(): string | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface NatGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/nat_gateway.html#allocation_id NatGateway#allocation_id}.
         *
         * @stability stable
         */
        readonly allocationId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/nat_gateway.html#connectivity_type NatGateway#connectivity_type}.
         *
         * @stability stable
         */
        readonly connectivityType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/nat_gateway.html#subnet_id NatGateway#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/nat_gateway.html#tags NatGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/nat_gateway.html#tags_all NatGateway#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/nat_gateway.html aws_nat_gateway}.
     *
     * @stability stable
     */
    class NatGateway extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/nat_gateway.html aws_nat_gateway} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: NatGatewayConfig);
        private _allocationId?;
        /**
         * @stability stable
         */
        get allocationId(): string | undefined;
        /**
         * @stability stable
         */
        set allocationId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAllocationId(): void;
        /**
         * @stability stable
         */
        get allocationIdInput(): string | undefined;
        private _connectivityType?;
        /**
         * @stability stable
         */
        get connectivityType(): string | undefined;
        /**
         * @stability stable
         */
        set connectivityType(value: string | undefined);
        /**
         * @stability stable
         */
        resetConnectivityType(): void;
        /**
         * @stability stable
         */
        get connectivityTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        get privateIp(): string;
        /**
         * @stability stable
         */
        get publicIp(): string;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string;
        /**
         * @stability stable
         */
        set subnetId(value: string);
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface NetworkAclConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#egress NetworkAcl#egress}.
         *
         * @stability stable
         */
        readonly egress?: NetworkAclEgress[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#ingress NetworkAcl#ingress}.
         *
         * @stability stable
         */
        readonly ingress?: NetworkAclIngress[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#subnet_ids NetworkAcl#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#tags NetworkAcl#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#tags_all NetworkAcl#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#vpc_id NetworkAcl#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
    }
    /**
     * @stability stable
     */
    interface NetworkAclEgress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#action NetworkAcl#action}.
         *
         * @stability stable
         */
        readonly action?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#cidr_block NetworkAcl#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#from_port NetworkAcl#from_port}.
         *
         * @stability stable
         */
        readonly fromPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#icmp_code NetworkAcl#icmp_code}.
         *
         * @stability stable
         */
        readonly icmpCode?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#icmp_type NetworkAcl#icmp_type}.
         *
         * @stability stable
         */
        readonly icmpType?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#ipv6_cidr_block NetworkAcl#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#protocol NetworkAcl#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#rule_no NetworkAcl#rule_no}.
         *
         * @stability stable
         */
        readonly ruleNo?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#to_port NetworkAcl#to_port}.
         *
         * @stability stable
         */
        readonly toPort?: number;
    }
    /**
     * @stability stable
     */
    interface NetworkAclIngress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#action NetworkAcl#action}.
         *
         * @stability stable
         */
        readonly action?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#cidr_block NetworkAcl#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#from_port NetworkAcl#from_port}.
         *
         * @stability stable
         */
        readonly fromPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#icmp_code NetworkAcl#icmp_code}.
         *
         * @stability stable
         */
        readonly icmpCode?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#icmp_type NetworkAcl#icmp_type}.
         *
         * @stability stable
         */
        readonly icmpType?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#ipv6_cidr_block NetworkAcl#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#protocol NetworkAcl#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#rule_no NetworkAcl#rule_no}.
         *
         * @stability stable
         */
        readonly ruleNo?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html#to_port NetworkAcl#to_port}.
         *
         * @stability stable
         */
        readonly toPort?: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html aws_network_acl}.
     *
     * @stability stable
     */
    class NetworkAcl extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/network_acl.html aws_network_acl} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: NetworkAclConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _egress?;
        /**
         * @stability stable
         */
        get egress(): NetworkAclEgress[] | undefined;
        /**
         * @stability stable
         */
        set egress(value: NetworkAclEgress[] | undefined);
        /**
         * @stability stable
         */
        resetEgress(): void;
        /**
         * @stability stable
         */
        get egressInput(): NetworkAclEgress[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ingress?;
        /**
         * @stability stable
         */
        get ingress(): NetworkAclIngress[] | undefined;
        /**
         * @stability stable
         */
        set ingress(value: NetworkAclIngress[] | undefined);
        /**
         * @stability stable
         */
        resetIngress(): void;
        /**
         * @stability stable
         */
        get ingressInput(): NetworkAclIngress[] | undefined;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnetIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetIds(): void;
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface NetworkAclRuleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#cidr_block NetworkAclRule#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#egress NetworkAclRule#egress}.
         *
         * @stability stable
         */
        readonly egress?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#from_port NetworkAclRule#from_port}.
         *
         * @stability stable
         */
        readonly fromPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#icmp_code NetworkAclRule#icmp_code}.
         *
         * @stability stable
         */
        readonly icmpCode?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#icmp_type NetworkAclRule#icmp_type}.
         *
         * @stability stable
         */
        readonly icmpType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#ipv6_cidr_block NetworkAclRule#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#network_acl_id NetworkAclRule#network_acl_id}.
         *
         * @stability stable
         */
        readonly networkAclId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#protocol NetworkAclRule#protocol}.
         *
         * @stability stable
         */
        readonly protocol: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#rule_action NetworkAclRule#rule_action}.
         *
         * @stability stable
         */
        readonly ruleAction: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#rule_number NetworkAclRule#rule_number}.
         *
         * @stability stable
         */
        readonly ruleNumber: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html#to_port NetworkAclRule#to_port}.
         *
         * @stability stable
         */
        readonly toPort?: number;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html aws_network_acl_rule}.
     *
     * @stability stable
     */
    class NetworkAclRule extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/network_acl_rule.html aws_network_acl_rule} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: NetworkAclRuleConfig);
        private _cidrBlock?;
        /**
         * @stability stable
         */
        get cidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set cidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetCidrBlock(): void;
        /**
         * @stability stable
         */
        get cidrBlockInput(): string | undefined;
        private _egress?;
        /**
         * @stability stable
         */
        get egress(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set egress(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEgress(): void;
        /**
         * @stability stable
         */
        get egressInput(): boolean | cdktf.IResolvable | undefined;
        private _fromPort?;
        /**
         * @stability stable
         */
        get fromPort(): number | undefined;
        /**
         * @stability stable
         */
        set fromPort(value: number | undefined);
        /**
         * @stability stable
         */
        resetFromPort(): void;
        /**
         * @stability stable
         */
        get fromPortInput(): number | undefined;
        private _icmpCode?;
        /**
         * @stability stable
         */
        get icmpCode(): string | undefined;
        /**
         * @stability stable
         */
        set icmpCode(value: string | undefined);
        /**
         * @stability stable
         */
        resetIcmpCode(): void;
        /**
         * @stability stable
         */
        get icmpCodeInput(): string | undefined;
        private _icmpType?;
        /**
         * @stability stable
         */
        get icmpType(): string | undefined;
        /**
         * @stability stable
         */
        set icmpType(value: string | undefined);
        /**
         * @stability stable
         */
        resetIcmpType(): void;
        /**
         * @stability stable
         */
        get icmpTypeInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipv6CidrBlock?;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set ipv6CidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpv6CidrBlock(): void;
        /**
         * @stability stable
         */
        get ipv6CidrBlockInput(): string | undefined;
        private _networkAclId?;
        /**
         * @stability stable
         */
        get networkAclId(): string;
        /**
         * @stability stable
         */
        set networkAclId(value: string);
        /**
         * @stability stable
         */
        get networkAclIdInput(): string | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        set protocol(value: string);
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _ruleAction?;
        /**
         * @stability stable
         */
        get ruleAction(): string;
        /**
         * @stability stable
         */
        set ruleAction(value: string);
        /**
         * @stability stable
         */
        get ruleActionInput(): string | undefined;
        private _ruleNumber?;
        /**
         * @stability stable
         */
        get ruleNumber(): number;
        /**
         * @stability stable
         */
        set ruleNumber(value: number);
        /**
         * @stability stable
         */
        get ruleNumberInput(): number | undefined;
        private _toPort?;
        /**
         * @stability stable
         */
        get toPort(): number | undefined;
        /**
         * @stability stable
         */
        set toPort(value: number | undefined);
        /**
         * @stability stable
         */
        resetToPort(): void;
        /**
         * @stability stable
         */
        get toPortInput(): number | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface NetworkInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#description NetworkInterface#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#interface_type NetworkInterface#interface_type}.
         *
         * @stability stable
         */
        readonly interfaceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#ipv6_address_count NetworkInterface#ipv6_address_count}.
         *
         * @stability stable
         */
        readonly ipv6AddressCount?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#ipv6_addresses NetworkInterface#ipv6_addresses}.
         *
         * @stability stable
         */
        readonly ipv6Addresses?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#private_ip NetworkInterface#private_ip}.
         *
         * @stability stable
         */
        readonly privateIp?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#private_ips NetworkInterface#private_ips}.
         *
         * @stability stable
         */
        readonly privateIps?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#private_ips_count NetworkInterface#private_ips_count}.
         *
         * @stability stable
         */
        readonly privateIpsCount?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#security_groups NetworkInterface#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#source_dest_check NetworkInterface#source_dest_check}.
         *
         * @stability stable
         */
        readonly sourceDestCheck?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#subnet_id NetworkInterface#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#tags NetworkInterface#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#tags_all NetworkInterface#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * attachment block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#attachment NetworkInterface#attachment}
         *
         * @stability stable
         */
        readonly attachment?: NetworkInterfaceAttachment[];
    }
    /**
     * @stability stable
     */
    interface NetworkInterfaceAttachment {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#device_index NetworkInterface#device_index}.
         *
         * @stability stable
         */
        readonly deviceIndex: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html#instance NetworkInterface#instance}.
         *
         * @stability stable
         */
        readonly instance: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html aws_network_interface}.
     *
     * @stability stable
     */
    class NetworkInterface extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/network_interface.html aws_network_interface} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: NetworkInterfaceConfig);
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _interfaceType?;
        /**
         * @stability stable
         */
        get interfaceType(): string | undefined;
        /**
         * @stability stable
         */
        set interfaceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetInterfaceType(): void;
        /**
         * @stability stable
         */
        get interfaceTypeInput(): string | undefined;
        private _ipv6AddressCount?;
        /**
         * @stability stable
         */
        get ipv6AddressCount(): number | undefined;
        /**
         * @stability stable
         */
        set ipv6AddressCount(value: number | undefined);
        /**
         * @stability stable
         */
        resetIpv6AddressCount(): void;
        /**
         * @stability stable
         */
        get ipv6AddressCountInput(): number | undefined;
        private _ipv6Addresses?;
        /**
         * @stability stable
         */
        get ipv6Addresses(): string[] | undefined;
        /**
         * @stability stable
         */
        set ipv6Addresses(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetIpv6Addresses(): void;
        /**
         * @stability stable
         */
        get ipv6AddressesInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get macAddress(): string;
        /**
         * @stability stable
         */
        get outpostArn(): string;
        /**
         * @stability stable
         */
        get privateDnsName(): string;
        private _privateIp?;
        /**
         * @stability stable
         */
        get privateIp(): string | undefined;
        /**
         * @stability stable
         */
        set privateIp(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrivateIp(): void;
        /**
         * @stability stable
         */
        get privateIpInput(): string | undefined;
        private _privateIps?;
        /**
         * @stability stable
         */
        get privateIps(): string[] | undefined;
        /**
         * @stability stable
         */
        set privateIps(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPrivateIps(): void;
        /**
         * @stability stable
         */
        get privateIpsInput(): string[] | undefined;
        private _privateIpsCount?;
        /**
         * @stability stable
         */
        get privateIpsCount(): number | undefined;
        /**
         * @stability stable
         */
        set privateIpsCount(value: number | undefined);
        /**
         * @stability stable
         */
        resetPrivateIpsCount(): void;
        /**
         * @stability stable
         */
        get privateIpsCountInput(): number | undefined;
        private _securityGroups?;
        /**
         * @stability stable
         */
        get securityGroups(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroups(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroups(): void;
        /**
         * @stability stable
         */
        get securityGroupsInput(): string[] | undefined;
        private _sourceDestCheck?;
        /**
         * @stability stable
         */
        get sourceDestCheck(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set sourceDestCheck(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSourceDestCheck(): void;
        /**
         * @stability stable
         */
        get sourceDestCheckInput(): boolean | cdktf.IResolvable | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string;
        /**
         * @stability stable
         */
        set subnetId(value: string);
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _attachment?;
        /**
         * @stability stable
         */
        get attachment(): NetworkInterfaceAttachment[] | undefined;
        /**
         * @stability stable
         */
        set attachment(value: NetworkInterfaceAttachment[] | undefined);
        /**
         * @stability stable
         */
        resetAttachment(): void;
        /**
         * @stability stable
         */
        get attachmentInput(): NetworkInterfaceAttachment[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface NetworkInterfaceAttachmentAConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface_attachment.html#device_index NetworkInterfaceAttachmentA#device_index}.
         *
         * @stability stable
         */
        readonly deviceIndex: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface_attachment.html#instance_id NetworkInterfaceAttachmentA#instance_id}.
         *
         * @stability stable
         */
        readonly instanceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface_attachment.html#network_interface_id NetworkInterfaceAttachmentA#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/network_interface_attachment.html aws_network_interface_attachment}.
     *
     * @stability stable
     */
    class NetworkInterfaceAttachmentA extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/network_interface_attachment.html aws_network_interface_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: NetworkInterfaceAttachmentAConfig);
        /**
         * @stability stable
         */
        get attachmentId(): string;
        private _deviceIndex?;
        /**
         * @stability stable
         */
        get deviceIndex(): number;
        /**
         * @stability stable
         */
        set deviceIndex(value: number);
        /**
         * @stability stable
         */
        get deviceIndexInput(): number | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceId?;
        /**
         * @stability stable
         */
        get instanceId(): string;
        /**
         * @stability stable
         */
        set instanceId(value: string);
        /**
         * @stability stable
         */
        get instanceIdInput(): string | undefined;
        private _networkInterfaceId?;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        set networkInterfaceId(value: string);
        /**
         * @stability stable
         */
        get networkInterfaceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface NetworkInterfaceSgAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface_sg_attachment.html#network_interface_id NetworkInterfaceSgAttachment#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/network_interface_sg_attachment.html#security_group_id NetworkInterfaceSgAttachment#security_group_id}.
         *
         * @stability stable
         */
        readonly securityGroupId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/network_interface_sg_attachment.html aws_network_interface_sg_attachment}.
     *
     * @stability stable
     */
    class NetworkInterfaceSgAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/network_interface_sg_attachment.html aws_network_interface_sg_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: NetworkInterfaceSgAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _networkInterfaceId?;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        set networkInterfaceId(value: string);
        /**
         * @stability stable
         */
        get networkInterfaceIdInput(): string | undefined;
        private _securityGroupId?;
        /**
         * @stability stable
         */
        get securityGroupId(): string;
        /**
         * @stability stable
         */
        set securityGroupId(value: string);
        /**
         * @stability stable
         */
        get securityGroupIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RouteConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#carrier_gateway_id Route#carrier_gateway_id}.
         *
         * @stability stable
         */
        readonly carrierGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#destination_cidr_block Route#destination_cidr_block}.
         *
         * @stability stable
         */
        readonly destinationCidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#destination_ipv6_cidr_block Route#destination_ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly destinationIpv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#destination_prefix_list_id Route#destination_prefix_list_id}.
         *
         * @stability stable
         */
        readonly destinationPrefixListId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#egress_only_gateway_id Route#egress_only_gateway_id}.
         *
         * @stability stable
         */
        readonly egressOnlyGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#gateway_id Route#gateway_id}.
         *
         * @stability stable
         */
        readonly gatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#instance_id Route#instance_id}.
         *
         * @stability stable
         */
        readonly instanceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#local_gateway_id Route#local_gateway_id}.
         *
         * @stability stable
         */
        readonly localGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#nat_gateway_id Route#nat_gateway_id}.
         *
         * @stability stable
         */
        readonly natGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#network_interface_id Route#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#route_table_id Route#route_table_id}.
         *
         * @stability stable
         */
        readonly routeTableId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#transit_gateway_id Route#transit_gateway_id}.
         *
         * @stability stable
         */
        readonly transitGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#vpc_endpoint_id Route#vpc_endpoint_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#vpc_peering_connection_id Route#vpc_peering_connection_id}.
         *
         * @stability stable
         */
        readonly vpcPeeringConnectionId?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#timeouts Route#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: RouteTimeouts;
    }
    /**
     * @stability stable
     */
    interface RouteTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#create Route#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#delete Route#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route.html#update Route#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class RouteTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/route.html aws_route}.
     *
     * @stability stable
     */
    class Route extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/route.html aws_route} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RouteConfig);
        private _carrierGatewayId?;
        /**
         * @stability stable
         */
        get carrierGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set carrierGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCarrierGatewayId(): void;
        /**
         * @stability stable
         */
        get carrierGatewayIdInput(): string | undefined;
        private _destinationCidrBlock?;
        /**
         * @stability stable
         */
        get destinationCidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set destinationCidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetDestinationCidrBlock(): void;
        /**
         * @stability stable
         */
        get destinationCidrBlockInput(): string | undefined;
        private _destinationIpv6CidrBlock?;
        /**
         * @stability stable
         */
        get destinationIpv6CidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set destinationIpv6CidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetDestinationIpv6CidrBlock(): void;
        /**
         * @stability stable
         */
        get destinationIpv6CidrBlockInput(): string | undefined;
        private _destinationPrefixListId?;
        /**
         * @stability stable
         */
        get destinationPrefixListId(): string | undefined;
        /**
         * @stability stable
         */
        set destinationPrefixListId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDestinationPrefixListId(): void;
        /**
         * @stability stable
         */
        get destinationPrefixListIdInput(): string | undefined;
        private _egressOnlyGatewayId?;
        /**
         * @stability stable
         */
        get egressOnlyGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set egressOnlyGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetEgressOnlyGatewayId(): void;
        /**
         * @stability stable
         */
        get egressOnlyGatewayIdInput(): string | undefined;
        private _gatewayId?;
        /**
         * @stability stable
         */
        get gatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set gatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetGatewayId(): void;
        /**
         * @stability stable
         */
        get gatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceId?;
        /**
         * @stability stable
         */
        get instanceId(): string | undefined;
        /**
         * @stability stable
         */
        set instanceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceId(): void;
        /**
         * @stability stable
         */
        get instanceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get instanceOwnerId(): string;
        private _localGatewayId?;
        /**
         * @stability stable
         */
        get localGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set localGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocalGatewayId(): void;
        /**
         * @stability stable
         */
        get localGatewayIdInput(): string | undefined;
        private _natGatewayId?;
        /**
         * @stability stable
         */
        get natGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set natGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetNatGatewayId(): void;
        /**
         * @stability stable
         */
        get natGatewayIdInput(): string | undefined;
        private _networkInterfaceId?;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string | undefined;
        /**
         * @stability stable
         */
        set networkInterfaceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetNetworkInterfaceId(): void;
        /**
         * @stability stable
         */
        get networkInterfaceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get origin(): string;
        private _routeTableId?;
        /**
         * @stability stable
         */
        get routeTableId(): string;
        /**
         * @stability stable
         */
        set routeTableId(value: string);
        /**
         * @stability stable
         */
        get routeTableIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get state(): string;
        private _transitGatewayId?;
        /**
         * @stability stable
         */
        get transitGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set transitGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetTransitGatewayId(): void;
        /**
         * @stability stable
         */
        get transitGatewayIdInput(): string | undefined;
        private _vpcEndpointId?;
        /**
         * @stability stable
         */
        get vpcEndpointId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcEndpointId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcEndpointId(): void;
        /**
         * @stability stable
         */
        get vpcEndpointIdInput(): string | undefined;
        private _vpcPeeringConnectionId?;
        /**
         * @stability stable
         */
        get vpcPeeringConnectionId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcPeeringConnectionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcPeeringConnectionId(): void;
        /**
         * @stability stable
         */
        get vpcPeeringConnectionIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): RouteTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: RouteTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): RouteTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RouteTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#propagating_vgws RouteTable#propagating_vgws}.
         *
         * @stability stable
         */
        readonly propagatingVgws?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#route RouteTable#route}.
         *
         * @stability stable
         */
        readonly route?: RouteTableRoute[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#tags RouteTable#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#tags_all RouteTable#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#vpc_id RouteTable#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#timeouts RouteTable#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: RouteTableTimeouts;
    }
    /**
     * @stability stable
     */
    interface RouteTableRoute {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#carrier_gateway_id RouteTable#carrier_gateway_id}.
         *
         * @stability stable
         */
        readonly carrierGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#cidr_block RouteTable#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#destination_prefix_list_id RouteTable#destination_prefix_list_id}.
         *
         * @stability stable
         */
        readonly destinationPrefixListId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#egress_only_gateway_id RouteTable#egress_only_gateway_id}.
         *
         * @stability stable
         */
        readonly egressOnlyGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#gateway_id RouteTable#gateway_id}.
         *
         * @stability stable
         */
        readonly gatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#instance_id RouteTable#instance_id}.
         *
         * @stability stable
         */
        readonly instanceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#ipv6_cidr_block RouteTable#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#local_gateway_id RouteTable#local_gateway_id}.
         *
         * @stability stable
         */
        readonly localGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#nat_gateway_id RouteTable#nat_gateway_id}.
         *
         * @stability stable
         */
        readonly natGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#network_interface_id RouteTable#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#transit_gateway_id RouteTable#transit_gateway_id}.
         *
         * @stability stable
         */
        readonly transitGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#vpc_endpoint_id RouteTable#vpc_endpoint_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#vpc_peering_connection_id RouteTable#vpc_peering_connection_id}.
         *
         * @stability stable
         */
        readonly vpcPeeringConnectionId?: string;
    }
    /**
     * @stability stable
     */
    interface RouteTableTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#create RouteTable#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#delete RouteTable#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table.html#update RouteTable#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class RouteTableTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/route_table.html aws_route_table}.
     *
     * @stability stable
     */
    class RouteTable extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/route_table.html aws_route_table} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RouteTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _propagatingVgws?;
        /**
         * @stability stable
         */
        get propagatingVgws(): string[] | undefined;
        /**
         * @stability stable
         */
        set propagatingVgws(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPropagatingVgws(): void;
        /**
         * @stability stable
         */
        get propagatingVgwsInput(): string[] | undefined;
        private _route?;
        /**
         * @stability stable
         */
        get route(): RouteTableRoute[] | undefined;
        /**
         * @stability stable
         */
        set route(value: RouteTableRoute[] | undefined);
        /**
         * @stability stable
         */
        resetRoute(): void;
        /**
         * @stability stable
         */
        get routeInput(): RouteTableRoute[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): RouteTableTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: RouteTableTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): RouteTableTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface RouteTableAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table_association.html#gateway_id RouteTableAssociation#gateway_id}.
         *
         * @stability stable
         */
        readonly gatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table_association.html#route_table_id RouteTableAssociation#route_table_id}.
         *
         * @stability stable
         */
        readonly routeTableId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/route_table_association.html#subnet_id RouteTableAssociation#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/route_table_association.html aws_route_table_association}.
     *
     * @stability stable
     */
    class RouteTableAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/route_table_association.html aws_route_table_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: RouteTableAssociationConfig);
        private _gatewayId?;
        /**
         * @stability stable
         */
        get gatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set gatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetGatewayId(): void;
        /**
         * @stability stable
         */
        get gatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _routeTableId?;
        /**
         * @stability stable
         */
        get routeTableId(): string;
        /**
         * @stability stable
         */
        set routeTableId(value: string);
        /**
         * @stability stable
         */
        get routeTableIdInput(): string | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#description SecurityGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#egress SecurityGroup#egress}.
         *
         * @stability stable
         */
        readonly egress?: SecurityGroupEgress[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#ingress SecurityGroup#ingress}.
         *
         * @stability stable
         */
        readonly ingress?: SecurityGroupIngress[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#name SecurityGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#name_prefix SecurityGroup#name_prefix}.
         *
         * @stability stable
         */
        readonly namePrefix?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#revoke_rules_on_delete SecurityGroup#revoke_rules_on_delete}.
         *
         * @stability stable
         */
        readonly revokeRulesOnDelete?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#tags SecurityGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#tags_all SecurityGroup#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#vpc_id SecurityGroup#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#timeouts SecurityGroup#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: SecurityGroupTimeouts;
    }
    /**
     * @stability stable
     */
    interface SecurityGroupEgress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#cidr_blocks SecurityGroup#cidr_blocks}.
         *
         * @stability stable
         */
        readonly cidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#description SecurityGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#from_port SecurityGroup#from_port}.
         *
         * @stability stable
         */
        readonly fromPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#ipv6_cidr_blocks SecurityGroup#ipv6_cidr_blocks}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#prefix_list_ids SecurityGroup#prefix_list_ids}.
         *
         * @stability stable
         */
        readonly prefixListIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#protocol SecurityGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#security_groups SecurityGroup#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#self SecurityGroup#self}.
         *
         * @stability stable
         */
        readonly selfAttribute?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#to_port SecurityGroup#to_port}.
         *
         * @stability stable
         */
        readonly toPort?: number;
    }
    /**
     * @stability stable
     */
    interface SecurityGroupIngress {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#cidr_blocks SecurityGroup#cidr_blocks}.
         *
         * @stability stable
         */
        readonly cidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#description SecurityGroup#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#from_port SecurityGroup#from_port}.
         *
         * @stability stable
         */
        readonly fromPort?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#ipv6_cidr_blocks SecurityGroup#ipv6_cidr_blocks}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#prefix_list_ids SecurityGroup#prefix_list_ids}.
         *
         * @stability stable
         */
        readonly prefixListIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#protocol SecurityGroup#protocol}.
         *
         * @stability stable
         */
        readonly protocol?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#security_groups SecurityGroup#security_groups}.
         *
         * @stability stable
         */
        readonly securityGroups?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#self SecurityGroup#self}.
         *
         * @stability stable
         */
        readonly selfAttribute?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#to_port SecurityGroup#to_port}.
         *
         * @stability stable
         */
        readonly toPort?: number;
    }
    /**
     * @stability stable
     */
    interface SecurityGroupTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#create SecurityGroup#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group.html#delete SecurityGroup#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class SecurityGroupTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/security_group.html aws_security_group}.
     *
     * @stability stable
     */
    class SecurityGroup extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/security_group.html aws_security_group} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: SecurityGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _egress?;
        /**
         * @stability stable
         */
        get egress(): SecurityGroupEgress[] | undefined;
        /**
         * @stability stable
         */
        set egress(value: SecurityGroupEgress[] | undefined);
        /**
         * @stability stable
         */
        resetEgress(): void;
        /**
         * @stability stable
         */
        get egressInput(): SecurityGroupEgress[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ingress?;
        /**
         * @stability stable
         */
        get ingress(): SecurityGroupIngress[] | undefined;
        /**
         * @stability stable
         */
        set ingress(value: SecurityGroupIngress[] | undefined);
        /**
         * @stability stable
         */
        resetIngress(): void;
        /**
         * @stability stable
         */
        get ingressInput(): SecurityGroupIngress[] | undefined;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _namePrefix?;
        /**
         * @stability stable
         */
        get namePrefix(): string | undefined;
        /**
         * @stability stable
         */
        set namePrefix(value: string | undefined);
        /**
         * @stability stable
         */
        resetNamePrefix(): void;
        /**
         * @stability stable
         */
        get namePrefixInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _revokeRulesOnDelete?;
        /**
         * @stability stable
         */
        get revokeRulesOnDelete(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set revokeRulesOnDelete(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetRevokeRulesOnDelete(): void;
        /**
         * @stability stable
         */
        get revokeRulesOnDeleteInput(): boolean | cdktf.IResolvable | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): SecurityGroupTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: SecurityGroupTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): SecurityGroupTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SecurityGroupRuleConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#cidr_blocks SecurityGroupRule#cidr_blocks}.
         *
         * @stability stable
         */
        readonly cidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#description SecurityGroupRule#description}.
         *
         * @stability stable
         */
        readonly description?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#from_port SecurityGroupRule#from_port}.
         *
         * @stability stable
         */
        readonly fromPort: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#ipv6_cidr_blocks SecurityGroupRule#ipv6_cidr_blocks}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlocks?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#prefix_list_ids SecurityGroupRule#prefix_list_ids}.
         *
         * @stability stable
         */
        readonly prefixListIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#protocol SecurityGroupRule#protocol}.
         *
         * @stability stable
         */
        readonly protocol: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#security_group_id SecurityGroupRule#security_group_id}.
         *
         * @stability stable
         */
        readonly securityGroupId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#self SecurityGroupRule#self}.
         *
         * @stability stable
         */
        readonly selfAttribute?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#source_security_group_id SecurityGroupRule#source_security_group_id}.
         *
         * @stability stable
         */
        readonly sourceSecurityGroupId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#to_port SecurityGroupRule#to_port}.
         *
         * @stability stable
         */
        readonly toPort: number;
        /**
         * Type of rule, ingress (inbound) or egress (outbound).
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html#type SecurityGroupRule#type}
         *
         * @stability stable
         */
        readonly type: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html aws_security_group_rule}.
     *
     * @stability stable
     */
    class SecurityGroupRule extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/security_group_rule.html aws_security_group_rule} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SecurityGroupRuleConfig);
        private _cidrBlocks?;
        /**
         * @stability stable
         */
        get cidrBlocks(): string[] | undefined;
        /**
         * @stability stable
         */
        set cidrBlocks(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetCidrBlocks(): void;
        /**
         * @stability stable
         */
        get cidrBlocksInput(): string[] | undefined;
        private _description?;
        /**
         * @stability stable
         */
        get description(): string | undefined;
        /**
         * @stability stable
         */
        set description(value: string | undefined);
        /**
         * @stability stable
         */
        resetDescription(): void;
        /**
         * @stability stable
         */
        get descriptionInput(): string | undefined;
        private _fromPort?;
        /**
         * @stability stable
         */
        get fromPort(): number;
        /**
         * @stability stable
         */
        set fromPort(value: number);
        /**
         * @stability stable
         */
        get fromPortInput(): number | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipv6CidrBlocks?;
        /**
         * @stability stable
         */
        get ipv6CidrBlocks(): string[] | undefined;
        /**
         * @stability stable
         */
        set ipv6CidrBlocks(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetIpv6CidrBlocks(): void;
        /**
         * @stability stable
         */
        get ipv6CidrBlocksInput(): string[] | undefined;
        private _prefixListIds?;
        /**
         * @stability stable
         */
        get prefixListIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set prefixListIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetPrefixListIds(): void;
        /**
         * @stability stable
         */
        get prefixListIdsInput(): string[] | undefined;
        private _protocol?;
        /**
         * @stability stable
         */
        get protocol(): string;
        /**
         * @stability stable
         */
        set protocol(value: string);
        /**
         * @stability stable
         */
        get protocolInput(): string | undefined;
        private _securityGroupId?;
        /**
         * @stability stable
         */
        get securityGroupId(): string;
        /**
         * @stability stable
         */
        set securityGroupId(value: string);
        /**
         * @stability stable
         */
        get securityGroupIdInput(): string | undefined;
        private _self?;
        /**
         * @stability stable
         */
        get selfAttribute(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set selfAttribute(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetSelfAttribute(): void;
        /**
         * @stability stable
         */
        get selfAttributeInput(): boolean | cdktf.IResolvable | undefined;
        private _sourceSecurityGroupId?;
        /**
         * @stability stable
         */
        get sourceSecurityGroupId(): string | undefined;
        /**
         * @stability stable
         */
        set sourceSecurityGroupId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSourceSecurityGroupId(): void;
        /**
         * @stability stable
         */
        get sourceSecurityGroupIdInput(): string | undefined;
        private _toPort?;
        /**
         * @stability stable
         */
        get toPort(): number;
        /**
         * @stability stable
         */
        set toPort(value: number);
        /**
         * @stability stable
         */
        get toPortInput(): number | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface SubnetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#assign_ipv6_address_on_creation Subnet#assign_ipv6_address_on_creation}.
         *
         * @stability stable
         */
        readonly assignIpv6AddressOnCreation?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#availability_zone Subnet#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#availability_zone_id Subnet#availability_zone_id}.
         *
         * @stability stable
         */
        readonly availabilityZoneId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#cidr_block Subnet#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#customer_owned_ipv4_pool Subnet#customer_owned_ipv4_pool}.
         *
         * @stability stable
         */
        readonly customerOwnedIpv4Pool?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#ipv6_cidr_block Subnet#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#map_customer_owned_ip_on_launch Subnet#map_customer_owned_ip_on_launch}.
         *
         * @stability stable
         */
        readonly mapCustomerOwnedIpOnLaunch?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#map_public_ip_on_launch Subnet#map_public_ip_on_launch}.
         *
         * @stability stable
         */
        readonly mapPublicIpOnLaunch?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#outpost_arn Subnet#outpost_arn}.
         *
         * @stability stable
         */
        readonly outpostArn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#tags Subnet#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#tags_all Subnet#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#vpc_id Subnet#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#timeouts Subnet#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: SubnetTimeouts;
    }
    /**
     * @stability stable
     */
    interface SubnetTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#create Subnet#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/subnet.html#delete Subnet#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class SubnetTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/subnet.html aws_subnet}.
     *
     * @stability stable
     */
    class Subnet extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/subnet.html aws_subnet} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: SubnetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _assignIpv6AddressOnCreation?;
        /**
         * @stability stable
         */
        get assignIpv6AddressOnCreation(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set assignIpv6AddressOnCreation(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAssignIpv6AddressOnCreation(): void;
        /**
         * @stability stable
         */
        get assignIpv6AddressOnCreationInput(): boolean | cdktf.IResolvable | undefined;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _availabilityZoneId?;
        /**
         * @stability stable
         */
        get availabilityZoneId(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZoneId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZoneId(): void;
        /**
         * @stability stable
         */
        get availabilityZoneIdInput(): string | undefined;
        private _cidrBlock?;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        /**
         * @stability stable
         */
        set cidrBlock(value: string);
        /**
         * @stability stable
         */
        get cidrBlockInput(): string | undefined;
        private _customerOwnedIpv4Pool?;
        /**
         * @stability stable
         */
        get customerOwnedIpv4Pool(): string | undefined;
        /**
         * @stability stable
         */
        set customerOwnedIpv4Pool(value: string | undefined);
        /**
         * @stability stable
         */
        resetCustomerOwnedIpv4Pool(): void;
        /**
         * @stability stable
         */
        get customerOwnedIpv4PoolInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipv6CidrBlock?;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set ipv6CidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpv6CidrBlock(): void;
        /**
         * @stability stable
         */
        get ipv6CidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        get ipv6CidrBlockAssociationId(): string;
        private _mapCustomerOwnedIpOnLaunch?;
        /**
         * @stability stable
         */
        get mapCustomerOwnedIpOnLaunch(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mapCustomerOwnedIpOnLaunch(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMapCustomerOwnedIpOnLaunch(): void;
        /**
         * @stability stable
         */
        get mapCustomerOwnedIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
        private _mapPublicIpOnLaunch?;
        /**
         * @stability stable
         */
        get mapPublicIpOnLaunch(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set mapPublicIpOnLaunch(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetMapPublicIpOnLaunch(): void;
        /**
         * @stability stable
         */
        get mapPublicIpOnLaunchInput(): boolean | cdktf.IResolvable | undefined;
        private _outpostArn?;
        /**
         * @stability stable
         */
        get outpostArn(): string | undefined;
        /**
         * @stability stable
         */
        set outpostArn(value: string | undefined);
        /**
         * @stability stable
         */
        resetOutpostArn(): void;
        /**
         * @stability stable
         */
        get outpostArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): SubnetTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: SubnetTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): SubnetTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#assign_generated_ipv6_cidr_block Vpc#assign_generated_ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly assignGeneratedIpv6CidrBlock?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#cidr_block Vpc#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#enable_classiclink Vpc#enable_classiclink}.
         *
         * @stability stable
         */
        readonly enableClassiclink?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#enable_classiclink_dns_support Vpc#enable_classiclink_dns_support}.
         *
         * @stability stable
         */
        readonly enableClassiclinkDnsSupport?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#enable_dns_hostnames Vpc#enable_dns_hostnames}.
         *
         * @stability stable
         */
        readonly enableDnsHostnames?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#enable_dns_support Vpc#enable_dns_support}.
         *
         * @stability stable
         */
        readonly enableDnsSupport?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#instance_tenancy Vpc#instance_tenancy}.
         *
         * @stability stable
         */
        readonly instanceTenancy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#tags Vpc#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc.html#tags_all Vpc#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc.html aws_vpc}.
     *
     * @stability stable
     */
    class Vpc extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc.html aws_vpc} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _assignGeneratedIpv6CidrBlock?;
        /**
         * @stability stable
         */
        get assignGeneratedIpv6CidrBlock(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set assignGeneratedIpv6CidrBlock(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAssignGeneratedIpv6CidrBlock(): void;
        /**
         * @stability stable
         */
        get assignGeneratedIpv6CidrBlockInput(): boolean | cdktf.IResolvable | undefined;
        private _cidrBlock?;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        /**
         * @stability stable
         */
        set cidrBlock(value: string);
        /**
         * @stability stable
         */
        get cidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        get defaultNetworkAclId(): string;
        /**
         * @stability stable
         */
        get defaultRouteTableId(): string;
        /**
         * @stability stable
         */
        get defaultSecurityGroupId(): string;
        /**
         * @stability stable
         */
        get dhcpOptionsId(): string;
        private _enableClassiclink?;
        /**
         * @stability stable
         */
        get enableClassiclink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableClassiclink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableClassiclink(): void;
        /**
         * @stability stable
         */
        get enableClassiclinkInput(): boolean | cdktf.IResolvable | undefined;
        private _enableClassiclinkDnsSupport?;
        /**
         * @stability stable
         */
        get enableClassiclinkDnsSupport(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableClassiclinkDnsSupport(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableClassiclinkDnsSupport(): void;
        /**
         * @stability stable
         */
        get enableClassiclinkDnsSupportInput(): boolean | cdktf.IResolvable | undefined;
        private _enableDnsHostnames?;
        /**
         * @stability stable
         */
        get enableDnsHostnames(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableDnsHostnames(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableDnsHostnames(): void;
        /**
         * @stability stable
         */
        get enableDnsHostnamesInput(): boolean | cdktf.IResolvable | undefined;
        private _enableDnsSupport?;
        /**
         * @stability stable
         */
        get enableDnsSupport(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableDnsSupport(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableDnsSupport(): void;
        /**
         * @stability stable
         */
        get enableDnsSupportInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceTenancy?;
        /**
         * @stability stable
         */
        get instanceTenancy(): string | undefined;
        /**
         * @stability stable
         */
        set instanceTenancy(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceTenancy(): void;
        /**
         * @stability stable
         */
        get instanceTenancyInput(): string | undefined;
        /**
         * @stability stable
         */
        get ipv6AssociationId(): string;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string;
        /**
         * @stability stable
         */
        get mainRouteTableId(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcDhcpOptionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html#domain_name VpcDhcpOptions#domain_name}.
         *
         * @stability stable
         */
        readonly domainName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html#domain_name_servers VpcDhcpOptions#domain_name_servers}.
         *
         * @stability stable
         */
        readonly domainNameServers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html#netbios_name_servers VpcDhcpOptions#netbios_name_servers}.
         *
         * @stability stable
         */
        readonly netbiosNameServers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html#netbios_node_type VpcDhcpOptions#netbios_node_type}.
         *
         * @stability stable
         */
        readonly netbiosNodeType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html#ntp_servers VpcDhcpOptions#ntp_servers}.
         *
         * @stability stable
         */
        readonly ntpServers?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html#tags VpcDhcpOptions#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html#tags_all VpcDhcpOptions#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html aws_vpc_dhcp_options}.
     *
     * @stability stable
     */
    class VpcDhcpOptions extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options.html aws_vpc_dhcp_options} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: VpcDhcpOptionsConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _domainName?;
        /**
         * @stability stable
         */
        get domainName(): string | undefined;
        /**
         * @stability stable
         */
        set domainName(value: string | undefined);
        /**
         * @stability stable
         */
        resetDomainName(): void;
        /**
         * @stability stable
         */
        get domainNameInput(): string | undefined;
        private _domainNameServers?;
        /**
         * @stability stable
         */
        get domainNameServers(): string[] | undefined;
        /**
         * @stability stable
         */
        set domainNameServers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetDomainNameServers(): void;
        /**
         * @stability stable
         */
        get domainNameServersInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _netbiosNameServers?;
        /**
         * @stability stable
         */
        get netbiosNameServers(): string[] | undefined;
        /**
         * @stability stable
         */
        set netbiosNameServers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetNetbiosNameServers(): void;
        /**
         * @stability stable
         */
        get netbiosNameServersInput(): string[] | undefined;
        private _netbiosNodeType?;
        /**
         * @stability stable
         */
        get netbiosNodeType(): string | undefined;
        /**
         * @stability stable
         */
        set netbiosNodeType(value: string | undefined);
        /**
         * @stability stable
         */
        resetNetbiosNodeType(): void;
        /**
         * @stability stable
         */
        get netbiosNodeTypeInput(): string | undefined;
        private _ntpServers?;
        /**
         * @stability stable
         */
        get ntpServers(): string[] | undefined;
        /**
         * @stability stable
         */
        set ntpServers(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetNtpServers(): void;
        /**
         * @stability stable
         */
        get ntpServersInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcDhcpOptionsAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options_association.html#dhcp_options_id VpcDhcpOptionsAssociation#dhcp_options_id}.
         *
         * @stability stable
         */
        readonly dhcpOptionsId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options_association.html#vpc_id VpcDhcpOptionsAssociation#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options_association.html aws_vpc_dhcp_options_association}.
     *
     * @stability stable
     */
    class VpcDhcpOptionsAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_dhcp_options_association.html aws_vpc_dhcp_options_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcDhcpOptionsAssociationConfig);
        private _dhcpOptionsId?;
        /**
         * @stability stable
         */
        get dhcpOptionsId(): string;
        /**
         * @stability stable
         */
        set dhcpOptionsId(value: string);
        /**
         * @stability stable
         */
        get dhcpOptionsIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#auto_accept VpcEndpoint#auto_accept}.
         *
         * @stability stable
         */
        readonly autoAccept?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#policy VpcEndpoint#policy}.
         *
         * @stability stable
         */
        readonly policy?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#private_dns_enabled VpcEndpoint#private_dns_enabled}.
         *
         * @stability stable
         */
        readonly privateDnsEnabled?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#route_table_ids VpcEndpoint#route_table_ids}.
         *
         * @stability stable
         */
        readonly routeTableIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#security_group_ids VpcEndpoint#security_group_ids}.
         *
         * @stability stable
         */
        readonly securityGroupIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#service_name VpcEndpoint#service_name}.
         *
         * @stability stable
         */
        readonly serviceName: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#subnet_ids VpcEndpoint#subnet_ids}.
         *
         * @stability stable
         */
        readonly subnetIds?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#tags VpcEndpoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#tags_all VpcEndpoint#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#vpc_endpoint_type VpcEndpoint#vpc_endpoint_type}.
         *
         * @stability stable
         */
        readonly vpcEndpointType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#vpc_id VpcEndpoint#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#timeouts VpcEndpoint#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: VpcEndpointTimeouts;
    }
    /**
     * @stability stable
     */
    class VpcEndpointDnsEntry extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get hostedZoneId(): string;
    }
    /**
     * @stability stable
     */
    interface VpcEndpointTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#create VpcEndpoint#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#delete VpcEndpoint#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html#update VpcEndpoint#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class VpcEndpointTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html aws_vpc_endpoint}.
     *
     * @stability stable
     */
    class VpcEndpoint extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint.html aws_vpc_endpoint} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcEndpointConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _autoAccept?;
        /**
         * @stability stable
         */
        get autoAccept(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoAccept(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoAccept(): void;
        /**
         * @stability stable
         */
        get autoAcceptInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get cidrBlocks(): string[];
        /**
         * @stability stable
         */
        dnsEntry(index: string): VpcEndpointDnsEntry;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get networkInterfaceIds(): string[];
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _policy?;
        /**
         * @stability stable
         */
        get policy(): string | undefined;
        /**
         * @stability stable
         */
        set policy(value: string | undefined);
        /**
         * @stability stable
         */
        resetPolicy(): void;
        /**
         * @stability stable
         */
        get policyInput(): string | undefined;
        /**
         * @stability stable
         */
        get prefixListId(): string;
        private _privateDnsEnabled?;
        /**
         * @stability stable
         */
        get privateDnsEnabled(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set privateDnsEnabled(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetPrivateDnsEnabled(): void;
        /**
         * @stability stable
         */
        get privateDnsEnabledInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get requesterManaged(): any;
        private _routeTableIds?;
        /**
         * @stability stable
         */
        get routeTableIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set routeTableIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetRouteTableIds(): void;
        /**
         * @stability stable
         */
        get routeTableIdsInput(): string[] | undefined;
        private _securityGroupIds?;
        /**
         * @stability stable
         */
        get securityGroupIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set securityGroupIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSecurityGroupIds(): void;
        /**
         * @stability stable
         */
        get securityGroupIdsInput(): string[] | undefined;
        private _serviceName?;
        /**
         * @stability stable
         */
        get serviceName(): string;
        /**
         * @stability stable
         */
        set serviceName(value: string);
        /**
         * @stability stable
         */
        get serviceNameInput(): string | undefined;
        /**
         * @stability stable
         */
        get state(): string;
        private _subnetIds?;
        /**
         * @stability stable
         */
        get subnetIds(): string[] | undefined;
        /**
         * @stability stable
         */
        set subnetIds(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetSubnetIds(): void;
        /**
         * @stability stable
         */
        get subnetIdsInput(): string[] | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcEndpointType?;
        /**
         * @stability stable
         */
        get vpcEndpointType(): string | undefined;
        /**
         * @stability stable
         */
        set vpcEndpointType(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcEndpointType(): void;
        /**
         * @stability stable
         */
        get vpcEndpointTypeInput(): string | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): VpcEndpointTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: VpcEndpointTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): VpcEndpointTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcEndpointConnectionNotificationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_connection_notification.html#connection_events VpcEndpointConnectionNotification#connection_events}.
         *
         * @stability stable
         */
        readonly connectionEvents: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_connection_notification.html#connection_notification_arn VpcEndpointConnectionNotification#connection_notification_arn}.
         *
         * @stability stable
         */
        readonly connectionNotificationArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_connection_notification.html#vpc_endpoint_id VpcEndpointConnectionNotification#vpc_endpoint_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_connection_notification.html#vpc_endpoint_service_id VpcEndpointConnectionNotification#vpc_endpoint_service_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointServiceId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_connection_notification.html aws_vpc_endpoint_connection_notification}.
     *
     * @stability stable
     */
    class VpcEndpointConnectionNotification extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_connection_notification.html aws_vpc_endpoint_connection_notification} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcEndpointConnectionNotificationConfig);
        private _connectionEvents?;
        /**
         * @stability stable
         */
        get connectionEvents(): string[];
        /**
         * @stability stable
         */
        set connectionEvents(value: string[]);
        /**
         * @stability stable
         */
        get connectionEventsInput(): string[] | undefined;
        private _connectionNotificationArn?;
        /**
         * @stability stable
         */
        get connectionNotificationArn(): string;
        /**
         * @stability stable
         */
        set connectionNotificationArn(value: string);
        /**
         * @stability stable
         */
        get connectionNotificationArnInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get notificationType(): string;
        /**
         * @stability stable
         */
        get state(): string;
        private _vpcEndpointId?;
        /**
         * @stability stable
         */
        get vpcEndpointId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcEndpointId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcEndpointId(): void;
        /**
         * @stability stable
         */
        get vpcEndpointIdInput(): string | undefined;
        private _vpcEndpointServiceId?;
        /**
         * @stability stable
         */
        get vpcEndpointServiceId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcEndpointServiceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcEndpointServiceId(): void;
        /**
         * @stability stable
         */
        get vpcEndpointServiceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcEndpointRouteTableAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_route_table_association.html#route_table_id VpcEndpointRouteTableAssociation#route_table_id}.
         *
         * @stability stable
         */
        readonly routeTableId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_route_table_association.html#vpc_endpoint_id VpcEndpointRouteTableAssociation#vpc_endpoint_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_route_table_association.html aws_vpc_endpoint_route_table_association}.
     *
     * @stability stable
     */
    class VpcEndpointRouteTableAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_route_table_association.html aws_vpc_endpoint_route_table_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcEndpointRouteTableAssociationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _routeTableId?;
        /**
         * @stability stable
         */
        get routeTableId(): string;
        /**
         * @stability stable
         */
        set routeTableId(value: string);
        /**
         * @stability stable
         */
        get routeTableIdInput(): string | undefined;
        private _vpcEndpointId?;
        /**
         * @stability stable
         */
        get vpcEndpointId(): string;
        /**
         * @stability stable
         */
        set vpcEndpointId(value: string);
        /**
         * @stability stable
         */
        get vpcEndpointIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcEndpointServiceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#acceptance_required VpcEndpointService#acceptance_required}.
         *
         * @stability stable
         */
        readonly acceptanceRequired: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#allowed_principals VpcEndpointService#allowed_principals}.
         *
         * @stability stable
         */
        readonly allowedPrincipals?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#gateway_load_balancer_arns VpcEndpointService#gateway_load_balancer_arns}.
         *
         * @stability stable
         */
        readonly gatewayLoadBalancerArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#network_load_balancer_arns VpcEndpointService#network_load_balancer_arns}.
         *
         * @stability stable
         */
        readonly networkLoadBalancerArns?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#private_dns_name VpcEndpointService#private_dns_name}.
         *
         * @stability stable
         */
        readonly privateDnsName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#tags VpcEndpointService#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html#tags_all VpcEndpointService#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class VpcEndpointServicePrivateDnsNameConfiguration extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get name(): string;
        /**
         * @stability stable
         */
        get state(): string;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        get value(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html aws_vpc_endpoint_service}.
     *
     * @stability stable
     */
    class VpcEndpointService extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service.html aws_vpc_endpoint_service} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcEndpointServiceConfig);
        private _acceptanceRequired?;
        /**
         * @stability stable
         */
        get acceptanceRequired(): boolean | cdktf.IResolvable;
        /**
         * @stability stable
         */
        set acceptanceRequired(value: boolean | cdktf.IResolvable);
        /**
         * @stability stable
         */
        get acceptanceRequiredInput(): boolean | cdktf.IResolvable | undefined;
        private _allowedPrincipals?;
        /**
         * @stability stable
         */
        get allowedPrincipals(): string[] | undefined;
        /**
         * @stability stable
         */
        set allowedPrincipals(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetAllowedPrincipals(): void;
        /**
         * @stability stable
         */
        get allowedPrincipalsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get baseEndpointDnsNames(): string[];
        private _gatewayLoadBalancerArns?;
        /**
         * @stability stable
         */
        get gatewayLoadBalancerArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set gatewayLoadBalancerArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetGatewayLoadBalancerArns(): void;
        /**
         * @stability stable
         */
        get gatewayLoadBalancerArnsInput(): string[] | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get managesVpcEndpoints(): any;
        private _networkLoadBalancerArns?;
        /**
         * @stability stable
         */
        get networkLoadBalancerArns(): string[] | undefined;
        /**
         * @stability stable
         */
        set networkLoadBalancerArns(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetNetworkLoadBalancerArns(): void;
        /**
         * @stability stable
         */
        get networkLoadBalancerArnsInput(): string[] | undefined;
        private _privateDnsName?;
        /**
         * @stability stable
         */
        get privateDnsName(): string | undefined;
        /**
         * @stability stable
         */
        set privateDnsName(value: string | undefined);
        /**
         * @stability stable
         */
        resetPrivateDnsName(): void;
        /**
         * @stability stable
         */
        get privateDnsNameInput(): string | undefined;
        /**
         * @stability stable
         */
        privateDnsNameConfiguration(index: string): VpcEndpointServicePrivateDnsNameConfiguration;
        /**
         * @stability stable
         */
        get serviceName(): string;
        /**
         * @stability stable
         */
        get serviceType(): string;
        /**
         * @stability stable
         */
        get state(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcEndpointServiceAllowedPrincipalConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service_allowed_principal.html#principal_arn VpcEndpointServiceAllowedPrincipal#principal_arn}.
         *
         * @stability stable
         */
        readonly principalArn: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service_allowed_principal.html#vpc_endpoint_service_id VpcEndpointServiceAllowedPrincipal#vpc_endpoint_service_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointServiceId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service_allowed_principal.html aws_vpc_endpoint_service_allowed_principal}.
     *
     * @stability stable
     */
    class VpcEndpointServiceAllowedPrincipal extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_service_allowed_principal.html aws_vpc_endpoint_service_allowed_principal} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcEndpointServiceAllowedPrincipalConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _principalArn?;
        /**
         * @stability stable
         */
        get principalArn(): string;
        /**
         * @stability stable
         */
        set principalArn(value: string);
        /**
         * @stability stable
         */
        get principalArnInput(): string | undefined;
        private _vpcEndpointServiceId?;
        /**
         * @stability stable
         */
        get vpcEndpointServiceId(): string;
        /**
         * @stability stable
         */
        set vpcEndpointServiceId(value: string);
        /**
         * @stability stable
         */
        get vpcEndpointServiceIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcEndpointSubnetAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_subnet_association.html#subnet_id VpcEndpointSubnetAssociation#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_subnet_association.html#vpc_endpoint_id VpcEndpointSubnetAssociation#vpc_endpoint_id}.
         *
         * @stability stable
         */
        readonly vpcEndpointId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_subnet_association.html#timeouts VpcEndpointSubnetAssociation#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: VpcEndpointSubnetAssociationTimeouts;
    }
    /**
     * @stability stable
     */
    interface VpcEndpointSubnetAssociationTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_subnet_association.html#create VpcEndpointSubnetAssociation#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_subnet_association.html#delete VpcEndpointSubnetAssociation#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class VpcEndpointSubnetAssociationTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_subnet_association.html aws_vpc_endpoint_subnet_association}.
     *
     * @stability stable
     */
    class VpcEndpointSubnetAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_endpoint_subnet_association.html aws_vpc_endpoint_subnet_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcEndpointSubnetAssociationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string;
        /**
         * @stability stable
         */
        set subnetId(value: string);
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _vpcEndpointId?;
        /**
         * @stability stable
         */
        get vpcEndpointId(): string;
        /**
         * @stability stable
         */
        set vpcEndpointId(value: string);
        /**
         * @stability stable
         */
        get vpcEndpointIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): VpcEndpointSubnetAssociationTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: VpcEndpointSubnetAssociationTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): VpcEndpointSubnetAssociationTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcIpv4CidrBlockAssociationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_ipv4_cidr_block_association.html#cidr_block VpcIpv4CidrBlockAssociation#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_ipv4_cidr_block_association.html#vpc_id VpcIpv4CidrBlockAssociation#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_ipv4_cidr_block_association.html#timeouts VpcIpv4CidrBlockAssociation#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: VpcIpv4CidrBlockAssociationTimeouts;
    }
    /**
     * @stability stable
     */
    interface VpcIpv4CidrBlockAssociationTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_ipv4_cidr_block_association.html#create VpcIpv4CidrBlockAssociation#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_ipv4_cidr_block_association.html#delete VpcIpv4CidrBlockAssociation#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class VpcIpv4CidrBlockAssociationTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_ipv4_cidr_block_association.html aws_vpc_ipv4_cidr_block_association}.
     *
     * @stability stable
     */
    class VpcIpv4CidrBlockAssociation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_ipv4_cidr_block_association.html aws_vpc_ipv4_cidr_block_association} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcIpv4CidrBlockAssociationConfig);
        private _cidrBlock?;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        /**
         * @stability stable
         */
        set cidrBlock(value: string);
        /**
         * @stability stable
         */
        get cidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): VpcIpv4CidrBlockAssociationTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: VpcIpv4CidrBlockAssociationTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): VpcIpv4CidrBlockAssociationTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#auto_accept VpcPeeringConnection#auto_accept}.
         *
         * @stability stable
         */
        readonly autoAccept?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#peer_owner_id VpcPeeringConnection#peer_owner_id}.
         *
         * @stability stable
         */
        readonly peerOwnerId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#peer_region VpcPeeringConnection#peer_region}.
         *
         * @stability stable
         */
        readonly peerRegion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#peer_vpc_id VpcPeeringConnection#peer_vpc_id}.
         *
         * @stability stable
         */
        readonly peerVpcId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#tags VpcPeeringConnection#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#tags_all VpcPeeringConnection#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#vpc_id VpcPeeringConnection#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * accepter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#accepter VpcPeeringConnection#accepter}
         *
         * @stability stable
         */
        readonly accepter?: VpcPeeringConnectionAccepter;
        /**
         * requester block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#requester VpcPeeringConnection#requester}
         *
         * @stability stable
         */
        readonly requester?: VpcPeeringConnectionRequester;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#timeouts VpcPeeringConnection#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: VpcPeeringConnectionTimeouts;
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionAccepter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_classic_link_to_remote_vpc VpcPeeringConnection#allow_classic_link_to_remote_vpc}.
         *
         * @stability stable
         */
        readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_remote_vpc_dns_resolution VpcPeeringConnection#allow_remote_vpc_dns_resolution}.
         *
         * @stability stable
         */
        readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_vpc_to_remote_classic_link VpcPeeringConnection#allow_vpc_to_remote_classic_link}.
         *
         * @stability stable
         */
        readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class VpcPeeringConnectionAccepterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowClassicLinkToRemoteVpc?;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowClassicLinkToRemoteVpc(): void;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
        private _allowRemoteVpcDnsResolution?;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowRemoteVpcDnsResolution(): void;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
        private _allowVpcToRemoteClassicLink?;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowVpcToRemoteClassicLink(): void;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionRequester {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_classic_link_to_remote_vpc VpcPeeringConnection#allow_classic_link_to_remote_vpc}.
         *
         * @stability stable
         */
        readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_remote_vpc_dns_resolution VpcPeeringConnection#allow_remote_vpc_dns_resolution}.
         *
         * @stability stable
         */
        readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#allow_vpc_to_remote_classic_link VpcPeeringConnection#allow_vpc_to_remote_classic_link}.
         *
         * @stability stable
         */
        readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class VpcPeeringConnectionRequesterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowClassicLinkToRemoteVpc?;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowClassicLinkToRemoteVpc(): void;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
        private _allowRemoteVpcDnsResolution?;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowRemoteVpcDnsResolution(): void;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
        private _allowVpcToRemoteClassicLink?;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowVpcToRemoteClassicLink(): void;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#create VpcPeeringConnection#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#delete VpcPeeringConnection#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html#update VpcPeeringConnection#update}.
         *
         * @stability stable
         */
        readonly update?: string;
    }
    /**
     * @stability stable
     */
    class VpcPeeringConnectionTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
        private _update?;
        /**
         * @stability stable
         */
        get update(): string | undefined;
        /**
         * @stability stable
         */
        set update(value: string | undefined);
        /**
         * @stability stable
         */
        resetUpdate(): void;
        /**
         * @stability stable
         */
        get updateInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html aws_vpc_peering_connection}.
     *
     * @stability stable
     */
    class VpcPeeringConnection extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection.html aws_vpc_peering_connection} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcPeeringConnectionConfig);
        /**
         * @stability stable
         */
        get acceptStatus(): string;
        private _autoAccept?;
        /**
         * @stability stable
         */
        get autoAccept(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoAccept(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoAccept(): void;
        /**
         * @stability stable
         */
        get autoAcceptInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _peerOwnerId?;
        /**
         * @stability stable
         */
        get peerOwnerId(): string | undefined;
        /**
         * @stability stable
         */
        set peerOwnerId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPeerOwnerId(): void;
        /**
         * @stability stable
         */
        get peerOwnerIdInput(): string | undefined;
        private _peerRegion?;
        /**
         * @stability stable
         */
        get peerRegion(): string | undefined;
        /**
         * @stability stable
         */
        set peerRegion(value: string | undefined);
        /**
         * @stability stable
         */
        resetPeerRegion(): void;
        /**
         * @stability stable
         */
        get peerRegionInput(): string | undefined;
        private _peerVpcId?;
        /**
         * @stability stable
         */
        get peerVpcId(): string;
        /**
         * @stability stable
         */
        set peerVpcId(value: string);
        /**
         * @stability stable
         */
        get peerVpcIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _accepter?;
        private __accepterOutput;
        /**
         * @stability stable
         */
        get accepter(): VpcPeeringConnectionAccepterOutputReference;
        /**
         * @stability stable
         */
        putAccepter(value: VpcPeeringConnectionAccepter | undefined): void;
        /**
         * @stability stable
         */
        resetAccepter(): void;
        /**
         * @stability stable
         */
        get accepterInput(): VpcPeeringConnectionAccepter | undefined;
        private _requester?;
        private __requesterOutput;
        /**
         * @stability stable
         */
        get requester(): VpcPeeringConnectionRequesterOutputReference;
        /**
         * @stability stable
         */
        putRequester(value: VpcPeeringConnectionRequester | undefined): void;
        /**
         * @stability stable
         */
        resetRequester(): void;
        /**
         * @stability stable
         */
        get requesterInput(): VpcPeeringConnectionRequester | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): VpcPeeringConnectionTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: VpcPeeringConnectionTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): VpcPeeringConnectionTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionAccepterAConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#auto_accept VpcPeeringConnectionAccepterA#auto_accept}.
         *
         * @stability stable
         */
        readonly autoAccept?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#tags VpcPeeringConnectionAccepterA#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#tags_all VpcPeeringConnectionAccepterA#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#vpc_peering_connection_id VpcPeeringConnectionAccepterA#vpc_peering_connection_id}.
         *
         * @stability stable
         */
        readonly vpcPeeringConnectionId: string;
        /**
         * accepter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#accepter VpcPeeringConnectionAccepterA#accepter}
         *
         * @stability stable
         */
        readonly accepter?: VpcPeeringConnectionAccepterAccepter;
        /**
         * requester block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#requester VpcPeeringConnectionAccepterA#requester}
         *
         * @stability stable
         */
        readonly requester?: VpcPeeringConnectionAccepterRequester;
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionAccepterAccepter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#allow_classic_link_to_remote_vpc VpcPeeringConnectionAccepterA#allow_classic_link_to_remote_vpc}.
         *
         * @stability stable
         */
        readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#allow_remote_vpc_dns_resolution VpcPeeringConnectionAccepterA#allow_remote_vpc_dns_resolution}.
         *
         * @stability stable
         */
        readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#allow_vpc_to_remote_classic_link VpcPeeringConnectionAccepterA#allow_vpc_to_remote_classic_link}.
         *
         * @stability stable
         */
        readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class VpcPeeringConnectionAccepterAccepterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowClassicLinkToRemoteVpc?;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowClassicLinkToRemoteVpc(): void;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
        private _allowRemoteVpcDnsResolution?;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowRemoteVpcDnsResolution(): void;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
        private _allowVpcToRemoteClassicLink?;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowVpcToRemoteClassicLink(): void;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionAccepterRequester {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#allow_classic_link_to_remote_vpc VpcPeeringConnectionAccepterA#allow_classic_link_to_remote_vpc}.
         *
         * @stability stable
         */
        readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#allow_remote_vpc_dns_resolution VpcPeeringConnectionAccepterA#allow_remote_vpc_dns_resolution}.
         *
         * @stability stable
         */
        readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html#allow_vpc_to_remote_classic_link VpcPeeringConnectionAccepterA#allow_vpc_to_remote_classic_link}.
         *
         * @stability stable
         */
        readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class VpcPeeringConnectionAccepterRequesterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowClassicLinkToRemoteVpc?;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowClassicLinkToRemoteVpc(): void;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
        private _allowRemoteVpcDnsResolution?;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowRemoteVpcDnsResolution(): void;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
        private _allowVpcToRemoteClassicLink?;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowVpcToRemoteClassicLink(): void;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html aws_vpc_peering_connection_accepter}.
     *
     * @stability stable
     */
    class VpcPeeringConnectionAccepterA extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_accepter.html aws_vpc_peering_connection_accepter} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcPeeringConnectionAccepterAConfig);
        /**
         * @stability stable
         */
        get acceptStatus(): string;
        private _autoAccept?;
        /**
         * @stability stable
         */
        get autoAccept(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set autoAccept(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAutoAccept(): void;
        /**
         * @stability stable
         */
        get autoAcceptInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get peerOwnerId(): string;
        /**
         * @stability stable
         */
        get peerRegion(): string;
        /**
         * @stability stable
         */
        get peerVpcId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _vpcPeeringConnectionId?;
        /**
         * @stability stable
         */
        get vpcPeeringConnectionId(): string;
        /**
         * @stability stable
         */
        set vpcPeeringConnectionId(value: string);
        /**
         * @stability stable
         */
        get vpcPeeringConnectionIdInput(): string | undefined;
        private _accepter?;
        private __accepterOutput;
        /**
         * @stability stable
         */
        get accepter(): VpcPeeringConnectionAccepterAccepterOutputReference;
        /**
         * @stability stable
         */
        putAccepter(value: VpcPeeringConnectionAccepterAccepter | undefined): void;
        /**
         * @stability stable
         */
        resetAccepter(): void;
        /**
         * @stability stable
         */
        get accepterInput(): VpcPeeringConnectionAccepterAccepter | undefined;
        private _requester?;
        private __requesterOutput;
        /**
         * @stability stable
         */
        get requester(): VpcPeeringConnectionAccepterRequesterOutputReference;
        /**
         * @stability stable
         */
        putRequester(value: VpcPeeringConnectionAccepterRequester | undefined): void;
        /**
         * @stability stable
         */
        resetRequester(): void;
        /**
         * @stability stable
         */
        get requesterInput(): VpcPeeringConnectionAccepterRequester | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionOptionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#vpc_peering_connection_id VpcPeeringConnectionOptions#vpc_peering_connection_id}.
         *
         * @stability stable
         */
        readonly vpcPeeringConnectionId: string;
        /**
         * accepter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#accepter VpcPeeringConnectionOptions#accepter}
         *
         * @stability stable
         */
        readonly accepter?: VpcPeeringConnectionOptionsAccepter;
        /**
         * requester block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#requester VpcPeeringConnectionOptions#requester}
         *
         * @stability stable
         */
        readonly requester?: VpcPeeringConnectionOptionsRequester;
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionOptionsAccepter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#allow_classic_link_to_remote_vpc VpcPeeringConnectionOptions#allow_classic_link_to_remote_vpc}.
         *
         * @stability stable
         */
        readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#allow_remote_vpc_dns_resolution VpcPeeringConnectionOptions#allow_remote_vpc_dns_resolution}.
         *
         * @stability stable
         */
        readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#allow_vpc_to_remote_classic_link VpcPeeringConnectionOptions#allow_vpc_to_remote_classic_link}.
         *
         * @stability stable
         */
        readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class VpcPeeringConnectionOptionsAccepterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowClassicLinkToRemoteVpc?;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowClassicLinkToRemoteVpc(): void;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
        private _allowRemoteVpcDnsResolution?;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowRemoteVpcDnsResolution(): void;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
        private _allowVpcToRemoteClassicLink?;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowVpcToRemoteClassicLink(): void;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * @stability stable
     */
    interface VpcPeeringConnectionOptionsRequester {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#allow_classic_link_to_remote_vpc VpcPeeringConnectionOptions#allow_classic_link_to_remote_vpc}.
         *
         * @stability stable
         */
        readonly allowClassicLinkToRemoteVpc?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#allow_remote_vpc_dns_resolution VpcPeeringConnectionOptions#allow_remote_vpc_dns_resolution}.
         *
         * @stability stable
         */
        readonly allowRemoteVpcDnsResolution?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html#allow_vpc_to_remote_classic_link VpcPeeringConnectionOptions#allow_vpc_to_remote_classic_link}.
         *
         * @stability stable
         */
        readonly allowVpcToRemoteClassicLink?: boolean | cdktf.IResolvable;
    }
    /**
     * @stability stable
     */
    class VpcPeeringConnectionOptionsRequesterOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _allowClassicLinkToRemoteVpc?;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpc(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowClassicLinkToRemoteVpc(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowClassicLinkToRemoteVpc(): void;
        /**
         * @stability stable
         */
        get allowClassicLinkToRemoteVpcInput(): boolean | cdktf.IResolvable | undefined;
        private _allowRemoteVpcDnsResolution?;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolution(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowRemoteVpcDnsResolution(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowRemoteVpcDnsResolution(): void;
        /**
         * @stability stable
         */
        get allowRemoteVpcDnsResolutionInput(): boolean | cdktf.IResolvable | undefined;
        private _allowVpcToRemoteClassicLink?;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLink(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set allowVpcToRemoteClassicLink(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetAllowVpcToRemoteClassicLink(): void;
        /**
         * @stability stable
         */
        get allowVpcToRemoteClassicLinkInput(): boolean | cdktf.IResolvable | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html aws_vpc_peering_connection_options}.
     *
     * @stability stable
     */
    class VpcPeeringConnectionOptions extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpc_peering_connection_options.html aws_vpc_peering_connection_options} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpcPeeringConnectionOptionsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _vpcPeeringConnectionId?;
        /**
         * @stability stable
         */
        get vpcPeeringConnectionId(): string;
        /**
         * @stability stable
         */
        set vpcPeeringConnectionId(value: string);
        /**
         * @stability stable
         */
        get vpcPeeringConnectionIdInput(): string | undefined;
        private _accepter?;
        private __accepterOutput;
        /**
         * @stability stable
         */
        get accepter(): VpcPeeringConnectionOptionsAccepterOutputReference;
        /**
         * @stability stable
         */
        putAccepter(value: VpcPeeringConnectionOptionsAccepter | undefined): void;
        /**
         * @stability stable
         */
        resetAccepter(): void;
        /**
         * @stability stable
         */
        get accepterInput(): VpcPeeringConnectionOptionsAccepter | undefined;
        private _requester?;
        private __requesterOutput;
        /**
         * @stability stable
         */
        get requester(): VpcPeeringConnectionOptionsRequesterOutputReference;
        /**
         * @stability stable
         */
        putRequester(value: VpcPeeringConnectionOptionsRequester | undefined): void;
        /**
         * @stability stable
         */
        resetRequester(): void;
        /**
         * @stability stable
         */
        get requesterInput(): VpcPeeringConnectionOptionsRequester | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpnConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#customer_gateway_id VpnConnection#customer_gateway_id}.
         *
         * @stability stable
         */
        readonly customerGatewayId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#enable_acceleration VpnConnection#enable_acceleration}.
         *
         * @stability stable
         */
        readonly enableAcceleration?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#local_ipv4_network_cidr VpnConnection#local_ipv4_network_cidr}.
         *
         * @stability stable
         */
        readonly localIpv4NetworkCidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#local_ipv6_network_cidr VpnConnection#local_ipv6_network_cidr}.
         *
         * @stability stable
         */
        readonly localIpv6NetworkCidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#remote_ipv4_network_cidr VpnConnection#remote_ipv4_network_cidr}.
         *
         * @stability stable
         */
        readonly remoteIpv4NetworkCidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#remote_ipv6_network_cidr VpnConnection#remote_ipv6_network_cidr}.
         *
         * @stability stable
         */
        readonly remoteIpv6NetworkCidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#static_routes_only VpnConnection#static_routes_only}.
         *
         * @stability stable
         */
        readonly staticRoutesOnly?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tags VpnConnection#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tags_all VpnConnection#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#transit_gateway_id VpnConnection#transit_gateway_id}.
         *
         * @stability stable
         */
        readonly transitGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_dpd_timeout_action VpnConnection#tunnel1_dpd_timeout_action}.
         *
         * @stability stable
         */
        readonly tunnel1DpdTimeoutAction?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_dpd_timeout_seconds VpnConnection#tunnel1_dpd_timeout_seconds}.
         *
         * @stability stable
         */
        readonly tunnel1DpdTimeoutSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_ike_versions VpnConnection#tunnel1_ike_versions}.
         *
         * @stability stable
         */
        readonly tunnel1IkeVersions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_inside_cidr VpnConnection#tunnel1_inside_cidr}.
         *
         * @stability stable
         */
        readonly tunnel1InsideCidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_inside_ipv6_cidr VpnConnection#tunnel1_inside_ipv6_cidr}.
         *
         * @stability stable
         */
        readonly tunnel1InsideIpv6Cidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase1_dh_group_numbers VpnConnection#tunnel1_phase1_dh_group_numbers}.
         *
         * @stability stable
         */
        readonly tunnel1Phase1DhGroupNumbers?: number[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase1_encryption_algorithms VpnConnection#tunnel1_phase1_encryption_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel1Phase1EncryptionAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase1_integrity_algorithms VpnConnection#tunnel1_phase1_integrity_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel1Phase1IntegrityAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase1_lifetime_seconds VpnConnection#tunnel1_phase1_lifetime_seconds}.
         *
         * @stability stable
         */
        readonly tunnel1Phase1LifetimeSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase2_dh_group_numbers VpnConnection#tunnel1_phase2_dh_group_numbers}.
         *
         * @stability stable
         */
        readonly tunnel1Phase2DhGroupNumbers?: number[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase2_encryption_algorithms VpnConnection#tunnel1_phase2_encryption_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel1Phase2EncryptionAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase2_integrity_algorithms VpnConnection#tunnel1_phase2_integrity_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel1Phase2IntegrityAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_phase2_lifetime_seconds VpnConnection#tunnel1_phase2_lifetime_seconds}.
         *
         * @stability stable
         */
        readonly tunnel1Phase2LifetimeSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_preshared_key VpnConnection#tunnel1_preshared_key}.
         *
         * @stability stable
         */
        readonly tunnel1PresharedKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_rekey_fuzz_percentage VpnConnection#tunnel1_rekey_fuzz_percentage}.
         *
         * @stability stable
         */
        readonly tunnel1RekeyFuzzPercentage?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_rekey_margin_time_seconds VpnConnection#tunnel1_rekey_margin_time_seconds}.
         *
         * @stability stable
         */
        readonly tunnel1RekeyMarginTimeSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_replay_window_size VpnConnection#tunnel1_replay_window_size}.
         *
         * @stability stable
         */
        readonly tunnel1ReplayWindowSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel1_startup_action VpnConnection#tunnel1_startup_action}.
         *
         * @stability stable
         */
        readonly tunnel1StartupAction?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_dpd_timeout_action VpnConnection#tunnel2_dpd_timeout_action}.
         *
         * @stability stable
         */
        readonly tunnel2DpdTimeoutAction?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_dpd_timeout_seconds VpnConnection#tunnel2_dpd_timeout_seconds}.
         *
         * @stability stable
         */
        readonly tunnel2DpdTimeoutSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_ike_versions VpnConnection#tunnel2_ike_versions}.
         *
         * @stability stable
         */
        readonly tunnel2IkeVersions?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_inside_cidr VpnConnection#tunnel2_inside_cidr}.
         *
         * @stability stable
         */
        readonly tunnel2InsideCidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_inside_ipv6_cidr VpnConnection#tunnel2_inside_ipv6_cidr}.
         *
         * @stability stable
         */
        readonly tunnel2InsideIpv6Cidr?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase1_dh_group_numbers VpnConnection#tunnel2_phase1_dh_group_numbers}.
         *
         * @stability stable
         */
        readonly tunnel2Phase1DhGroupNumbers?: number[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase1_encryption_algorithms VpnConnection#tunnel2_phase1_encryption_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel2Phase1EncryptionAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase1_integrity_algorithms VpnConnection#tunnel2_phase1_integrity_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel2Phase1IntegrityAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase1_lifetime_seconds VpnConnection#tunnel2_phase1_lifetime_seconds}.
         *
         * @stability stable
         */
        readonly tunnel2Phase1LifetimeSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase2_dh_group_numbers VpnConnection#tunnel2_phase2_dh_group_numbers}.
         *
         * @stability stable
         */
        readonly tunnel2Phase2DhGroupNumbers?: number[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase2_encryption_algorithms VpnConnection#tunnel2_phase2_encryption_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel2Phase2EncryptionAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase2_integrity_algorithms VpnConnection#tunnel2_phase2_integrity_algorithms}.
         *
         * @stability stable
         */
        readonly tunnel2Phase2IntegrityAlgorithms?: string[];
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_phase2_lifetime_seconds VpnConnection#tunnel2_phase2_lifetime_seconds}.
         *
         * @stability stable
         */
        readonly tunnel2Phase2LifetimeSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_preshared_key VpnConnection#tunnel2_preshared_key}.
         *
         * @stability stable
         */
        readonly tunnel2PresharedKey?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_rekey_fuzz_percentage VpnConnection#tunnel2_rekey_fuzz_percentage}.
         *
         * @stability stable
         */
        readonly tunnel2RekeyFuzzPercentage?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_rekey_margin_time_seconds VpnConnection#tunnel2_rekey_margin_time_seconds}.
         *
         * @stability stable
         */
        readonly tunnel2RekeyMarginTimeSeconds?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_replay_window_size VpnConnection#tunnel2_replay_window_size}.
         *
         * @stability stable
         */
        readonly tunnel2ReplayWindowSize?: number;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel2_startup_action VpnConnection#tunnel2_startup_action}.
         *
         * @stability stable
         */
        readonly tunnel2StartupAction?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#tunnel_inside_ip_version VpnConnection#tunnel_inside_ip_version}.
         *
         * @stability stable
         */
        readonly tunnelInsideIpVersion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#type VpnConnection#type}.
         *
         * @stability stable
         */
        readonly type: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html#vpn_gateway_id VpnConnection#vpn_gateway_id}.
         *
         * @stability stable
         */
        readonly vpnGatewayId?: string;
    }
    /**
     * @stability stable
     */
    class VpnConnectionRoutes extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get destinationCidrBlock(): string;
        /**
         * @stability stable
         */
        get source(): string;
        /**
         * @stability stable
         */
        get state(): string;
    }
    /**
     * @stability stable
     */
    class VpnConnectionVgwTelemetry extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get acceptedRouteCount(): number;
        /**
         * @stability stable
         */
        get lastStatusChange(): string;
        /**
         * @stability stable
         */
        get outsideIpAddress(): string;
        /**
         * @stability stable
         */
        get status(): string;
        /**
         * @stability stable
         */
        get statusMessage(): string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html aws_vpn_connection}.
     *
     * @stability stable
     */
    class VpnConnection extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection.html aws_vpn_connection} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpnConnectionConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get customerGatewayConfiguration(): string;
        private _customerGatewayId?;
        /**
         * @stability stable
         */
        get customerGatewayId(): string;
        /**
         * @stability stable
         */
        set customerGatewayId(value: string);
        /**
         * @stability stable
         */
        get customerGatewayIdInput(): string | undefined;
        private _enableAcceleration?;
        /**
         * @stability stable
         */
        get enableAcceleration(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set enableAcceleration(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetEnableAcceleration(): void;
        /**
         * @stability stable
         */
        get enableAccelerationInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _localIpv4NetworkCidr?;
        /**
         * @stability stable
         */
        get localIpv4NetworkCidr(): string | undefined;
        /**
         * @stability stable
         */
        set localIpv4NetworkCidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocalIpv4NetworkCidr(): void;
        /**
         * @stability stable
         */
        get localIpv4NetworkCidrInput(): string | undefined;
        private _localIpv6NetworkCidr?;
        /**
         * @stability stable
         */
        get localIpv6NetworkCidr(): string | undefined;
        /**
         * @stability stable
         */
        set localIpv6NetworkCidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocalIpv6NetworkCidr(): void;
        /**
         * @stability stable
         */
        get localIpv6NetworkCidrInput(): string | undefined;
        private _remoteIpv4NetworkCidr?;
        /**
         * @stability stable
         */
        get remoteIpv4NetworkCidr(): string | undefined;
        /**
         * @stability stable
         */
        set remoteIpv4NetworkCidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetRemoteIpv4NetworkCidr(): void;
        /**
         * @stability stable
         */
        get remoteIpv4NetworkCidrInput(): string | undefined;
        private _remoteIpv6NetworkCidr?;
        /**
         * @stability stable
         */
        get remoteIpv6NetworkCidr(): string | undefined;
        /**
         * @stability stable
         */
        set remoteIpv6NetworkCidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetRemoteIpv6NetworkCidr(): void;
        /**
         * @stability stable
         */
        get remoteIpv6NetworkCidrInput(): string | undefined;
        /**
         * @stability stable
         */
        routes(index: string): VpnConnectionRoutes;
        private _staticRoutesOnly?;
        /**
         * @stability stable
         */
        get staticRoutesOnly(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set staticRoutesOnly(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetStaticRoutesOnly(): void;
        /**
         * @stability stable
         */
        get staticRoutesOnlyInput(): boolean | cdktf.IResolvable | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get transitGatewayAttachmentId(): string;
        private _transitGatewayId?;
        /**
         * @stability stable
         */
        get transitGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set transitGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetTransitGatewayId(): void;
        /**
         * @stability stable
         */
        get transitGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get tunnel1Address(): string;
        /**
         * @stability stable
         */
        get tunnel1BgpAsn(): string;
        /**
         * @stability stable
         */
        get tunnel1BgpHoldtime(): number;
        /**
         * @stability stable
         */
        get tunnel1CgwInsideAddress(): string;
        private _tunnel1DpdTimeoutAction?;
        /**
         * @stability stable
         */
        get tunnel1DpdTimeoutAction(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel1DpdTimeoutAction(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel1DpdTimeoutAction(): void;
        /**
         * @stability stable
         */
        get tunnel1DpdTimeoutActionInput(): string | undefined;
        private _tunnel1DpdTimeoutSeconds?;
        /**
         * @stability stable
         */
        get tunnel1DpdTimeoutSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel1DpdTimeoutSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel1DpdTimeoutSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel1DpdTimeoutSecondsInput(): number | undefined;
        private _tunnel1IkeVersions?;
        /**
         * @stability stable
         */
        get tunnel1IkeVersions(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel1IkeVersions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel1IkeVersions(): void;
        /**
         * @stability stable
         */
        get tunnel1IkeVersionsInput(): string[] | undefined;
        private _tunnel1InsideCidr?;
        /**
         * @stability stable
         */
        get tunnel1InsideCidr(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel1InsideCidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel1InsideCidr(): void;
        /**
         * @stability stable
         */
        get tunnel1InsideCidrInput(): string | undefined;
        private _tunnel1InsideIpv6Cidr?;
        /**
         * @stability stable
         */
        get tunnel1InsideIpv6Cidr(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel1InsideIpv6Cidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel1InsideIpv6Cidr(): void;
        /**
         * @stability stable
         */
        get tunnel1InsideIpv6CidrInput(): string | undefined;
        private _tunnel1Phase1DhGroupNumbers?;
        /**
         * @stability stable
         */
        get tunnel1Phase1DhGroupNumbers(): number[] | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase1DhGroupNumbers(value: number[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase1DhGroupNumbers(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase1DhGroupNumbersInput(): number[] | undefined;
        private _tunnel1Phase1EncryptionAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel1Phase1EncryptionAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase1EncryptionAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase1EncryptionAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase1EncryptionAlgorithmsInput(): string[] | undefined;
        private _tunnel1Phase1IntegrityAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel1Phase1IntegrityAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase1IntegrityAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase1IntegrityAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase1IntegrityAlgorithmsInput(): string[] | undefined;
        private _tunnel1Phase1LifetimeSeconds?;
        /**
         * @stability stable
         */
        get tunnel1Phase1LifetimeSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase1LifetimeSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase1LifetimeSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase1LifetimeSecondsInput(): number | undefined;
        private _tunnel1Phase2DhGroupNumbers?;
        /**
         * @stability stable
         */
        get tunnel1Phase2DhGroupNumbers(): number[] | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase2DhGroupNumbers(value: number[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase2DhGroupNumbers(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase2DhGroupNumbersInput(): number[] | undefined;
        private _tunnel1Phase2EncryptionAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel1Phase2EncryptionAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase2EncryptionAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase2EncryptionAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase2EncryptionAlgorithmsInput(): string[] | undefined;
        private _tunnel1Phase2IntegrityAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel1Phase2IntegrityAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase2IntegrityAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase2IntegrityAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase2IntegrityAlgorithmsInput(): string[] | undefined;
        private _tunnel1Phase2LifetimeSeconds?;
        /**
         * @stability stable
         */
        get tunnel1Phase2LifetimeSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel1Phase2LifetimeSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel1Phase2LifetimeSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel1Phase2LifetimeSecondsInput(): number | undefined;
        private _tunnel1PresharedKey?;
        /**
         * @stability stable
         */
        get tunnel1PresharedKey(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel1PresharedKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel1PresharedKey(): void;
        /**
         * @stability stable
         */
        get tunnel1PresharedKeyInput(): string | undefined;
        private _tunnel1RekeyFuzzPercentage?;
        /**
         * @stability stable
         */
        get tunnel1RekeyFuzzPercentage(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel1RekeyFuzzPercentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel1RekeyFuzzPercentage(): void;
        /**
         * @stability stable
         */
        get tunnel1RekeyFuzzPercentageInput(): number | undefined;
        private _tunnel1RekeyMarginTimeSeconds?;
        /**
         * @stability stable
         */
        get tunnel1RekeyMarginTimeSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel1RekeyMarginTimeSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel1RekeyMarginTimeSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel1RekeyMarginTimeSecondsInput(): number | undefined;
        private _tunnel1ReplayWindowSize?;
        /**
         * @stability stable
         */
        get tunnel1ReplayWindowSize(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel1ReplayWindowSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel1ReplayWindowSize(): void;
        /**
         * @stability stable
         */
        get tunnel1ReplayWindowSizeInput(): number | undefined;
        private _tunnel1StartupAction?;
        /**
         * @stability stable
         */
        get tunnel1StartupAction(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel1StartupAction(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel1StartupAction(): void;
        /**
         * @stability stable
         */
        get tunnel1StartupActionInput(): string | undefined;
        /**
         * @stability stable
         */
        get tunnel1VgwInsideAddress(): string;
        /**
         * @stability stable
         */
        get tunnel2Address(): string;
        /**
         * @stability stable
         */
        get tunnel2BgpAsn(): string;
        /**
         * @stability stable
         */
        get tunnel2BgpHoldtime(): number;
        /**
         * @stability stable
         */
        get tunnel2CgwInsideAddress(): string;
        private _tunnel2DpdTimeoutAction?;
        /**
         * @stability stable
         */
        get tunnel2DpdTimeoutAction(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel2DpdTimeoutAction(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel2DpdTimeoutAction(): void;
        /**
         * @stability stable
         */
        get tunnel2DpdTimeoutActionInput(): string | undefined;
        private _tunnel2DpdTimeoutSeconds?;
        /**
         * @stability stable
         */
        get tunnel2DpdTimeoutSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel2DpdTimeoutSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel2DpdTimeoutSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel2DpdTimeoutSecondsInput(): number | undefined;
        private _tunnel2IkeVersions?;
        /**
         * @stability stable
         */
        get tunnel2IkeVersions(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel2IkeVersions(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel2IkeVersions(): void;
        /**
         * @stability stable
         */
        get tunnel2IkeVersionsInput(): string[] | undefined;
        private _tunnel2InsideCidr?;
        /**
         * @stability stable
         */
        get tunnel2InsideCidr(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel2InsideCidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel2InsideCidr(): void;
        /**
         * @stability stable
         */
        get tunnel2InsideCidrInput(): string | undefined;
        private _tunnel2InsideIpv6Cidr?;
        /**
         * @stability stable
         */
        get tunnel2InsideIpv6Cidr(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel2InsideIpv6Cidr(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel2InsideIpv6Cidr(): void;
        /**
         * @stability stable
         */
        get tunnel2InsideIpv6CidrInput(): string | undefined;
        private _tunnel2Phase1DhGroupNumbers?;
        /**
         * @stability stable
         */
        get tunnel2Phase1DhGroupNumbers(): number[] | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase1DhGroupNumbers(value: number[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase1DhGroupNumbers(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase1DhGroupNumbersInput(): number[] | undefined;
        private _tunnel2Phase1EncryptionAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel2Phase1EncryptionAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase1EncryptionAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase1EncryptionAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase1EncryptionAlgorithmsInput(): string[] | undefined;
        private _tunnel2Phase1IntegrityAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel2Phase1IntegrityAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase1IntegrityAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase1IntegrityAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase1IntegrityAlgorithmsInput(): string[] | undefined;
        private _tunnel2Phase1LifetimeSeconds?;
        /**
         * @stability stable
         */
        get tunnel2Phase1LifetimeSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase1LifetimeSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase1LifetimeSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase1LifetimeSecondsInput(): number | undefined;
        private _tunnel2Phase2DhGroupNumbers?;
        /**
         * @stability stable
         */
        get tunnel2Phase2DhGroupNumbers(): number[] | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase2DhGroupNumbers(value: number[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase2DhGroupNumbers(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase2DhGroupNumbersInput(): number[] | undefined;
        private _tunnel2Phase2EncryptionAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel2Phase2EncryptionAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase2EncryptionAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase2EncryptionAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase2EncryptionAlgorithmsInput(): string[] | undefined;
        private _tunnel2Phase2IntegrityAlgorithms?;
        /**
         * @stability stable
         */
        get tunnel2Phase2IntegrityAlgorithms(): string[] | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase2IntegrityAlgorithms(value: string[] | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase2IntegrityAlgorithms(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase2IntegrityAlgorithmsInput(): string[] | undefined;
        private _tunnel2Phase2LifetimeSeconds?;
        /**
         * @stability stable
         */
        get tunnel2Phase2LifetimeSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel2Phase2LifetimeSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel2Phase2LifetimeSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel2Phase2LifetimeSecondsInput(): number | undefined;
        private _tunnel2PresharedKey?;
        /**
         * @stability stable
         */
        get tunnel2PresharedKey(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel2PresharedKey(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel2PresharedKey(): void;
        /**
         * @stability stable
         */
        get tunnel2PresharedKeyInput(): string | undefined;
        private _tunnel2RekeyFuzzPercentage?;
        /**
         * @stability stable
         */
        get tunnel2RekeyFuzzPercentage(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel2RekeyFuzzPercentage(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel2RekeyFuzzPercentage(): void;
        /**
         * @stability stable
         */
        get tunnel2RekeyFuzzPercentageInput(): number | undefined;
        private _tunnel2RekeyMarginTimeSeconds?;
        /**
         * @stability stable
         */
        get tunnel2RekeyMarginTimeSeconds(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel2RekeyMarginTimeSeconds(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel2RekeyMarginTimeSeconds(): void;
        /**
         * @stability stable
         */
        get tunnel2RekeyMarginTimeSecondsInput(): number | undefined;
        private _tunnel2ReplayWindowSize?;
        /**
         * @stability stable
         */
        get tunnel2ReplayWindowSize(): number | undefined;
        /**
         * @stability stable
         */
        set tunnel2ReplayWindowSize(value: number | undefined);
        /**
         * @stability stable
         */
        resetTunnel2ReplayWindowSize(): void;
        /**
         * @stability stable
         */
        get tunnel2ReplayWindowSizeInput(): number | undefined;
        private _tunnel2StartupAction?;
        /**
         * @stability stable
         */
        get tunnel2StartupAction(): string | undefined;
        /**
         * @stability stable
         */
        set tunnel2StartupAction(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnel2StartupAction(): void;
        /**
         * @stability stable
         */
        get tunnel2StartupActionInput(): string | undefined;
        /**
         * @stability stable
         */
        get tunnel2VgwInsideAddress(): string;
        private _tunnelInsideIpVersion?;
        /**
         * @stability stable
         */
        get tunnelInsideIpVersion(): string | undefined;
        /**
         * @stability stable
         */
        set tunnelInsideIpVersion(value: string | undefined);
        /**
         * @stability stable
         */
        resetTunnelInsideIpVersion(): void;
        /**
         * @stability stable
         */
        get tunnelInsideIpVersionInput(): string | undefined;
        private _type?;
        /**
         * @stability stable
         */
        get type(): string;
        /**
         * @stability stable
         */
        set type(value: string);
        /**
         * @stability stable
         */
        get typeInput(): string | undefined;
        /**
         * @stability stable
         */
        vgwTelemetry(index: string): VpnConnectionVgwTelemetry;
        private _vpnGatewayId?;
        /**
         * @stability stable
         */
        get vpnGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set vpnGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpnGatewayId(): void;
        /**
         * @stability stable
         */
        get vpnGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpnConnectionRouteConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection_route.html#destination_cidr_block VpnConnectionRoute#destination_cidr_block}.
         *
         * @stability stable
         */
        readonly destinationCidrBlock: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection_route.html#vpn_connection_id VpnConnectionRoute#vpn_connection_id}.
         *
         * @stability stable
         */
        readonly vpnConnectionId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection_route.html aws_vpn_connection_route}.
     *
     * @stability stable
     */
    class VpnConnectionRoute extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpn_connection_route.html aws_vpn_connection_route} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpnConnectionRouteConfig);
        private _destinationCidrBlock?;
        /**
         * @stability stable
         */
        get destinationCidrBlock(): string;
        /**
         * @stability stable
         */
        set destinationCidrBlock(value: string);
        /**
         * @stability stable
         */
        get destinationCidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _vpnConnectionId?;
        /**
         * @stability stable
         */
        get vpnConnectionId(): string;
        /**
         * @stability stable
         */
        set vpnConnectionId(value: string);
        /**
         * @stability stable
         */
        get vpnConnectionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpnGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway.html#amazon_side_asn VpnGateway#amazon_side_asn}.
         *
         * @stability stable
         */
        readonly amazonSideAsn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway.html#availability_zone VpnGateway#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway.html#tags VpnGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway.html#tags_all VpnGateway#tags_all}.
         *
         * @stability stable
         */
        readonly tagsAll?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway.html#vpc_id VpnGateway#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway.html aws_vpn_gateway}.
     *
     * @stability stable
     */
    class VpnGateway extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway.html aws_vpn_gateway} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: VpnGatewayConfig);
        private _amazonSideAsn?;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string | undefined;
        /**
         * @stability stable
         */
        set amazonSideAsn(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonSideAsn(): void;
        /**
         * @stability stable
         */
        get amazonSideAsnInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _tagsAll?;
        /**
         * @stability stable
         */
        get tagsAll(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tagsAll(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTagsAll(): void;
        /**
         * @stability stable
         */
        get tagsAllInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpnGatewayAttachmentConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_attachment.html#vpc_id VpnGatewayAttachment#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_attachment.html#vpn_gateway_id VpnGatewayAttachment#vpn_gateway_id}.
         *
         * @stability stable
         */
        readonly vpnGatewayId: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_attachment.html aws_vpn_gateway_attachment}.
     *
     * @stability stable
     */
    class VpnGatewayAttachment extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_attachment.html aws_vpn_gateway_attachment} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpnGatewayAttachmentConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _vpnGatewayId?;
        /**
         * @stability stable
         */
        get vpnGatewayId(): string;
        /**
         * @stability stable
         */
        set vpnGatewayId(value: string);
        /**
         * @stability stable
         */
        get vpnGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface VpnGatewayRoutePropagationConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_route_propagation.html#route_table_id VpnGatewayRoutePropagation#route_table_id}.
         *
         * @stability stable
         */
        readonly routeTableId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_route_propagation.html#vpn_gateway_id VpnGatewayRoutePropagation#vpn_gateway_id}.
         *
         * @stability stable
         */
        readonly vpnGatewayId: string;
        /**
         * timeouts block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_route_propagation.html#timeouts VpnGatewayRoutePropagation#timeouts}
         *
         * @stability stable
         */
        readonly timeouts?: VpnGatewayRoutePropagationTimeouts;
    }
    /**
     * @stability stable
     */
    interface VpnGatewayRoutePropagationTimeouts {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_route_propagation.html#create VpnGatewayRoutePropagation#create}.
         *
         * @stability stable
         */
        readonly create?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_route_propagation.html#delete VpnGatewayRoutePropagation#delete}.
         *
         * @stability stable
         */
        readonly delete?: string;
    }
    /**
     * @stability stable
     */
    class VpnGatewayRoutePropagationTimeoutsOutputReference extends cdktf.ComplexObject {
        /**
         * @param terraformResource The parent resource.
         * @param terraformAttribute The attribute on the parent resource this class is referencing.
         * @param isSingleItem True if this is a block, false if it's a list.
         * @stability stable
         */
        constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
        private _create?;
        /**
         * @stability stable
         */
        get create(): string | undefined;
        /**
         * @stability stable
         */
        set create(value: string | undefined);
        /**
         * @stability stable
         */
        resetCreate(): void;
        /**
         * @stability stable
         */
        get createInput(): string | undefined;
        private _delete?;
        /**
         * @stability stable
         */
        get delete(): string | undefined;
        /**
         * @stability stable
         */
        set delete(value: string | undefined);
        /**
         * @stability stable
         */
        resetDelete(): void;
        /**
         * @stability stable
         */
        get deleteInput(): string | undefined;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_route_propagation.html aws_vpn_gateway_route_propagation}.
     *
     * @stability stable
     */
    class VpnGatewayRoutePropagation extends cdktf.TerraformResource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/r/vpn_gateway_route_propagation.html aws_vpn_gateway_route_propagation} Resource.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: VpnGatewayRoutePropagationConfig);
        /**
         * @stability stable
         */
        get id(): string;
        private _routeTableId?;
        /**
         * @stability stable
         */
        get routeTableId(): string;
        /**
         * @stability stable
         */
        set routeTableId(value: string);
        /**
         * @stability stable
         */
        get routeTableIdInput(): string | undefined;
        private _vpnGatewayId?;
        /**
         * @stability stable
         */
        get vpnGatewayId(): string;
        /**
         * @stability stable
         */
        set vpnGatewayId(value: string);
        /**
         * @stability stable
         */
        get vpnGatewayIdInput(): string | undefined;
        private _timeouts?;
        private __timeoutsOutput;
        /**
         * @stability stable
         */
        get timeouts(): VpnGatewayRoutePropagationTimeoutsOutputReference;
        /**
         * @stability stable
         */
        putTimeouts(value: VpnGatewayRoutePropagationTimeouts | undefined): void;
        /**
         * @stability stable
         */
        resetTimeouts(): void;
        /**
         * @stability stable
         */
        get timeoutsInput(): VpnGatewayRoutePropagationTimeouts | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsCustomerGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/customer_gateway.html#tags DataAwsCustomerGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/customer_gateway.html#filter DataAwsCustomerGateway#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsCustomerGatewayFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsCustomerGatewayFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/customer_gateway.html#name DataAwsCustomerGateway#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/customer_gateway.html#values DataAwsCustomerGateway#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/customer_gateway.html aws_customer_gateway}.
     *
     * @stability stable
     */
    class DataAwsCustomerGateway extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/customer_gateway.html aws_customer_gateway} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsCustomerGatewayConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get bgpAsn(): number;
        /**
         * @stability stable
         */
        get deviceName(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ipAddress(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get type(): string;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsCustomerGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsCustomerGatewayFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsCustomerGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsInternetGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/internet_gateway.html#internet_gateway_id DataAwsInternetGateway#internet_gateway_id}.
         *
         * @stability stable
         */
        readonly internetGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/internet_gateway.html#tags DataAwsInternetGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/internet_gateway.html#filter DataAwsInternetGateway#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsInternetGatewayFilter[];
    }
    /**
     * @stability stable
     */
    class DataAwsInternetGatewayAttachments extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get state(): string;
        /**
         * @stability stable
         */
        get vpcId(): string;
    }
    /**
     * @stability stable
     */
    interface DataAwsInternetGatewayFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/internet_gateway.html#name DataAwsInternetGateway#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/internet_gateway.html#values DataAwsInternetGateway#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/internet_gateway.html aws_internet_gateway}.
     *
     * @stability stable
     */
    class DataAwsInternetGateway extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/internet_gateway.html aws_internet_gateway} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsInternetGatewayConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        attachments(index: string): DataAwsInternetGatewayAttachments;
        /**
         * @stability stable
         */
        get id(): string;
        private _internetGatewayId?;
        /**
         * @stability stable
         */
        get internetGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set internetGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetInternetGatewayId(): void;
        /**
         * @stability stable
         */
        get internetGatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsInternetGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsInternetGatewayFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsInternetGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsNatGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html#state DataAwsNatGateway#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html#subnet_id DataAwsNatGateway#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html#tags DataAwsNatGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html#vpc_id DataAwsNatGateway#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html#filter DataAwsNatGateway#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsNatGatewayFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsNatGatewayFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html#name DataAwsNatGateway#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html#values DataAwsNatGateway#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html aws_nat_gateway}.
     *
     * @stability stable
     */
    class DataAwsNatGateway extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/nat_gateway.html aws_nat_gateway} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsNatGatewayConfig);
        /**
         * @stability stable
         */
        get allocationId(): string;
        /**
         * @stability stable
         */
        get connectivityType(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        get privateIp(): string;
        /**
         * @stability stable
         */
        get publicIp(): string;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsNatGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsNatGatewayFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsNatGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsNetworkAclsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_acls.html#tags DataAwsNetworkAcls#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_acls.html#vpc_id DataAwsNetworkAcls#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_acls.html#filter DataAwsNetworkAcls#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsNetworkAclsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsNetworkAclsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_acls.html#name DataAwsNetworkAcls#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_acls.html#values DataAwsNetworkAcls#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/network_acls.html aws_network_acls}.
     *
     * @stability stable
     */
    class DataAwsNetworkAcls extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/network_acls.html aws_network_acls} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsNetworkAclsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsNetworkAclsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsNetworkAclsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsNetworkAclsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsNetworkInterfaceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interface.html#tags DataAwsNetworkInterface#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interface.html#filter DataAwsNetworkInterface#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsNetworkInterfaceFilter[];
    }
    /**
     * @stability stable
     */
    class DataAwsNetworkInterfaceAssociation extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get allocationId(): string;
        /**
         * @stability stable
         */
        get associationId(): string;
        /**
         * @stability stable
         */
        get carrierIp(): string;
        /**
         * @stability stable
         */
        get customerOwnedIp(): string;
        /**
         * @stability stable
         */
        get ipOwnerId(): string;
        /**
         * @stability stable
         */
        get publicDnsName(): string;
        /**
         * @stability stable
         */
        get publicIp(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsNetworkInterfaceAttachment extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get attachmentId(): string;
        /**
         * @stability stable
         */
        get deviceIndex(): number;
        /**
         * @stability stable
         */
        get instanceId(): string;
        /**
         * @stability stable
         */
        get instanceOwnerId(): string;
    }
    /**
     * @stability stable
     */
    interface DataAwsNetworkInterfaceFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interface.html#name DataAwsNetworkInterface#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interface.html#values DataAwsNetworkInterface#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/network_interface.html aws_network_interface}.
     *
     * @stability stable
     */
    class DataAwsNetworkInterface extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/network_interface.html aws_network_interface} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsNetworkInterfaceConfig);
        /**
         * @stability stable
         */
        association(index: string): DataAwsNetworkInterfaceAssociation;
        /**
         * @stability stable
         */
        attachment(index: string): DataAwsNetworkInterfaceAttachment;
        /**
         * @stability stable
         */
        get availabilityZone(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get interfaceType(): string;
        /**
         * @stability stable
         */
        get ipv6Addresses(): string[];
        /**
         * @stability stable
         */
        get macAddress(): string;
        /**
         * @stability stable
         */
        get outpostArn(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        /**
         * @stability stable
         */
        get privateDnsName(): string;
        /**
         * @stability stable
         */
        get privateIp(): string;
        /**
         * @stability stable
         */
        get privateIps(): string[];
        /**
         * @stability stable
         */
        get requesterId(): string;
        /**
         * @stability stable
         */
        get securityGroups(): string[];
        /**
         * @stability stable
         */
        get subnetId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcId(): string;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsNetworkInterfaceFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsNetworkInterfaceFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsNetworkInterfaceFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsNetworkInterfacesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interfaces.html#tags DataAwsNetworkInterfaces#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interfaces.html#filter DataAwsNetworkInterfaces#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsNetworkInterfacesFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsNetworkInterfacesFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interfaces.html#name DataAwsNetworkInterfaces#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/network_interfaces.html#values DataAwsNetworkInterfaces#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/network_interfaces.html aws_network_interfaces}.
     *
     * @stability stable
     */
    class DataAwsNetworkInterfaces extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/network_interfaces.html aws_network_interfaces} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsNetworkInterfacesConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsNetworkInterfacesFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsNetworkInterfacesFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsNetworkInterfacesFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRouteConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#carrier_gateway_id DataAwsRoute#carrier_gateway_id}.
         *
         * @stability stable
         */
        readonly carrierGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#destination_cidr_block DataAwsRoute#destination_cidr_block}.
         *
         * @stability stable
         */
        readonly destinationCidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#destination_ipv6_cidr_block DataAwsRoute#destination_ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly destinationIpv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#destination_prefix_list_id DataAwsRoute#destination_prefix_list_id}.
         *
         * @stability stable
         */
        readonly destinationPrefixListId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#egress_only_gateway_id DataAwsRoute#egress_only_gateway_id}.
         *
         * @stability stable
         */
        readonly egressOnlyGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#gateway_id DataAwsRoute#gateway_id}.
         *
         * @stability stable
         */
        readonly gatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#instance_id DataAwsRoute#instance_id}.
         *
         * @stability stable
         */
        readonly instanceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#local_gateway_id DataAwsRoute#local_gateway_id}.
         *
         * @stability stable
         */
        readonly localGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#nat_gateway_id DataAwsRoute#nat_gateway_id}.
         *
         * @stability stable
         */
        readonly natGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#network_interface_id DataAwsRoute#network_interface_id}.
         *
         * @stability stable
         */
        readonly networkInterfaceId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#route_table_id DataAwsRoute#route_table_id}.
         *
         * @stability stable
         */
        readonly routeTableId: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#transit_gateway_id DataAwsRoute#transit_gateway_id}.
         *
         * @stability stable
         */
        readonly transitGatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route.html#vpc_peering_connection_id DataAwsRoute#vpc_peering_connection_id}.
         *
         * @stability stable
         */
        readonly vpcPeeringConnectionId?: string;
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/route.html aws_route}.
     *
     * @stability stable
     */
    class DataAwsRoute extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/route.html aws_route} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsRouteConfig);
        private _carrierGatewayId?;
        /**
         * @stability stable
         */
        get carrierGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set carrierGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetCarrierGatewayId(): void;
        /**
         * @stability stable
         */
        get carrierGatewayIdInput(): string | undefined;
        private _destinationCidrBlock?;
        /**
         * @stability stable
         */
        get destinationCidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set destinationCidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetDestinationCidrBlock(): void;
        /**
         * @stability stable
         */
        get destinationCidrBlockInput(): string | undefined;
        private _destinationIpv6CidrBlock?;
        /**
         * @stability stable
         */
        get destinationIpv6CidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set destinationIpv6CidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetDestinationIpv6CidrBlock(): void;
        /**
         * @stability stable
         */
        get destinationIpv6CidrBlockInput(): string | undefined;
        private _destinationPrefixListId?;
        /**
         * @stability stable
         */
        get destinationPrefixListId(): string | undefined;
        /**
         * @stability stable
         */
        set destinationPrefixListId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDestinationPrefixListId(): void;
        /**
         * @stability stable
         */
        get destinationPrefixListIdInput(): string | undefined;
        private _egressOnlyGatewayId?;
        /**
         * @stability stable
         */
        get egressOnlyGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set egressOnlyGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetEgressOnlyGatewayId(): void;
        /**
         * @stability stable
         */
        get egressOnlyGatewayIdInput(): string | undefined;
        private _gatewayId?;
        /**
         * @stability stable
         */
        get gatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set gatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetGatewayId(): void;
        /**
         * @stability stable
         */
        get gatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _instanceId?;
        /**
         * @stability stable
         */
        get instanceId(): string | undefined;
        /**
         * @stability stable
         */
        set instanceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetInstanceId(): void;
        /**
         * @stability stable
         */
        get instanceIdInput(): string | undefined;
        private _localGatewayId?;
        /**
         * @stability stable
         */
        get localGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set localGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetLocalGatewayId(): void;
        /**
         * @stability stable
         */
        get localGatewayIdInput(): string | undefined;
        private _natGatewayId?;
        /**
         * @stability stable
         */
        get natGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set natGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetNatGatewayId(): void;
        /**
         * @stability stable
         */
        get natGatewayIdInput(): string | undefined;
        private _networkInterfaceId?;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string | undefined;
        /**
         * @stability stable
         */
        set networkInterfaceId(value: string | undefined);
        /**
         * @stability stable
         */
        resetNetworkInterfaceId(): void;
        /**
         * @stability stable
         */
        get networkInterfaceIdInput(): string | undefined;
        private _routeTableId?;
        /**
         * @stability stable
         */
        get routeTableId(): string;
        /**
         * @stability stable
         */
        set routeTableId(value: string);
        /**
         * @stability stable
         */
        get routeTableIdInput(): string | undefined;
        private _transitGatewayId?;
        /**
         * @stability stable
         */
        get transitGatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set transitGatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetTransitGatewayId(): void;
        /**
         * @stability stable
         */
        get transitGatewayIdInput(): string | undefined;
        private _vpcPeeringConnectionId?;
        /**
         * @stability stable
         */
        get vpcPeeringConnectionId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcPeeringConnectionId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcPeeringConnectionId(): void;
        /**
         * @stability stable
         */
        get vpcPeeringConnectionIdInput(): string | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRouteTableConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#gateway_id DataAwsRouteTable#gateway_id}.
         *
         * @stability stable
         */
        readonly gatewayId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#route_table_id DataAwsRouteTable#route_table_id}.
         *
         * @stability stable
         */
        readonly routeTableId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#subnet_id DataAwsRouteTable#subnet_id}.
         *
         * @stability stable
         */
        readonly subnetId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#tags DataAwsRouteTable#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#vpc_id DataAwsRouteTable#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#filter DataAwsRouteTable#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsRouteTableFilter[];
    }
    /**
     * @stability stable
     */
    class DataAwsRouteTableAssociations extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get gatewayId(): string;
        /**
         * @stability stable
         */
        get main(): any;
        /**
         * @stability stable
         */
        get routeTableAssociationId(): string;
        /**
         * @stability stable
         */
        get routeTableId(): string;
        /**
         * @stability stable
         */
        get subnetId(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsRouteTableRoutes extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get carrierGatewayId(): string;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        /**
         * @stability stable
         */
        get destinationPrefixListId(): string;
        /**
         * @stability stable
         */
        get egressOnlyGatewayId(): string;
        /**
         * @stability stable
         */
        get gatewayId(): string;
        /**
         * @stability stable
         */
        get instanceId(): string;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string;
        /**
         * @stability stable
         */
        get localGatewayId(): string;
        /**
         * @stability stable
         */
        get natGatewayId(): string;
        /**
         * @stability stable
         */
        get networkInterfaceId(): string;
        /**
         * @stability stable
         */
        get transitGatewayId(): string;
        /**
         * @stability stable
         */
        get vpcEndpointId(): string;
        /**
         * @stability stable
         */
        get vpcPeeringConnectionId(): string;
    }
    /**
     * @stability stable
     */
    interface DataAwsRouteTableFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#name DataAwsRouteTable#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_table.html#values DataAwsRouteTable#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/route_table.html aws_route_table}.
     *
     * @stability stable
     */
    class DataAwsRouteTable extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/route_table.html aws_route_table} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsRouteTableConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        associations(index: string): DataAwsRouteTableAssociations;
        private _gatewayId?;
        /**
         * @stability stable
         */
        get gatewayId(): string | undefined;
        /**
         * @stability stable
         */
        set gatewayId(value: string | undefined);
        /**
         * @stability stable
         */
        resetGatewayId(): void;
        /**
         * @stability stable
         */
        get gatewayIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _routeTableId?;
        /**
         * @stability stable
         */
        get routeTableId(): string | undefined;
        /**
         * @stability stable
         */
        set routeTableId(value: string | undefined);
        /**
         * @stability stable
         */
        resetRouteTableId(): void;
        /**
         * @stability stable
         */
        get routeTableIdInput(): string | undefined;
        /**
         * @stability stable
         */
        routes(index: string): DataAwsRouteTableRoutes;
        private _subnetId?;
        /**
         * @stability stable
         */
        get subnetId(): string | undefined;
        /**
         * @stability stable
         */
        set subnetId(value: string | undefined);
        /**
         * @stability stable
         */
        resetSubnetId(): void;
        /**
         * @stability stable
         */
        get subnetIdInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsRouteTableFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsRouteTableFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsRouteTableFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsRouteTablesConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_tables.html#tags DataAwsRouteTables#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_tables.html#vpc_id DataAwsRouteTables#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_tables.html#filter DataAwsRouteTables#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsRouteTablesFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsRouteTablesFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_tables.html#name DataAwsRouteTables#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/route_tables.html#values DataAwsRouteTables#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/route_tables.html aws_route_tables}.
     *
     * @stability stable
     */
    class DataAwsRouteTables extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/route_tables.html aws_route_tables} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsRouteTablesConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsRouteTablesFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsRouteTablesFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsRouteTablesFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSecurityGroupConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_group.html#name DataAwsSecurityGroup#name}.
         *
         * @stability stable
         */
        readonly name?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_group.html#tags DataAwsSecurityGroup#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_group.html#vpc_id DataAwsSecurityGroup#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_group.html#filter DataAwsSecurityGroup#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsSecurityGroupFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsSecurityGroupFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_group.html#name DataAwsSecurityGroup#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_group.html#values DataAwsSecurityGroup#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/security_group.html aws_security_group}.
     *
     * @stability stable
     */
    class DataAwsSecurityGroup extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/security_group.html aws_security_group} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsSecurityGroupConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get description(): string;
        /**
         * @stability stable
         */
        get id(): string;
        private _name?;
        /**
         * @stability stable
         */
        get name(): string | undefined;
        /**
         * @stability stable
         */
        set name(value: string | undefined);
        /**
         * @stability stable
         */
        resetName(): void;
        /**
         * @stability stable
         */
        get nameInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsSecurityGroupFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsSecurityGroupFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsSecurityGroupFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSecurityGroupsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_groups.html#tags DataAwsSecurityGroups#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_groups.html#filter DataAwsSecurityGroups#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsSecurityGroupsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsSecurityGroupsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_groups.html#name DataAwsSecurityGroups#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/security_groups.html#values DataAwsSecurityGroups#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/security_groups.html aws_security_groups}.
     *
     * @stability stable
     */
    class DataAwsSecurityGroups extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/security_groups.html aws_security_groups} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsSecurityGroupsConfig);
        /**
         * @stability stable
         */
        get arns(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcIds(): string[];
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsSecurityGroupsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsSecurityGroupsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsSecurityGroupsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSubnetConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#availability_zone DataAwsSubnet#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#availability_zone_id DataAwsSubnet#availability_zone_id}.
         *
         * @stability stable
         */
        readonly availabilityZoneId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#cidr_block DataAwsSubnet#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#default_for_az DataAwsSubnet#default_for_az}.
         *
         * @stability stable
         */
        readonly defaultForAz?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#ipv6_cidr_block DataAwsSubnet#ipv6_cidr_block}.
         *
         * @stability stable
         */
        readonly ipv6CidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#state DataAwsSubnet#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#tags DataAwsSubnet#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#vpc_id DataAwsSubnet#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#filter DataAwsSubnet#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsSubnetFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsSubnetFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#name DataAwsSubnet#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet.html#values DataAwsSubnet#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/subnet.html aws_subnet}.
     *
     * @stability stable
     */
    class DataAwsSubnet extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/subnet.html aws_subnet} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsSubnetConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get assignIpv6AddressOnCreation(): any;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        private _availabilityZoneId?;
        /**
         * @stability stable
         */
        get availabilityZoneId(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZoneId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZoneId(): void;
        /**
         * @stability stable
         */
        get availabilityZoneIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get availableIpAddressCount(): number;
        private _cidrBlock?;
        /**
         * @stability stable
         */
        get cidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set cidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetCidrBlock(): void;
        /**
         * @stability stable
         */
        get cidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        get customerOwnedIpv4Pool(): string;
        private _defaultForAz?;
        /**
         * @stability stable
         */
        get defaultForAz(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set defaultForAz(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDefaultForAz(): void;
        /**
         * @stability stable
         */
        get defaultForAzInput(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _ipv6CidrBlock?;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set ipv6CidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetIpv6CidrBlock(): void;
        /**
         * @stability stable
         */
        get ipv6CidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        get ipv6CidrBlockAssociationId(): string;
        /**
         * @stability stable
         */
        get mapCustomerOwnedIpOnLaunch(): any;
        /**
         * @stability stable
         */
        get mapPublicIpOnLaunch(): any;
        /**
         * @stability stable
         */
        get outpostArn(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsSubnetFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsSubnetFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsSubnetFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSubnetIdsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet_ids.html#tags DataAwsSubnetIds#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet_ids.html#vpc_id DataAwsSubnetIds#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet_ids.html#filter DataAwsSubnetIds#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsSubnetIdsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsSubnetIdsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet_ids.html#name DataAwsSubnetIds#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnet_ids.html#values DataAwsSubnetIds#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/subnet_ids.html aws_subnet_ids}.
     *
     * @stability stable
     */
    class DataAwsSubnetIds extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/subnet_ids.html aws_subnet_ids} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config: DataAwsSubnetIdsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string;
        /**
         * @stability stable
         */
        set vpcId(value: string);
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsSubnetIdsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsSubnetIdsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsSubnetIdsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsSubnetsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnets.html#tags DataAwsSubnets#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnets.html#filter DataAwsSubnets#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsSubnetsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsSubnetsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnets.html#name DataAwsSubnets#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/subnets.html#values DataAwsSubnets#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/subnets.html aws_subnets}.
     *
     * @stability stable
     */
    class DataAwsSubnets extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/subnets.html aws_subnets} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsSubnetsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsSubnetsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsSubnetsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsSubnetsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#cidr_block DataAwsVpc#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#default DataAwsVpc#default}.
         *
         * @stability stable
         */
        readonly default?: boolean | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#dhcp_options_id DataAwsVpc#dhcp_options_id}.
         *
         * @stability stable
         */
        readonly dhcpOptionsId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#state DataAwsVpc#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#tags DataAwsVpc#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#filter DataAwsVpc#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpcFilter[];
    }
    /**
     * @stability stable
     */
    class DataAwsVpcCidrBlockAssociations extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get associationId(): string;
        /**
         * @stability stable
         */
        get cidrBlock(): string;
        /**
         * @stability stable
         */
        get state(): string;
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#name DataAwsVpc#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc.html#values DataAwsVpc#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpc.html aws_vpc}.
     *
     * @stability stable
     */
    class DataAwsVpc extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpc.html aws_vpc} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpcConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _cidrBlock?;
        /**
         * @stability stable
         */
        get cidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set cidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetCidrBlock(): void;
        /**
         * @stability stable
         */
        get cidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        cidrBlockAssociations(index: string): DataAwsVpcCidrBlockAssociations;
        private _default?;
        /**
         * @stability stable
         */
        get default(): boolean | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set default(value: boolean | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetDefault(): void;
        /**
         * @stability stable
         */
        get defaultInput(): boolean | cdktf.IResolvable | undefined;
        private _dhcpOptionsId?;
        /**
         * @stability stable
         */
        get dhcpOptionsId(): string | undefined;
        /**
         * @stability stable
         */
        set dhcpOptionsId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDhcpOptionsId(): void;
        /**
         * @stability stable
         */
        get dhcpOptionsIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get enableDnsHostnames(): any;
        /**
         * @stability stable
         */
        get enableDnsSupport(): any;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get instanceTenancy(): string;
        /**
         * @stability stable
         */
        get ipv6AssociationId(): string;
        /**
         * @stability stable
         */
        get ipv6CidrBlock(): string;
        /**
         * @stability stable
         */
        get mainRouteTableId(): string;
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpcFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpcFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpcFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcDhcpOptionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_dhcp_options.html#dhcp_options_id DataAwsVpcDhcpOptions#dhcp_options_id}.
         *
         * @stability stable
         */
        readonly dhcpOptionsId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_dhcp_options.html#tags DataAwsVpcDhcpOptions#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_dhcp_options.html#filter DataAwsVpcDhcpOptions#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpcDhcpOptionsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcDhcpOptionsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_dhcp_options.html#name DataAwsVpcDhcpOptions#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_dhcp_options.html#values DataAwsVpcDhcpOptions#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpc_dhcp_options.html aws_vpc_dhcp_options}.
     *
     * @stability stable
     */
    class DataAwsVpcDhcpOptions extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpc_dhcp_options.html aws_vpc_dhcp_options} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpcDhcpOptionsConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        private _dhcpOptionsId?;
        /**
         * @stability stable
         */
        get dhcpOptionsId(): string | undefined;
        /**
         * @stability stable
         */
        set dhcpOptionsId(value: string | undefined);
        /**
         * @stability stable
         */
        resetDhcpOptionsId(): void;
        /**
         * @stability stable
         */
        get dhcpOptionsIdInput(): string | undefined;
        /**
         * @stability stable
         */
        get domainName(): string;
        /**
         * @stability stable
         */
        get domainNameServers(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get netbiosNameServers(): string[];
        /**
         * @stability stable
         */
        get netbiosNodeType(): string;
        /**
         * @stability stable
         */
        get ntpServers(): string[];
        /**
         * @stability stable
         */
        get ownerId(): string;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpcDhcpOptionsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpcDhcpOptionsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpcDhcpOptionsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcEndpointConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html#service_name DataAwsVpcEndpoint#service_name}.
         *
         * @stability stable
         */
        readonly serviceName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html#state DataAwsVpcEndpoint#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html#tags DataAwsVpcEndpoint#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html#vpc_id DataAwsVpcEndpoint#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html#filter DataAwsVpcEndpoint#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpcEndpointFilter[];
    }
    /**
     * @stability stable
     */
    class DataAwsVpcEndpointDnsEntry extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get dnsName(): string;
        /**
         * @stability stable
         */
        get hostedZoneId(): string;
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcEndpointFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html#name DataAwsVpcEndpoint#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html#values DataAwsVpcEndpoint#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html aws_vpc_endpoint}.
     *
     * @stability stable
     */
    class DataAwsVpcEndpoint extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint.html aws_vpc_endpoint} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpcEndpointConfig);
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get cidrBlocks(): string[];
        /**
         * @stability stable
         */
        dnsEntry(index: string): DataAwsVpcEndpointDnsEntry;
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get networkInterfaceIds(): string[];
        /**
         * @stability stable
         */
        get ownerId(): string;
        /**
         * @stability stable
         */
        get policy(): string;
        /**
         * @stability stable
         */
        get prefixListId(): string;
        /**
         * @stability stable
         */
        get privateDnsEnabled(): any;
        /**
         * @stability stable
         */
        get requesterManaged(): any;
        /**
         * @stability stable
         */
        get routeTableIds(): string[];
        /**
         * @stability stable
         */
        get securityGroupIds(): string[];
        private _serviceName?;
        /**
         * @stability stable
         */
        get serviceName(): string | undefined;
        /**
         * @stability stable
         */
        set serviceName(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceName(): void;
        /**
         * @stability stable
         */
        get serviceNameInput(): string | undefined;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        /**
         * @stability stable
         */
        get subnetIds(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcEndpointType(): string;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpcEndpointFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpcEndpointFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpcEndpointFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcEndpointServiceConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html#service DataAwsVpcEndpointService#service}.
         *
         * @stability stable
         */
        readonly service?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html#service_name DataAwsVpcEndpointService#service_name}.
         *
         * @stability stable
         */
        readonly serviceName?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html#service_type DataAwsVpcEndpointService#service_type}.
         *
         * @stability stable
         */
        readonly serviceType?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html#tags DataAwsVpcEndpointService#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html#filter DataAwsVpcEndpointService#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpcEndpointServiceFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcEndpointServiceFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html#name DataAwsVpcEndpointService#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html#values DataAwsVpcEndpointService#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html aws_vpc_endpoint_service}.
     *
     * @stability stable
     */
    class DataAwsVpcEndpointService extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpc_endpoint_service.html aws_vpc_endpoint_service} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpcEndpointServiceConfig);
        /**
         * @stability stable
         */
        get acceptanceRequired(): any;
        /**
         * @stability stable
         */
        get arn(): string;
        /**
         * @stability stable
         */
        get availabilityZones(): string[];
        /**
         * @stability stable
         */
        get baseEndpointDnsNames(): string[];
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get managesVpcEndpoints(): any;
        /**
         * @stability stable
         */
        get owner(): string;
        /**
         * @stability stable
         */
        get privateDnsName(): string;
        private _service?;
        /**
         * @stability stable
         */
        get service(): string | undefined;
        /**
         * @stability stable
         */
        set service(value: string | undefined);
        /**
         * @stability stable
         */
        resetService(): void;
        /**
         * @stability stable
         */
        get serviceInput(): string | undefined;
        /**
         * @stability stable
         */
        get serviceId(): string;
        private _serviceName?;
        /**
         * @stability stable
         */
        get serviceName(): string | undefined;
        /**
         * @stability stable
         */
        set serviceName(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceName(): void;
        /**
         * @stability stable
         */
        get serviceNameInput(): string | undefined;
        private _serviceType?;
        /**
         * @stability stable
         */
        get serviceType(): string | undefined;
        /**
         * @stability stable
         */
        set serviceType(value: string | undefined);
        /**
         * @stability stable
         */
        resetServiceType(): void;
        /**
         * @stability stable
         */
        get serviceTypeInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        /**
         * @stability stable
         */
        get vpcEndpointPolicySupported(): any;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpcEndpointServiceFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpcEndpointServiceFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpcEndpointServiceFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcPeeringConnectionConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#cidr_block DataAwsVpcPeeringConnection#cidr_block}.
         *
         * @stability stable
         */
        readonly cidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#owner_id DataAwsVpcPeeringConnection#owner_id}.
         *
         * @stability stable
         */
        readonly ownerId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#peer_cidr_block DataAwsVpcPeeringConnection#peer_cidr_block}.
         *
         * @stability stable
         */
        readonly peerCidrBlock?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#peer_owner_id DataAwsVpcPeeringConnection#peer_owner_id}.
         *
         * @stability stable
         */
        readonly peerOwnerId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#peer_region DataAwsVpcPeeringConnection#peer_region}.
         *
         * @stability stable
         */
        readonly peerRegion?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#peer_vpc_id DataAwsVpcPeeringConnection#peer_vpc_id}.
         *
         * @stability stable
         */
        readonly peerVpcId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#region DataAwsVpcPeeringConnection#region}.
         *
         * @stability stable
         */
        readonly region?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#status DataAwsVpcPeeringConnection#status}.
         *
         * @stability stable
         */
        readonly status?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#tags DataAwsVpcPeeringConnection#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#vpc_id DataAwsVpcPeeringConnection#vpc_id}.
         *
         * @stability stable
         */
        readonly vpcId?: string;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#filter DataAwsVpcPeeringConnection#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpcPeeringConnectionFilter[];
    }
    /**
     * @stability stable
     */
    class DataAwsVpcPeeringConnectionCidrBlockSet extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get cidrBlock(): string;
    }
    /**
     * @stability stable
     */
    class DataAwsVpcPeeringConnectionPeerCidrBlockSet extends cdktf.ComplexComputedList {
        /**
         * @stability stable
         */
        get cidrBlock(): string;
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcPeeringConnectionFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#name DataAwsVpcPeeringConnection#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html#values DataAwsVpcPeeringConnection#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html aws_vpc_peering_connection}.
     *
     * @stability stable
     */
    class DataAwsVpcPeeringConnection extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connection.html aws_vpc_peering_connection} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpcPeeringConnectionConfig);
        /**
         * @stability stable
         */
        accepter(key: string): boolean;
        private _cidrBlock?;
        /**
         * @stability stable
         */
        get cidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set cidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetCidrBlock(): void;
        /**
         * @stability stable
         */
        get cidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        cidrBlockSet(index: string): DataAwsVpcPeeringConnectionCidrBlockSet;
        /**
         * @stability stable
         */
        get id(): string;
        private _ownerId?;
        /**
         * @stability stable
         */
        get ownerId(): string | undefined;
        /**
         * @stability stable
         */
        set ownerId(value: string | undefined);
        /**
         * @stability stable
         */
        resetOwnerId(): void;
        /**
         * @stability stable
         */
        get ownerIdInput(): string | undefined;
        private _peerCidrBlock?;
        /**
         * @stability stable
         */
        get peerCidrBlock(): string | undefined;
        /**
         * @stability stable
         */
        set peerCidrBlock(value: string | undefined);
        /**
         * @stability stable
         */
        resetPeerCidrBlock(): void;
        /**
         * @stability stable
         */
        get peerCidrBlockInput(): string | undefined;
        /**
         * @stability stable
         */
        peerCidrBlockSet(index: string): DataAwsVpcPeeringConnectionPeerCidrBlockSet;
        private _peerOwnerId?;
        /**
         * @stability stable
         */
        get peerOwnerId(): string | undefined;
        /**
         * @stability stable
         */
        set peerOwnerId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPeerOwnerId(): void;
        /**
         * @stability stable
         */
        get peerOwnerIdInput(): string | undefined;
        private _peerRegion?;
        /**
         * @stability stable
         */
        get peerRegion(): string | undefined;
        /**
         * @stability stable
         */
        set peerRegion(value: string | undefined);
        /**
         * @stability stable
         */
        resetPeerRegion(): void;
        /**
         * @stability stable
         */
        get peerRegionInput(): string | undefined;
        private _peerVpcId?;
        /**
         * @stability stable
         */
        get peerVpcId(): string | undefined;
        /**
         * @stability stable
         */
        set peerVpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetPeerVpcId(): void;
        /**
         * @stability stable
         */
        get peerVpcIdInput(): string | undefined;
        private _region?;
        /**
         * @stability stable
         */
        get region(): string | undefined;
        /**
         * @stability stable
         */
        set region(value: string | undefined);
        /**
         * @stability stable
         */
        resetRegion(): void;
        /**
         * @stability stable
         */
        get regionInput(): string | undefined;
        /**
         * @stability stable
         */
        requester(key: string): boolean;
        private _status?;
        /**
         * @stability stable
         */
        get status(): string | undefined;
        /**
         * @stability stable
         */
        set status(value: string | undefined);
        /**
         * @stability stable
         */
        resetStatus(): void;
        /**
         * @stability stable
         */
        get statusInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _vpcId?;
        /**
         * @stability stable
         */
        get vpcId(): string | undefined;
        /**
         * @stability stable
         */
        set vpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetVpcId(): void;
        /**
         * @stability stable
         */
        get vpcIdInput(): string | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpcPeeringConnectionFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpcPeeringConnectionFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpcPeeringConnectionFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcPeeringConnectionsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connections.html#tags DataAwsVpcPeeringConnections#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connections.html#filter DataAwsVpcPeeringConnections#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpcPeeringConnectionsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcPeeringConnectionsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connections.html#name DataAwsVpcPeeringConnections#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connections.html#values DataAwsVpcPeeringConnections#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connections.html aws_vpc_peering_connections}.
     *
     * @stability stable
     */
    class DataAwsVpcPeeringConnections extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpc_peering_connections.html aws_vpc_peering_connections} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpcPeeringConnectionsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpcPeeringConnectionsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpcPeeringConnectionsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpcPeeringConnectionsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcsConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpcs.html#tags DataAwsVpcs#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpcs.html#filter DataAwsVpcs#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpcsFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsVpcsFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpcs.html#name DataAwsVpcs#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpcs.html#values DataAwsVpcs#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpcs.html aws_vpcs}.
     *
     * @stability stable
     */
    class DataAwsVpcs extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpcs.html aws_vpcs} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpcsConfig);
        /**
         * @stability stable
         */
        get id(): string;
        /**
         * @stability stable
         */
        get ids(): string[];
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpcsFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpcsFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpcsFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
    /**
     * @stability stable
     */
    interface DataAwsVpnGatewayConfig extends cdktf.TerraformMetaArguments {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#amazon_side_asn DataAwsVpnGateway#amazon_side_asn}.
         *
         * @stability stable
         */
        readonly amazonSideAsn?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#attached_vpc_id DataAwsVpnGateway#attached_vpc_id}.
         *
         * @stability stable
         */
        readonly attachedVpcId?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#availability_zone DataAwsVpnGateway#availability_zone}.
         *
         * @stability stable
         */
        readonly availabilityZone?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#state DataAwsVpnGateway#state}.
         *
         * @stability stable
         */
        readonly state?: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#tags DataAwsVpnGateway#tags}.
         *
         * @stability stable
         */
        readonly tags?: {
            [key: string]: string;
        } | cdktf.IResolvable;
        /**
         * filter block.
         *
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#filter DataAwsVpnGateway#filter}
         *
         * @stability stable
         */
        readonly filter?: DataAwsVpnGatewayFilter[];
    }
    /**
     * @stability stable
     */
    interface DataAwsVpnGatewayFilter {
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#name DataAwsVpnGateway#name}.
         *
         * @stability stable
         */
        readonly name: string;
        /**
         * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html#values DataAwsVpnGateway#values}.
         *
         * @stability stable
         */
        readonly values: string[];
    }
    /**
     * Represents a {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html aws_vpn_gateway}.
     *
     * @stability stable
     */
    class DataAwsVpnGateway extends cdktf.TerraformDataSource {
        /**
         * @stability stable
         */
        static readonly tfResourceType: string;
        /**
         * Create a new {@link https://www.terraform.io/docs/providers/aws/d/vpn_gateway.html aws_vpn_gateway} Data Source.
         *
         * @param scope The scope in which to define this construct.
         * @param id The scoped construct ID.
         * @stability stable
         */
        constructor(scope: Construct, id: string, config?: DataAwsVpnGatewayConfig);
        private _amazonSideAsn?;
        /**
         * @stability stable
         */
        get amazonSideAsn(): string | undefined;
        /**
         * @stability stable
         */
        set amazonSideAsn(value: string | undefined);
        /**
         * @stability stable
         */
        resetAmazonSideAsn(): void;
        /**
         * @stability stable
         */
        get amazonSideAsnInput(): string | undefined;
        /**
         * @stability stable
         */
        get arn(): string;
        private _attachedVpcId?;
        /**
         * @stability stable
         */
        get attachedVpcId(): string | undefined;
        /**
         * @stability stable
         */
        set attachedVpcId(value: string | undefined);
        /**
         * @stability stable
         */
        resetAttachedVpcId(): void;
        /**
         * @stability stable
         */
        get attachedVpcIdInput(): string | undefined;
        private _availabilityZone?;
        /**
         * @stability stable
         */
        get availabilityZone(): string | undefined;
        /**
         * @stability stable
         */
        set availabilityZone(value: string | undefined);
        /**
         * @stability stable
         */
        resetAvailabilityZone(): void;
        /**
         * @stability stable
         */
        get availabilityZoneInput(): string | undefined;
        /**
         * @stability stable
         */
        get id(): string;
        private _state?;
        /**
         * @stability stable
         */
        get state(): string | undefined;
        /**
         * @stability stable
         */
        set state(value: string | undefined);
        /**
         * @stability stable
         */
        resetState(): void;
        /**
         * @stability stable
         */
        get stateInput(): string | undefined;
        private _tags?;
        /**
         * @stability stable
         */
        get tags(): {
            [key: string]: string;
        } | cdktf.IResolvable | undefined;
        /**
         * @stability stable
         */
        set tags(value: {
            [key: string]: string;
        } | cdktf.IResolvable | undefined);
        /**
         * @stability stable
         */
        resetTags(): void;
        /**
         * @stability stable
         */
        get tagsInput(): cdktf.IResolvable | {
            [key: string]: string;
        } | undefined;
        private _filter?;
        /**
         * @stability stable
         */
        get filter(): DataAwsVpnGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        set filter(value: DataAwsVpnGatewayFilter[] | undefined);
        /**
         * @stability stable
         */
        resetFilter(): void;
        /**
         * @stability stable
         */
        get filterInput(): DataAwsVpnGatewayFilter[] | undefined;
        /**
         * @stability stable
         */
        protected synthesizeAttributes(): {
            [name: string]: any;
        };
    }
}
